(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   1949665,      46559]*)
(*NotebookOutlinePosition[   1991007,      47532]*)
(*  CellTagsIndexPosition[   1984979,      47391]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["4.4.2 Second-Order Ordinary Differential Equations", "Section",
  CounterAssignments->{{"Title", 4}, {"SubTitle", 0}, {"SubSubTitle", 0}, {
      "Section", 0}, {"SubSection", 0}, {"SubSubSection", 0}, {
      "NumberedEquation", 56}, {"NumberedFigure", 0}, {"NumberedTable", 0}},
  CounterBoxOptions->{CounterFunction:>CapitalRomanNumeral},
  CellTags->"Second order ordinary differential equations"],

Cell[TextData[{
  "Second-order ordinary differential equations are very important for \
applications in physics and engineering. All equations based on Newton\
\[CloseCurlyQuote]s second law are second-order equations. Thus, mechanics, \
for example, is mainly based on second-order ordinary differential equations. \
The integration theory of second-order ODEs was developed by Lie during the \
years ",
  ButtonBox["1871",
    ButtonData:>{"Literat.nb", "Lie-1874"},
    ButtonStyle->"Hyperlink"],
  ButtonBox["\[Dash]",
    ButtonData:>{"Literat.nb", "Lie-1874"},
    ButtonStyle->"Hyperlink"],
  ButtonBox["1874",
    ButtonData:>{"Literat.nb", "Lie-1874"},
    ButtonStyle->"Hyperlink"],
  ". In 1891, Lie\[CloseCurlyQuote]s theory of integration was published by \
",
  ButtonBox["Scheffers and Lie [1891]",
    ButtonData:>{"Literat.nb", "Sche-1891"},
    ButtonStyle->"Hyperlink"],
  " in ",
  StyleBox["Vorlesungen \[UDoubleDot]ber Differentialgleichungen mit \
bekannten infinitesimalen Transformationen",
    FontSlant->"Italic"],
  ". Scheffers, a student of Lie, assembled all of Lie\[CloseCurlyQuote]s \
work on ordinary differential equations in a beginner\[CloseCurlyQuote]s \
book. In another series of books compiled by ",
  ButtonBox["Lie and Engel [1888],",
    ButtonData:>{"Literat.nb", "Lie-88"},
    ButtonStyle->"Hyperlink"],
  " Lie describes the problem of integrating a differential equation as \
follows: "
}], "Text",
  CellTags->{
  "second-order ordinary differential equations", "engineering", "physics", 
    "Newton's second law", "mechanics"}],

Cell[TextData[
"\[OpenCurlyDoubleQuote]I observed that a large number of ordinary \
differential equations integrated by older integration methods are invariant \
under easily derivable classes of transformations. The older integration \
methods are all based on the transformation properties of the equation. In \
other words, I realized that the term differential invariant of a finite \
continuous group is contained implicitly in every textbook on ordinary \
differential equations. Discovering the connection between transformation \
groups and older integration strategies I started to develop a general \
integration theory based on the finite or infinitesimal transformation of the \
equation. In my investigations it was clear from the beginning that the \
related transformations always created a group for each case.\
\[CloseCurlyDoubleQuote]"], "Text",
  CellTags->{
  "transformation groups", "integration strategies", 
    "general integration theory", "infinitesimal transformation", "group"}],

Cell[TextData[
"We will exemplify Lie\[CloseCurlyQuote]s line of thought below. The most \
general form of a second-order ODE is given by"], "Text",
  CellTags->"second-order ODE"],

Cell[BoxData[
    \(TraditionalForm\`\(F(x, u, u', \(u'\)')\  = \ 0, \)\)], 
  "NumberedEquation"],

Cell[TextData[{
  "where primes denote differentiation with respect to ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ". For our purposes, we assume that equation (4.57) is solvable with \
respect to the second-order derivative. Thus, we consider equations in the \
form"
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`\(\(u'\)'\  = \ \[Omega](x, u, u'), \)\)], 
  "NumberedEquation"],

Cell[TextData[{
  "where \[Omega] is a given function of ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`u\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`u'\)]],
  "."
}], "Text"],

Cell["\<\
For the general equation (4.58) or (4.57), there exist several \
procedures to derive the solution. Common to each method is the symmetry of \
the equation. In contrast to first-order equations, the determination of \
symmetries is not difficult. However, the problem here is to apply the \
appropriate solution procedure to a specific equation. In the following, we \
discuss three methods which allow us to identify the solution of a \
second-order ODE.\
\>", "Text",
  CellTags->{"solution of a second-order ODE", "symmetry of an equation"}],

Cell[CellGroupData[{

Cell["4.4.2.1 Integration by Group Classification", "Subsection",
  CellTags->"Algorithm of Integration"],

Cell[TextData[{
  "Following the reasoning of ",
  ButtonBox["Lie,",
    ButtonData:>{"Literat.nb", "Enge-12"},
    ButtonStyle->"Hyperlink"],
  " we can solve a second-order ODE if we can classify the group. The idea is \
 the following: If a second-order equation admits a Lie algebra of dimension \
",
  Cell[BoxData[
      \(TraditionalForm\`r \[GreaterEqual] 2\)]],
  ", it can be integrated by a group-theoretic quadrature method. This can be \
 done in various ways, one of which is given by the following algorithm:"
}], "Text",
  CellTags->{
  "second-order ODE", "Lie algebra", "group theoretic quadrature", 
    "quadrature method", "algorithm"}],

Cell[TextData[{
  "Compute the admitted Lie algebra ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(L\_r\),
          "InlineFormula"], TraditionalForm]]],
  ". A basis of  ",
  Cell[BoxData[
      \(TraditionalForm\`L\_r\)]],
  " is the set  ",
  Cell[BoxData[
      \(TraditionalForm\`\(v\& \[RightVector] \)\_1\)], "InlineFormula"],
  ",  ",
  Cell[BoxData[
      \(TraditionalForm\`\(v\& \[RightVector] \)\_2\)], "InlineFormula"],
  ", \[Ellipsis], ",
  Cell[BoxData[
      \(TraditionalForm\`\(v\& \[RightVector] \)\_r\)], "InlineFormula"],
  "."
}], "ListItem",
  CellDingbat->"1.",
  CellTags->{"admitted Lie algebra", "Lie algebra"}],

Cell[TextData[{
  "If ",
  Cell[BoxData[
      \(TraditionalForm\`r = 2\)]],
  ", go to the next step;\nif ",
  Cell[BoxData[
      \(TraditionalForm\`r > 2\)]],
  ", then distinguish any two-dimensional subalgebra ",
  Cell[BoxData[
      \(TraditionalForm\`L\_2\)]],
  " of ",
  Cell[BoxData[
      \(TraditionalForm\`L\_r\)]],
  ".\nIf ",
  Cell[BoxData[
      \(TraditionalForm\`r = 1\)]],
  ", The order of the equation may be lowered;\nif ",
  Cell[BoxData[
      \(TraditionalForm\`r = 0\)]],
  ", the group method is not useful."
}], "ListItem",
  CellDingbat->"2."],

Cell[TextData[{
  "Determine the type of the algebra ",
  Cell[BoxData[
      \(TraditionalForm\`L\_2\)]],
  " obtained by the following table:"
}], "ListItem",
  CellDingbat->"3."],

Cell[TextData[Cell[BoxData[GridBox[{
        {"I", 
          RowBox[{
            RowBox[{"[", 
              RowBox[{
                SubscriptBox[
                  StyleBox[
                    OverscriptBox["v", 
                      AdjustmentBox["\[RightVector]",
                        BoxMargins->{{0, 0}, {0.375, -0.375}},
                        BoxBaselineShift->-0.375]],
                    FontSlant->"Italic"], "1"], ",", 
                SubscriptBox[
                  OverscriptBox["v", 
                    AdjustmentBox["\[RightVector]",
                      BoxMargins->{{0, 0}, {0.375, -0.375}},
                      BoxBaselineShift->-0.375]], "2"]}], "]"}], "=", "0"}], 
          RowBox[{
            RowBox[{
              SubscriptBox[
                StyleBox[
                  OverscriptBox["v", 
                    AdjustmentBox["\[RightVector]",
                      BoxMargins->{{0, 0}, {0.375, -0.375}},
                      BoxBaselineShift->-0.375]],
                  FontSlant->"Italic"], "1"], "\[CircleTimes]", 
              SubscriptBox[
                StyleBox[
                  OverscriptBox["v", 
                    AdjustmentBox["\[RightVector]",
                      BoxMargins->{{0, 0}, {0.375, -0.375}},
                      BoxBaselineShift->-0.375]],
                  FontSlant->"Italic"], "2"]}], "\[NotEqual]", "0"}], 
          RowBox[{
            RowBox[{
              SubscriptBox[
                StyleBox[
                  OverscriptBox["v", 
                    AdjustmentBox["\[RightVector]",
                      BoxMargins->{{0, 0}, {0.375, -0.375}},
                      BoxBaselineShift->-0.375]],
                  FontSlant->"Italic"], "1"], "=", \(\[PartialD]\_x\)}], ",", 
            " ", 
            RowBox[{
              SubscriptBox[
                StyleBox[
                  OverscriptBox["v", 
                    AdjustmentBox["\[RightVector]",
                      BoxMargins->{{0, 0}, {0.375, -0.375}},
                      BoxBaselineShift->-0.375]],
                  FontSlant->"Italic"], "2"], "=", \(\[PartialD]\_u\)}]}], 
          \(\(u\^\*"\""\) = f \((u')\)\)},
        {"II", 
          RowBox[{
            RowBox[{"[", 
              RowBox[{
                SubscriptBox[
                  OverscriptBox["v", 
                    AdjustmentBox["\[RightVector]",
                      BoxMargins->{{0, 0}, {0.26087, -0.26087}},
                      BoxBaselineShift->-0.26087]], "1"], ",", 
                \(v\&\[RightVector]\_2\)}], "]"}], "=", "0"}], 
          RowBox[{
            RowBox[{
              SubscriptBox[
                StyleBox[
                  OverscriptBox["v", 
                    AdjustmentBox["\[RightVector]",
                      BoxMargins->{{0, 0}, {0.375, -0.375}},
                      BoxBaselineShift->-0.375]],
                  FontSlant->"Italic"], "1"], "\[CircleTimes]", 
              SubscriptBox[
                StyleBox[
                  OverscriptBox["v", 
                    AdjustmentBox["\[RightVector]",
                      BoxMargins->{{0, 0}, {0.375, -0.375}},
                      BoxBaselineShift->-0.375]],
                  FontSlant->"Italic"], "2"]}], "=", "0"}], 
          RowBox[{
            RowBox[{
              SubscriptBox[
                StyleBox[
                  OverscriptBox["v", 
                    AdjustmentBox["\[RightVector]",
                      BoxMargins->{{0, 0}, {0.375, -0.375}},
                      BoxBaselineShift->-0.375]],
                  FontSlant->"Italic"], "1"], "=", \(\[PartialD]\_u\)}], ",", 
            " ", 
            RowBox[{
              SubscriptBox[
                StyleBox[
                  OverscriptBox["v", 
                    AdjustmentBox["\[RightVector]",
                      BoxMargins->{{0, 0}, {0.375, -0.375}},
                      BoxBaselineShift->-0.375]],
                  FontSlant->"Italic"], "2"], "=", \(\[PartialD]\_x\)}]}], 
          \(\(u\^\*"\""\) = f \((x)\)\)},
        {"III", 
          RowBox[{
            RowBox[{"[", 
              RowBox[{
                SubscriptBox[
                  OverscriptBox["v", 
                    AdjustmentBox["\[RightVector]",
                      BoxMargins->{{0, 0}, {0.26087, -0.26087}},
                      BoxBaselineShift->-0.26087]], "1"], ",", 
                \(v\&\[RightVector]\_2\)}], "]"}], "=", 
            \(v\&\[RightVector]\_1\)}], 
          RowBox[{
            RowBox[{
              SubscriptBox[
                StyleBox[
                  OverscriptBox["v", 
                    AdjustmentBox["\[RightVector]",
                      BoxMargins->{{0, 0}, {0.375, -0.375}},
                      BoxBaselineShift->-0.375]],
                  FontSlant->"Italic"], "1"], "\[CircleTimes]", 
              SubscriptBox[
                StyleBox[
                  OverscriptBox["v", 
                    AdjustmentBox["\[RightVector]",
                      BoxMargins->{{0, 0}, {0.375, -0.375}},
                      BoxBaselineShift->-0.375]],
                  FontSlant->"Italic"], "2"]}], "\[NotEqual]", "0"}], 
          RowBox[{
            RowBox[{
              RowBox[{
                SubscriptBox[
                  StyleBox[
                    OverscriptBox["v", 
                      AdjustmentBox["\[RightVector]",
                        BoxMargins->{{0, 0}, {0.375, -0.375}},
                        BoxBaselineShift->-0.375]],
                    FontSlant->"Italic"], "1"], "=", \(\[PartialD]\_u\)}], 
              ",", " ", 
              RowBox[{
                SubscriptBox[
                  StyleBox[
                    OverscriptBox["v", 
                      AdjustmentBox["\[RightVector]",
                        BoxMargins->{{0, 0}, {0.375, -0.375}},
                        BoxBaselineShift->-0.375]],
                    FontSlant->"Italic"], "2"], "=", 
                \(x \[PartialD]\_x\(+u\)\ \[PartialD]\_u\)}]}], " "}], 
          \(\(u\^\*"\""\) = f \((u')\)/x\)},
        {\(\ IV\), 
          RowBox[{
            RowBox[{"[", 
              RowBox[{
                SubscriptBox[
                  StyleBox[
                    OverscriptBox["v", 
                      AdjustmentBox["\[RightVector]",
                        BoxMargins->{{0, 0}, {0.375, -0.375}},
                        BoxBaselineShift->-0.375]],
                    FontSlant->"Italic"], "1"], ",", 
                \(v\&\[RightVector]\_2\)}], "]"}], "=", 
            \(v\&\[RightVector]\_1\)}], 
          RowBox[{
            RowBox[{
              SubscriptBox[
                StyleBox[
                  OverscriptBox["v", 
                    AdjustmentBox["\[RightVector]",
                      BoxMargins->{{0, 0}, {0.375, -0.375}},
                      BoxBaselineShift->-0.375]],
                  FontSlant->"Italic"], "1"], "\[CircleTimes]", 
              SubscriptBox[
                StyleBox[
                  OverscriptBox["v", 
                    AdjustmentBox["\[RightVector]",
                      BoxMargins->{{0, 0}, {0.375, -0.375}},
                      BoxBaselineShift->-0.375]],
                  FontSlant->"Italic"], "2"]}], "=", "0"}], 
          RowBox[{
            RowBox[{
              SubscriptBox[
                StyleBox[
                  OverscriptBox["v", 
                    AdjustmentBox["\[RightVector]",
                      BoxMargins->{{0, 0}, {0.375, -0.375}},
                      BoxBaselineShift->-0.375]],
                  FontSlant->"Italic"], "1"], "=", \(\[PartialD]\_u\)}], ",", 
            " ", 
            RowBox[{
              SubscriptBox[
                StyleBox[
                  OverscriptBox["v", 
                    AdjustmentBox["\[RightVector]",
                      BoxMargins->{{0, 0}, {0.375, -0.375}},
                      BoxBaselineShift->-0.375]],
                  FontSlant->"Italic"], "2"], "=", \(u \[PartialD]\_u\)}]}], 
          \(\(u\^\*"\""\) = f \((x)\) u'\)}
        },
      ColumnAlignments->{Center, Left},
      RowLines->True,
      ColumnLines->True]],
  FontSize->8]], "NumberedEquation",
  CellMargins->{{64, Inherited}, {-4, 6}},
  TextAlignment->Left,
  TextJustification->0,
  CellTags->"classification of second order algebras"],

Cell[TextData[{
  "Cases I to IV of the table are identified by computing the commutator [",
  Cell[BoxData[
      \(TraditionalForm\`v\&\[RightVector]\_1\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`v\&\[RightVector]\_2\)]],
  "] of ",
  Cell[BoxData[
      \(TraditionalForm\`v\&\[RightVector]\_1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`v\&\[RightVector]\_2\)]],
  ", and their pseudo-scalar product  ",
  Cell[BoxData[
      \(v\&\[RightVector]\_1\[CircleTimes]v\&\[RightVector]\_2\)]],
  "= ",
  Cell[BoxData[
      \(TraditionalForm\`\[Xi]\_1\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_2\)]],
  " \[Dash] ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_1\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[Xi]\_2\)]],
  ". The subscripts of the infinitesimals ",
  Cell[BoxData[
      \(TraditionalForm\`\[Xi]\_i\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_i\)]],
  " denote the number of the vector field ",
  Cell[BoxData[
      \(TraditionalForm\`v\&\[RightVector]\_i\)]],
  ". If [",
  Cell[BoxData[
      \(TraditionalForm\`v\&\[RightVector]\_1\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`v\&\[RightVector]\_2\)]],
  "] is neither 0 nor ",
  Cell[BoxData[
      \(TraditionalForm\`v\&\[RightVector]\_1\)]],
  ", then choose a new basis ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox[
          OverscriptBox[
            StyleBox["v",
              FontSlant->"Italic"], "\[RightVector]"], "1", "\[Prime]"], 
        TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox[
          OverscriptBox[
            StyleBox["v",
              FontSlant->"Italic"], "\[RightVector]"], "2", "\[Prime]"], 
        TraditionalForm]]],
  ", such that ",
  Cell[BoxData[
      StyleBox[
        \(\([v\&\[RightVector]\_1\%\[Prime], v\&\[RightVector]\_2\%\[Prime]]
            \) = \(v\&\[RightVector]\_1\%'\)\),
        "InlineFormula",
        FontFamily->"Times"]]],
  "."
}], "ListItem",
  CellMargins->{{Inherited, Inherited}, {Inherited, 12}},
  CellTags->{"commutator", "pseudo scalar product", "infinitesimals"}],

Cell[TextData[{
  "Bring the basis of ",
  Cell[BoxData[
      \(TraditionalForm\`L\_2\)]],
  " into agreement with cases I\[Dash]IV by going over to canonical variables \
",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`w\)]],
  ". Rewrite the equation in canonical variables and integrate it."
}], "ListItem",
  CellDingbat->"4.",
  CellTags->"canonical variables"],

Cell["Rewrite the solution in terms of the original variables.", "ListItem",
  CellDingbat->"5."],

Cell[TextData[{
  "The stated algorithm is based on the fact that in the complex case, any \
Lie algebra of dimensionality ",
  Cell[BoxData[
      \(TraditionalForm\`r > 2\)]],
  " has a distinguished two-dimensional subalgebra. However, the structure of \
a two-dimensional Lie algebra with bases ",
  Cell[BoxData[
      \(TraditionalForm\`v\&\[RightVector]\_1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`v\&\[RightVector]\_2\)]],
  " can be described in terms of the commutator ",
  Cell[BoxData[
      StyleBox[
        \(\([v\&\[RightVector]\_1, v\&\[RightVector]\_2]\) = 
          \(v\&\[RightVector]\_1\) v\&\[RightVector]\_2 - 
            \(v\&\[RightVector]\_2\) v\&\[RightVector]\_1\),
        "InlineFormula",
        FontFamily->"Times"]]],
  " and the pseudo-scalar product ",
  Cell[BoxData[
      \(v\&\[RightVector]\_1\[CircleTimes]v\&\[RightVector]\_2\)], 
    "InlineFormula",
    FontFamily->"Times"],
  StyleBox["= ", "InlineFormula"],
  Cell[BoxData[
      \(TraditionalForm\`\[Xi]\_1\)], "InlineFormula"],
  StyleBox[" ", "InlineFormula"],
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_2\)], "InlineFormula"],
  StyleBox[" \[Dash] ", "InlineFormula"],
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_1\)], "InlineFormula"],
  StyleBox[" ", "InlineFormula"],
  Cell[BoxData[
      FormBox[
        StyleBox[\(\[Xi]\_2\),
          "InlineFormula"], TraditionalForm]]],
  ". For more details compare the work by ",
  ButtonBox["Scheffers and Lie [1891]",
    ButtonData:>{"Literat.nb", "Sche-1891"},
    ButtonStyle->"Hyperlink"],
  ", ",
  ButtonBox["Olver [1986]",
    ButtonData:>{"Literat.nb", "Olve-86"},
    ButtonStyle->"Hyperlink"],
  ", and ",
  ButtonBox["Bluman and Kumei [1989]",
    ButtonData:>{"Literat.nb", "Blum-89"},
    ButtonStyle->"Hyperlink"],
  ". Let us demonstrate these five steps by two examples."
}], "Text",
  CellTags->{
  "subalgebra", "Lie algebra", "commutator", "pseudo scalar product"}],

Cell["Example 1", "Example",
  CellTags->"Example: 1"],

Cell[TextData[{
  "The first example considers a second-order ODE. This equation was \
discussed by ",
  ButtonBox["Ibragimov [1994]",
    ButtonData:>{"Literat.nb", "Ibragimov-1994"},
    ButtonStyle->"Hyperlink"],
  " in connection with Lie\[CloseCurlyQuote]s group classification. We use \
the same example here to demonstrate how symbolic calculations with a \
computer can clarify the solution steps. The equation reads"
}], "Text",
  CellTags->{"second-order ODE", "Lie\.b4s group classification"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(equation = {
        \[PartialD]\_{x, 2}u[x] - \[PartialD]\_x u[x]\/u[x]\^2 + 
          1\/\(u[x]\ x\)}; equation // LTF\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {
            RowBox[{
              RowBox[{
                StyleBox[\(1\/\(u\ x\)\),
                  ScriptLevel->0], "-", 
                StyleBox[\(u\_x\/u\^2\),
                  ScriptLevel->0], "+", \(u\_\(x, x\)\)}], "==", "0"}]}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output"]
}, Open  ]],

Cell[TextData[{
  "The first step of the algorithm consists in finding the Lie algebra of the \
equation. This step is practically revealed by using the package ",
  StyleBox["MathLie.",
    FontSlant->"Italic"],
  " ",
  StyleBox["MathLie",
    FontSlant->"Italic"],
  " contains a function designed to determine the infinitesimal \
transformations. The name of the function is ",
  StyleBox["Infinitesimals[]", "MmaText"],
  " and has a symbolic template of the form",
  StyleBox[" ", "MmaText"],
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubsuperscriptBox[
            TagBox["\[ScriptCapitalP]\[ScriptCapitalS]",
              NotationBoxTag,
              Editable->True], \(u, x\), "\[Gamma]"], "[", "\[CapitalDelta]", 
          "]"}], TraditionalForm]], "MmaText"],
  ". This operator takes the independent and dependent variables as \
subscripts and the parameters as superscripts. The equation is given as a \
fourth argument. The equation above is free of any parameters. The \
determination of the infinitesimals is carried out by"
}], "Text",
  CellTags->{
  "Lie algebra", "Infinitesimals[]", "symbolic template", 
    "calculation of the infinitesimals"}],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"infi", " ", "=", " ", 
        RowBox[{
          SubsuperscriptBox[
            StyleBox[
              TagBox[
                StyleBox["\[ScriptCapitalP]\[ScriptCapitalS]",
                  FontSize->10],
                NotationBoxTag,
                Editable->True],
              FontSize->18], \({u}, {x}\), \({}\)], "[", "equation", "]"}]}], 
      ";", \(infi // LTF\)}]], "Input"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\(\[Phi]\_1 == 1\/2\ u\ \((k1 + 2\ k2\ x)\)\)},
          {\(\[Xi]\_1 == x\ \((k1 + k2\ x)\)\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {
        Equal[ 
          Subscript[ \[Phi], 1], 
          Times[ 
            Rational[ 1, 2], u, 
            Plus[ k1, 
              Times[ 2, k2, x]]]], 
        Equal[ 
          Subscript[ \[Xi], 1], 
          Times[ x, 
            Plus[ k1, 
              Times[ k2, x]]]]}]]], "Output"]
}, Open  ]],

Cell[TextData[{
  "The result is a representation of the infinitesimals for the independent \
and dependent variables. ",
  StyleBox["xi",
    FontSlant->"Italic"],
  "[",
  StyleBox["1",
    FontSlant->"Italic"],
  "] corresponds to the independent variable ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " and ",
  StyleBox["phi",
    FontSlant->"Italic"],
  "[",
  StyleBox["1",
    FontSlant->"Italic"],
  "] to the dependent variable ",
  StyleBox["u.",
    FontSlant->"Italic"],
  " It turns out that our equation admits a two-dimensional Lie group. The \
two parameters ",
  Cell[BoxData[
      \(TraditionalForm\`k1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`k2\)]],
  " are the group parameters. As discussed in ",
  ButtonBox["Chapter 2",
    ButtonData:>{"Algebra.nb", "Lie algebras"},
    ButtonStyle->"Hyperlink"],
  ", to each symmetry group there exists a related Lie algebra. We can \
inspect the structure of this algebra again by applying ",
  StyleBox["MathLie",
    FontSlant->"Italic"],
  ". The package provides tools to calculate the commutator table and the \
structure constants. The commutator table is created by"
}], "Text",
  CellTags->{
  "Lie group", "symmetry group", "Lie algebra", "commutator table", 
    "calculate the commutator table", "structure constants"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(LieCommutatorTable[infi, {u}, {x}] // TableForm\)], "Input",
  CellTags->"LieCommutatorTable[]"],

Cell[BoxData[
    TagBox[GridBox[{
          {"0", \(-V[2]\)},
          {\(V[2]\), "0"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output"]
}, Open  ]],

Cell[TextData[{
  "The result of this calculation shows that the corresponding algebra ",
  Cell[BoxData[
      \(TraditionalForm\`L\_2\)]],
  " belongs to type III of ",
  ButtonBox[" Lie's classification",
    ButtonData:>"classification of second order algebras",
    ButtonStyle->"Hyperlink"],
  ". This becomes obvious if we interchange the vector fields ",
  Cell[BoxData[
      \(TraditionalForm\`v\&\[RightVector]\_i\)]],
  " and calculate the pseudo-scalar product of the infinitesimals "
}], "Text",
  CellTags->{
  "algebra", "Lie's classification", "pseudo scalar product", 
    "infinitesimals"}],

Cell[BoxData[
    FormBox[
      RowBox[{
      \(v\&\[RightVector]\_1\[CircleTimes]v\&\[RightVector]\_2\), "=", " ", 
        RowBox[{
          RowBox[{
            FormBox[\(\[Xi]\_1\),
              "TraditionalForm"], " ", 
            FormBox[\(\[Phi]\_2\),
              "TraditionalForm"]}], " ", "-", " ", 
          RowBox[{
            FormBox[\(\[Phi]\_1\),
              "TraditionalForm"], " ", 
            FormBox[\(\[Xi]\_2\  = \ \(u\ x\^2\)\/2 \[NotEqual] \(0 . \)\),
              "TraditionalForm"]}]}]}], TraditionalForm]], "DisplayFormula",
  TextAlignment->Center],

Cell[TextData[{
  "The calculation of the pseudo-scalar product in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " needs the lines"
}], "Text",
  CellTags->"pseudo scalar product"],

Cell[BoxData[
    \(\(infi1\  = 
      \({\(xi[1]\)[x, u], \(phi[1]\)[x, u]} /. \ infi\)\  /. {k1 \[Rule] 1, 
          k2 \[Rule] 0}; \)\)], "Input"],

Cell[BoxData[
    \(\(infi2\  = 
      \({\(xi[1]\)[x, u], \(phi[1]\)[x, u]} /. \ infi\)\  /. {k1 \[Rule] 0, 
          k2 \[Rule] 1}; \)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(pseudoScalarProduct\  = \ 
      infi1\[LeftDoubleBracket]1\[RightDoubleBracket]\ 
          infi2\[LeftDoubleBracket]2\[RightDoubleBracket] - 
        infi1\[LeftDoubleBracket]2\[RightDoubleBracket]\ 
          infi2\[LeftDoubleBracket]1\[RightDoubleBracket]\)], "Input"],

Cell[BoxData[
    \(\(u\ x\^2\)\/2\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "In step 4 of the integration algorithm, we introduce ",
  ButtonBox["canonical variables ",
    ButtonData:>{"symmet11.nb", "Canonical variables"},
    ButtonStyle->"Hyperlink"],
  "which have to satisfy the conditions ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox[\(v\&\[RightVector]\_1\),
              "TraditionalForm"], "(", "t", ")"}], "=", "0"}], 
        TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox[\(v\&\[RightVector]\_1\),
              "TraditionalForm"], "(", "u", ")"}], "=", "1"}], 
        TraditionalForm]]],
  ". Solving the related characteristic equations by conducting the function \
",
  StyleBox["CanonicalVariables[]", "MmaText"],
  ", we end up with transformations probably simplifying the original \
equation. In the following ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " line, the first two arguments, ",
  Cell[BoxData[
      \(TraditionalForm\`{u}\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`{x}\)]],
  ", denote the dependent and independent variables, and the next two, ",
  Cell[BoxData[
      \(TraditionalForm\`{x}\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`{u\/2}\)]],
  ", are the infinitesimals for ",
  Cell[BoxData[
      \(TraditionalForm\`k1 = 1\)]],
  " and k2 = 0 of the independent and dependent variables, respectively. The \
last pair ",
  Cell[BoxData[
      \(TraditionalForm\`{w}\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`{t}\)]],
  " are the new dependent and independent canonical variables, respectively:"
}], "Text",
  CellTags->{
  "integration algorithm", "canonical variables", "characteristic equation", 
    "CanonicalVariables[]"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(substitution = CanonicalVariables[{u}, {x}, {x}, {u\/2}, {w}, {t}]; 
    substitution // LTF\)], "Input"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\(t == Log[x]\)},
          {
            RowBox[{"w", "==", 
              StyleBox[\(u\/\@x\),
                ScriptLevel->0]}]}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {
        Equal[ t, 
          Log[ x]], 
        Equal[ w, 
          Times[ u, 
            Power[ x, 
              Rational[ -1, 2]]]]}]]], "Output"]
}, Open  ]],

Cell["\<\
The result belongs to the subgroup with k1 = 1 and k2 = 0. The \
second set of transformations follows by the choice k1 = 0 and k2 = 1:\
\>", 
  "Text",
  CellTags->"transformations"],

Cell[CellGroupData[{

Cell[BoxData[
    \(secondtransformation\  = \ \n
      CanonicalVariables[{u}, {x}, {x\^2}, {x\ u}, {w}, {t}]; 
    secondtransformation // LTF\)], "Input"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {
            RowBox[{"t", "==", 
              RowBox[{"-", 
                StyleBox[\(1\/x\),
                  ScriptLevel->0]}]}]},
          {
            RowBox[{"w", "==", 
              StyleBox[\(u\/x\),
                ScriptLevel->0]}]}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {
        Equal[ t, 
          Times[ -1, 
            Power[ x, -1]]], 
        Equal[ w, 
          Times[ u, 
            Power[ x, -1]]]}]]], "Output"]
}, Open  ]],

Cell[TextData[{
  "The next step in the algorithm is to use these transformations to change \
the representation of the equation. For this kind of calculation, ",
  StyleBox["MathLie",
    FontSlant->"Italic"],
  " offers the function ",
  StyleBox["CanonicalRepresentation[]", "MmaText"],
  ". This function needs the input of the original equation, the canonical \
transformations given by rules, and the target variables. The first set of \
canonical variables descending from the subgroup with k1 = 1 and k2\
\[NonBreakingSpace]\[NoBreak]= 0 leads to the reduced equation"
}], "Text",
  CellTags->{"CanonicalRepresentation[]", "canonical variables"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(canonical1\  = \ 
      CanonicalRepresentation[
        equation\[LeftDoubleBracket]1\[RightDoubleBracket], u, 
        x, {w \[Rule] u\/\@x, t \[Rule] Log[x]}, w, t]; canonical1 // LTF\)], 
  "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {\(2\ w - w\^3 - 4\ w\_t + 4\ w\^2\ w\_\(t, t\) == 0\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output"]
}, Open  ]],

Cell[TextData[{
  "At this stage of the calculation, we can use the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function ",
  StyleBox["DSolve[]", "MmaText"],
  " to solve the second-order equation. We note that the achieved equation is \
as complicated as the original equation and, thus, ",
  StyleBox["DSolve[]", "MmaText"],
  " may fail to find a solution. In fact, we get"
}], "Text",
  CellTags->"DSolve[]"],

Cell[CellGroupData[{

Cell[BoxData[
    \(sol1\  = \ DSolve[canonical1, w, t]\)], "Input"],

Cell[BoxData[
    RowBox[{"DSolve", "[", 
      RowBox[{
        RowBox[{
          RowBox[{\(2\ w[t]\), "-", \(w[t]\^3\), "-", 
            RowBox[{"4", " ", 
              RowBox[{
                SuperscriptBox["w", "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            RowBox[{"4", " ", \(w[t]\^2\), " ", 
              RowBox[{
                SuperscriptBox["w", "\[DoublePrime]",
                  MultilineFunction->None], "[", "t", "]"}]}]}], "==", "0"}], 
        ",", "w", ",", "t"}], "]"}]], "Output"]
}, Open  ]],

Cell["\<\
However, using the second set of canonical variables, we discover \
the reduction\
\>", "Text",
  CellTags->"canonical variables"],

Cell[CellGroupData[{

Cell[BoxData[
    \(canonical2\  = \ 
      CanonicalRepresentation[
        equation\[LeftDoubleBracket]1\[RightDoubleBracket], u, 
        x, {w \[Rule] u\/x, t \[Rule] \(-1\)\/x}, w, t]; 
    canonical2 // LTF\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {
            RowBox[{
              RowBox[{\(t\^3\), " ", 
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(w\_t\/w\^2\),
                      ScriptLevel->0], "-", \(w\_\(t, t\)\)}], ")"}]}], "==", 
              "0"}]}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output"]
}, Open  ]],

Cell[TextData[{
  "which looks much simpler. This simplification is one aim of symmetry \
analysis. Exerting the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function ",
  StyleBox["DSolve[]", "MmaText"],
  " to this equation, we acquire"
}], "Text",
  CellTags->{"simplification of ODEs", "symmetry analysis", "DSolve[]"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(sol2\  = \ DSolve[canonical2, w, t]\)], "Input"],

Cell[BoxData[
    \(InverseFunction::"ifun" \( : \ \) 
      "Warning: Inverse functions are being used. Values may be lost for  \
multivalued inverses."\)], "Message"],

Cell[BoxData[
    \({{w \[Rule] 
          \((\(1 + ProductLog[E\^\(\(-1\) + C[1]\^2\ \((#1 - C[2])\)\)]\)\/C[
                  1]&)\)}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "As expected, the solution of the equation in canonical variables is given \
by a function containing two constants of integration. The ",
  StyleBox["ProductLog[]", "MmaText"],
  StyleBox[" function", "TB"],
  " depicts the solution for ",
  Cell[BoxData[
      \(TraditionalForm\`w\)], "InlineFormula",
    CellTags->"S3.2.10"],
  " in ",
  Cell[BoxData[
      FormBox[
        RowBox[{"z", "=", 
          SuperscriptBox[
            StyleBox["we",
              FontSlant->"Italic"], "w"]}], TraditionalForm]], 
    "InlineFormula",
    CellTags->"S3.2.10"],
  ". The function is a generalization of a logarithm. It can be used to \
represent solutions to a variety of transcendental equations."
}], "Text",
  CellTags->{
  "constants of integration", "ProductLog[]", 
    "generalization of a logarithm", "transcendental equation"}],

Cell[TextData[{
  "The last step of the integration procedure by Lie is the inversion of the \
transformation. This back substitution of the canonical variables is also \
supported by the package ",
  StyleBox["MathLie",
    FontSlant->"Italic"],
  ". The related function is ",
  StyleBox["BackTrafoCanonical[]", "MmaText"],
  ". For the inverse canonical transformation, we need the solution in \
canonical variables, the set of canonical variables themselves, the original \
variables, and the transformation between the two sets of variables. Knowing \
these quantities, we are able to apply the function to the solution:"
}], "Text",
  CellTags->{"inversion of a transformation", "BackTrafoCanonical[]"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(solu\  = 
      BackTrafoCanonical[sol2, w, t, u, 
        x, {u \[Rule] w\ x, t \[Rule] \(-1\)/x}]\)], "Input"],

Cell[BoxData[
    \({u \[Rule] 
        Function[x, 
          \(x\ \((1 + 
                  ProductLog[
                    E\^\(\(-1\) + C[1]\^2\ \((\(-\(1\/x\)\) - C[2])\)\)])
                \)\)\/C[1]]}\)], "Output"]
}, Open  ]],

Cell["\<\
The derived solution satisfies the original equation. We can check \
this by inserting the solution into the equation:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(equation\  /. \ solu // FullSimplify\)], "Input"],

Cell[BoxData[
    \({0}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The result confirms the solution. Since the solution contains a special \
function, we have no clear idea of the graph of this function. We can \
graphically represent the solution by specifying the constants of \
integration. For a set of five constants ",
  StyleBox["C",
    FontSlant->"Italic"],
  "[1] at fixed ",
  StyleBox["C",
    FontSlant->"Italic"],
  "[2], we create a table containing the different solutions:"
}], "Text",
  CellTags->"special function"],

Cell[BoxData[
    \(\(soluC\  = \ 
      Table[\(u[x]\  /. \ solu\)\  /. {C[1] \[Rule] \[Epsilon], 
            C[2] \[Rule] 1}, {\[Epsilon], 1, 5}]; \)\)], "Input"],

Cell[TextData[{
  "A LogLog plot shows that the solutions with fixed ",
  StyleBox["C",
    FontSlant->"Italic"],
  "[2] have a common slope:"
}], "Text"],

Cell[BoxData[
    \(<< Graphics`Graphics`\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(LogLogPlot[Evaluate[soluC], {x, 0.001, 10}, 
      PlotStyle 
        \[Rule] {RGBColor[0, \ 0, \ 0.250004], RGBColor[0.996109, \ 0, \ 0], 
          RGBColor[0, \ 0.500008, \ 0], RGBColor[0.500008, \ 0, \ 0.250004], 
          RGBColor[0.700008, \ 0, \ 0]}, AxesLabel \[Rule] {"\<x\>", "\<u\>"}]
      \ \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.455674 0.520516 0.371077 0.222195 [
[.09185 -0.0125 -11 -15 ]
[.09185 -0.0125 11 0 ]
[.29898 -0.0125 -11 -15 ]
[.29898 -0.0125 11 0 ]
[.45567 -0.0125 -5 -15 ]
[.45567 -0.0125 5 0 ]
[.61237 -0.0125 -5 -15 ]
[.61237 -0.0125 5 0 ]
[.8195 -0.0125 -5 -15 ]
[.8195 -0.0125 5 0 ]
[.97619 -0.0125 -8 -15 ]
[.97619 -0.0125 8 0 ]
[1.025 0 0 -7.5 ]
[1.025 0 10 7.5 ]
[-0.0125 .082 -28 -7.5 ]
[-0.0125 .082 0 7.5 ]
[-0.0125 .14888 -22 -7.5 ]
[-0.0125 .14888 0 7.5 ]
[-0.0125 .30419 -22 -7.5 ]
[-0.0125 .30419 0 7.5 ]
[-0.0125 .37108 -10 -7.5 ]
[-0.0125 .37108 0 7.5 ]
[-0.0125 .52638 -10 -7.5 ]
[-0.0125 .52638 0 7.5 ]
[-0.0125 .59327 -16 -7.5 ]
[-0.0125 .59327 0 7.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 15 ]
[ -0.0005 -0.0005 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.09185 0 m
.09185 .00625 L
s
gsave
.09185 -0.0125 -72 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.2) show
81.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.29898 0 m
.29898 .00625 L
s
gsave
.29898 -0.0125 -72 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.5) show
81.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.45567 0 m
.45567 .00625 L
s
gsave
.45567 -0.0125 -66 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.61237 0 m
.61237 .00625 L
s
gsave
.61237 -0.0125 -66 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.8195 0 m
.8195 .00625 L
s
gsave
.8195 -0.0125 -66 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -69 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
75.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.001 w
.18351 0 m
.18351 .00375 L
s
.24854 0 m
.24854 .00375 L
s
.3402 0 m
.3402 .00375 L
s
.37505 0 m
.37505 .00375 L
s
.40523 0 m
.40523 .00375 L
s
.43186 0 m
.43186 .00375 L
s
.70402 0 m
.70402 .00375 L
s
.76906 0 m
.76906 .00375 L
s
.86071 0 m
.86071 .00375 L
s
.89556 0 m
.89556 .00375 L
s
.92575 0 m
.92575 .00375 L
s
.95237 0 m
.95237 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
0 .082 m
.00625 .082 L
s
gsave
-0.0125 .082 -89 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.05) show
87.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
0 .14888 m
.00625 .14888 L
s
gsave
-0.0125 .14888 -83 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.1) show
81.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
0 .30419 m
.00625 .30419 L
s
gsave
-0.0125 .30419 -83 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.5) show
81.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
0 .37108 m
.00625 .37108 L
s
gsave
-0.0125 .37108 -71 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
0 .52638 m
.00625 .52638 L
s
gsave
-0.0125 .52638 -71 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
0 .59327 m
.00625 .59327 L
s
gsave
-0.0125 .59327 -77 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
75.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.001 w
0 .0327 m
.00375 .0327 L
s
0 .06046 m
.00375 .06046 L
s
0 .09959 m
.00375 .09959 L
s
0 .11446 m
.00375 .11446 L
s
0 .12735 m
.00375 .12735 L
s
0 .13872 m
.00375 .13872 L
s
0 .21577 m
.00375 .21577 L
s
0 .2549 m
.00375 .2549 L
s
0 .28266 m
.00375 .28266 L
s
0 .32178 m
.00375 .32178 L
s
0 .33666 m
.00375 .33666 L
s
0 .34954 m
.00375 .34954 L
s
0 .36091 m
.00375 .36091 L
s
0 .43796 m
.00375 .43796 L
s
0 .47709 m
.00375 .47709 L
s
0 .50485 m
.00375 .50485 L
s
0 .54398 m
.00375 .54398 L
s
0 .55885 m
.00375 .55885 L
s
0 .57174 m
.00375 .57174 L
s
0 .5831 m
.00375 .5831 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(u) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 .25 r
.5 Mabswid
0 .17746 m
.25226 .28534 L
.41867 .35907 L
.50872 .39915 L
.57079 .42668 L
.62224 .44939 L
.66269 .46718 L
.69898 .48309 L
.72917 .49629 L
.75485 .50749 L
.7793 .51814 L
.80058 .52739 L
.81931 .53552 L
.83768 .54349 L
.85406 .55058 L
.87026 .55759 L
.88483 .5639 L
.89802 .5696 L
.91126 .57532 L
.92331 .58052 L
.93544 .58576 L
.94655 .59055 L
.95675 .59494 L
.96712 .59941 L
.97619 .60332 L
s
.996 0 0 r
0 .10967 m
.25226 .21736 L
.41867 .2884 L
.50872 .32686 L
.57079 .35339 L
.62224 .37539 L
.66269 .39269 L
.69898 .40822 L
.72917 .42114 L
.75485 .43212 L
.7793 .44259 L
.80058 .45169 L
.81931 .45971 L
.83768 .46757 L
.85406 .47457 L
.87026 .4815 L
.88483 .48774 L
.89802 .49338 L
.91126 .49905 L
.92331 .5042 L
.93544 .50939 L
.94655 .51414 L
.95675 .5185 L
.96712 .52294 L
.97619 .52682 L
s
0 .5 0 r
0 .07055 m
.25226 .17823 L
.41867 .24927 L
.50872 .28771 L
.57079 .3142 L
.62224 .33617 L
.66269 .35343 L
.69898 .36893 L
.72917 .38181 L
.75485 .39277 L
.7793 .40321 L
.80058 .4123 L
.81931 .42029 L
.83768 .42813 L
.85406 .43512 L
.87026 .44204 L
.88483 .44826 L
.89802 .45389 L
.91126 .45954 L
.92331 .46468 L
.93544 .46987 L
.94655 .47461 L
.95675 .47896 L
.96712 .48339 L
.97619 .48726 L
s
.5 0 .25 r
0 .04279 m
.25226 .15047 L
.41867 .22151 L
.50872 .25995 L
.57079 .28644 L
.62224 .30841 L
.66269 .32567 L
.69898 .34116 L
.72917 .35405 L
.75485 .36501 L
.7793 .37545 L
.80058 .38453 L
.81931 .39253 L
.83768 .40037 L
.85406 .40736 L
.87026 .41428 L
.88483 .4205 L
.89802 .42613 L
.91126 .43178 L
.92331 .43692 L
.93544 .4421 L
.94655 .44685 L
.95675 .4512 L
.96712 .45562 L
.97619 .4595 L
s
.7 0 0 r
0 .02125 m
.25226 .12894 L
.41867 .19997 L
.50872 .23841 L
.57079 .26491 L
.62224 .28687 L
.66269 .30414 L
.69898 .31963 L
.72917 .33252 L
.75485 .34348 L
.7793 .35392 L
.80058 .363 L
.81931 .371 L
.83768 .37884 L
.85406 .38583 L
.87026 .39274 L
.88483 .39897 L
.89802 .4046 L
.91126 .41025 L
.92331 .41539 L
.93544 .42057 L
.94655 .42531 L
.95675 .42967 L
.96712 .43409 L
.97619 .43796 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{216, 136.938},
  ImageMargins->{{51, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003H0000R1000`40O003h00Of7oo003HOol00=Qo
o`00f7oo003HOol002Yoo`8000Aoo`8000=oo`@001=oo`8000Aoo`8000Aoo`80011oo`D001Aoo`@0
01moo`8001=oo`D0009oo`8001Aoo`00:Goo00@007ooOol000Qoo`03001oogoo01=oo`04001oogoo
0008Ool01000Oomoo`004Goo00<007ooOol057oo00<007ooOol07goo00@007ooOol001Aoo`05001o
ogooOol00002Ool00`00Oomoo`0AOol002Uoo`04001oogoo0009Ool00`00Oomoo`0BOol01000Oomo
o`002goo00<007ooOol03goo00<007ooOol05Goo00<007ooOol08Goo00<007ooOol04Woo00D007oo
Oomoo`00009oo`03001oogoo015oo`00:Goo00@007ooOol000Yoo`03001oogoo015oo`04001oogoo
0009Ool2000BOol00`00Oomoo`0FOol00`00Oomoo`0NOol2000EOol01@00Oomoogoo00000Woo00<0
07ooOol04Goo000YOol01000Oomoo`0027oo00@007ooOol0019oo`04001oogoo0009Ool00`00Oomo
o`0AOol00`00Oomoo`0DOol01000Oomoo`007goo00<007ooOol057oo00D007ooOomoo`00009oo`03
001oogoo015oo`00:Woo0P002Woo0P0057oo0P002Woo0`0047oo0P005goo0P0087oo0`004goo0P00
17oo0P0057oo003HOol00=Qoo`00f7oo003HOol00<Yoo`800003Ool0000000Uoo`00bgoo00<007oo
00002Woo000ROonS0007Ool00`00Oomoo`09Ool0029oo`03001oogoo00aoo`03001oogoo01moo`03
001oogoo01Ioo`03001oogoo01Ioo`03001oogoo01moo`03001oogoo01Ioo`03001oogoo00Moo`80
0003Ool0000000Uoo`008Woo00<007ooOol0/goo000ROol2E02dOol0029oo`04001ooe@0E02bOol0
029oo`80009oo`=D0:moo`008Woo0S`71Goo0U@0[Goo000ROol01000Ooll1c`71Goo0U@0Zgoo000R
Ool01000Oomoogoo0S`71Goo0e@0Z7oo000ROol20004Ool2?0L6Ool2E02VOol0029oo`03001oogoo
00Eoo`<l1`Eoo`=D0:=oo`0027oo0P0017oo0P0017oo0P0017oo0P001Woo0P7P2Goo0S`71Woo0U@0
XGoo0007Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool01000Ool1h07P2Goo
0S`71Woo0U@0Wgoo0007Ool01000Oomoo`0027oo00@007ooOol000Eoo`03001oogoo00=oo`80009o
o`<1h0Qoo`<l1`Eoo`=D09aoo`001goo00@007ooOol000Qoo`04001oogoo0003Ool20006Ool00`00
Oomoo`04Ool20N09Ool2?0L6Ool2E02JOol000Moo`04001oogoo0008Ool01000Oomoo`000goo00<0
07ooOol01Goo00<007ooOol01Woo0P7P2Goo0S`71Woo0e@0Ugoo0008Ool2000:Ool20004Ool30005
Ool20009Ool30N08Ool2?0L7Ool2E02EOol0029oo`9l00aoo`81h0Qoo`<l1`Ioo`9D09=oo`008Woo
0P000W`037oo0`7P27oo0S`71Woo0e@0T7oo000ROol01000Oomoogoo0W`03Goo0P7P27oo0S`71goo
0U@0SWoo000ROol20004Ool2O00=Ool20N08Ool3?0L6Ool3E02;Ool0029oo`03001oogoo00Eoo`=l
00aoo`<1h0Qoo`8l1`Moo`9D08Uoo`003Woo0P0017oo0P000goo1@0017oo0P002Goo0W`03Goo0P7P
27oo0S`71goo0U@0Qgoo000=Ool01000Oomoo`002Woo00<007ooOol017oo00<007ooOol02Woo0W`0
3Goo0`7P1goo0S`71goo0U@0QGoo000=Ool01000Oomoo`002Woo00<007ooOol017oo0P003Goo0g`0
3Goo0P7P1goo0c`71Woo0e@0PWoo000=Ool01000Oomoo`002Woo00<007ooOol017oo00<007ooOol0
3goo0W`03Goo0P7P27oo0S`71goo0U@0P7oo000=Ool01000Oomoo`002Woo00<007ooOol017oo00<0
07ooOol04Goo0W`03Goo0`7P1goo0c`71Woo0U@0OWoo000>Ool2000:Ool20006Ool00`00Oomoo`0C
Ool2O00>Ool20N08Ool2?0L6Ool2E01lOol0029oo`801aIoo`=l00eoo`<1h0Moo`<l1`Eoo`=D07Uo
o`008Woo00@007oo00L01aMoo`9l00ioo`81h0Qoo`8l1`Ioo`9D07Moo`008Woo00@007ooOomoo`80
1aMoo`9l00ioo`81h0Qoo`8l1`Ioo`9D07Eoo`008Woo00<007ooOol00goo0P075goo0g`03Goo0P7P
27oo0c`71Goo0U@0Lgoo000ROol00`00Oomoo`05Ool300LGOol2O00=Ool30N08Ool2?0L5Ool3E01`
Ool0029oo`03001oogoo00Qoo`801aMoo`9l00ioo`81h0Qoo`<l1`Eoo`9D06ioo`008Woo0P002goo
0P075goo0W`03Woo0P7P2Goo0S`71Goo0U@0K7oo000ROol00`00Oomoo`0<Ool300LFOol3O00=Ool2
0N09Ool2?0L5Ool3E01YOol0029oo`03001oogoo00moo`801aMoo`9l00eoo`<1h0Qoo`8l1`Ioo`9D
06Moo`008Woo00<007ooOol04Goo0P075goo0g`03Goo0P7P27oo0S`71Woo0U@0IGoo000ROol00`00
Oomoo`0COol200LHOol2O00=Ool20N08Ool2?0L6Ool3E01ROol0029oo`03001oogoo01Eoo`<01aMo
o`=l00aoo`81h0Qoo`8l1`Moo`9D061oo`008Woo00<007ooOol067oo0P0767oo0W`037oo0`7P1goo
0S`71goo0e@0GGoo000ROol2000KOol200LHOol2O00=Ool20N07Ool2?0L8Ool2E01KOol0029oo`03
001oogoo01aoo`<01aMoo`=l00aoo`81h0Moo`<l1`Moo`=D05Qoo`008Woo00<007ooOol07goo0P07
67oo0W`037oo0`7P1goo0S`727oo0U@0EWoo000ROol00`00Oomoo`0QOol200LHOol3O00<Ool20N07
Ool3?0L7Ool2E01DOol0029oo`8002Aoo`801aUoo`9l00aoo`81h0Qoo`8l1`Moo`9D059oo`008Woo
00<007ooOol09Goo0`0767oo0g`02goo0`7P1goo0c`71Woo0U@0D7oo000>Ool20004Ool20004Ool2
0006Ool00`00Oomoo`0XOol200LIOol2O00<Ool20N08Ool3?0L5Ool2E01>Ool000eoo`04001oogoo
0008Ool01000Oomoo`001Goo00<007ooOol0:Woo0P076Goo0W`037oo0`7P27oo0c`717oo0U@0C7oo
000=Ool01000Oomoo`002goo00<007ooOol00goo0P00;Goo0P076Goo0g`037oo0P7P2Goo0S`717oo
0e@0BGoo000=Ool01000Oomoo`002Goo0P001Woo00<007ooOol0;Woo0`076Goo0W`037oo0`7P27oo
0S`71Goo0e@0AWoo000=Ool01000Oomoo`002Goo00<007ooOol01Goo00<007ooOol0<Goo0P076Goo
0W`03Goo0P7P27oo0S`71Woo0e@0@goo000>Ool2000:Ool30005Ool2000dOol200LIOol2O00=Ool2
0N08Ool2?0L7Ool2E011Ool0029oo`03001oogoo03Eoo`801aUoo`9l00eoo`81h0Qoo`8l1`Moo`9D
03moo`008Woo0P00>7oo0`0767oo0W`03Goo0P7P27oo0S`71goo0U@0?Goo000ROol00`00Oomoo`0j
Ool200LHOol2O00=Ool20N08Ool3?0L6Ool2E00kOol0029oo`8003eoo`801aQoo`9l00eoo`81h0Uo
o`8l1`Ioo`9D03Uoo`008Woo00<007ooOol0?Woo0P0767oo0g`037oo0`7P27oo0S`71Woo0e@0=Woo
000IOol50004Ool20011Ool300LHOol3O00<Ool30N07Ool2?0L7Ool3E00cOol001]oo`03001oogoo
00Aoo`03001oogoo04=oo`801aUoo`=l00aoo`<1h0Ioo`<l1`Moo`9D035oo`006goo00<007ooOol0
17oo0P00AWoo0P076Woo0W`03Goo0P7P1goo0c`71Woo0U@0;goo000KOol00`00Oomoo`04Ool00`00
Oomoo`17Ool300LIOol2O00=Ool20N08Ool2?0L6Ool2E00]Ool001]oo`03001oogoo00Aoo`03001o
ogoo04Yoo`801aUoo`9l00eoo`81h0Qoo`<l1`Eoo`=D02Yoo`006Woo0P001Woo00<007ooOol0C7oo
0P076Goo0W`03Goo0P7P2Goo0c`71Goo0U@0:7oo000ROol00`00Oomoo`1>Ool200LIOol2O00=Ool2
0N0:Ool2?0L5Ool2E00VOol0029oo`03001oogoo051oo`801aUoo`9l00eoo`<1h0Uoo`8l1`Eoo`9D
02Aoo`008Woo00<007ooOol0DWoo0P076Goo0g`03Goo0`7P27oo0S`71Goo0U@08Woo000ROol00`00
Oomoo`1DOol200LJOol2O00>Ool20N08Ool00c`7Oomoo`04Ool2E00POol0029oo`03001oogoo05Io
o`801aYoo`=l00eoo`81h0Moo`@l1`Aoo`AD01aoo`008Woo00<007ooOol0F7oo0`076Woo0g`037oo
0P7P2Goo0S`71Woo0U@06Woo000ROol2001LOol300LJOol2O00<Ool30N08Ool2?0L6Ool3E00GOol0
029oo`03001oogoo05ioo`<01aUoo`9l00eoo`81h0Qoo`8l1aioo`008Woo00<007ooOol0HGoo0P07
6Goo0W`03Goo0P7P27oo13`76Woo000ROol00`00Oomoo`1SOol200LIOol3O00<Ool20N0:Ool00c`7
Oomoo`0GOol0029oo`03001oogoo06Eoo`801aYoo`=l00]oo`81h0Uoo`8l1aMoo`008Woo00<007oo
Ool0Igoo0P076goo0W`02goo0P7P87oo000ROol00`00Oomoo`1YOol200LKOol3O00:Ool40N0LOol0
029oo`8006aoo`801aaoo`9l00aoo`81h1Yoo`008Woo00<007ooOol0KGoo0`076goo0W`037oo0`7P
5goo000ROol00`00Oomoo`1`Ool200LKOol2O00TOol0029oo`03001oogoo079oo`801a]oo`9l029o
o`008Woo0P00MGoo0P076goo0W`087oo000ROol00`00Oomoo`1fOol300LJOol2O00NOol001Yoo`80
00Ioo`03001oogoo07Uoo`<01aUoo`Al01Yoo`006Goo00@007ooOol000Eoo`03001oogoo07aoo`80
1a]oo`03O01oogoo01Moo`0077oo00<007ooOol00goo0P00Ogoo0`076Goo0W`05goo000JOol20006
Ool00`00Oomoo`21Ool300L_Ool001Yoo`03001oogoo00Eoo`8008Eoo`801beoo`006Woo0`001Goo
00<007ooOol0QWoo00<01gooOol0:Woo000ROol00`00Oomoo`27Ool200LZOol0029oo`8008Yoo`80
1bQoo`008Woo00<007ooOol0Rgoo0P079Woo000ROol2002>Ool200LTOol0029oo`03001oogoo08mo
o`@01b1oo`004goo1@000Woo0P001Woo0P00U7oo0P077Woo000EOol01@00Oomoogoo00000Woo00<0
07ooOol00goo0P00UWoo0P0777oo000EOol01@00Oomoogoo00000Woo00<007ooOol00goo00<007oo
Ool0Ugoo0`076Goo000EOol01@00Oomoogoo00000Woo00<007ooOol00goo00<007ooOol0VWoo0P07
5goo000EOol01@00Oomoogoo00000Woo00<007ooOol00goo00<007ooOol0/goo000DOol20004Ool2
0006Ool00`00Oomoo`2cOol00=Qoo`00f7oo003HOol00=Qoo`00f7oo003HOol00=Qoo`00f7oo003H
Ool0025oo`@00;=oo`0087oo00@007ooOol00;Aoo`0087oo00@007ooOol00;Aoo`007goo0P0000=o
o`000000]7oo003HOol00=Qoo`00f7oo003HOol00=Qoo`00f7oo0000\
\>"],
  ImageRangeCache->{{{0, 215}, {135.938, 0}} -> {-1.2878, -2.14406, \
0.0118881, 0.0278492}}]
}, Open  ]],

Cell[TextData[{
  "Varying ",
  StyleBox["C",
    FontSlant->"Italic"],
  "[2] we observe only a minor change in the slope:"
}], "Text"],

Cell[BoxData[
    \(\(soluC\  = \ 
      Table[\(u[x]\  /. \ solu\)\  /. {C[1] \[Rule] 1, C[2] \[Rule] y}, {y, 
          1, 5, 1}]; \)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(LogLogPlot[Evaluate[soluC], {x, 0.001, 10}, 
      PlotStyle 
        \[Rule] {RGBColor[0, \ 0, \ 0.250004], RGBColor[0.996109, \ 0, \ 0], 
          RGBColor[0, \ 0.500008, \ 0], RGBColor[0.500008, \ 0, \ 0.250004], 
          RGBColor[0.700008, \ 0, \ 0]}, AxesLabel \[Rule] {"\<x\>", "\<u\>"}]
      \ \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.455674 0.520516 0.279902 0.309426 [
[.09185 -0.0125 -11 -15 ]
[.09185 -0.0125 11 0 ]
[.29898 -0.0125 -11 -15 ]
[.29898 -0.0125 11 0 ]
[.45567 -0.0125 -5 -15 ]
[.45567 -0.0125 5 0 ]
[.61237 -0.0125 -5 -15 ]
[.61237 -0.0125 5 0 ]
[.8195 -0.0125 -5 -15 ]
[.8195 -0.0125 5 0 ]
[.97619 -0.0125 -8 -15 ]
[.97619 -0.0125 8 0 ]
[1.025 0 0 -7.5 ]
[1.025 0 10 7.5 ]
[-0.0125 .06362 -22 -7.5 ]
[-0.0125 .06362 0 7.5 ]
[-0.0125 .18676 -22 -7.5 ]
[-0.0125 .18676 0 7.5 ]
[-0.0125 .2799 -10 -7.5 ]
[-0.0125 .2799 0 7.5 ]
[-0.0125 .37305 -10 -7.5 ]
[-0.0125 .37305 0 7.5 ]
[-0.0125 .49618 -10 -7.5 ]
[-0.0125 .49618 0 7.5 ]
[-0.0125 .58933 -16 -7.5 ]
[-0.0125 .58933 0 7.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 15 ]
[ -0.0005 -0.0005 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.09185 0 m
.09185 .00625 L
s
gsave
.09185 -0.0125 -72 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.2) show
81.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.29898 0 m
.29898 .00625 L
s
gsave
.29898 -0.0125 -72 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.5) show
81.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.45567 0 m
.45567 .00625 L
s
gsave
.45567 -0.0125 -66 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.61237 0 m
.61237 .00625 L
s
gsave
.61237 -0.0125 -66 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.8195 0 m
.8195 .00625 L
s
gsave
.8195 -0.0125 -66 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -69 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
75.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.001 w
.18351 0 m
.18351 .00375 L
s
.24854 0 m
.24854 .00375 L
s
.3402 0 m
.3402 .00375 L
s
.37505 0 m
.37505 .00375 L
s
.40523 0 m
.40523 .00375 L
s
.43186 0 m
.43186 .00375 L
s
.70402 0 m
.70402 .00375 L
s
.76906 0 m
.76906 .00375 L
s
.86071 0 m
.86071 .00375 L
s
.89556 0 m
.89556 .00375 L
s
.92575 0 m
.92575 .00375 L
s
.95237 0 m
.95237 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
0 .06362 m
.00625 .06362 L
s
gsave
-0.0125 .06362 -83 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.2) show
81.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
0 .18676 m
.00625 .18676 L
s
gsave
-0.0125 .18676 -83 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.5) show
81.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
0 .2799 m
.00625 .2799 L
s
gsave
-0.0125 .2799 -71 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
0 .37305 m
.00625 .37305 L
s
gsave
-0.0125 .37305 -71 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
0 .49618 m
.00625 .49618 L
s
gsave
-0.0125 .49618 -71 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
0 .58933 m
.00625 .58933 L
s
gsave
-0.0125 .58933 -77 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
75.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.001 w
0 .11811 m
.00375 .11811 L
s
0 .15677 m
.00375 .15677 L
s
0 .21126 m
.00375 .21126 L
s
0 .23197 m
.00375 .23197 L
s
0 .24992 m
.00375 .24992 L
s
0 .26574 m
.00375 .26574 L
s
0 .42754 m
.00375 .42754 L
s
0 .46619 m
.00375 .46619 L
s
0 .52068 m
.00375 .52068 L
s
0 .5414 m
.00375 .5414 L
s
0 .55934 m
.00375 .55934 L
s
0 .57517 m
.00375 .57517 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(u) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 .25 r
.5 Mabswid
0 .01027 m
.25226 .16051 L
.41867 .26318 L
.50872 .319 L
.57079 .35733 L
.62224 .38896 L
.66269 .41373 L
.69898 .43589 L
.72917 .45427 L
.75485 .46987 L
.7793 .48469 L
.80058 .49758 L
.81931 .5089 L
.83768 .52 L
.85406 .52988 L
.87026 .53964 L
.88483 .54842 L
.89802 .55636 L
.91126 .56432 L
.92331 .57157 L
.93544 .57886 L
.94655 .58553 L
.95675 .59166 L
.96712 .59788 L
.97619 .60332 L
s
.996 0 0 r
0 .00948 m
.25226 .15955 L
.41867 .25992 L
.50872 .31437 L
.57079 .35186 L
.62224 .38288 L
.66269 .40724 L
.69898 .42906 L
.72917 .44719 L
.75485 .4626 L
.7793 .47726 L
.80058 .49002 L
.81931 .50123 L
.83768 .51223 L
.85406 .52203 L
.87026 .53172 L
.88483 .54044 L
.89802 .54832 L
.91126 .55623 L
.92331 .56343 L
.93544 .57068 L
.94655 .57731 L
.95675 .5834 L
.96712 .58959 L
.97619 .595 L
s
0 .5 0 r
0 .00919 m
.25226 .15919 L
.41867 .25866 L
.50872 .31254 L
.57079 .34966 L
.62224 .38042 L
.66269 .40458 L
.69898 .42626 L
.72917 .44428 L
.75485 .4596 L
.7793 .47418 L
.80058 .48687 L
.81931 .49804 L
.83768 .50899 L
.85406 .51875 L
.87026 .5284 L
.88483 .53709 L
.89802 .54495 L
.91126 .55283 L
.92331 .56001 L
.93544 .56724 L
.94655 .57385 L
.95675 .57993 L
.96712 .5861 L
.97619 .5915 L
s
.5 0 .25 r
0 .00908 m
.25226 .15906 L
.41867 .25818 L
.50872 .31184 L
.57079 .34883 L
.62224 .37948 L
.66269 .40357 L
.69898 .42518 L
.72917 .44315 L
.75485 .45844 L
.7793 .47299 L
.80058 .48566 L
.81931 .4968 L
.83768 .50774 L
.85406 .51748 L
.87026 .52712 L
.88483 .53579 L
.89802 .54364 L
.91126 .55151 L
.92331 .55868 L
.93544 .5659 L
.94655 .57251 L
.95675 .57858 L
.96712 .58474 L
.97619 .59014 L
s
.7 0 0 r
0 .00904 m
.25226 .15901 L
.41867 .25801 L
.50872 .31159 L
.57079 .34852 L
.62224 .37913 L
.66269 .40319 L
.69898 .42477 L
.72917 .44273 L
.75485 .458 L
.7793 .47255 L
.80058 .4852 L
.81931 .49634 L
.83768 .50727 L
.85406 .517 L
.87026 .52664 L
.88483 .5353 L
.89802 .54315 L
.91126 .55102 L
.92331 .55818 L
.93544 .5654 L
.94655 .57201 L
.95675 .57807 L
.96712 .58423 L
.97619 .58963 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{217.875, 129.125},
  ImageMargins->{{51.3125, 0}, {0, 0}},
  ImageRegion->{{-0.029344, 1.02705}, {-0.000351, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003I0000PA000`40O003h00OfGoo003IOol00=Uo
o`00fGoo003IOol00=Uoo`00;Goo0P0017oo0P000goo100047oo0P0017oo0P0017oo0P003Woo1@00
4goo100077oo0P004Goo1@000Woo0P007Goo000/Ool01000Oomoo`0027oo00<007ooOol047oo00@0
07ooOol000Qoo`04001oogoo000?Ool00`00Oomoo`0COol00`00Oomoo`0LOol01000Oomoo`004Woo
00D007ooOomoo`00009oo`03001oogoo01Yoo`00;7oo00@007ooOol000Uoo`03001oogoo00moo`04
001oogoo000;Ool00`00Oomoo`0=Ool00`00Oomoo`0DOol00`00Oomoo`0NOol00`00Oomoo`0@Ool0
1@00Oomoogoo00000Woo00<007ooOol06Woo000/Ool01000Oomoo`002Woo00<007ooOol03Woo00@0
07ooOol000Uoo`80011oo`03001oogoo01Eoo`03001oogoo01]oo`8001=oo`05001oogooOol00002
Ool00`00Oomoo`0JOol002aoo`04001oogoo0008Ool01000Oomoo`003goo00@007ooOol000Uoo`03
001oogoo00moo`03001oogoo01=oo`04001oogoo000LOol00`00Oomoo`0BOol01@00Oomoogoo0000
0Woo00<007ooOol06Woo000]Ool2000:Ool2000AOol2000:Ool3000>Ool2000FOol2000MOol3000A
Ool20004Ool2000MOol00=Uoo`00fGoo003IOol00<5oo`800003Ool0000001=oo`00`Woo00<007oo
000057oo000VOonG0006Ool00`00Oomoo`0COol002Ioo`03001oogoo00]oo`03001oogoo00Yoo`03
001oogoo00Moo`03001oogoo00Eoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo009oo`05
001oogooOol00002Ool00`00Oomoo`0EOol00`00Oomoo`0:Ool00`00Oomoo`07Ool00`00Oomoo`05
Ool00`00Oomoo`03Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Qoo`80
0003Ool0000001=oo`009Woo00=D07ooOol0/7oo000VOol00`00E01D002`Ool002Ioo`03001oogoo
009D0:ioo`009Woo00<007ooOol00Woo0U@0[7oo000VOol00`00Oomoo`04Ool00e@0Oomoo`2YOol0
02Ioo`03001oogoo00Eoo`9D0:Uoo`004Woo0P0017oo0P000goo10001Goo00<007ooOol01goo0U@0
Ygoo000AOol01000Oomoo`0027oo00<007ooOol01Woo00<007ooOol02Goo00=D07ooOol0Y7oo000A
Ool01000Oomoo`002Goo00<007ooOol01Goo0P002goo0U@0Y7oo000AOol01000Oomoo`002Woo00<0
07ooOol017oo00<007ooOol037oo0U@0XWoo000AOol01000Oomoo`0027oo00@007ooOol000Eoo`03
001oogoo00ioo`9D0:1oo`004Woo0P002Woo0P001Woo00<007ooOol047oo00=D07ooOol0WGoo000V
Ool00`00Oomoo`0AOol2E02MOol002Ioo`03001oogoo01=oo`9D09]oo`009Woo00<007ooOol05Goo
0U@0VGoo000VOol00`00Oomoo`0GOol00e@0Oomoo`2FOol002Ioo`03001oogoo01Qoo`9D09Ioo`00
9Woo00<007ooOol06Woo0U@0U7oo000VOol00`00Oomoo`0LOol00e@0Oomoo`2AOol002Ioo`03001o
ogoo01eoo`9D095oo`009Woo00<007ooOol07goo0U@0Sgoo000VOol00`00Oomoo`0QOol2E02=Ool0
02Ioo`03001oogoo02=oo`03E01oogoo08Yoo`009Woo00<007ooOol097oo0U@0RWoo000BOol20004
Ool20004Ool20006Ool00`00Oomoo`0VOol2E028Ool0015oo`04001oogoo0008Ool01000Oomoo`00
1Goo00<007ooOol09goo00<01e@0Ool0QWoo000AOol01000Oomoo`002goo00<007ooOol00goo0P00
:Woo0U@0QGoo000AOol01000Oomoo`002Goo0P001Woo00<007ooOol0:goo0U@0Pgoo000AOol01000
Oomoo`002Goo00<007ooOol01Goo00<007ooOol0;7oo00<01e@0Ool0PGoo000BOol2000:Ool30005
Ool00`00Oomoo`0^Ool2E020Ool002Ioo`03001oogoo02moo`0300MD05@007ioo`009Woo00<007oo
Ool0<Goo00<01e@0Ool0O7oo000VOol00`00Oomoo`0bOol00`07E01D001kOol002Ioo`03001oogoo
03Aoo`0300MD05@007Uoo`009Woo00<007ooOol0=Goo0P0700=D07ooOol0MWoo000VOol00`00Oomo
o`0gOol00`07E01D001fOol002Ioo`03001oogoo03Uoo`0300MD05@007Aoo`009Woo00<007ooOol0
>Woo0P0700=D07ooOol0LGoo000MOol50004Ool00`00Oomoo`0lOol00`07E01D001aOol001moo`03
001oogoo00Aoo`03001oogoo03eoo`801`9D06moo`007goo00<007ooOol017oo0P00@7oo0P0700=D
07ooOol0K7oo000OOol00`00Oomoo`04Ool00`00Oomoo`11Ool00`07E01D001/Ool001moo`03001o
ogoo00Aoo`03001oogoo049oo`801`03E01oogoo06Uoo`007Woo0P001Woo00<007ooOol0A7oo00<0
1e@0E000JGoo000VOol00`00Oomoo`15Ool200L2E01WOol002Ioo`03001oogoo04Moo`801`03E01o
ogoo06Aoo`009Woo00<007ooOol0BGoo00<01e@0E000I7oo000VOol00`00Oomoo`1:Ool200L2E01R
Ool002Ioo`03001oogoo04aoo`0400L1h5@0E01POol002Ioo`03001oogoo04eoo`801`030N1D05@0
05ioo`009Woo00<007ooOol0Cgoo00@01`7P0N1D05eoo`009Woo00<007ooOol0D7oo0P0700<1h5@0
E000Fgoo000MOol40005Ool00`00Oomoo`1BOol010070N01h5@0FWoo000MOol00`00Oomoo`06Ool0
0`00Oomoo`1COol200L00`7PE01D001HOol001ioo`03001oogoo00Eoo`8005Ioo`0300Ml007P009D
05Ioo`007goo00<007ooOol017oo00<007ooOol0Egoo00@01g`00N1D05Eoo`007Goo00@007ooOol0
00Eoo`03001oogoo05Uoo`0400Ml05@0E01COol001ioo`8000Ioo`03001oogoo05]oo`9l0003E01o
ogoo051oo`009Woo00<007ooOol0GGoo00=l05@0E000D7oo000VOol00`00Oomoo`1NOol00`07O01D
001?Ool002Ioo`03001oogoo061oo`0300MD05@004eoo`009Woo00<007ooOol0HGoo0P070U@0Bgoo
000VOol00`00Oomoo`1SOol200L2E019Ool002Ioo`03001oogoo06Eoo`801`03E01oogoo04Ioo`00
9Woo00<007ooOol0Igoo00<01e@0E000AWoo000VOol00`00Oomoo`1XOol200L00e@0Oomoo`13Ool0
02Ioo`03001oogoo06Yoo`0300MD05@004=oo`009Woo00<007ooOol0Jgoo00@01gooE01D045oo`00
9Woo00<007ooOol0K7oo0P0700=ooe@0E000?goo000VOol00`00Oomoo`1^Ool00`07Ooml0002E00m
Ool002Ioo`03001oogoo06moo`801`04Ooml05@0E00kOol001ioo`8000Ioo`03001oogoo075oo`80
1`9l0003E01oogoo03Qoo`007Goo00@007ooOol000Eoo`03001oogoo07=oo`801`03O01D05@003Qo
o`0087oo00<007ooOol00goo0P00MWoo0P0700=l05@0Ool0=Woo000NOol20006Ool00`00Oomoo`1g
Ool200L2E00eOol001ioo`03001oogoo00Eoo`03001oogoo07Uoo`0400Ml05@0E00cOol001ioo`<0
00Eoo`03001oogoo07Yoo`0400Moog`0E00bOol002Ioo`03001oogoo07]oo`801`03OomD05@0031o
o`009Woo00<007ooOol0OGoo00<01gooO0000U@0;Woo000VOol00`00Oomoo`1nOol200L00g`00N1D
000]Ool002Ioo`03001oogoo081oo`801`030N1D07oo02]oo`009Woo00<007ooOol0PWoo00@01goo
E01D02Yoo`009Woo00<007ooOol0Pgoo00<01gooO0000U@0:7oo000VOol00`00Oomoo`24Ool200L2
O002E00VOol002Ioo`03001oogoo08Ioo`801`9l009D02Aoo`005goo1@000Woo0P001Woo00<007oo
Ool0R7oo0P070W`000=D07ooOol08Goo000IOol01@00Oomoogoo00000Woo00<007ooOol00goo0P00
Rgoo0P0700=l05@0E0008Goo000IOol01@00Oomoogoo00000Woo00<007ooOol00goo00<007ooOol0
S7oo00@01gooOomD021oo`006Goo00D007ooOomoo`00009oo`03001oogoo00=oo`03001oogoo08eo
o`801b5oo`006Goo00D007ooOomoo`00009oo`03001oogoo00=oo`03001oogoo08moo`0300Moogoo
01ioo`0067oo0P0017oo0P001Woo00<007ooOol0/7oo000VOol00`00Oomoo`2`Ool00=Uoo`00fGoo
003IOol00=Uoo`00fGoo003IOol00=Uoo`00fGoo000UOol4002`Ool002Aoo`04001oogoo002aOol0
02Aoo`04001oogoo002aOol002=oo`800003Ool000000;5oo`00fGoo003IOol00=Uoo`00fGoo003I
Ool00=Uoo`00\
\>"],
  ImageRangeCache->{{{-6.375, 222.75}, {128.125, 0}} -> {-1.36839, -1.26885, \
0.0128346, 0.0215904}}]
}, Open  ]],

Cell[TextData[{
  "In conclusion, we see that Lie\[CloseCurlyQuote]s algorithm of group \
classification is straightforward to derive explicit solutions of a \
second-order ODE. All the steps needed to carry out the calculation are \
supported by ",
  StyleBox["MathLie. ",
    FontSlant->"Italic"],
  "Thus, it is fairly easy to construct a solution. The next example \
discusses the solution procedure for a more complicated equation."
}], "Text",
  CellTags->"algorithm of group classification"],

Cell["Example 2", "Example"],

Cell[TextData[{
  "The second example is connected with kinetics and heat transfer (cf. ",
  ButtonBox["Ames [1968]",
    ButtonData:>{"Literat.nb", "Ames-68"},
    ButtonStyle->"Hyperlink"],
  "). Ames' equation also occurs in certain other problems like vortex motion \
of incompressible fluids, in the theory of the space charge of elasticity \
around a glowing wire, and in the nebular theory for the mass distribution of \
gaseous interstellar material under the influence of its own gravitational \
field."
}], "Text",
  CellTags->{
  "heat transfer", "vortex motion", "space charge of elasticity", 
    "glowing wire", "nebular theory", 
    "mass distribution of gaseous interstellar material", 
    "gravitational field"}],

Cell[TextData[{
  "We concentrate our attention on the one-dimensional representations of \
these problems. The equation is discussed in cylindrical coordinates. For \
this special case, the equation reduces to a second-order ordinary \
differential equation (",
  ButtonBox["Ames [1968]",
    ButtonData:>{"Literat.nb", "Ames-68"},
    ButtonStyle->"Hyperlink"],
  ") given by"
}], "Text",
  CellTags->{
  "cylindrical coordinates", "second-order ordinary differential equation"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(ames\  = \ 
      \[PartialD]\_\(x, x\)u[x]\  + \ \(\ \[PartialD]\_x u[x]\)\/x + \ 
        \[Alpha]\ Exp[u[x]]; ames == 0 // LTF\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {
            RowBox[{
              RowBox[{\(E\^u\ \[Alpha]\), "+", 
                StyleBox[\(u\_x\/x\),
                  ScriptLevel->0], "+", \(u\_\(x, x\)\)}], "==", "0"}]}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output"]
}, Open  ]],

Cell[TextData[{
  "When trying to solve this simple equation by ",
  StyleBox["DSolve[]", "MmaText"],
  ", we end up with the dissatisfying result"
}], "Text",
  CellTags->"DSolve[]"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DSolve[ames == 0, u, x]\)], "Input"],

Cell[BoxData[
    RowBox[{"DSolve", "[", 
      RowBox[{
        RowBox[{
          RowBox[{\(E\^u[x]\ \[Alpha]\), "+", 
            FractionBox[
              RowBox[{
                SuperscriptBox["u", "\[Prime]",
                  MultilineFunction->None], "[", "x", "]"}], "x"], "+", 
            RowBox[{
              SuperscriptBox["u", "\[DoublePrime]",
                MultilineFunction->None], "[", "x", "]"}]}], "==", "0"}], 
        ",", "u", ",", "x"}], "]"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Thus, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " is unable to find the solution. However, we are currently discussing a \
constructive procedure to derive solutions of second-order equations. Thus, a \
solution should be accessible if we know the symmetry transformations. The \
symmetries of the equation are calculated by the function ",
  StyleBox["Infinitesimals[]", "MmaText"],
  " or the operator ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{
            SubsuperscriptBox[
              TagBox["\[ScriptCapitalP]\[ScriptCapitalS]",
                NotationBoxTag,
                Editable->True], \(u, x\), "\[Gamma]"], "[", 
            "\[CapitalDelta]", "]"}],
          "MmaText"], TraditionalForm]]],
  ". The application of this operator provides"
}], "Text",
  CellTags->{"symmetry transformation", "Infinitesimals[]"}],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        SubsuperscriptBox[
          StyleBox[
            TagBox[
              StyleBox["\[ScriptCapitalP]\[ScriptCapitalS]",
                FontSize->9],
              NotationBoxTag,
              Editable->True],
            FontSize->18], \({u}, {x}\), \({\[Alpha]}\)], "[", "ames", "]"}], 
      "//", "LTF"}]], "Input"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\(\[Phi]\_1 == k2 + k1\ Log[x]\)},
          {\(\[Xi]\_1 == \(-\(1\/2\)\)\ x\ \((\(-k1\) + k2 + k1\ Log[x])\)\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {
        Equal[ 
          Subscript[ \[Phi], 1], 
          Plus[ k2, 
            Times[ k1, 
              Log[ x]]]], 
        Equal[ 
          Subscript[ \[Xi], 1], 
          Times[ 
            Rational[ -1, 2], x, 
            Plus[ 
              Times[ -1, k1], k2, 
              Times[ k1, 
                Log[ x]]]]]}]]], "Output"]
}, Open  ]],

Cell[TextData[{
  "a two-dimensional symmetry group with group parameters ",
  Cell[BoxData[
      \(TraditionalForm\`k1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`k2\)]],
  ". The subgroups created by the parameters k1 and k2 are the cornerstones \
of the integration process. Let us consider the subgroup related to ",
  Cell[BoxData[
      \(TraditionalForm\`k1 = 0\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`k2 = 1\)]],
  ". This choice of the group parameters allows to derive the canonical \
variables ",
  Cell[BoxData[
      \(TraditionalForm\`w\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  " to be"
}], "Text",
  CellTags->{
  "subgroups", "integration process", "group parameter", 
    "canonical variables"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(ctransformation\  = \ \n
      CanonicalVariables[{u}, {x}, {\(-x\)/2}, {1}, {w}, {t}]; 
    ctransformation\  // LTF\)], "Input"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\(t == \(-2\)\ Log[x]\)},
          {\(w == u + 2\ Log[x]\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {
        Equal[ t, 
          Times[ -2, 
            Log[ x]]], 
        Equal[ w, 
          Plus[ u, 
            Times[ 2, 
              Log[ x]]]]}]]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Converting the original equation ",
  StyleBox["ames",
    FontSlant->"Italic"],
  " into the new coordinates simplifies the representation of the equation:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(canonical\  = \ 
      CanonicalRepresentation[ames, u, 
        x, {w \[Rule] u + 2\ Log[x], t \[Rule] \(-2\)\ Log[x]}, w, t]; 
    canonical // LTF\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {\(E\^t\ \((E\^w\ \[Alpha] + 4\ w\_\(t, t\))\) == 0\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output"]
}, Open  ]],

Cell[TextData[{
  "The introduction of the canonical variables allows the elimination of the \
term containing first derivatives. As a result, the original equation was \
simplified. Trying again ",
  StyleBox["DSolve[]", "MmaText"],
  " to disclose the solution in canonical coordinates,"
}], "Text",
  CellTags->{"DSolve[]", "canonical coordinates"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(csol\  = \ DSolve[canonical, w, t]\)], "Input"],

Cell[BoxData[
    \({{w \[Rule] 
          \((Log[\(1\/\[Alpha]\) 
                  \((C[1] - 
                      C[1]\ Tanh[
                            1\/4\ \((\@2\ #1\ \@C[1] - \@2\ \@C[1]\ C[2])\)]
                            \^2)\)]&)\)}, {
        w \[Rule] 
          \((Log[\(1\/\[Alpha]\) 
                  \((C[1] - 
                      C[1]\ Tanh[
                            1\/4\ \((\(-\@2\)\ #1\ \@C[1] + \@2\ \@C[1]\ C[2])
                                \)]\^2)\)]&)\)}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The inversion of the canonical transformation provides the solutions in \
the original variables ",
  Cell[BoxData[
      \(TraditionalForm\`u\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ":"
}], "Text",
  CellTags->{"inversion", "canonical transformation"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(sol1\  = \ 
      BackTrafoCanonical[sol, w, t, u, 
        x, {u \[Rule] w - 2\ Log[x]\ , t \[Rule] \(-2\)\ Log[x]}]\)], "Input"],

Cell[BoxData[
    \({u \[Rule] 
        Function[x, 
          \(-2\)\ Log[x] + 
            Log[\(1\/\[Alpha]\) 
                \((C[1] - 
                    C[1]\ Tanh[
                          1\/4\ \((
                              \(-\@2\)\ \@C[1]\ C[2] - 2\ \@2\ \@C[1]\ Log[x])
                              \)]^2)\)]], 
      u \[Rule] 
        Function[x, 
          \(-2\)\ Log[x] + 
            Log[\(1\/\[Alpha]\) 
                \((C[1] - 
                    C[1]\ Tanh[
                          1\/4\ \((\@2\ \@C[1]\ C[2] + 2\ \@2\ \@C[1]\ Log[x])
                              \)]^2)\)]]}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Inserting the derived solutions into the original equation ",
  StyleBox["ames, ",
    FontSlant->"Italic"],
  "we can check the solution"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ames\  /. \ sol1 // Simplify\)], "Input"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "To get an impression of the solution, we plot it for a set of constants ",
  StyleBox["C",
    FontSlant->"Italic"],
  "[1] at fixed ",
  StyleBox["C",
    FontSlant->"Italic"],
  "[2]",
  StyleBox[" ",
    FontSlant->"Italic"],
  "and \[Alpha]. "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[
      Evaluate[Table[
          \(u[x] /. sol1\[LeftDoubleBracket]1\[RightDoubleBracket]\)\  /. {
              C[1] \[Rule] i, C[2] \[Rule] 1, \[Alpha] \[Rule] 1/100}, {i, 1, 
            5, 1}]], {x,  .1, 100}, 
      PlotStyle \[Rule] RGBColor[0.996109, \ 0, \ 0], 
      AxesLabel \[Rule] {"\<x\>", "\<u\>"}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 0.422107 0.0229473 [
[.21429 .40961 -6 -9 ]
[.21429 .40961 6 0 ]
[.40476 .40961 -6 -9 ]
[.40476 .40961 6 0 ]
[.59524 .40961 -6 -9 ]
[.59524 .40961 6 0 ]
[.78571 .40961 -6 -9 ]
[.78571 .40961 6 0 ]
[.97619 .40961 -9 -9 ]
[.97619 .40961 9 0 ]
[1.025 .42211 0 -7.5 ]
[1.025 .42211 10 7.5 ]
[.01131 .0779 -18 -4.5 ]
[.01131 .0779 0 4.5 ]
[.01131 .19263 -18 -4.5 ]
[.01131 .19263 0 4.5 ]
[.01131 .30737 -12 -4.5 ]
[.01131 .30737 0 4.5 ]
[.01131 .53684 -6 -4.5 ]
[.01131 .53684 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 15 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.21429 .42211 m
.21429 .42836 L
s
[(20)] .21429 .40961 0 1 Mshowa
.40476 .42211 m
.40476 .42836 L
s
[(40)] .40476 .40961 0 1 Mshowa
.59524 .42211 m
.59524 .42836 L
s
[(60)] .59524 .40961 0 1 Mshowa
.78571 .42211 m
.78571 .42836 L
s
[(80)] .78571 .40961 0 1 Mshowa
.97619 .42211 m
.97619 .42836 L
s
[(100)] .97619 .40961 0 1 Mshowa
.125 Mabswid
.07143 .42211 m
.07143 .42586 L
s
.11905 .42211 m
.11905 .42586 L
s
.16667 .42211 m
.16667 .42586 L
s
.2619 .42211 m
.2619 .42586 L
s
.30952 .42211 m
.30952 .42586 L
s
.35714 .42211 m
.35714 .42586 L
s
.45238 .42211 m
.45238 .42586 L
s
.5 .42211 m
.5 .42586 L
s
.54762 .42211 m
.54762 .42586 L
s
.64286 .42211 m
.64286 .42586 L
s
.69048 .42211 m
.69048 .42586 L
s
.7381 .42211 m
.7381 .42586 L
s
.83333 .42211 m
.83333 .42586 L
s
.88095 .42211 m
.88095 .42586 L
s
.92857 .42211 m
.92857 .42586 L
s
.25 Mabswid
0 .42211 m
1 .42211 L
s
gsave
1.025 .42211 -61 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.02381 .0779 m
.03006 .0779 L
s
[(-15)] .01131 .0779 1 0 Mshowa
.02381 .19263 m
.03006 .19263 L
s
[(-10)] .01131 .19263 1 0 Mshowa
.02381 .30737 m
.03006 .30737 L
s
[(-5)] .01131 .30737 1 0 Mshowa
.02381 .53684 m
.03006 .53684 L
s
[(5)] .01131 .53684 1 0 Mshowa
.125 Mabswid
.02381 .10085 m
.02756 .10085 L
s
.02381 .12379 m
.02756 .12379 L
s
.02381 .14674 m
.02756 .14674 L
s
.02381 .16969 m
.02756 .16969 L
s
.02381 .21558 m
.02756 .21558 L
s
.02381 .23853 m
.02756 .23853 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28442 m
.02756 .28442 L
s
.02381 .33032 m
.02756 .33032 L
s
.02381 .35327 m
.02756 .35327 L
s
.02381 .37621 m
.02756 .37621 L
s
.02381 .39916 m
.02756 .39916 L
s
.02381 .44505 m
.02756 .44505 L
s
.02381 .468 m
.02756 .468 L
s
.02381 .49095 m
.02756 .49095 L
s
.02381 .5139 m
.02756 .5139 L
s
.02381 .05495 m
.02756 .05495 L
s
.02381 .032 m
.02756 .032 L
s
.02381 .00906 m
.02756 .00906 L
s
.02381 .55979 m
.02756 .55979 L
s
.02381 .58274 m
.02756 .58274 L
s
.02381 .60569 m
.02756 .60569 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(u) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.996 0 0 r
.5 Mabswid
.02476 .60332 m
.02594 .58597 L
.027 .57399 L
.0294 .55219 L
.03373 .52264 L
.03878 .49733 L
.04355 .47882 L
.05305 .45107 L
.06336 .4289 L
.08525 .39572 L
.10545 .37397 L
.14476 .34362 L
.18256 .32252 L
.22281 .30493 L
.26154 .29106 L
.30272 .27859 L
.34239 .26821 L
.38055 .25937 L
.42115 .25094 L
.46024 .2436 L
.50178 .23649 L
.54181 .2302 L
.58032 .22459 L
.62128 .21903 L
.66073 .21403 L
.69867 .2095 L
.73905 .20495 L
.77792 .20081 L
.81924 .19663 L
.85904 .19281 L
.89734 .1893 L
.93808 .18573 L
.97619 .18253 L
s
.02476 .59722 m
.03373 .53542 L
.04355 .48188 L
.04851 .46265 L
.05381 .44558 L
.06336 .4209 L
.0854 .38081 L
.10545 .35511 L
.14534 .31872 L
.18372 .29357 L
.22454 .27273 L
.26385 .25632 L
.30165 .24291 L
.3419 .23049 L
.38063 .21995 L
.42181 .20993 L
.46148 .20121 L
.49964 .19354 L
.54024 .18602 L
.57933 .17932 L
.62087 .1727 L
.6609 .16675 L
.69941 .16136 L
.74038 .15596 L
.77982 .15104 L
.81776 .14655 L
.85814 .14199 L
.89701 .13781 L
.93833 .13357 L
.97619 .12985 L
s
.02476 .58861 m
.03373 .54172 L
.04355 .48007 L
.04851 .45812 L
.05381 .43876 L
.06336 .41092 L
.07469 .38539 L
.0854 .36597 L
.10545 .33726 L
.14383 .29796 L
.18465 .26808 L
.22396 .24576 L
.26176 .2281 L
.30201 .21214 L
.34074 .19884 L
.38193 .18636 L
.42159 .17564 L
.45975 .16628 L
.50035 .15719 L
.53944 .14914 L
.58098 .14123 L
.62101 .13415 L
.65952 .12777 L
.70049 .12139 L
.73993 .11561 L
.77787 .11034 L
.81825 .10501 L
.85712 .10013 L
.89844 .09519 L
.93825 .09065 L
.97619 .0865 L
s
.02476 .57981 m
.02594 .59272 L
.027 .59522 L
.02824 .59157 L
.0294 .58396 L
.03373 .54544 L
.03884 .50545 L
.04355 .47679 L
.05305 .4342 L
.06336 .40101 L
.07308 .37674 L
.08379 .355 L
.10545 .32087 L
.12484 .29727 L
.1457 .27648 L
.18688 .24424 L
.22655 .22011 L
.26471 .20101 L
.30531 .18375 L
.3444 .16934 L
.38594 .15584 L
.42597 .14423 L
.46448 .13409 L
.50544 .12425 L
.54489 .11552 L
.58282 .10774 L
.62321 .10001 L
.66208 .09305 L
.7034 .0861 L
.7432 .07979 L
.78149 .07404 L
.82224 .06824 L
.86146 .06293 L
.89918 .05805 L
.93934 .05308 L
.97619 .04871 L
s
.02476 .57125 m
.04355 .47296 L
.05312 .4268 L
.06336 .39148 L
.07376 .36388 L
.08345 .3429 L
.10545 .30572 L
.12674 .27828 L
.14686 .25713 L
.18523 .22497 L
.22606 .19827 L
.26537 .17722 L
.30317 .16 L
.34341 .14406 L
.38215 .13051 L
.42333 .11762 L
.463 .10641 L
.50115 .09654 L
.54176 .08687 L
.58085 .07825 L
.62239 .06973 L
.66242 .06206 L
.70093 .05512 L
.74189 .04817 L
.78134 .04183 L
.81927 .03604 L
.85966 .03018 L
.89852 .02479 L
.93984 .01932 L
.97619 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{226.5, 140.688},
  ImageMargins->{{50.625, 0}, {0, 0}},
  ImageRegion->{{-0.062096, 1.06598}, {-0.000534, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003R0000S1000`40O003h00O5Goo00<007ooOol0
bWoo000EOol00`00Oomoo`3:Ool001Eoo`800<]oo`005Goo00<007ooOol0[7oo2g`04goo000EOol0
0`00Oomoo`2XOol4O00NOol001Eoo`03001oogoo0:=oo`El029oo`005Goo0P00W7oo27`09goo000E
Ool00`00Oomoo`2DOol7O00_Ool001Eoo`03001oogoo08aoo`Ql03Ioo`005Goo00<007ooOol0Q7oo
27`09Woo1G`04goo000EOol20020Ool5O00WOol7O00HOol001Eoo`03001oogoo07]oo`Al02Aoo`Ql
01moo`005Goo00<007ooOol0MGoo1W`08Goo1g`09goo0007Ool50002Ool20005Ool00`00Oomoo`1_
Ool6O00OOol8O00^Ool000Uoo`05001oogooOol00002Ool00`00Oomoo`02Ool00`00Oomoo`1[Ool4
O00MOol8O00fOol000Uoo`03001oogoo00Aoo`03001oogoo009oo`8006Qoo`Al01Yoo`Ml03ioo`00
00=oo`0000000P0017oo00<007ooOol00Woo0P001Goo00<007ooOol0Hgoo17`067oo1W`0AGoo0009
Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`1MOol6O00HOol4O00[Ool=O00COol000Qo
o`8000Aoo`<000Aoo`03001oogoo05Qoo`El01Qoo`Il02Moo`Ql021oo`005Goo0P00EGoo17`05goo
1W`09Woo1g`0:7oo000EOol00`00Oomoo`1AOol3O00GOol4O00TOol8O00_Ool001Eoo`03001oogoo
04ioo`=l01Eoo`El025oo`Ml03Moo`005Goo00<007ooOol0C7oo0W`04Woo1W`07Woo27`0?Woo000E
Ool00`00Oomoo`18Ool4O00@Ool4O00NOol6O016Ool001Eoo`8004Eoo`Al011oo`Al01ioo`Al04ao
o`005Goo00<007ooOol0@Goo0g`047oo17`07Goo1G`0>7oo1G`04goo000EOol00`00Oomoo`0oOol2
O00@Ool3O00IOol8O00^Ool?O00HOol001Eoo`03001oogoo03eoo`9l00ioo`Al01Ioo`Il02ioo`Ql
02Moo`005Goo0P00>goo0g`037oo17`05Woo17`0;7oo27`0;goo000EOol00`00Oomoo`0gOol3O00;
Ool4O00DOol6O00YOol7O00gOol001Eoo`03001oogoo03Eoo`9l00]oo`=l019oo`Il02Moo`Ql03io
o`005Goo00<007ooOol0<Woo0g`02Woo0g`04Goo17`09Goo27`0AWoo000EOol00`00Oomoo`0`Ool2
O00;Ool2O00AOol3O00ROol7O01>Ool001Eoo`8002moo`9l00Uoo`Al00moo`Al01moo`Il05Eoo`00
5Goo00<007ooOol0:goo0g`01goo17`03goo17`07goo17`0Fgoo0007Ool50002Ool20005Ool00`00
Oomoo`0YOol2O008Ool2O00?Ool4O00MOol6O017Ool5O00COol000Uoo`05001oogooOol00002Ool0
0`00Oomoo`02Ool00`00Oomoo`0WOol2O008Ool2O00=Ool4O00IOol8O00nOol?O00HOol000Uoo`05
001oogooOol00002Ool00`00Oomoo`02Ool2000VOol2O008Ool2O00;Ool4O00HOol5O00nOol8O00W
Ool00003Ool00000008000Aoo`05001oogooOol00002Ool00`00Oomoo`02Ool00`00Oomoo`0TOol0
0g`0Oomoo`06Ool2O00:Ool3O00HOol4O00kOol8O00_Ool000Uoo`05001oogooOol00002Ool00`00
Oomoo`02Ool00`00Oomoo`0ROol2O007Ool2O00:Ool2O00EOol6O00hOol7O00gOol000Qoo`8000Ao
o`8000Eoo`03001oogoo021oo`9l00Ioo`=l00Yoo`9l015oo`Il02iooa1l03ioo`005Goo00<007oo
Ool07goo00=l07ooOol017oo0W`02Woo0g`03goo17`0;Goo1g`0CWoo000EOol2000NOol2O005Ool2
O009Ool3O00>Ool4O00YOol8O01EOol001Eoo`03001oogoo01aoo`03O01oogoo00=oo`9l00Uoo`9l
00eoo`Al02Eoo`Ql05eoo`005Goo00<007ooOol06goo00=l07ooOol00Woo0W`027oo0g`037oo0g`0
97oo1G`0IGoo000EOol00`00Oomoo`0JOol00g`0Oomoo`02Ool00g`0Oomoo`06Ool2O00=Ool2O00S
Ool4O01ZOol001Eoo`8001Yoo`04O01oogooOol2O007Ool2O00=Ool2O00OOol6O01^Ool001Eoo`03
001oogoo01Qoo`05O01oogooOoml0007Ool2O00;Ool4O00IOol8O01dOol001Eoo`03001oogoo01Mo
o`03O01oogoo009l00Ioo`9l00Uoo`Al01Moo`Il07aoo`005Goo00<007ooOol05Woo00Al07ooOoml
00Ioo`9l00Uoo`9l01Moo`Al089oo`005Goo0P005Woo00Al07ooOoml00Ioo`03O01oogoo00Moo`9l
01Ioo`=l08Ioo`005Goo00<007ooOol057oo00Al07ooO01l00Eoo`9l00Qoo`9l01Aoo`Al08Uoo`00
5Goo00<007ooOol04goo00=l07ooO0001Woo00=l07ooOol01Woo0W`04Woo17`0SGoo000EOol00`00
Oomoo`0BOol00g`0Ooml0005Ool2O007Ool2O00@Ool4O02AOol001Eoo`03001oogoo015oo`03O01o
og`000Eoo`03O01oogoo00Eoo`9l00ioo`Al09Eoo`005Goo0P004Goo00=l07ooO0001Goo00=l07oo
Ool017oo0W`037oo17`0VGoo000EOol00`00Oomoo`0?Ool00g`0Ooml0004Ool2O005Ool2O00;Ool3
O02MOol000ioo`8000Eoo`03001oogoo00moo`9l00Aoo`03O01oogoo00Aoo`03O01oogoo00Qoo`=l
0:1oo`003Goo00@007ooOol000Aoo`03001oogoo00ioo`9l00Aoo`03O01oogoo00=oo`9l00Uoo`9l
0:=oo`0047oo00<007ooOol00Woo0P003Woo00=l07ooO0000goo00=l07ooOol00Woo0W`027oo0g`0
YGoo0007Ool40003Ool20005Ool00`00Oomoo`0<Ool00g`0Ooml0003Ool00g`0Oomoo`02Ool00g`0
Oomoo`06Ool2O02XOol000ioo`03001oogoo00Aoo`03001oogoo00aoo`03O01oog`0009oo`04O01o
ogooOol2O007Ool2O02ZOol000ioo`<000Aoo`03001oogoo00]oo`03O01oog`0009oo`05O01oogoo
Ooml0006Ool3O02/Ool001Eoo`03001oogoo00Yoo`03O01oog`0009oo`05O01oogooOoml0005Ool2
O02_Ool001Eoo`8000Yoo`06O01oogooO01oog`00goo00=l07ooOol00Woo0W`0/Goo000EOol00`00
Oomoo`09Ool01G`0Ooml07ooO0000goo00Al07ooOomoo`9l0;=oo`005Goo00<007ooOol027oo00El
07ooO01oog`000=oo`05O01oogooOoml002eOol001Eoo`03001oogoo00Qoo`9l009oo`04O01oogoo
O003Ool00g`0Oomoo`2dOol001Eoo`8000Qoo`05O01oog`0Ooml0002Ool01G`0OomoogooO000]goo
000EOol00`00Oomoo`07Ool2O0001GooO01oogooO0000Woo0W`0^7oo000EOol00`00Oomoo`06Ool0
1g`0Ooml07ooO01oog`0009oo`03O01oogoo0;Qoo`005Goo00<007ooOol01Woo0W`000Aoog`0Ooml
009oo`03O01oogoo00aoo`@000=oo`8001ioo`<0009oo`8001aoo`<000Aoo`8001eoo`8000Aoo`80
01Uoo`D0009oo`8000Aoo`8000eoo`005Goo00<007ooOol01Goo00Ul07ooO01oog`0Ooml07ooO000
3goo00<007ooOol00goo00@007ooOol001ioo`04001oogoo0002Ool00`00Oomoo`0IOol01000Oomo
o`000Woo00@007ooOol001]oo`04001oogoo0002Ool01000Oomoo`006Woo00D007ooOomoo`00009o
o`04001oogoo0002Ool00`00Oomoo`0:Ool001Eoo`8000Ioo`9l0006Ooml07ooO01oog`04Goo00<0
07ooOol00Woo00@007ooOol001]oo`D00005Ool007ooOol0000KOol01000Oomoo`000Woo00@007oo
Ool001]oo`04001oogoo0002Ool01000Oomoo`006Woo00D007ooOomoo`00009oo`04001oogoo0002
Ool00`00Oomoo`0:Ool001Eoo`03001oogoo00Eoo`9l0005Ooml07`0Ooml000COol01@00Oomoogoo
00000Woo00<007ooOol06Goo00@007ooOol0009oo`04001oogoo000KOol30003Ool01000Oomoo`00
77oo0P000goo00@007ooOol001Yoo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol0
2Woo000EOol00`00Oomoo`04Ool2O0000gooO01l0002Ool00g`0Oomoo`0?Ool01000Oomoo`000Woo
00@007ooOol001aoo`03001oo`00009oo`04001oogoo000LOol00`00Oomoo`02Ool01000Oomoo`00
6goo00@007ooOol0009oo`04001oogoo000JOol01@00Oomoogoo00000Woo00@007ooOol0009oo`03
001oogoo00Yoo`005Goo00<007ooOol017oo0g`000Aoog`0Ooml01=oo`8000Aoo`8001ioo`8000=o
o`8001eoo`<000=oo`8001eoo`8000Aoo`8001Yoo`8000Aoo`8000Aoo`8000eoo`005Goo0P001Goo
00Il07ooO01l07ooO030Ool001Eoo`03001oogoo00=oo`Al0003Ooml07oo0<1oo`005Goo00<007oo
Ool00goo0g`000=oog`0Ool0`Goo000EOol00`00Oomoo`03Ool3O0000gooO01oo`2hOol200000goo
00000004Ool001Eoo`03001oogoo00=oo`9l0003Ooml07oo0;Yoo`03001oo`0000Eoo`0047oo2P00
17`0]@0027oo00<007ooOol017oo000EOol00`00Oomoo`02Ool3O00MOol00`00Oomoo`0ROol00`00
Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`08Ool200000goo00000004Ool0
01Eoo`03001oogoo009oo`=l0<Eoo`005Goo00<007ooOol00Woo0W`0aWoo000EOol20003Ool2O036
Ool001Eoo`03001oogoo009oo`9l0<Ioo`005Goo00@007ooOomoo`=l0<Ioo`005Goo00@007ooOomo
o`9l0<Moo`005Goo00@007ooOomoo`9l0<Moo`005Goo0P000Woo0W`0agoo000EOol01@00Oomoogoo
O000b7oo000EOol01@00OomoogooO000b7oo000EOol01@00OomoogooO000b7oo000EOol200000goo
O01l0038Ool001Eoo`03001oogoo009l0<Qoo`005Goo00@007ooOoml0<Uoo`005Goo00@007ooOoml
0<Uoo`005Goo0P000W`0bGoo000EOol01000Ooml07`0bGoo000EOol01000Ooml07`0bGoo000>Ool2
0005Ool01000Ooml07`0bGoo000=Ool01000Oomoo`0017oo00<007ooO000bWoo000@Ool00`00Oomo
o`02Ool00`00O01l003:Ool000ioo`8000Eoo`03001l07`00<Yoo`003Woo00<007ooOol017oo00<0
07`0O000bWoo000>Ool30004Ool00`00O01l003:Ool001Eoo`03001l07`00<Yoo`005Goo0g`0bWoo
000EOol2O03;Ool001Eoo`9l0<]oo`005Goo0W`0bgoo000EOol2O03;Ool001Eoo`9l0<]oo`005Goo
0W`0bgoo000EOol00g`0Oomoo`3:Ool001Eoo`03O00007oo0<Yoo`005Goo00<007ooOol0bWoo000E
Ool00`00Oomoo`3:Ool001Eoo`03001oogoo0<Yoo`00hWoo003ROol00>9oo`00hWoo003ROol00>9o
o`00hWoo003ROol00>9oo`0057oo1000bWoo000COol01000Oomoo`00bgoo000COol01000Oomoo`00
bgoo000BOol200000goo0000003;Ool00>9oo`00hWoo003ROol00>9oo`00hWoo003ROol00001\
\>"],
  ImageRangeCache->{{{-14.0625, 240.438}, {139.75, 0}} -> {-11.5195, \
-18.3948, 0.541233, 0.224628}}]
}, Open  ]],

Cell["\<\
This example shows that solutions of a second-order ordinary \
differential equation are easy to derive if we know the symmetries of the \
equation.\
\>", "Text",
  CellTags->{
  "second-order ordinary differential equation", "classification", 
    "quadrature"}],

Cell[TextData[
"Actually, we did not use in our calculations the complete theory of Lie \
discussed above. In this second example, we only used the existence of a \
certain symmetry. This symmetry is sufficient to determine the corresponding \
canonical variables. Thus, a canonical transformation can be carried out \
independently of the classification scheme by Lie. The canonical \
transformation of the equation into new variables simplified the \
representation. In both examples, this simplification was the main step \
toward the solution. However, in Lie\[CloseCurlyQuote]s theory, there exists \
a more efficient way to detect the solvability of the equation. In turn, \
there is a procedure which reduces the complete calculations to quadratures. \
The following section will discuss this procedure in detail."], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["4.4.2.2 The Integrating Factor Method", "Subsection",
  CellTags->"Method of integrating factor"],

Cell[TextData[{
  "In S",
  ButtonBox["ection 4.4.1.2,",
    ButtonData:>{"symmet2.nb", "Integrating factor"},
    ButtonStyle->"Hyperlink"],
  " we discussed the method of an integrating factor for a first-order ODE. \
We remarked that this method has a generalization to higher-order equations. \
In this section, we generalize the method to second-order equations. The main \
result of this procedure is that a second-order equation can be solved by \
pure quadratures if the equation possesses an appropriate number of \
symmetries. The solution procedure based on integrating factors is completely \
algorithmic. The algorithm consists of five steps which Lie discussed in his \
numerous papers (cf. ",
  ButtonBox["Engel and Heegaard [1912]",
    ButtonData:>{"Literat.nb", "Enge-12"},
    ButtonStyle->"Hyperlink"],
  ")."
}], "Text",
  CellTags->{
  "integrating factor", "quadrature", "algorithm for integrating factors"}],

Cell[TextData[{
  "According to Lie, we can state the integration procedure in the following \
way: If a second-order equation admits a finite symmetry of dimension ",
  Cell[BoxData[
      \(TraditionalForm\`r \[GreaterEqual] 2\)]],
  ", it can be integrated with a group-theoretic quadrature method by"
}], "Text",
  CellTags->{"integration procedure", "group theoretic quadrature"}],

Cell[TextData[{
  "Computing the Lie algebra ",
  Cell[BoxData[
      \(TraditionalForm\`L\_r\)]],
  ". A basis of  ",
  Cell[BoxData[
      \(TraditionalForm\`L\_r\)]],
  " is the set  ",
  Cell[BoxData[
      \(TraditionalForm\`\(v\& \[RightVector] \)\_1\)]],
  ",  ",
  Cell[BoxData[
      \(TraditionalForm\`\(v\& \[RightVector] \)\_2\)]],
  ", \[Ellipsis], ",
  Cell[BoxData[
      \(TraditionalForm\`\(v\& \[RightVector] \)\_r\)]],
  ". The tangent vector fields ",
  Cell[BoxData[
      \(TraditionalForm\`\(v\& \[RightVector] \)\_i\)]],
  " follow by appropriately specifying the group constants."
}], "ListItem",
  CellDingbat->"1.",
  CellTags->{
  "five steps of integration", "Lie algebra", "tangent vector field", 
    "group constant"}],

Cell[TextData[{
  "If ",
  Cell[BoxData[
      \(TraditionalForm\`r = 2\)]],
  ", go to step 3;\nif ",
  Cell[BoxData[
      \(TraditionalForm\`r > 2\)]],
  ",  distinguish any two-dimensional subalgebra ",
  Cell[BoxData[
      \(TraditionalForm\`L\_2\)]],
  " of ",
  Cell[BoxData[
      \(TraditionalForm\`L\_r\)]],
  ".\nIf ",
  Cell[BoxData[
      \(TraditionalForm\`r = 1\)]],
  ", the order of the equation may be lowered;\nif ",
  Cell[BoxData[
      \(TraditionalForm\`r = 0\)]],
  ", the group method is not useful."
}], "ListItem",
  CellDingbat->"2."],

Cell[TextData[{
  "Calculate the Lie determinants ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox[
            RowBox[{
              StyleBox["d",
                FontSlant->"Italic"], "\[CapitalDelta]"}]], "i"], 
        TraditionalForm]]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\)]],
  " and determine the two first integrals by integration. The Lie \
determinants are defined by"
}], "ListItem",
  CellDingbat->"3.",
  CellTags->{"determinant", "Lie determinant", "first integrals"}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox[
              RowBox[{
                StyleBox["d",
                  FontSlant->"Italic"], "\[CapitalDelta]"}]], "1"], " ", "=", 
          " ", 
          RowBox[{"det", "(", GridBox[{
                {
                  StyleBox["dx",
                    FontSlant->"Italic"], 
                  StyleBox["du",
                    FontSlant->"Italic"], 
                  StyleBox[\(du'\),
                    FontSlant->"Italic"]},
                {\(\[Xi]\_2\), \(\[Phi]\_2\), \(\[Phi]\_2\%'\)},
                {"1", \(u'\), "\[Omega]"}
                }], ")"}]}], ",", "        ", 
        RowBox[{
          SubscriptBox[
            StyleBox[
              RowBox[{
                StyleBox["d",
                  FontSlant->"Italic"], "\[CapitalDelta]"}]], "2"], "=", 
          " ", 
          RowBox[{"det", "(", GridBox[{
                {\(\[Xi]\_1\), \(\[Phi]\_1\), \(\[Phi]\_1'\)},
                {
                  StyleBox["dx",
                    FontSlant->"Italic"], 
                  StyleBox["du",
                    FontSlant->"Italic"], 
                  StyleBox[\(du\^'\),
                    FontSlant->"Italic"]},
                {"1", \(u'\), "\[Omega]"}
                }], ")"}]}]}], TraditionalForm]], "NumberedEquation",
  CellTags->"Lie matrix"],

Cell["and", "ListItem"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"\[CapitalDelta]", " ", "=", " ", 
          RowBox[{"det", 
            FormBox[
              RowBox[{"(", GridBox[{
                    {\(\[Xi]\_1\), \(\[Phi]\_1\), \(\[Phi]\_1\%'\)},
                    {\(\[Xi]\_2\), \(\[Phi]\_2\), \(\[Phi]\_2\%'\)},
                    {"1", \(u'\), "\[Omega]"}
                    }], ")"}],
              "TraditionalForm"]}]}], ","}], TraditionalForm]], 
  "NumberedEquation"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Xi]\_i\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_i\)]],
  " are the infinitesimals corresponding to the vector field ",
  Cell[BoxData[
      \(TraditionalForm\`v\&\[RightVector]\_i\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\_i\%'\)\)]],
  " denote the first extensions of the infinitesimals ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_i\)]],
  ". The first integrals ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\_i\)]],
  " related to the Lie determinants ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox[
            RowBox[{
              StyleBox["d",
                FontSlant->"Italic"], "\[CapitalDelta]"}]], "i"], 
        TraditionalForm]]],
  " are given by"
}], "ListItem",
  CellTags->"infinitesimals"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{\(\[Psi]\_i\), " ", "=", " ", 
          RowBox[{
            RowBox[{"\[Integral]", 
              FractionBox[
                SubscriptBox[
                  StyleBox[
                    RowBox[{
                      StyleBox["d",
                        FontSlant->"Italic"], "\[CapitalDelta]"}]], "i"], 
                "\[CapitalDelta]"]}], " ", "=", " ", \(c\_i\)}]}], ",", 
        "         ", \(i = 1\), ",", "2."}], TraditionalForm]], 
  "NumberedEquation",
  CellTags->"eq-21"],

Cell[TextData[{
  "The constants ",
  Cell[BoxData[
      \(TraditionalForm\`c\_i\)]],
  " denote the integration constants of the ODE."
}], "ListItem"],

Cell["\<\
Solve one of the two integrals with respect to the first-order \
derivative and substitute the result into the remaining relation.\
\>", 
  "ListItem",
  CellDingbat->"4."],

Cell[TextData[{
  "If we can solve the resulting relation from step 4 with respect to the \
unknown function ",
  Cell[BoxData[
      \(TraditionalForm\`u\)]],
  ", we end up with an explicit solution. Otherwise, we get the solution in \
an implicit form."
}], "ListItem",
  CellDingbat->"5."],

Cell[TextData[{
  "These five steps are implemented in the package ",
  StyleBox["MathLie.",
    FontSlant->"Italic"],
  " The functions of ",
  StyleBox["MathLie",
    FontSlant->"Italic"],
  " carry out the necessary calculations automatically. To show how the \
solution procedure works interactively, we demonstrate the algorithm by two \
examples. The functions needed for the interactive calculation are ",
  StyleBox["Infinitesimals[]", "MmaText"],
  " for the determination of the symmetries, the function ",
  StyleBox["SecondOrderAlgebras[] for the", "MmaText"],
  " extraction of the second-order subalgebras, the functions ",
  StyleBox["DeltaMatrix[]", "MmaText"],
  ", and the ",
  StyleBox["FirstIntegral[], which", "MmaText"],
  " are responsible for the determination of the integrals."
}], "Text",
  PageBreakBelow->True,
  CellTags->{
  "Infinitesimals[]", "SecondOrderAlgebras[]", "subalgebra", "DeltaMatrix[]", 
    "FirstIntegral[]", "determination of integrals"}],

Cell[TextData[StyleBox["Example 1",
  FontFamily->"Times New Roman",
  FontWeight->"Bold"]], "Text"],

Cell[TextData[
"The first example considers a non-linear second-order equation in which the \
nonlinearity is given by the square of the first derivative. This non-linear \
term is multiplied by a real constant \[Alpha]:"], "Text",
  CellTags->"nonlinear second-order equation"],

Cell[CellGroupData[{

Cell[BoxData[
    \(firstExample\  = \ 
      \[PartialD]\_{x, 2}u[x] - \[Alpha]\ \((\[PartialD]\_x u[x])\)\^2; 
    firstExample // LTF\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {\(\(-\[Alpha]\)\ u\_x\%2 + u\_\(x, x\) == 0\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output"]
}, Open  ]],

Cell[TextData[{
  "The infinitesimal symmetries are derived by the function ",
  StyleBox["Infinitesimals[], ", "MmaText"],
  "which is part of the package ",
  StyleBox["MathLie.",
    FontSlant->"Italic"]
}], "Text",
  CellTags->{"infinitesimal symmetries", "Infinitesimals[]"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(infi\  = \ 
      Infinitesimals[firstExample, u, x, {\[Alpha]}, 
        SubstitutionRules \[Rule] {\[PartialD]\_{x, 2}u[x]}]; infi // LTF\)], 
  "Input"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {
            RowBox[{\(\[Phi]\_1\), "==", 
              
              StyleBox[
                \(\(\(-E\^\(\(-u\)\ \[Alpha]\)\)\ k6 + 
                      E\^\(u\ \[Alpha]\)\ k7 + E\^\(u\ \[Alpha]\)\ k1\ x + 
                      k8\ \[Alpha] + k2\ x\ \[Alpha]\)\/\[Alpha]\),
                ScriptLevel->0]}]},
          {
            RowBox[{\(\[Xi]\_1\), "==", 
              RowBox[{
              "k4", "+", \(\((k5 + E\^\(\(-u\)\ \[Alpha]\)\ k6)\)\ x\), "-", 
                StyleBox[\(\(E\^\(\(-u\)\ \[Alpha]\)\ k3\)\/\[Alpha]\),
                  ScriptLevel->0], "-", \(k2\ x\^2\ \[Alpha]\)}]}]}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {
        Equal[ 
          Subscript[ \[Phi], 1], 
          Times[ 
            Power[ \[Alpha], -1], 
            Plus[ 
              Times[ -1, 
                Power[ E, 
                  Times[ -1, u, \[Alpha]]], k6], 
              Times[ 
                Power[ E, 
                  Times[ u, \[Alpha]]], k7], 
              Times[ 
                Power[ E, 
                  Times[ u, \[Alpha]]], k1, x], 
              Times[ k8, \[Alpha]], 
              Times[ k2, x, \[Alpha]]]]], 
        Equal[ 
          Subscript[ \[Xi], 1], 
          Plus[ k4, 
            Times[ 
              Plus[ k5, 
                Times[ 
                  Power[ E, 
                    Times[ -1, u, \[Alpha]]], k6]], x], 
            Times[ -1, 
              Power[ E, 
                Times[ -1, u, \[Alpha]]], k3, 
              Power[ \[Alpha], -1]], 
            Times[ -1, k2, 
              Power[ x, 2], \[Alpha]]]]}]]], "Output"]
}, Open  ]],

Cell[TextData[{
  "The option ",
  StyleBox["SubstitutionRules", "MmaText"],
  " is set to the second-order derivative ",
  Cell[BoxData[
      \(TraditionalForm\`u\_\(x, x\)\)]],
  " to help ",
  StyleBox["Infinitesimals[]", "MmaText"],
  " to find the side conditions more easily. The result is a symmetry group \
with eight group parameters ",
  Cell[BoxData[
      \(TraditionalForm\`k\_i\)]],
  StyleBox[", i ",
    FontSlant->"Italic"],
  "= 1,2,\[Ellipsis]8. The infinitesimals ",
  Cell[BoxData[
      \(TraditionalForm\`\[Xi]\_1 = xi[1]\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_1 = \ phi[1]\)]],
  " are represented in a pure function form. The group constants ",
  StyleBox["ki",
    FontSlant->"Italic"],
  " characterize the symmetries of the equation. We note that this \
eight-parameter group is the largest group a second-order ODE can have. Lie \
proved that such an equation allows a transformation reducing the original \
equation to the simple form ",
  Cell[BoxData[
      \(TraditionalForm\`\(y'\)'\  = 0. \)]],
  " This reduction is always possible if a second-order equation allows a \
symmetry group of order eight (Scheffers and ",
  ButtonBox["Lie [1891]",
    ButtonData:>{"Literat.nb", "Sche-1891"},
    ButtonStyle->"Hyperlink"],
  "). Thus, the above equation should be solvable."
}], "Text",
  CellTags->{
  "SubstitutionRules", "Infinitesimals[]", "eight parameter group", 
    "largest group of a second-order ODE", "solvable"}],

Cell[TextData[{
  "To detect that the non-linear second-order ODE is solvable, we examine the \
algebraic properties of the corresponding Lie algebra. If we can find a \
solvable subgroup of order two in the eight-dimensional algebra, we \
succeeded. This argument is based on the fact that all second-order Lie \
algebras are solvable. To detect all the solvable subgroups, we apply the \
function ",
  StyleBox["SecondOrderAlgebras[]", "MmaText"],
  " to the infinitesimals. This function determines all the second-order \
solvable subalgebras and represents them by a set of rules for the group \
constants:"
}], "Text",
  CellTags->{
  "Lie algebra", "subgroup of order two", "SecondOrderAlgebras[]", 
    "second-order solvable subalgebras", "group constants"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(secAlgebras\  = SecondOrderAlgebras[infi, {u}, {x}, {\[Alpha]}]\)], 
  "Input"],

Cell[BoxData[
    \({{{k1 \[Rule] 1}, {k2 \[Rule] 1}}, {{k1 \[Rule] 1}, {k5 \[Rule] 1}}, {{
          k1 \[Rule] 1}, {k7 \[Rule] 1}}, {{k1 \[Rule] 1}, {k8 \[Rule] 1}}, {{
          k2 \[Rule] 1}, {k5 \[Rule] 1}}, {{k2 \[Rule] 1}, {k6 \[Rule] 1}}, {{
          k2 \[Rule] 1}, {k8 \[Rule] 1}}, {{k3 \[Rule] 1}, {k4 \[Rule] 1}}, {{
          k3 \[Rule] 1}, {k5 \[Rule] 1}}, {{k3 \[Rule] 1}, {k6 \[Rule] 1}}, {{
          k3 \[Rule] 1}, {k8 \[Rule] 1}}, {{k4 \[Rule] 1}, {k5 \[Rule] 1}}, {{
          k4 \[Rule] 1}, {k7 \[Rule] 1}}, {{k4 \[Rule] 1}, {k8 \[Rule] 1}}, {{
          k5 \[Rule] 1}, {k6 \[Rule] 1}}, {{k5 \[Rule] 1}, {k7 \[Rule] 1}}, {{
          k5 \[Rule] 1}, {k8 \[Rule] 1}}, {{k6 \[Rule] 1}, {k8 \[Rule] 1}}, {{
          k7 \[Rule] 1}, {k8 \[Rule] 1}}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The function ",
  StyleBox["SecondOrderAlgebras[]", "MmaText"],
  " returns a list containing substitution rules for second-order algebras. \
The input of the function are the infinitesimals, the dependent and \
independent variables, and the parameters of the equation. This set of rules \
is useful in selecting one of the possible two-dimensional solvable \
subalgebras which will serve to solve the equation. For the following \
calculation, we select the seventh rule to represent the set of \
infinitesimals by"
}], "Text",
  CellTags->{"SecondOrderAlgebras[]", "infinitesimals", "subalgebra"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(infhelp\  = \ 
      \(\(\(\({{\(xi[1]\)[x, u]}, {\(phi[1]\)[x, u]}}\  /. infi\)\  /. 
                k8 \[Rule] \[Beta]\)\  /. 
              secAlgebras\[LeftDoubleBracket]7\[RightDoubleBracket]\)\  /. {
              k1 \[Rule] 0, k2 \[Rule] 0, k3 \[Rule] 0, k4 \[Rule] 0, 
              k5 \[Rule] 0, k6 \[Rule] 0, k7 \[Rule] 0, k8 \[Rule] 0}\)\  /. 
          u \[Rule] u[x] // Simplify\)], "Input"],

Cell[BoxData[
    \({{{\(-x\^2\)\ \[Alpha]}, {x + \[Beta]}}, {{0}, {\[Beta]}}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Actually, we changed the subgroup by choosing the group constant ",
  Cell[BoxData[
      \(TraditionalForm\`k8\)]],
  " to be an arbitrary constant \[Beta]. In addition to the infinitesimals of \
the subgroup, we need the ",
  ButtonBox["Lie matrix",
    ButtonData:>"Lie matrix",
    ButtonStyle->"Hyperlink"],
  " for the integration. The function ",
  StyleBox["DeltaMatrix[]", "MmaText"],
  " serves to create this kind of matrix, which is defined by relation \
(4.61). "
}], "Text",
  CellTags->{"Lie matrix", "DeltaMatrix[]", "matrix"}],

Cell[TextData[{
  "Lie's matrix, part of the integrating factor, is calculated by the \
function ",
  StyleBox["DeltaMatrix[]", "MmaText"],
  ". This function needs information on the independent and dependent \
variables on the right-hand side \[Omega] of the ODE, the order of the ODE, \
and the selected subgroup of the algebra:"
}], "Text",
  CellTags->{
  "Lie's matrix", "integrating factor", "DeltaMatrix[]", "subgroup"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[CapitalDelta]matrix = 
      DeltaMatrix[x, u, \[Alpha]\ \((\[PartialD]\_x u[x])\)\^2, 2, infhelp
        \ ]; TableForm[\[CapitalDelta]matrix] // LieTraditionalForm\)], 
  "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {\(\(-x\^2\)\ \[Alpha]\), \(x + \[Beta]\), 
            \(1 + 2\ x\ \[Alpha]\ u\_x\)},
          {"0", "\[Beta]", "0"},
          {"1", \(u\_x\), \(\[Alpha]\ u\_x\%2\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output"]
}, Open  ]],

Cell["\<\
The result is a 3\[Times]3 matrix containing the infinitesimals, \
the first prolongation of the two subgroups, and the right-hand side of the \
equation. The determinant of this matrix \
\>", "Text",
  CellTags->{
  "infinitesimals", "matrix", "first prolongation", "prolongation"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(Det[\[CapitalDelta]matrix] // LieTraditionalForm\)], "Input"],

Cell[BoxData[
    \(\(-\[Beta]\) - 2\ x\ \[Alpha]\ \[Beta]\ u\_x - 
      x\^2\ \[Alpha]\^2\ \[Beta]\ u\_x\%2\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "is a non-vanishing expression containing a second-order polynomial of \
first derivatives. The coefficients of this polynomial depend on the \
independent variable ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " and the parameters \[Alpha] and \[Beta]. Inserting the Lie matrix into \
equation (",
  ButtonBox["4.62",
    ButtonData:>"eq-21",
    ButtonStyle->"Hyperlink"],
  "), we are able to calculate the first integrals of the non-linear ODE"
}], "Text",
  CellTags->{
  "second-order polynomial", "first integral", "calculate first integrals"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(integrals\  = \ 
      Thread[FirstIntegral[x, u, \[CapitalDelta]matrix, {1, 2}] == 
          \ {c1, c2}]; \(integrals // LieTraditionalForm\) // TableForm\)], 
  "Input"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {
            RowBox[{
              RowBox[{
                StyleBox[\(1\/\(x\ \[Alpha]\)\),
                  ScriptLevel->0], "-", 
                StyleBox[\(1\/\(x\ \[Alpha]\ \((1 + x\ \[Alpha]\ u\_x)\)\)\),
                  ScriptLevel->0]}], "==", "c1"}]},
          {
            RowBox[{
              RowBox[{
                RowBox[{"-", 
                  StyleBox[\(1\/\(x\ \[Alpha]\)\),
                    ScriptLevel->0]}], 
                StyleBox["+",
                  ScriptLevel->0], 
                StyleBox[\(u\/\[Beta]\),
                  ScriptLevel->0], 
                StyleBox["-",
                  ScriptLevel->0], 
                
                StyleBox[
                  \(Log[1 + x\ \[Alpha]\ u\_x]\/\(\[Alpha]\ \[Beta]\)\),
                  ScriptLevel->0], 
                StyleBox["+",
                  ScriptLevel->0], 
                StyleBox[\(1\/\(x\ \[Alpha]\ \((1 + x\ \[Alpha]\ u\_x)\)\)\),
                  ScriptLevel->0]}], "==", "c2"}]}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {
        Equal[ 
          Plus[ 
            Times[ 
              Power[ x, -1], 
              Power[ \[Alpha], -1]], 
            Times[ -1, 
              Power[ x, -1], 
              Power[ \[Alpha], -1], 
              Power[ 
                Plus[ 1, 
                  Times[ x, \[Alpha], 
                    Subscript[ u, x]]], -1]]], c1], 
        Equal[ 
          Plus[ 
            Times[ -1, 
              Power[ x, -1], 
              Power[ \[Alpha], -1]], 
            Times[ u, 
              Power[ \[Beta], -1]], 
            Times[ -1, 
              Power[ \[Alpha], -1], 
              Power[ \[Beta], -1], 
              Log[ 
                Plus[ 1, 
                  Times[ x, \[Alpha], 
                    Subscript[ u, x]]]]], 
            Times[ 
              Power[ x, -1], 
              Power[ \[Alpha], -1], 
              Power[ 
                Plus[ 1, 
                  Times[ x, \[Alpha], 
                    Subscript[ u, x]]], -1]]], c2]}]]], "Output"]
}, Open  ]],

Cell[TextData[{
  "The result contains two expressions for the integrals combining the \
variable ",
  Cell[BoxData[
      \(TraditionalForm\`u\)]],
  " and its first-order derivative in an algebraic way. These two first \
integrals define two surfaces in the space ",
  Cell[BoxData[
      \(TraditionalForm\`\((x, u, u')\)\)]],
  ". The projection of the intersection of these two surfaces onto the ",
  Cell[BoxData[
      \(TraditionalForm\`\((x, u)\)\)]],
  "-plane defines the solution for which we are looking. The following figure \
 represents a case with fixed values ",
  Cell[BoxData[
      \(TraditionalForm\`c\_1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`c\_2\)]],
  ". "
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-017 1.04977 -0.0679587 1.04977 [
[.04138 .24075 -6 -8.74209 ]
[.04138 .24075 0 .25791 ]
[.18378 .18471 -17.6536 -9 ]
[.18378 .18471 .34636 0 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.49429 .06259 -15.8666 -9 ]
[.49429 .06259 2.13343 0 ]
[.664 -0.00409 -4.99101 -9 ]
[.664 -0.00409 1.00899 0 ]
[.29165 .07573 -9.31117 -15 ]
[.29165 .07573 .68883 0 ]
[.76189 .08851 0 -6.17016 ]
[.76189 .08851 12 2.82984 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.93905 .3598 0 -5.91371 ]
[.93905 .3598 6 3.08629 ]
[.91861 .21225 0 -10.0521 ]
[.91861 .21225 10 4.94788 ]
[.02136 .28234 -12 -2.75687 ]
[.02136 .28234 0 6.24313 ]
[.0139 .32909 -24 -2.79643 ]
[.0139 .32909 0 6.20357 ]
[.00622 .37728 -6 -2.83733 ]
[.00622 .37728 0 6.16267 ]
[-0.00171 .42696 -18 -2.87964 ]
[-0.00171 .42696 0 6.12036 ]
[-0.00989 .47822 -6 -2.92343 ]
[-0.00989 .47822 0 6.07657 ]
[-0.05457 .39542 -16 -4.72232 ]
[-0.05457 .39542 0 10.2777 ]
[ 0 0 0 0 ]
[ 1 .84114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.03716 .25514 m
.68874 0 L
s
.05093 .24975 m
.0557 .25425 L
s
[(0)] .04138 .24075 1 .94269 Mshowa
.19287 .19417 m
.19742 .1989 L
s
[(0.5)] .18378 .18471 .96152 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(1)] .3345 .12542 .86223 1 Mshowa
.50225 .07302 m
.50623 .07824 L
s
[(1.5)] .49429 .06259 .76295 1 Mshowa
.67126 .00684 m
.67489 .01231 L
s
[(2)] .664 -0.00409 .66367 1 Mshowa
.125 Mabswid
.07869 .23888 m
.08153 .2416 L
s
.10676 .22788 m
.10957 .23064 L
s
.13514 .21677 m
.13793 .21955 L
s
.16384 .20553 m
.1666 .20834 L
s
.22223 .18267 m
.22493 .18554 L
s
.25192 .17104 m
.25459 .17394 L
s
.28195 .15928 m
.28459 .16221 L
s
.31233 .14739 m
.31494 .15034 L
s
.37416 .12318 m
.37669 .12619 L
s
.40562 .11086 m
.40812 .1139 L
s
.43745 .0984 m
.43991 .10147 L
s
.46966 .08579 m
.47208 .08889 L
s
.53524 .06011 m
.53759 .06327 L
s
.56863 .04703 m
.57093 .05022 L
s
.60242 .0338 m
.60468 .03702 L
s
.63663 .0204 m
.63885 .02365 L
s
gsave
.29165 .07573 -70.3112 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.74959 .09308 m
.74344 .09536 L
s
[(-2)] .76189 .08851 -1 .37115 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.92653 .36374 m
.92027 .3657 L
s
[(2)] .93905 .3598 -1 .31416 Mshowa
.125 Mabswid
.77448 .13116 m
.77078 .1325 L
s
.79849 .16789 m
.79478 .16921 L
s
.82168 .20336 m
.81796 .20465 L
s
.86572 .27073 m
.86199 .27197 L
s
.88666 .30275 m
.88291 .30397 L
s
.90691 .33374 m
.90316 .33494 L
s
.72377 .05359 m
.72009 .05499 L
s
.69697 .0126 m
.69331 .01403 L
s
.94552 .3928 m
.94176 .39396 L
s
.96393 .42096 m
.96017 .4221 L
s
gsave
.91861 .21225 -61 -14.0521 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
55.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
55.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(u) show
56.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.0336 .2776 m
.03972 .27523 L
s
[(-5)] .02136 .28234 1 -0.38736 Mshowa
.02618 .32445 m
.03231 .32212 L
s
[(-2.5)] .0139 .32909 1 -0.37857 Mshowa
.01853 .37273 m
.02468 .37045 L
s
[(0)] .00622 .37728 1 -0.36948 Mshowa
.01064 .42252 m
.01681 .42029 L
s
[(2.5)] -0.00171 .42696 1 -0.36008 Mshowa
.0025 .47388 m
.00869 .47171 L
s
[(5)] -0.00989 .47822 1 -0.35035 Mshowa
.125 Mabswid
.03213 .28686 m
.03581 .28544 L
s
.03066 .29617 m
.03433 .29476 L
s
.02917 .30554 m
.03285 .30413 L
s
.02768 .31496 m
.03136 .31356 L
s
.02467 .33398 m
.02835 .3326 L
s
.02314 .34358 m
.02683 .3422 L
s
.02161 .35324 m
.0253 .35186 L
s
.02007 .36295 m
.02376 .36158 L
s
.01697 .38256 m
.02066 .38121 L
s
.0154 .39246 m
.0191 .39111 L
s
.01382 .40242 m
.01752 .40107 L
s
.01223 .41244 m
.01593 .4111 L
s
.00903 .43266 m
.01273 .43133 L
s
.00741 .44287 m
.01112 .44155 L
s
.00578 .45314 m
.00949 .45183 L
s
.00414 .46348 m
.00786 .46217 L
s
.03506 .2684 m
.03873 .26697 L
s
.03651 .25925 m
.04018 .25782 L
s
.00084 .48435 m
.00455 .48305 L
s
gsave
-0.05457 .39542 -77 -8.72232 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
57.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
57.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(u) show
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(') show
75.000000 14.437500 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .91114 L
0 .91114 L
closepath
clip
newpath
.40857 .71318 m .41716 .69633 L .42971 .70742 L .651 .753 .924 r
F
.40857 .71318 m .39592 .70218 L .41716 .69633 L F
.42971 .70742 m .43857 .69045 L .45101 .70162 L F
.42971 .70742 m .41716 .69633 L .43857 .69045 L F
.39592 .70218 m .40444 .68509 L .41716 .69633 L F
.39592 .70218 m .38309 .69102 L .40444 .68509 L F
.45101 .70162 m .46016 .68451 L .47248 .69578 L F
.45101 .70162 m .43857 .69045 L .46016 .68451 L F
.41716 .69633 m .42595 .67911 L .43857 .69045 L F
.41716 .69633 m .40444 .68509 L .42595 .67911 L F
.47248 .69578 m .48192 .67854 L .49413 .68989 L F
.47248 .69578 m .46016 .68451 L .48192 .67854 L F
.38309 .69102 m .39152 .67367 L .40444 .68509 L F
.38309 .69102 m .37007 .67969 L .39152 .67367 L F
.43857 .69045 m .44765 .67309 L .46016 .68451 L F
.43857 .69045 m .42595 .67911 L .44765 .67309 L F
.49413 .68989 m .50385 .67251 L .51595 .68395 L F
.49413 .68989 m .48192 .67854 L .50385 .67251 L F
.40444 .68509 m .41314 .6676 L .42595 .67911 L F
.40444 .68509 m .39152 .67367 L .41314 .6676 L F
.46016 .68451 m .46952 .66702 L .48192 .67854 L F
.46016 .68451 m .44765 .67309 L .46952 .66702 L F
.51595 .68395 m .52597 .66644 L .53795 .67798 L F
.51595 .68395 m .50385 .67251 L .52597 .66644 L F
.37007 .67969 m .37841 .66208 L .39152 .67367 L F
.37007 .67969 m .35685 .66819 L .37841 .66208 L F
.42595 .67911 m .43495 .66149 L .44765 .67309 L F
.42595 .67911 m .41314 .6676 L .43495 .66149 L F
.48192 .67854 m .49157 .6609 L .50385 .67251 L F
.48192 .67854 m .46952 .66702 L .49157 .6609 L F
.31451 .47225 m .30314 .60192 L .30689 .4878 L 0 0 .355 r
F
.53795 .67798 m .54826 .66033 L .56013 .67195 L .651 .753 .924 r
F
.53795 .67798 m .52597 .66644 L .54826 .66033 L F
.39152 .67367 m .40014 .65592 L .41314 .6676 L F
.39152 .67367 m .37841 .66208 L .40014 .65592 L F
.44765 .67309 m .45693 .65532 L .46952 .66702 L F
.44765 .67309 m .43495 .66149 L .45693 .65532 L F
.50385 .67251 m .5138 .65474 L .52597 .66644 L F
.50385 .67251 m .49157 .6609 L .5138 .65474 L F
.56013 .67195 m .57074 .65416 L .58249 .66588 L F
.56013 .67195 m .54826 .66033 L .57074 .65416 L F
.35685 .66819 m .3651 .65032 L .37841 .66208 L F
.35685 .66819 m .34343 .65653 L .3651 .65032 L F
.41314 .6676 m .42206 .64971 L .43495 .66149 L F
.41314 .6676 m .40014 .65592 L .42206 .64971 L F
.46952 .66702 m .4791 .64911 L .49157 .6609 L F
.46952 .66702 m .45693 .65532 L .4791 .64911 L F
.52597 .66644 m .53621 .64853 L .54826 .66033 L F
.52597 .66644 m .5138 .65474 L .53621 .64853 L F
.58249 .66588 m .59341 .64795 L .60503 .65976 L .65 .753 .924 r
F
.58249 .66588 m .57074 .65416 L .59341 .64795 L F
.31451 .47225 m .31401 .53412 L .30314 .60192 L 0 0 .355 r
F
.30383 .45893 m .31401 .53412 L .31451 .47225 L .867 .699 .174 r
F
.37841 .66208 m .38694 .64406 L .40014 .65592 L .651 .753 .924 r
F
.37841 .66208 m .3651 .65032 L .38694 .64406 L F
.43495 .66149 m .44415 .64345 L .45693 .65532 L F
.43495 .66149 m .42206 .64971 L .44415 .64345 L F
.49157 .6609 m .50144 .64285 L .5138 .65474 L F
.49157 .6609 m .4791 .64911 L .50144 .64285 L F
.54826 .66033 m .55881 .64227 L .57074 .65416 L F
.54826 .66033 m .53621 .64853 L .55881 .64227 L F
.60503 .65976 m .61626 .64169 L .62776 .6536 L .65 .753 .924 r
F
.60503 .65976 m .59341 .64795 L .61626 .64169 L F
.34343 .65653 m .35158 .63837 L .3651 .65032 L .651 .753 .924 r
F
.34343 .65653 m .32981 .64468 L .35158 .63837 L F
.40014 .65592 m .40897 .63775 L .42206 .64971 L F
.40014 .65592 m .38694 .64406 L .40897 .63775 L F
.45693 .65532 m .46643 .63714 L .4791 .64911 L F
.45693 .65532 m .44415 .64345 L .46643 .63714 L F
.5138 .65474 m .52398 .63655 L .53621 .64853 L F
.5138 .65474 m .50144 .64285 L .52398 .63655 L F
.57074 .65416 m .5816 .63596 L .59341 .64795 L .65 .753 .924 r
F
.57074 .65416 m .55881 .64227 L .5816 .63596 L F
.30373 .45807 m .30306 .47498 L .30383 .45893 L .867 .699 .174 r
F
.30383 .45893 m .30306 .47498 L .31401 .53412 L F
.62776 .6536 m .6393 .63538 L .65068 .64739 L .65 .753 .925 r
F
.62776 .6536 m .61626 .64169 L .6393 .63538 L F
.29884 .45275 m .30306 .47498 L .30373 .45807 L .958 .694 .494 r
F
.3651 .65032 m .37354 .63202 L .38694 .64406 L .651 .753 .924 r
F
.3651 .65032 m .35158 .63837 L .37354 .63202 L F
.53818 .73943 m .54853 .70077 L .56063 .72181 L .73 .657 .777 r
F
.53818 .73943 m .52598 .71692 L .54853 .70077 L F
.51576 .76157 m .52598 .71692 L .53818 .73943 L .745 .649 .754 r
F
.42206 .64971 m .43118 .6314 L .44415 .64345 L .651 .753 .924 r
F
.42206 .64971 m .40897 .63775 L .43118 .6314 L F
.51576 .76157 m .50346 .73694 L .52598 .71692 L .745 .649 .754 r
F
.49701 .77148 m .51576 .76157 L .50623 .7743 L .764 .641 .725 r
F
.49701 .77148 m .50346 .73694 L .51576 .76157 L F
.56063 .72181 m .57117 .68703 L .58317 .70699 L .718 .664 .795 r
F
.56063 .72181 m .54853 .70077 L .57117 .68703 L F
.4791 .64911 m .4889 .63079 L .50144 .64285 L .651 .753 .924 r
F
.4791 .64911 m .46643 .63714 L .4889 .63079 L F
.53621 .64853 m .5467 .63019 L .55881 .64227 L F
.53621 .64853 m .52398 .63655 L .5467 .63019 L F
.2994 .44142 m .30306 .47498 L .29884 .45275 L 0 0 .433 r
F
.59341 .64795 m .60458 .6296 L .61626 .64169 L .65 .753 .924 r
F
.59341 .64795 m .5816 .63596 L .60458 .6296 L F
.58317 .70699 m .59394 .67487 L .60582 .69402 L .709 .67 .81 r
F
.58317 .70699 m .57117 .68703 L .59394 .67487 L F
.65068 .64739 m .66254 .62902 L .67379 .64113 L .65 .753 .925 r
F
.65068 .64739 m .6393 .63538 L .66254 .62902 L F
.32981 .64468 m .33786 .62625 L .35158 .63837 L .651 .753 .924 r
F
.32981 .64468 m .31598 .63265 L .33786 .62625 L F
.48303 .76864 m .50346 .73694 L .49701 .77148 L .764 .641 .725 r
F
.38694 .64406 m .39568 .62562 L .40897 .63775 L .651 .753 .924 r
F
.38694 .64406 m .37354 .63202 L .39568 .62562 L F
.48303 .76864 m .48087 .76378 L .50346 .73694 L .764 .641 .725 r
F
.50346 .73694 m .51367 .69449 L .52598 .71692 L .734 .647 .762 r
F
.50346 .73694 m .49107 .71246 L .51367 .69449 L F
.48087 .76378 m .49107 .71246 L .50346 .73694 L .752 .638 .734 r
F
.31401 .53412 m .30306 .47498 L .32208 .51197 L .154 .157 .608 r
F
.30306 .47498 m .3095 .47462 L .32208 .51197 L 0 0 .433 r
F
.2994 .44142 m .3095 .47462 L .30306 .47498 L F
.52598 .71692 m .53631 .67976 L .54853 .70077 L .721 .655 .784 r
F
.52598 .71692 m .51367 .69449 L .53631 .67976 L F
.44415 .64345 m .45358 .62499 L .46643 .63714 L .651 .753 .924 r
F
.44415 .64345 m .43118 .6314 L .45358 .62499 L F
.60582 .69402 m .61684 .6638 L .62861 .68233 L .701 .676 .822 r
F
.60582 .69402 m .59394 .67487 L .61684 .6638 L F
.50144 .64285 m .51155 .62438 L .52398 .63655 L .651 .753 .924 r
F
.50144 .64285 m .4889 .63079 L .51155 .62438 L F
.48033 .76761 m .48087 .76378 L .48303 .76864 L .788 .633 .689 r
F
.54853 .70077 m .55905 .66706 L .57117 .68703 L .71 .663 .801 r
F
.54853 .70077 m .53631 .67976 L .55905 .66706 L F
.55881 .64227 m .56961 .62378 L .5816 .63596 L .65 .753 .924 r
F
.55881 .64227 m .5467 .63019 L .56961 .62378 L F
.47892 .76723 m .48087 .76378 L .48033 .76761 L .788 .633 .689 r
F
.48087 .76378 m .46842 .73616 L .49107 .71246 L .752 .638 .734 r
F
.46442 .76216 m .48087 .76378 L .47892 .76723 L .775 .629 .698 r
F
.46442 .76216 m .46842 .73616 L .48087 .76378 L F
.61626 .64169 m .62775 .62319 L .6393 .63538 L .65 .753 .925 r
F
.61626 .64169 m .60458 .6296 L .62775 .62319 L F
.62861 .68233 m .6399 .65351 L .65156 .67155 L .695 .681 .832 r
F
.62861 .68233 m .61684 .6638 L .6399 .65351 L F
.35158 .63837 m .35993 .61979 L .37354 .63202 L .651 .753 .924 r
F
.35158 .63837 m .33786 .62625 L .35993 .61979 L F
.67379 .64113 m .68598 .62261 L .69709 .63482 L .65 .753 .925 r
F
.67379 .64113 m .66254 .62902 L .68598 .62261 L F
.57117 .68703 m .58192 .65568 L .59394 .67487 L .702 .669 .815 r
F
.57117 .68703 m .55905 .66706 L .58192 .65568 L F
.40897 .63775 m .41801 .61916 L .43118 .6314 L .651 .753 .924 r
F
.40897 .63775 m .39568 .62562 L .41801 .61916 L F
.49107 .71246 m .50125 .67212 L .51367 .69449 L .723 .644 .77 r
F
.49107 .71246 m .47858 .68811 L .50125 .67212 L F
.46842 .73616 m .47858 .68811 L .49107 .71246 L .739 .634 .743 r
F
.29522 .43077 m .3095 .47462 L .2994 .44142 L 0 0 .169 r
F
.46643 .63714 m .47616 .61854 L .4889 .63079 L .651 .753 .924 r
F
.46643 .63714 m .45358 .62499 L .47616 .61854 L F
.51367 .69449 m .52397 .65877 L .53631 .67976 L .71 .653 .791 r
F
.51367 .69449 m .50125 .67212 L .52397 .65877 L F
.45311 .75962 m .46842 .73616 L .46442 .76216 L .775 .629 .698 r
F
.46842 .73616 m .45589 .70877 L .47858 .68811 L .739 .634 .743 r
F
.4477 .75794 m .46842 .73616 L .45311 .75962 L .761 .623 .708 r
F
.4477 .75794 m .45589 .70877 L .46842 .73616 L F
.52398 .63655 m .5344 .61792 L .5467 .63019 L .651 .753 .924 r
F
.52398 .63655 m .51155 .62438 L .5344 .61792 L F
.5816 .63596 m .59272 .61732 L .60458 .6296 L .65 .753 .924 r
F
.5816 .63596 m .56961 .62378 L .59272 .61732 L F
.65156 .67155 m .66313 .64379 L .67466 .66145 L .69 .685 .84 r
F
.65156 .67155 m .6399 .65351 L .66313 .64379 L F
.59394 .67487 m .60494 .64522 L .61684 .6638 L .695 .675 .827 r
F
.59394 .67487 m .58192 .65568 L .60494 .64522 L F
.32503 .59521 m .31401 .53412 L .33461 .54991 L .442 .356 .663 r
F
.30314 .60192 m .31401 .53412 L .32503 .59521 L 0 0 .355 r
F
.31401 .53412 m .32208 .51197 L .33461 .54991 L .154 .157 .608 r
F
.53631 .67976 m .54681 .64708 L .55905 .66706 L .701 .661 .807 r
F
.53631 .67976 m .52397 .65877 L .54681 .64708 L F
.6393 .63538 m .65112 .61673 L .66254 .62902 L .65 .753 .925 r
F
.6393 .63538 m .62775 .62319 L .65112 .61673 L F
.32062 .61557 m .30314 .60192 L .32503 .59521 L .562 .357 .561 r
F
.31598 .63265 m .32097 .6209 L .33786 .62625 L .651 .753 .924 r
F
.32097 .6209 m .32361 .61469 L .32854 .61869 L F
.32097 .6209 m .32854 .61869 L .33786 .62625 L F
.34302 .61446 m .32503 .59521 L .3471 .58846 L .602 .464 .665 r
F
.32361 .61469 m .32361 .61469 L .32912 .61852 L .562 .357 .561 r
F
.32361 .61469 m .32503 .59521 L .32912 .61852 L F
.34302 .61446 m .32912 .61852 L .34302 .61446 L .602 .464 .665 r
F
.33842 .62499 m .32971 .61835 L .34302 .61446 L .651 .753 .924 r
F
.33786 .62625 m .32912 .61852 L .33842 .62499 L F
.32912 .61852 m .32503 .59521 L .34302 .61446 L .602 .464 .665 r
F
.32912 .61852 m .32393 .61394 L .33842 .62499 L .651 .753 .924 r
F
.32361 .61469 m .32912 .61852 L .33786 .62625 L F
.33786 .62625 m .3403 .62069 L .35993 .61979 L F
.3403 .62069 m .34302 .61446 L .35591 .61618 L F
.3403 .62069 m .35591 .61618 L .35993 .61979 L F
.33612 .6584 m .34302 .61446 L .35956 .62766 L .602 .464 .665 r
F
.34302 .61446 m .3471 .58846 L .35591 .61618 L F
.3624 .6143 m .3471 .58846 L .36936 .58164 L .623 .528 .727 r
F
.3624 .6143 m .35591 .61618 L .3624 .6143 L F
.36124 .61689 m .35879 .61535 L .3624 .6143 L .651 .753 .924 r
F
.35993 .61979 m .35591 .61618 L .36124 .61689 L F
.35591 .61618 m .3471 .58846 L .3624 .6143 L .623 .528 .727 r
F
.35591 .61618 m .34611 .60738 L .36124 .61689 L .651 .753 .924 r
F
.37354 .63202 m .35993 .61979 L .3799 .61396 L F
.37354 .63202 m .3799 .61396 L .38095 .61386 L F
.38197 .61376 m .3799 .61396 L .38222 .61239 L .676 .557 .713 r
F
.37354 .63202 m .38105 .61362 L .38197 .61376 L .651 .753 .924 r
F
.37354 .63202 m .38185 .61402 L .39568 .62562 L F
.38197 .61376 m .38197 .61376 L .38284 .61389 L .676 .557 .713 r
F
.38197 .61376 m .38222 .61239 L .38284 .61389 L F
.4025 .61122 m .38222 .61239 L .40482 .60123 L .669 .586 .753 r
F
.4025 .61122 m .38284 .61389 L .4025 .61122 L F
.40005 .61641 m .3844 .61367 L .4025 .61122 L .651 .753 .924 r
F
.39568 .62562 m .38284 .61389 L .40005 .61641 L F
.38284 .61389 m .38222 .61239 L .4025 .61122 L .669 .586 .753 r
F
.38284 .61389 m .38219 .61329 L .40005 .61641 L .651 .753 .924 r
F
.38185 .61402 m .38284 .61389 L .39568 .62562 L F
.4227 .60951 m .40482 .60123 L .4275 .59174 L .665 .609 .782 r
F
.39568 .62562 m .40172 .61287 L .41801 .61916 L .651 .753 .924 r
F
.40172 .61287 m .40477 .61238 L .41801 .61916 L F
.4025 .61122 m .40984 .61157 L .41801 .61916 L F
.43118 .6314 m .41801 .61916 L .44052 .61265 L F
.44268 .60833 m .4275 .59174 L .45032 .58306 L .663 .627 .803 r
F
.41801 .61916 m .42146 .61206 L .44052 .61265 L .651 .753 .924 r
F
.42146 .61206 m .4293 .61068 L .44052 .61265 L F
.42269 .60952 m .4227 .60951 L .437 .60932 L .665 .609 .782 r
F
.4227 .60951 m .4275 .59174 L .437 .60932 L F
.44268 .60833 m .437 .60932 L .44268 .60833 L .663 .627 .803 r
F
.44222 .60926 m .44114 .6086 L .44268 .60833 L .651 .753 .924 r
F
.44052 .61265 m .437 .60932 L .44222 .60926 L F
.437 .60932 m .4275 .59174 L .44268 .60833 L .663 .627 .803 r
F
.437 .60932 m .42726 .60012 L .44222 .60926 L .651 .753 .924 r
F
.42269 .60952 m .437 .60932 L .44052 .61265 L F
.43118 .6314 m .44052 .61265 L .45358 .62499 L F
.45358 .62499 m .44052 .61265 L .45846 .60747 L F
.45358 .62499 m .45846 .60747 L .45992 .60734 L F
.46272 .60708 m .45846 .60747 L .46324 .60528 L .68 .632 .795 r
F
.45358 .62499 m .46004 .60701 L .46272 .60708 L .651 .753 .924 r
F
.46272 .60708 m .46272 .60708 L .4643 .60712 L .68 .632 .795 r
F
.46272 .60708 m .46324 .60528 L .4643 .60712 L F
.4889 .63079 m .49894 .61203 L .51155 .62438 L .651 .753 .924 r
F
.4889 .63079 m .47616 .61854 L .49894 .61203 L F
.48324 .60501 m .48324 .60501 L .49168 .60491 L .675 .645 .812 r
F
.48324 .60501 m .48617 .59584 L .49168 .60491 L F
.51155 .62438 m .52191 .60546 L .5344 .61792 L .651 .753 .924 r
F
.51155 .62438 m .49894 .61203 L .52191 .60546 L F
.50356 .6034 m .50356 .60339 L .51921 .60278 L .672 .655 .825 r
F
.50356 .60339 m .50925 .58698 L .51921 .60278 L F
.53623 .60138 m .5325 .5785 L .54507 .59788 L .669 .664 .836 r
F
.5344 .61792 m .52191 .60546 L .53623 .60138 L .65 .753 .924 r
F
.5344 .61792 m .53623 .60138 L .5383 .6012 L F
.54404 .6007 m .53623 .60138 L .54507 .59788 L .678 .666 .831 r
F
.5344 .61792 m .5384 .60076 L .54404 .6007 L .65 .753 .924 r
F
.5467 .63019 m .5344 .61792 L .55744 .61141 L F
.54404 .6007 m .54404 .6007 L .54687 .60067 L .678 .666 .831 r
F
.54404 .6007 m .54507 .59788 L .54687 .60067 L F
.5467 .63019 m .55744 .61141 L .56961 .62378 L .65 .753 .924 r
F
.56961 .62378 m .58067 .60485 L .59272 .61732 L F
.56961 .62378 m .55744 .61141 L .58067 .60485 L F
.5646 .59889 m .5646 .59889 L .57462 .59858 L .675 .673 .84 r
F
.5646 .59889 m .5684 .58911 L .57462 .59858 L F
.59272 .61732 m .60411 .59824 L .61602 .61081 L .65 .753 .925 r
F
.59272 .61732 m .58067 .60485 L .60411 .59824 L F
.58502 .59742 m .58502 .59741 L .60252 .59656 L .672 .678 .848 r
F
.58502 .59741 m .59191 .58063 L .60252 .59656 L F
.61293 .59575 m .61561 .57233 L .62771 .59034 L .67 .684 .854 r
F
.61602 .61081 m .60411 .59824 L .61293 .59575 L .65 .753 .925 r
F
.60458 .6296 m .61602 .61081 L .62775 .62319 L F
.60458 .6296 m .59272 .61732 L .61602 .61081 L F
.61619 .61722 m .60413 .59897 L .61293 .59575 L .675 .684 .851 r
F
.62585 .59468 m .61293 .59575 L .62771 .59034 L F
.61602 .61081 m .61293 .59575 L .6158 .59551 L .65 .753 .925 r
F
.61602 .61081 m .61579 .59494 L .62585 .59468 L F
.62775 .62319 m .61602 .61081 L .63952 .60425 L F
.62585 .59468 m .62585 .59468 L .63052 .59456 L .675 .684 .851 r
F
.62585 .59468 m .62771 .59034 L .63052 .59456 L F
.62775 .62319 m .63952 .60425 L .65112 .61673 L .65 .753 .925 r
F
.65112 .61673 m .66323 .59763 L .67469 .61022 L F
.65112 .61673 m .63952 .60425 L .66323 .59763 L F
.64646 .59308 m .64647 .59308 L .65864 .59259 L .673 .688 .857 r
F
.64647 .59308 m .65147 .58192 L .65864 .59259 L F
.67469 .61022 m .68713 .59096 L .69846 .60366 L .65 .753 .925 r
F
.67469 .61022 m .66323 .59763 L .68713 .59096 L F
.66695 .59176 m .66696 .59175 L .68691 .59072 L .671 .692 .861 r
F
.66696 .59175 m .67543 .57364 L .68691 .59072 L F
.68842 .59061 m .69959 .56548 L .71116 .58271 L .669 .696 .866 r
F
.69846 .60366 m .68713 .59096 L .68842 .59061 L .65 .753 .925 r
F
.68598 .62261 m .69846 .60366 L .70961 .61615 L F
.68598 .62261 m .67469 .61022 L .69846 .60366 L F
.6987 .60834 m .68714 .59105 L .68842 .59061 L .673 .696 .863 r
F
.70807 .58906 m .68842 .59061 L .71116 .58271 L F
.69846 .60366 m .68842 .59061 L .69235 .5903 L .65 .753 .925 r
F
.69846 .60366 m .69203 .5896 L .70807 .58906 L F
.70961 .61615 m .69846 .60366 L .72243 .59704 L F
.70807 .58906 m .70808 .58905 L .71524 .58882 L .673 .696 .863 r
F
.70808 .58905 m .71116 .58271 L .71524 .58882 L F
.70961 .61615 m .72243 .59704 L .73344 .60964 L .65 .753 .925 r
F
.73344 .60964 m .74661 .59037 L .75748 .60308 L F
.73344 .60964 m .72243 .59704 L .74661 .59037 L F
.72873 .58766 m .72873 .58765 L .74372 .587 L .671 .699 .867 r
F
.72873 .58765 m .73538 .57448 L .74372 .587 L F
.7634 .58575 m .7598 .56633 L .77096 .58317 L .67 .701 .871 r
F
.75748 .60308 m .74661 .59037 L .7634 .58575 L .65 .753 .925 r
F
.75748 .60308 m .7634 .58575 L .76434 .58568 L F
.76985 .58531 m .7634 .58575 L .77096 .58317 L .672 .701 .868 r
F
.75748 .60308 m .76443 .58546 L .76985 .58531 L .65 .753 .925 r
F
.74428 .62205 m .75748 .60308 L .76818 .61559 L F
.74428 .62205 m .73344 .60964 L .75748 .60308 L F
.76818 .61559 m .75748 .60308 L .78172 .59647 L F
.76985 .58531 m .76985 .58531 L .77232 .58524 L .672 .701 .868 r
F
.76985 .58531 m .77096 .58317 L .77232 .58524 L F
.76818 .61559 m .78172 .59647 L .79228 .60908 L .65 .753 .925 r
F
.79228 .60908 m .80618 .5898 L .81659 .60252 L F
.79228 .60908 m .78172 .59647 L .80618 .5898 L F
.79064 .58387 m .79065 .58387 L .80101 .58349 L .671 .704 .872 r
F
.79065 .58387 m .79545 .57499 L .80101 .58349 L F
.81659 .60252 m .83084 .58308 L .8411 .59591 L .65 .753 .925 r
F
.81659 .60252 m .80618 .5898 L .83084 .58308 L F
.81132 .58266 m .81133 .58265 L .82984 .58183 L .67 .706 .875 r
F
.81133 .58265 m .82014 .56687 L .82984 .58183 L F
.83701 .5814 m .84503 .55879 L .85562 .57528 L .668 .708 .877 r
F
.8411 .59591 m .83084 .58308 L .83701 .5814 L .65 .753 .925 r
F
.84147 .59983 m .83087 .58342 L .83701 .5814 L .671 .708 .875 r
F
.85268 .58038 m .83701 .5814 L .85562 .57528 L F
.8411 .59591 m .83701 .5814 L .83924 .58125 L .65 .753 .925 r
F
.8411 .59591 m .83918 .58081 L .85268 .58038 L F
.85268 .58038 m .85268 .58037 L .85875 .58019 L .671 .708 .875 r
F
.85268 .58037 m .85562 .57528 L .85875 .58019 L F
.87348 .57916 m .87348 .57914 L .88779 .57861 L .669 .709 .878 r
F
.87348 .57914 m .88058 .56719 L .88779 .57861 L F
.90957 .57746 m .90574 .55913 L .91589 .57542 L .668 .711 .88 r
F
.89415 .57814 m .90574 .55913 L .90957 .57746 L F
.91195 .57682 m .90613 .56259 L .91593 .57575 L .65 .753 .925 r
F
.89077 .58252 m .89415 .57814 L .91195 .57682 L F
.89415 .57814 m .90613 .56259 L .91195 .57682 L F
.89415 .57814 m .88058 .56719 L .90574 .55913 L .668 .711 .88 r
F
.89397 .57838 m .89365 .57816 L .89415 .57814 L .65 .753 .925 r
F
.89077 .58252 m .88779 .57861 L .89397 .57838 L F
.88779 .57861 m .88058 .56719 L .89415 .57814 L .668 .711 .88 r
F
.88779 .57861 m .88082 .56948 L .89397 .57838 L .65 .753 .925 r
F
.86583 .58924 m .87306 .57971 L .89077 .58252 L F
.87348 .57916 m .85562 .57528 L .88058 .56719 L .669 .709 .878 r
F
.87306 .57971 m .87348 .57916 L .88779 .57861 L .65 .753 .925 r
F
.87306 .57971 m .88779 .57861 L .89077 .58252 L F
.85875 .58019 m .85562 .57528 L .87348 .57916 L .669 .709 .878 r
F
.87303 .57974 m .87063 .57926 L .87348 .57916 L .65 .753 .925 r
F
.86583 .58924 m .85875 .58019 L .87303 .57974 L F
.85875 .58019 m .85572 .57631 L .87303 .57974 L F
.8411 .59591 m .8525 .58063 L .86583 .58924 L F
.8525 .58063 m .85572 .57631 L .85875 .58019 L F
.8525 .58063 m .85875 .58019 L .86583 .58924 L F
.86607 .59164 m .85875 .58019 L .87348 .57916 L .669 .709 .878 r
F
.87348 .57916 m .88082 .56948 L .88746 .57818 L .65 .753 .925 r
F
.87348 .57916 m .88746 .57818 L .88779 .57861 L F
.89088 .58351 m .88779 .57861 L .89415 .57814 L .668 .711 .88 r
F
.89088 .58351 m .89415 .57814 L .90957 .57746 L F
.89415 .57814 m .88082 .56948 L .90613 .56259 L .65 .753 .925 r
F
.89365 .57816 m .88082 .56948 L .89415 .57814 L F
.86607 .59164 m .87348 .57916 L .89088 .58351 L .669 .709 .878 r
F
.87348 .57916 m .88779 .57861 L .89088 .58351 L F
.87348 .57916 m .85572 .57631 L .88082 .56948 L .65 .753 .925 r
F
.87063 .57926 m .85572 .57631 L .87348 .57916 L F
.84147 .59983 m .83701 .5814 L .85268 .58038 L .671 .708 .875 r
F
.83924 .58125 m .83701 .5814 L .83918 .58081 L .65 .753 .925 r
F
.85268 .58038 m .83918 .58081 L .85572 .57631 L F
.84147 .59983 m .85268 .58038 L .86607 .59164 L .671 .708 .875 r
F
.85268 .58038 m .85875 .58019 L .86607 .59164 L F
.83188 .58166 m .84503 .55879 L .83701 .5814 L .668 .708 .877 r
F
.83792 .58115 m .84545 .56316 L .85572 .57631 L .65 .753 .925 r
F
.83084 .58308 m .83188 .58166 L .83792 .58115 L F
.83188 .58166 m .84545 .56316 L .83792 .58115 L F
.83188 .58166 m .82014 .56687 L .84503 .55879 L .668 .708 .877 r
F
.83182 .58175 m .83174 .58167 L .83188 .58166 L .65 .753 .925 r
F
.83084 .58308 m .82984 .58183 L .83182 .58175 L F
.82984 .58183 m .82014 .56687 L .83188 .58166 L .668 .708 .877 r
F
.82984 .58183 m .82041 .57005 L .83182 .58175 L .65 .753 .925 r
F
.80618 .5898 m .81074 .58346 L .83084 .58308 L F
.81132 .58266 m .79545 .57499 L .82014 .56687 L .67 .706 .875 r
F
.81074 .58346 m .81132 .58266 L .82984 .58183 L .65 .753 .925 r
F
.81074 .58346 m .82984 .58183 L .83084 .58308 L F
.80101 .58349 m .79545 .57499 L .81132 .58266 L .67 .706 .875 r
F
.81099 .58312 m .81 .58272 L .81132 .58266 L .65 .753 .925 r
F
.80618 .5898 m .80101 .58349 L .81099 .58312 L F
.80101 .58349 m .7956 .57688 L .81099 .58312 L F
.78172 .59647 m .79031 .58435 L .80618 .5898 L F
.79064 .58387 m .77096 .58317 L .79545 .57499 L .671 .704 .872 r
F
.79031 .58435 m .79064 .58387 L .80101 .58349 L .65 .753 .925 r
F
.79031 .58435 m .80101 .58349 L .80618 .5898 L F
.77232 .58524 m .77096 .58317 L .79064 .58387 L .671 .704 .872 r
F
.79003 .58474 m .78108 .58423 L .79064 .58387 L .65 .753 .925 r
F
.78172 .59647 m .77232 .58524 L .79003 .58474 L F
.77232 .58524 m .771 .58365 L .79003 .58474 L F
.75748 .60308 m .76976 .58543 L .78172 .59647 L F
.76976 .58543 m .771 .58365 L .77232 .58524 L F
.76976 .58543 m .77232 .58524 L .78172 .59647 L F
.78198 .59989 m .77232 .58524 L .79064 .58387 L .671 .704 .872 r
F
.79064 .58387 m .7956 .57688 L .80071 .58312 L .65 .753 .925 r
F
.79064 .58387 m .80071 .58312 L .80101 .58349 L F
.80632 .59161 m .80101 .58349 L .81132 .58266 L .67 .706 .875 r
F
.81132 .58266 m .82041 .57005 L .82935 .58122 L .65 .753 .925 r
F
.81132 .58266 m .82935 .58122 L .82984 .58183 L F
.83087 .58342 m .82984 .58183 L .83188 .58166 L .668 .708 .877 r
F
.83087 .58342 m .83188 .58166 L .83701 .5814 L F
.83188 .58166 m .82041 .57005 L .84545 .56316 L .65 .753 .925 r
F
.83174 .58167 m .82041 .57005 L .83188 .58166 L F
.80632 .59161 m .81132 .58266 L .83087 .58342 L .67 .706 .875 r
F
.81132 .58266 m .82984 .58183 L .83087 .58342 L F
.81132 .58266 m .7956 .57688 L .82041 .57005 L .65 .753 .925 r
F
.81 .58272 m .7956 .57688 L .81132 .58266 L F
.78198 .59989 m .79064 .58387 L .80632 .59161 L .671 .704 .872 r
F
.79064 .58387 m .80101 .58349 L .80632 .59161 L F
.79064 .58387 m .771 .58365 L .7956 .57688 L .65 .753 .925 r
F
.78108 .58423 m .771 .58365 L .79064 .58387 L F
.75783 .60828 m .74668 .59144 L .7634 .58575 L .672 .701 .868 r
F
.75783 .60828 m .7634 .58575 L .76985 .58531 L F
.76434 .58568 m .7634 .58575 L .76443 .58546 L .65 .753 .925 r
F
.76985 .58531 m .76443 .58546 L .771 .58365 L F
.75783 .60828 m .76985 .58531 L .78198 .59989 L .672 .701 .868 r
F
.76985 .58531 m .77232 .58524 L .78198 .59989 L F
.74927 .58649 m .7598 .56633 L .7634 .58575 L .67 .701 .871 r
F
.76645 .58491 m .7601 .57063 L .771 .58365 L .65 .753 .925 r
F
.74661 .59037 m .74927 .58649 L .76645 .58491 L F
.74927 .58649 m .7601 .57063 L .76645 .58491 L F
.74927 .58649 m .73538 .57448 L .7598 .56633 L .67 .701 .871 r
F
.74907 .58677 m .74871 .58652 L .74927 .58649 L .65 .753 .925 r
F
.74661 .59037 m .74372 .587 L .74907 .58677 L F
.74372 .587 m .73538 .57448 L .74927 .58649 L .67 .701 .871 r
F
.74372 .587 m .73557 .57747 L .74907 .58677 L .65 .753 .925 r
F
.72243 .59704 m .72821 .58844 L .74661 .59037 L F
.72873 .58766 m .71116 .58271 L .73538 .57448 L .671 .699 .867 r
F
.72821 .58844 m .72873 .58766 L .74372 .587 L .65 .753 .925 r
F
.72821 .58844 m .74372 .587 L .74661 .59037 L F
.71524 .58882 m .71116 .58271 L .72873 .58766 L .671 .699 .867 r
F
.72824 .58838 m .72579 .58779 L .72873 .58766 L .65 .753 .925 r
F
.72243 .59704 m .71524 .58882 L .72824 .58838 L F
.71524 .58882 m .71125 .58424 L .72824 .58838 L F
.69846 .60366 m .70781 .58946 L .72243 .59704 L F
.70781 .58946 m .71125 .58424 L .71524 .58882 L F
.70781 .58946 m .71524 .58882 L .72243 .59704 L F
.72259 .59982 m .71524 .58882 L .72873 .58766 L .671 .699 .867 r
F
.72873 .58766 m .73557 .57747 L .74322 .58641 L .65 .753 .925 r
F
.72873 .58766 m .74322 .58641 L .74372 .587 L F
.74668 .59144 m .74372 .587 L .74927 .58649 L .67 .701 .871 r
F
.74668 .59144 m .74927 .58649 L .7634 .58575 L F
.74927 .58649 m .73557 .57747 L .7601 .57063 L .65 .753 .925 r
F
.74871 .58652 m .73557 .57747 L .74927 .58649 L F
.72259 .59982 m .72873 .58766 L .74668 .59144 L .671 .699 .867 r
F
.72873 .58766 m .74372 .587 L .74668 .59144 L F
.72873 .58766 m .71125 .58424 L .73557 .57747 L .65 .753 .925 r
F
.72579 .58779 m .71125 .58424 L .72873 .58766 L F
.6987 .60834 m .68842 .59061 L .70807 .58906 L .673 .696 .863 r
F
.69235 .5903 m .68842 .59061 L .69203 .5896 L .65 .753 .925 r
F
.70807 .58906 m .69203 .5896 L .71125 .58424 L F
.6987 .60834 m .70807 .58906 L .72259 .59982 L .673 .696 .863 r
F
.70807 .58906 m .71524 .58882 L .72259 .59982 L F
.68732 .59067 m .69959 .56548 L .68842 .59061 L .669 .696 .866 r
F
.68871 .59052 m .69988 .57124 L .71125 .58424 L .65 .753 .925 r
F
.68713 .59096 m .68732 .59067 L .68871 .59052 L F
.68732 .59067 m .69988 .57124 L .68871 .59052 L F
.68732 .59067 m .67543 .57364 L .69959 .56548 L .669 .696 .866 r
F
.68731 .5907 m .68729 .59068 L .68732 .59067 L .65 .753 .925 r
F
.68713 .59096 m .68691 .59072 L .68731 .5907 L F
.68714 .59105 m .68691 .59072 L .68732 .59067 L .669 .696 .866 r
F
.68691 .59072 m .67543 .57364 L .68732 .59067 L F
.68714 .59105 m .68732 .59067 L .68842 .59061 L F
.68732 .59067 m .67563 .57807 L .69988 .57124 L .65 .753 .925 r
F
.68729 .59068 m .67563 .57807 L .68732 .59067 L F
.68691 .59072 m .67563 .57807 L .68731 .5907 L F
.66323 .59763 m .66695 .59176 L .68713 .59096 L F
.66695 .59176 m .67563 .57807 L .68612 .58983 L F
.66695 .59176 m .68612 .58983 L .68713 .59096 L F
.66695 .59176 m .65147 .58192 L .67543 .57364 L .671 .692 .861 r
F
.65864 .59259 m .65147 .58192 L .66695 .59176 L F
.66662 .59228 m .6657 .59182 L .66695 .59176 L .65 .753 .925 r
F
.66323 .59763 m .65864 .59259 L .66662 .59228 L F
.65864 .59259 m .65158 .58485 L .66662 .59228 L F
.63952 .60425 m .64597 .59388 L .66323 .59763 L F
.64646 .59308 m .62771 .59034 L .65147 .58192 L .673 .688 .857 r
F
.64597 .59388 m .64646 .59308 L .65864 .59259 L .65 .753 .925 r
F
.64597 .59388 m .65864 .59259 L .66323 .59763 L F
.63052 .59456 m .62771 .59034 L .64646 .59308 L .673 .688 .857 r
F
.64579 .59417 m .64005 .59334 L .64646 .59308 L .65 .753 .925 r
F
.63952 .60425 m .63052 .59456 L .64579 .59417 L F
.63052 .59456 m .62774 .59157 L .64579 .59417 L F
.61602 .61081 m .62565 .59501 L .63952 .60425 L F
.62565 .59501 m .62774 .59157 L .63052 .59456 L F
.62565 .59501 m .63052 .59456 L .63952 .60425 L F
.63966 .60825 m .63052 .59456 L .64646 .59308 L .673 .688 .857 r
F
.64646 .59308 m .65158 .58485 L .6581 .59201 L .65 .753 .925 r
F
.64646 .59308 m .6581 .59201 L .65864 .59259 L F
.6633 .59955 m .65864 .59259 L .66695 .59176 L .671 .692 .861 r
F
.6633 .59955 m .66695 .59176 L .68714 .59105 L F
.66695 .59176 m .68691 .59072 L .68714 .59105 L F
.66695 .59176 m .65158 .58485 L .67563 .57807 L .65 .753 .925 r
F
.6657 .59182 m .65158 .58485 L .66695 .59176 L F
.63966 .60825 m .64646 .59308 L .6633 .59955 L .673 .688 .857 r
F
.64646 .59308 m .65864 .59259 L .6633 .59955 L F
.64646 .59308 m .62774 .59157 L .65158 .58485 L .65 .753 .925 r
F
.64005 .59334 m .62774 .59157 L .64646 .59308 L F
.61619 .61722 m .61293 .59575 L .62585 .59468 L .675 .684 .851 r
F
.6158 .59551 m .61293 .59575 L .61579 .59494 L .65 .753 .925 r
F
.62585 .59468 m .61579 .59494 L .62774 .59157 L F
.61619 .61722 m .62585 .59468 L .63966 .60825 L .675 .684 .851 r
F
.62585 .59468 m .63052 .59456 L .63966 .60825 L F
.60531 .59623 m .61561 .57233 L .61293 .59575 L .67 .684 .854 r
F
.61563 .59498 m .61578 .57869 L .62774 .59157 L .65 .753 .925 r
F
.60411 .59824 m .60531 .59623 L .61563 .59498 L F
.60531 .59623 m .61578 .57869 L .61563 .59498 L F
.60531 .59623 m .59191 .58063 L .61561 .57233 L .67 .684 .854 r
F
.60518 .59643 m .60496 .59625 L .60531 .59623 L .65 .753 .925 r
F
.60411 .59824 m .60252 .59656 L .60518 .59643 L F
.60252 .59656 m .59191 .58063 L .60531 .59623 L .67 .684 .854 r
F
.60252 .59656 m .59201 .58546 L .60518 .59643 L .65 .753 .925 r
F
.58067 .60485 m .58423 .59878 L .60411 .59824 L F
.58502 .59742 m .5684 .58911 L .59191 .58063 L .672 .678 .848 r
F
.58423 .59878 m .58502 .59742 L .60252 .59656 L .65 .753 .925 r
F
.58423 .59878 m .60252 .59656 L .60411 .59824 L F
.57462 .59858 m .5684 .58911 L .58502 .59742 L .672 .678 .848 r
F
.58452 .59827 m .58258 .59754 L .58502 .59742 L .65 .753 .925 r
F
.58067 .60485 m .57462 .59858 L .58452 .59827 L F
.57462 .59858 m .56844 .59218 L .58452 .59827 L F
.55744 .61141 m .56411 .59975 L .58067 .60485 L .65 .753 .924 r
F
.5646 .59889 m .54507 .59788 L .5684 .58911 L .675 .673 .84 r
F
.56411 .59975 m .5646 .59889 L .57462 .59858 L .65 .753 .924 r
F
.56411 .59975 m .57462 .59858 L .58067 .60485 L F
.54687 .60067 m .54507 .59788 L .5646 .59889 L .675 .673 .84 r
F
.56368 .60051 m .5505 .59933 L .5646 .59889 L .65 .753 .924 r
F
.55744 .61141 m .54687 .60067 L .56368 .60051 L F
.54687 .60067 m .54508 .59885 L .56368 .60051 L F
.5344 .61792 m .54389 .60097 L .55744 .61141 L F
.54389 .60097 m .54508 .59885 L .54687 .60067 L F
.54389 .60097 m .54687 .60067 L .55744 .61141 L F
.55749 .61719 m .54687 .60067 L .5646 .59889 L .675 .673 .84 r
F
.5646 .59889 m .56844 .59218 L .57401 .59795 L .65 .753 .924 r
F
.5646 .59889 m .57401 .59795 L .57462 .59858 L F
.58072 .60788 m .57462 .59858 L .58502 .59742 L .672 .678 .848 r
F
.58502 .59742 m .59201 .58546 L .60158 .59557 L .65 .753 .925 r
F
.58502 .59742 m .60158 .59557 L .60252 .59656 L F
.60413 .59897 m .60252 .59656 L .60531 .59623 L .67 .684 .854 r
F
.60413 .59897 m .60531 .59623 L .61293 .59575 L F
.60531 .59623 m .59201 .58546 L .61578 .57869 L .65 .753 .925 r
F
.60496 .59625 m .59201 .58546 L .60531 .59623 L F
.58072 .60788 m .58502 .59742 L .60413 .59897 L .672 .678 .848 r
F
.58502 .59742 m .60252 .59656 L .60413 .59897 L F
.58502 .59742 m .56844 .59218 L .59201 .58546 L .65 .753 .925 r
F
.58258 .59754 m .56844 .59218 L .58502 .59742 L F
.55749 .61719 m .5646 .59889 L .58072 .60788 L .675 .673 .84 r
F
.5646 .59889 m .57462 .59858 L .58072 .60788 L F
.5646 .59889 m .54508 .59885 L .56844 .59218 L .65 .753 .924 r
F
.5505 .59933 m .54508 .59885 L .5646 .59889 L F
.53443 .62708 m .52191 .60705 L .53623 .60138 L .678 .666 .831 r
F
.53443 .62708 m .53623 .60138 L .54404 .6007 L F
.5383 .6012 m .53623 .60138 L .5384 .60076 L .65 .753 .924 r
F
.54404 .6007 m .5384 .60076 L .54508 .59885 L F
.53443 .62708 m .54404 .6007 L .55749 .61719 L .678 .666 .831 r
F
.54404 .6007 m .54687 .60067 L .55749 .61719 L F
.52373 .60215 m .5325 .5785 L .53623 .60138 L .669 .664 .836 r
F
.54293 .59946 m .53252 .58609 L .54508 .59885 L .65 .753 .924 r
F
.52191 .60546 m .52373 .60215 L .54293 .59946 L F
.52373 .60215 m .53252 .58609 L .54293 .59946 L F
.52373 .60215 m .50925 .58698 L .5325 .5785 L .669 .664 .836 r
F
.52347 .60261 m .52288 .6022 L .52373 .60215 L .65 .753 .924 r
F
.52191 .60546 m .51921 .60278 L .52347 .60261 L F
.51921 .60278 m .50925 .58698 L .52373 .60215 L .669 .664 .836 r
F
.51921 .60278 m .50922 .59281 L .52347 .60261 L .65 .753 .924 r
F
.49894 .61203 m .50265 .6051 L .52191 .60546 L .651 .753 .924 r
F
.50356 .6034 m .48617 .59584 L .50925 .58698 L .672 .655 .825 r
F
.50265 .6051 m .50356 .6034 L .51921 .60278 L .651 .753 .924 r
F
.50265 .6051 m .51921 .60278 L .52191 .60546 L F
.49168 .60491 m .48617 .59584 L .50356 .6034 L .672 .655 .825 r
F
.50281 .60479 m .499 .60358 L .50356 .6034 L .651 .753 .924 r
F
.49894 .61203 m .49168 .60491 L .50281 .60479 L F
.49168 .60491 m .48613 .59948 L .50281 .60479 L F
.47616 .61854 m .48269 .60606 L .49894 .61203 L F
.48324 .60501 m .46324 .60528 L .48617 .59584 L .675 .645 .812 r
F
.48269 .60606 m .48324 .60501 L .49168 .60491 L .651 .753 .924 r
F
.48269 .60606 m .49168 .60491 L .49894 .61203 L F
.4643 .60712 m .46324 .60528 L .48324 .60501 L .675 .645 .812 r
F
.48189 .60759 m .46323 .60609 L .46632 .6052 L .651 .753 .924 r
F
.48189 .60759 m .46632 .6052 L .48324 .60501 L F
.47616 .61854 m .4643 .60712 L .48189 .60759 L F
.4643 .60712 m .46323 .60609 L .48189 .60759 L F
.45358 .62499 m .4626 .60731 L .47616 .61854 L F
.4626 .60731 m .46323 .60609 L .4643 .60712 L F
.4626 .60731 m .4643 .60712 L .47616 .61854 L F
.47604 .62753 m .4643 .60712 L .48324 .60501 L .675 .645 .812 r
F
.48324 .60501 m .48613 .59948 L .4909 .60415 L .651 .753 .924 r
F
.48324 .60501 m .4909 .60415 L .49168 .60491 L F
.4989 .61682 m .49168 .60491 L .50356 .6034 L .672 .655 .825 r
F
.50356 .6034 m .50922 .59281 L .51799 .60156 L .651 .753 .924 r
F
.50356 .6034 m .51799 .60156 L .51921 .60278 L F
.52191 .60705 m .51921 .60278 L .52373 .60215 L .669 .664 .836 r
F
.52191 .60705 m .52373 .60215 L .53623 .60138 L F
.52373 .60215 m .50922 .59281 L .53252 .58609 L .65 .753 .924 r
F
.52288 .6022 m .50922 .59281 L .52373 .60215 L F
.4989 .61682 m .50356 .6034 L .52191 .60705 L .672 .655 .825 r
F
.50356 .6034 m .51921 .60278 L .52191 .60705 L F
.50356 .6034 m .48613 .59948 L .50922 .59281 L .651 .753 .924 r
F
.499 .60358 m .48613 .59948 L .50356 .6034 L F
.47604 .62753 m .48324 .60501 L .4989 .61682 L .675 .645 .812 r
F
.48324 .60501 m .49168 .60491 L .4989 .61682 L F
.48324 .60501 m .46632 .6052 L .48613 .59948 L .651 .753 .924 r
F
.45327 .63974 m .44045 .6157 L .45846 .60747 L .68 .632 .795 r
F
.45327 .63974 m .45846 .60747 L .46272 .60708 L F
.45992 .60734 m .45846 .60747 L .46004 .60701 L .651 .753 .924 r
F
.46272 .60708 m .46004 .60701 L .46323 .60609 L F
.45327 .63974 m .46272 .60708 L .47604 .62753 L .68 .632 .795 r
F
.46272 .60708 m .4643 .60712 L .47604 .62753 L F
.45846 .60747 m .45032 .58306 L .46324 .60528 L .663 .627 .803 r
F
.44268 .60833 m .45032 .58306 L .45846 .60747 L F
.45846 .60747 m .45009 .59345 L .46323 .60609 L .651 .753 .924 r
F
.44052 .61265 m .44268 .60833 L .45846 .60747 L F
.44268 .60833 m .45009 .59345 L .45846 .60747 L F
.44045 .6157 m .44268 .60833 L .45846 .60747 L .663 .627 .803 r
F
.44045 .6157 m .437 .60932 L .44268 .60833 L F
.44268 .60833 m .42726 .60012 L .45009 .59345 L .651 .753 .924 r
F
.44114 .6086 m .42726 .60012 L .44268 .60833 L F
.42269 .60952 m .43511 .60754 L .437 .60932 L F
.42146 .61206 m .42269 .60952 L .4293 .61068 L F
.41774 .62785 m .42269 .60952 L .44045 .6157 L .665 .609 .782 r
F
.42269 .60952 m .437 .60932 L .44045 .6157 L F
.42269 .60952 m .42726 .60012 L .43511 .60754 L .651 .753 .924 r
F
.42269 .60952 m .40984 .61157 L .4227 .60951 L .665 .609 .782 r
F
.40984 .61157 m .40482 .60123 L .4227 .60951 L F
.4025 .61122 m .40482 .60123 L .40984 .61157 L .669 .586 .753 r
F
.42143 .61212 m .40463 .60673 L .42726 .60012 L .651 .753 .924 r
F
.41801 .61916 m .40984 .61157 L .42143 .61212 L F
.40984 .61157 m .40463 .60673 L .42143 .61212 L F
.4025 .61122 m .4025 .61122 L .40984 .61157 L .669 .586 .753 r
F
.41774 .62785 m .40984 .61157 L .42269 .60952 L .665 .609 .782 r
F
.40172 .61287 m .4025 .61122 L .40477 .61238 L .651 .753 .924 r
F
.4025 .61122 m .40463 .60673 L .40984 .61157 L F
.39501 .64345 m .4025 .61122 L .41774 .62785 L .669 .586 .753 r
F
.4025 .61122 m .40984 .61157 L .41774 .62785 L F
.39501 .64345 m .38284 .61389 L .4025 .61122 L F
.4025 .61122 m .38219 .61329 L .40463 .60673 L .651 .753 .924 r
F
.3844 .61367 m .38219 .61329 L .4025 .61122 L F
.38185 .61402 m .38219 .61329 L .38284 .61389 L F
.37198 .66757 m .35956 .62766 L .3799 .61396 L .676 .557 .713 r
F
.37198 .66757 m .3799 .61396 L .38197 .61376 L F
.38095 .61386 m .3799 .61396 L .38105 .61362 L .651 .753 .924 r
F
.38197 .61376 m .38105 .61362 L .38219 .61329 L F
.37198 .66757 m .38197 .61376 L .39501 .64345 L .676 .557 .713 r
F
.38197 .61376 m .38284 .61389 L .39501 .64345 L F
.3799 .61396 m .36936 .58164 L .38222 .61239 L .623 .528 .727 r
F
.3624 .6143 m .36936 .58164 L .3799 .61396 L F
.3799 .61396 m .36848 .60077 L .38219 .61329 L .651 .753 .924 r
F
.35993 .61979 m .3624 .6143 L .3799 .61396 L F
.3624 .6143 m .36848 .60077 L .3799 .61396 L F
.35956 .62766 m .3624 .6143 L .3799 .61396 L .623 .528 .727 r
F
.35956 .62766 m .35591 .61618 L .3624 .6143 L F
.3624 .6143 m .34611 .60738 L .36848 .60077 L .651 .753 .924 r
F
.35879 .61535 m .34611 .60738 L .3624 .6143 L F
.34302 .61446 m .34302 .61446 L .35591 .61618 L .602 .464 .665 r
F
.34302 .61446 m .35591 .61618 L .35956 .62766 L F
.34302 .61446 m .34611 .60738 L .35591 .61618 L .651 .753 .924 r
F
.33612 .6584 m .32912 .61852 L .34302 .61446 L .602 .464 .665 r
F
.34302 .61446 m .32393 .61394 L .34611 .60738 L .651 .753 .924 r
F
.32971 .61835 m .32393 .61394 L .34302 .61446 L F
.32361 .61469 m .32449 .61443 L .32912 .61852 L F
.31677 .70888 m .32361 .61469 L .33612 .6584 L .562 .357 .561 r
F
.32361 .61469 m .32912 .61852 L .33612 .6584 L F
.3025 .62093 m .30314 .60192 L .32062 .61557 L F
.32062 .61557 m .32503 .59521 L .32361 .61469 L F
.32361 .61469 m .30194 .62044 L .32393 .61394 L .651 .753 .924 r
F
.31598 .63265 m .3025 .62093 L .32361 .61469 L F
.3025 .62093 m .30194 .62044 L .32361 .61469 L F
.29937 .71384 m .32062 .61557 L .31677 .70888 L .562 .357 .561 r
F
.32062 .61557 m .32361 .61469 L .31677 .70888 L F
.29937 .71384 m .3025 .62093 L .32062 .61557 L F
.32361 .61469 m .32393 .61394 L .32449 .61443 L .651 .753 .924 r
F
.69709 .63482 m .70961 .61615 L .72059 .62846 L .65 .753 .925 r
F
.69709 .63482 m .68598 .62261 L .70961 .61615 L F
.43979 .75654 m .45589 .70877 L .4477 .75794 L .761 .623 .708 r
F
.43979 .75654 m .43295 .73876 L .45589 .70877 L F
.45589 .70877 m .46598 .66387 L .47858 .68811 L .724 .629 .752 r
F
.45589 .70877 m .44327 .6816 L .46598 .66387 L F
.43295 .73876 m .44327 .6816 L .45589 .70877 L .743 .617 .718 r
F
.47858 .68811 m .4887 .6498 L .50125 .67212 L .71 .641 .778 r
F
.47858 .68811 m .46598 .66387 L .4887 .6498 L F
.61684 .6638 m .62812 .6354 L .6399 .65351 L .69 .68 .836 r
F
.61684 .6638 m .60494 .64522 L .62812 .6354 L F
.55905 .66706 m .56978 .63646 L .58192 .65568 L .694 .668 .82 r
F
.55905 .66706 m .54681 .64708 L .56978 .63646 L F
.67466 .66145 m .68653 .6345 L .69794 .65184 L .686 .689 .847 r
F
.67466 .66145 m .66313 .64379 L .68653 .6345 L F
.50125 .67212 m .5115 .6378 L .52397 .65877 L .699 .651 .798 r
F
.50125 .67212 m .4887 .6498 L .5115 .6378 L F
.43127 .75299 m .43295 .73876 L .43979 .75654 L .79 .614 .663 r
F
.29522 .43077 m .29686 .43781 L .3095 .47462 L 0 0 .169 r
F
.29418 .42473 m .29686 .43781 L .29522 .43077 L F
.42706 .75191 m .43295 .73876 L .43127 .75299 L .79 .614 .663 r
F
.43295 .73876 m .42037 .70661 L .44327 .6816 L .743 .617 .718 r
F
.415 .74745 m .43295 .73876 L .42706 .75191 L .771 .605 .673 r
F
.415 .74745 m .42037 .70661 L .43295 .73876 L F
.66254 .62902 m .67469 .61022 L .68598 .62261 L .65 .753 .925 r
F
.66254 .62902 m .65112 .61673 L .67469 .61022 L F
.44327 .6816 m .45327 .63974 L .46598 .66387 L .707 .624 .762 r
F
.44327 .6816 m .43055 .65463 L .45327 .63974 L F
.42037 .70661 m .43055 .65463 L .44327 .6816 L .723 .609 .729 r
F
.72059 .62846 m .73344 .60964 L .74428 .62205 L .65 .753 .925 r
F
.72059 .62846 m .70961 .61615 L .73344 .60964 L F
.58192 .65568 m .5929 .62658 L .60494 .64522 L .688 .674 .831 r
F
.58192 .65568 m .56978 .63646 L .5929 .62658 L F
.52397 .65877 m .53443 .62708 L .54681 .64708 L .692 .659 .813 r
F
.52397 .65877 m .5115 .6378 L .53443 .62708 L F
.6399 .65351 m .65146 .62606 L .66313 .64379 L .685 .685 .844 r
F
.6399 .65351 m .62812 .6354 L .65146 .62606 L F
.46598 .66387 m .47604 .62753 L .4887 .6498 L .696 .637 .786 r
F
.46598 .66387 m .45327 .63974 L .47604 .62753 L F
.69794 .65184 m .71011 .62553 L .72139 .64262 L .683 .692 .853 r
F
.69794 .65184 m .68653 .6345 L .71011 .62553 L F
.39963 .74443 m .42037 .70661 L .415 .74745 L .771 .605 .673 r
F
.42037 .70661 m .40773 .67485 L .43055 .65463 L .723 .609 .729 r
F
.39763 .74381 m .42037 .70661 L .39963 .74443 L .747 .594 .685 r
F
.39763 .74381 m .40773 .67485 L .42037 .70661 L F
.32503 .59521 m .33461 .54991 L .3471 .58846 L .442 .356 .663 r
F
.28874 .41458 m .29686 .43781 L .29418 .42473 L .915 .58 .113 r
F
.4887 .6498 m .4989 .61682 L .5115 .6378 L .688 .648 .805 r
F
.4887 .6498 m .47604 .62753 L .4989 .61682 L F
.54681 .64708 m .55749 .61719 L .56978 .63646 L .686 .667 .826 r
F
.54681 .64708 m .53443 .62708 L .55749 .61719 L F
.30194 .62044 m .30978 .60143 L .32393 .61394 L .651 .753 .924 r
F
.30194 .62044 m .28768 .60804 L .30978 .60143 L F
.39494 .74348 m .40773 .67485 L .39763 .74381 L .747 .594 .685 r
F
.39494 .74348 m .38439 .70821 L .40773 .67485 L F
.40773 .67485 m .41774 .62785 L .43055 .65463 L .698 .599 .741 r
F
.40773 .67485 m .39501 .64345 L .41774 .62785 L F
.38439 .70821 m .39501 .64345 L .40773 .67485 L .716 .578 .699 r
F
.60494 .64522 m .61619 .61722 L .62812 .6354 L .684 .68 .84 r
F
.60494 .64522 m .5929 .62658 L .61619 .61722 L F
.43055 .65463 m .44045 .6157 L .45327 .63974 L .687 .617 .772 r
F
.43055 .65463 m .41774 .62785 L .44045 .6157 L F
.66313 .64379 m .67499 .61707 L .68653 .6345 L .682 .689 .85 r
F
.66313 .64379 m .65146 .62606 L .67499 .61707 L F
.72139 .64262 m .73388 .61681 L .74503 .6337 L .68 .696 .858 r
F
.72139 .64262 m .71011 .62553 L .73388 .61681 L F
.38439 .70821 m .37198 .66757 L .39501 .64345 L .716 .578 .699 r
F
.5115 .6378 m .52191 .60705 L .53443 .62708 L .682 .658 .819 r
F
.5115 .6378 m .4989 .61682 L .52191 .60705 L F
.3471 .58846 m .3564 .55119 L .36936 .58164 L .549 .487 .738 r
F
.3471 .58846 m .33461 .54991 L .3564 .55119 L F
.56978 .63646 m .58072 .60788 L .5929 .62658 L .682 .674 .836 r
F
.56978 .63646 m .55749 .61719 L .58072 .60788 L F
.34731 .72382 m .35956 .62766 L .37198 .66757 L .693 .524 .654 r
F
.34731 .72382 m .33612 .6584 L .35956 .62766 L F
.33461 .54991 m .34336 .52102 L .3564 .55119 L .448 .428 .744 r
F
.33461 .54991 m .32208 .51197 L .34336 .52102 L F
.3651 .73136 m .37198 .66757 L .38439 .70821 L .749 .561 .64 r
F
.34822 .7293 m .37198 .66757 L .3651 .73136 L F
.34822 .7293 m .34731 .72382 L .37198 .66757 L F
.32208 .51197 m .33022 .49109 L .34336 .52102 L .307 .342 .734 r
F
.32208 .51197 m .3095 .47462 L .33022 .49109 L F
.62812 .6354 m .63966 .60825 L .65146 .62606 L .68 .684 .847 r
F
.62812 .6354 m .61619 .61722 L .63966 .60825 L F
.38169 .7371 m .38439 .70821 L .39494 .74348 L .785 .584 .628 r
F
.37587 .73578 m .38439 .70821 L .38169 .7371 L F
.3651 .73136 m .38439 .70821 L .37587 .73578 L .749 .561 .64 r
F
.3095 .47462 m .31698 .4614 L .33022 .49109 L .119 .222 .697 r
F
.3095 .47462 m .29686 .43781 L .31698 .4614 L F
.68653 .6345 m .6987 .60834 L .71011 .62553 L .679 .692 .856 r
F
.68653 .6345 m .67499 .61707 L .6987 .60834 L F
.32393 .61394 m .33208 .59477 L .34611 .60738 L .651 .753 .924 r
F
.32393 .61394 m .30978 .60143 L .33208 .59477 L F
.29686 .43781 m .30363 .43193 L .31698 .4614 L 0 .069 .616 r
F
.28827 .40793 m .29686 .43781 L .28874 .41458 L F
.28827 .40793 m .30363 .43193 L .29686 .43781 L F
.38222 .61239 m .3918 .57477 L .40482 .60123 L .634 .57 .766 r
F
.38222 .61239 m .36936 .58164 L .3918 .57477 L F
.74503 .6337 m .75783 .60828 L .76885 .625 L .677 .698 .862 r
F
.74503 .6337 m .73388 .61681 L .75783 .60828 L F
.38219 .61329 m .39104 .59411 L .40463 .60673 L .651 .753 .924 r
F
.38219 .61329 m .36848 .60077 L .39104 .59411 L F
.33245 .71775 m .33612 .6584 L .34731 .72382 L .744 .509 .574 r
F
.32995 .71747 m .33612 .6584 L .33245 .71775 L F
.31677 .70888 m .33612 .6584 L .32995 .71747 L .562 .357 .561 r
F
.5929 .62658 m .60413 .59897 L .61619 .61722 L .678 .679 .844 r
F
.5929 .62658 m .58072 .60788 L .60413 .59897 L F
.65146 .62606 m .6633 .59955 L .67499 .61707 L .677 .689 .853 r
F
.65146 .62606 m .63966 .60825 L .6633 .59955 L F
.36936 .58164 m .37866 .54845 L .3918 .57477 L .591 .55 .777 r
F
.36936 .58164 m .3564 .55119 L .37866 .54845 L F
.40482 .60123 m .41443 .56784 L .4275 .59174 L .641 .6 .792 r
F
.40482 .60123 m .3918 .57477 L .41443 .56784 L F
.71011 .62553 m .72259 .59982 L .73388 .61681 L .676 .696 .861 r
F
.71011 .62553 m .6987 .60834 L .72259 .59982 L F
.28768 .60804 m .29541 .58873 L .30978 .60143 L .651 .753 .924 r
F
.28768 .60804 m .27319 .59544 L .29541 .58873 L F
.76885 .625 m .78198 .59989 L .79286 .61648 L .675 .701 .866 r
F
.76885 .625 m .75783 .60828 L .78198 .59989 L F
.34611 .60738 m .35456 .58805 L .36848 .60077 L .651 .753 .924 r
F
.34611 .60738 m .33208 .59477 L .35456 .58805 L F
.28626 .40192 m .30363 .43193 L .28827 .40793 L 0 0 .493 r
F
.40463 .60673 m .4138 .58739 L .42726 .60012 L .651 .753 .924 r
F
.40463 .60673 m .39104 .59411 L .4138 .58739 L F
.46324 .60528 m .47329 .57484 L .48617 .59584 L .662 .641 .819 r
F
.46324 .60528 m .45032 .58306 L .47329 .57484 L F
.3564 .55119 m .36541 .52226 L .37866 .54845 L .539 .525 .788 r
F
.3564 .55119 m .34336 .52102 L .36541 .52226 L F
.46323 .60609 m .47311 .58673 L .48613 .59948 L .651 .753 .924 r
F
.46323 .60609 m .45009 .59345 L .47311 .58673 L F
.67499 .61707 m .68714 .59105 L .6987 .60834 L .675 .692 .859 r
F
.67499 .61707 m .6633 .59955 L .68714 .59105 L F
.4275 .59174 m .43726 .56086 L .45032 .58306 L .645 .621 .812 r
F
.4275 .59174 m .41443 .56784 L .43726 .56086 L F
.73388 .61681 m .74668 .59144 L .75783 .60828 L .674 .699 .865 r
F
.73388 .61681 m .72259 .59982 L .74668 .59144 L F
.3918 .57477 m .40123 .544 L .41443 .56784 L .612 .588 .802 r
F
.3918 .57477 m .37866 .54845 L .40123 .544 L F
.30978 .60143 m .31782 .58196 L .33208 .59477 L .651 .753 .924 r
F
.30978 .60143 m .29541 .58873 L .31782 .58196 L F
.28626 .40192 m .29018 .40265 L .30363 .43193 L 0 0 .493 r
F
.28388 .39025 m .29018 .40265 L .28626 .40192 L F
.79286 .61648 m .80632 .59161 L .81706 .6081 L .674 .703 .87 r
F
.79286 .61648 m .78198 .59989 L .80632 .59161 L F
.34336 .52102 m .35204 .49617 L .36541 .52226 L .475 .492 .795 r
F
.34336 .52102 m .33022 .49109 L .35204 .49617 L F
.36848 .60077 m .37724 .58128 L .39104 .59411 L .651 .753 .924 r
F
.36848 .60077 m .35456 .58805 L .37724 .58128 L F
.48617 .59584 m .49645 .56687 L .50925 .58698 L .661 .653 .831 r
F
.48617 .59584 m .47329 .57484 L .49645 .56687 L F
.34705 .72841 m .34731 .72382 L .34822 .7293 L .811 .567 .57 r
F
.34697 .72838 m .34731 .72382 L .34705 .72841 L F
.33245 .71775 m .34731 .72382 L .34697 .72838 L .744 .509 .574 r
F
.42726 .60012 m .43675 .58062 L .45009 .59345 L .651 .753 .924 r
F
.42726 .60012 m .4138 .58739 L .43675 .58062 L F
.48613 .59948 m .49634 .57996 L .50922 .59281 L F
.48613 .59948 m .47311 .58673 L .49634 .57996 L F
.54507 .59788 m .55593 .57026 L .5684 .58911 L .667 .671 .845 r
F
.54507 .59788 m .5325 .5785 L .55593 .57026 L F
.45032 .58306 m .46028 .55381 L .47329 .57484 L .648 .638 .826 r
F
.45032 .58306 m .43726 .56086 L .46028 .55381 L F
.54508 .59885 m .55601 .57932 L .56844 .59218 L .65 .753 .924 r
F
.54508 .59885 m .53252 .58609 L .55601 .57932 L F
.37866 .54845 m .3879 .52021 L .40123 .544 L .58 .575 .812 r
F
.37866 .54845 m .36541 .52226 L .3879 .52021 L F
.33022 .49109 m .33853 .47019 L .35204 .49617 L .397 .45 .798 r
F
.33022 .49109 m .31698 .4614 L .33853 .47019 L F
.41443 .56784 m .42406 .53865 L .43726 .56086 L .625 .614 .82 r
F
.41443 .56784 m .40123 .544 L .42406 .53865 L F
.27319 .59544 m .28081 .57582 L .29541 .58873 L .651 .753 .924 r
F
.27319 .59544 m .25848 .58265 L .28081 .57582 L F
.81706 .6081 m .83087 .58342 L .84147 .59983 L .672 .706 .873 r
F
.81706 .6081 m .80632 .59161 L .83087 .58342 L F
.33208 .59477 m .34042 .57514 L .35456 .58805 L .651 .753 .924 r
F
.33208 .59477 m .31782 .58196 L .34042 .57514 L F
.50925 .58698 m .51978 .55906 L .5325 .5785 L .66 .662 .841 r
F
.50925 .58698 m .49645 .56687 L .51978 .55906 L F
.39104 .59411 m .40011 .57446 L .4138 .58739 L .651 .753 .924 r
F
.39104 .59411 m .37724 .58128 L .40011 .57446 L F
.45009 .59345 m .45989 .57379 L .47311 .58673 L F
.45009 .59345 m .43675 .58062 L .45989 .57379 L F
.31698 .4614 m .3249 .44428 L .33853 .47019 L .303 .396 .792 r
F
.31698 .4614 m .30363 .43193 L .3249 .44428 L F
.5684 .58911 m .57955 .56219 L .59191 .58063 L .666 .678 .852 r
F
.5684 .58911 m .55593 .57026 L .57955 .56219 L F
.50922 .59281 m .51976 .57313 L .53252 .58609 L .65 .753 .924 r
F
.50922 .59281 m .49634 .57996 L .51976 .57313 L F
.27654 .37346 m .29018 .40265 L .28388 .39025 L 0 0 .346 r
F
.47329 .57484 m .48349 .5467 L .49645 .56687 L .65 .65 .837 r
F
.47329 .57484 m .46028 .55381 L .48349 .5467 L F
.36541 .52226 m .37443 .49644 L .3879 .52021 L .543 .559 .82 r
F
.36541 .52226 m .35204 .49617 L .37443 .49644 L F
.56844 .59218 m .57971 .57249 L .59201 .58546 L .65 .753 .925 r
F
.56844 .59218 m .55601 .57932 L .57971 .57249 L F
.62771 .59034 m .63949 .56418 L .65147 .58192 L .668 .688 .86 r
F
.62771 .59034 m .61561 .57233 L .63949 .56418 L F
.43726 .56086 m .44711 .53275 L .46028 .55381 L .633 .633 .833 r
F
.43726 .56086 m .42406 .53865 L .44711 .53275 L F
.29541 .58873 m .30333 .56895 L .31782 .58196 L .651 .753 .924 r
F
.29541 .58873 m .28081 .57582 L .30333 .56895 L F
.62774 .59157 m .63975 .57185 L .65158 .58485 L .65 .753 .925 r
F
.62774 .59157 m .61578 .57869 L .63975 .57185 L F
.40123 .544 m .41071 .51644 L .42406 .53865 L .603 .606 .828 r
F
.40123 .544 m .3879 .52021 L .41071 .51644 L F
.5325 .5785 m .54331 .55133 L .55593 .57026 L .66 .67 .849 r
F
.5325 .5785 m .51978 .55906 L .54331 .55133 L F
.35456 .58805 m .36322 .56825 L .37724 .58128 L .651 .753 .924 r
F
.35456 .58805 m .34042 .57514 L .36322 .56825 L F
.4138 .58739 m .42319 .56757 L .43675 .58062 L F
.4138 .58739 m .40011 .57446 L .42319 .56757 L F
.30363 .43193 m .31113 .41844 L .3249 .44428 L .193 .331 .776 r
F
.30363 .43193 m .29018 .40265 L .31113 .41844 L F
.47311 .58673 m .48324 .5669 L .49634 .57996 L .651 .753 .924 r
F
.47311 .58673 m .45989 .57379 L .48324 .5669 L F
.59191 .58063 m .60335 .55422 L .61561 .57233 L .665 .683 .858 r
F
.59191 .58063 m .57955 .56219 L .60335 .55422 L F
.49645 .56687 m .50691 .53954 L .51978 .55906 L .651 .661 .846 r
F
.49645 .56687 m .48349 .5467 L .50691 .53954 L F
.53252 .58609 m .54339 .56625 L .55601 .57932 L .65 .753 .924 r
F
.53252 .58609 m .51976 .57313 L .54339 .56625 L F
.35204 .49617 m .36081 .47269 L .37443 .49644 L .502 .54 .828 r
F
.35204 .49617 m .33853 .47019 L .36081 .47269 L F
.65147 .58192 m .66358 .55612 L .67543 .57364 L .667 .692 .864 r
F
.65147 .58192 m .63949 .56418 L .66358 .55612 L F
.59201 .58546 m .60362 .5656 L .61578 .57869 L .65 .753 .925 r
F
.59201 .58546 m .57971 .57249 L .60362 .5656 L F
.25848 .58265 m .26598 .56272 L .28081 .57582 L .651 .753 .924 r
F
.25848 .58265 m .24354 .56965 L .26598 .56272 L F
.46028 .55381 m .47038 .52647 L .48349 .5467 L .638 .647 .843 r
F
.46028 .55381 m .44711 .53275 L .47038 .52647 L F
.31782 .58196 m .32605 .56201 L .34042 .57514 L .651 .753 .924 r
F
.31782 .58196 m .30333 .56895 L .32605 .56201 L F
.65158 .58485 m .66394 .56497 L .67563 .57807 L .65 .753 .925 r
F
.65158 .58485 m .63975 .57185 L .66394 .56497 L F
.55593 .57026 m .56702 .54366 L .57955 .56219 L .659 .677 .856 r
F
.55593 .57026 m .54331 .55133 L .56702 .54366 L F
.71116 .58271 m .72394 .55738 L .73538 .57448 L .668 .699 .869 r
F
.71116 .58271 m .69959 .56548 L .72394 .55738 L F
.29018 .40265 m .29721 .39266 L .31113 .41844 L .067 .252 .744 r
F
.29018 .40265 m .27661 .37356 L .29721 .39266 L F
.27654 .37346 m .27661 .37356 L .29018 .40265 L 0 0 .346 r
F
.37724 .58128 m .38621 .56132 L .40011 .57446 L .651 .753 .924 r
F
.37724 .58128 m .36322 .56825 L .38621 .56132 L F
.71125 .58424 m .72435 .56435 L .73557 .57747 L .65 .753 .925 r
F
.71125 .58424 m .69988 .57124 L .72435 .56435 L F
.3879 .52021 m .39721 .4942 L .41071 .51644 L .579 .597 .835 r
F
.3879 .52021 m .37443 .49644 L .39721 .4942 L F
.42406 .53865 m .43379 .51164 L .44711 .53275 L .617 .628 .84 r
F
.42406 .53865 m .41071 .51644 L .43379 .51164 L F
.77096 .58317 m .78443 .55823 L .79545 .57499 L .668 .704 .874 r
F
.77096 .58317 m .7598 .56633 L .78443 .55823 L F
.43675 .58062 m .44646 .56063 L .45989 .57379 L .651 .753 .924 r
F
.43675 .58062 m .42319 .56757 L .44646 .56063 L F
.771 .58365 m .78485 .56375 L .7956 .57688 L .65 .753 .925 r
F
.771 .58365 m .7601 .57063 L .78485 .56375 L F
.61561 .57233 m .62736 .54632 L .63949 .56418 L .664 .688 .863 r
F
.61561 .57233 m .60335 .55422 L .62736 .54632 L F
.49634 .57996 m .5068 .55996 L .51976 .57313 L .65 .753 .924 r
F
.49634 .57996 m .48324 .5669 L .5068 .55996 L F
.51978 .55906 m .53052 .53231 L .54331 .55133 L .652 .669 .853 r
F
.51978 .55906 m .50691 .53954 L .53052 .53231 L F
.55601 .57932 m .56722 .5593 L .57971 .57249 L .65 .753 .925 r
F
.55601 .57932 m .54339 .56625 L .56722 .5593 L F
.67543 .57364 m .68786 .54812 L .69959 .56548 L .666 .696 .868 r
F
.67543 .57364 m .66358 .55612 L .68786 .54812 L F
.33853 .47019 m .34704 .44895 L .36081 .47269 L .454 .517 .833 r
F
.33853 .47019 m .3249 .44428 L .34704 .44895 L F
.27647 .37324 m .27661 .37356 L .27654 .37346 L 0 0 .346 r
F
.27625 .37279 m .27661 .37356 L .27647 .37324 L .727 .354 0 r
F
.28081 .57582 m .28862 .55572 L .30333 .56895 L .651 .753 .924 r
F
.28081 .57582 m .26598 .56272 L .28862 .55572 L F
.61578 .57869 m .62773 .55866 L .63975 .57185 L .65 .753 .925 r
F
.61578 .57869 m .60362 .5656 L .62773 .55866 L F
.27661 .37356 m .28315 .36693 L .29721 .39266 L 0 .162 .695 r
F
.27213 .35478 m .27661 .37356 L .27625 .37279 L F
.27213 .35478 m .28315 .36693 L .27661 .37356 L F
.48349 .5467 m .49387 .51993 L .50691 .53954 L .642 .659 .851 r
F
.48349 .5467 m .47038 .52647 L .49387 .51993 L F
.57955 .56219 m .59094 .536 L .60335 .55422 L .659 .683 .861 r
F
.57955 .56219 m .56702 .54366 L .59094 .536 L F
.73538 .57448 m .7485 .54934 L .7598 .56633 L .667 .701 .873 r
F
.73538 .57448 m .72394 .55738 L .7485 .54934 L F
.34042 .57514 m .34897 .55502 L .36322 .56825 L .651 .753 .924 r
F
.34042 .57514 m .32605 .56201 L .34897 .55502 L F
.67563 .57807 m .68834 .55802 L .69988 .57124 L .65 .753 .925 r
F
.67563 .57807 m .66394 .56497 L .68834 .55802 L F
.40011 .57446 m .40941 .55432 L .42319 .56757 L .651 .753 .924 r
F
.40011 .57446 m .38621 .56132 L .40941 .55432 L F
.73557 .57747 m .74903 .55741 L .7601 .57063 L .65 .753 .925 r
F
.73557 .57747 m .72435 .56435 L .74903 .55741 L F
.79545 .57499 m .80926 .55018 L .82014 .56687 L .667 .706 .876 r
F
.79545 .57499 m .78443 .55823 L .80926 .55018 L F
.44711 .53275 m .45711 .50617 L .47038 .52647 L .626 .644 .849 r
F
.44711 .53275 m .43379 .51164 L .45711 .50617 L F
.37443 .49644 m .38355 .47194 L .39721 .4942 L .552 .587 .843 r
F
.37443 .49644 m .36081 .47269 L .38355 .47194 L F
.63949 .56418 m .65156 .53846 L .66358 .55612 L .663 .692 .867 r
F
.63949 .56418 m .62736 .54632 L .65156 .53846 L F
.45989 .57379 m .46994 .55364 L .48324 .5669 L .651 .753 .924 r
F
.45989 .57379 m .44646 .56063 L .46994 .55364 L F
.7956 .57688 m .80982 .5568 L .82041 .57005 L .65 .753 .925 r
F
.7956 .57688 m .78485 .56375 L .80982 .5568 L F
.41071 .51644 m .42031 .49048 L .43379 .51164 L .599 .622 .846 r
F
.41071 .51644 m .39721 .4942 L .42031 .49048 L F
.85562 .57528 m .87014 .55073 L .88058 .56719 L .667 .71 .879 r
F
.85562 .57528 m .84503 .55879 L .87014 .55073 L F
.54331 .55133 m .55434 .52501 L .56702 .54366 L .653 .676 .859 r
F
.54331 .55133 m .53052 .53231 L .55434 .52501 L F
.51976 .57313 m .53056 .55296 L .54339 .56625 L .65 .753 .924 r
F
.51976 .57313 m .5068 .55996 L .53056 .55296 L F
.85572 .57631 m .8707 .55622 L .88082 .56948 L .65 .753 .925 r
F
.85572 .57631 m .84545 .56316 L .8707 .55622 L F
.69959 .56548 m .71234 .54016 L .72394 .55738 L .665 .699 .872 r
F
.69959 .56548 m .68786 .54812 L .71234 .54016 L F
.57971 .57249 m .59126 .5523 L .60362 .5656 L .65 .753 .925 r
F
.57971 .57249 m .56722 .5593 L .59126 .5523 L F
.24354 .56965 m .25091 .54939 L .26598 .56272 L .651 .753 .924 r
F
.24354 .56965 m .22835 .55644 L .25091 .54939 L F
.91589 .57542 m .93113 .55109 L .94112 .56736 L .667 .713 .882 r
F
.91589 .57542 m .90574 .55913 L .93113 .55109 L F
.91593 .57575 m .93168 .55565 L .94131 .56892 L .649 .753 .925 r
F
.91593 .57575 m .90613 .56259 L .93168 .55565 L F
.3249 .44428 m .33312 .42521 L .34704 .44895 L .4 .49 .836 r
F
.3249 .44428 m .31113 .41844 L .33312 .42521 L F
.30333 .56895 m .31146 .54867 L .32605 .56201 L .651 .753 .924 r
F
.30333 .56895 m .28862 .55572 L .31146 .54867 L F
.63975 .57185 m .65206 .55166 L .66394 .56497 L .65 .753 .925 r
F
.63975 .57185 m .62773 .55866 L .65206 .55166 L F
.7598 .56633 m .77326 .54133 L .78443 .55823 L .666 .704 .876 r
F
.7598 .56633 m .7485 .54934 L .77326 .54133 L F
.60335 .55422 m .61507 .52835 L .62736 .54632 L .659 .687 .866 r
F
.60335 .55422 m .59094 .536 L .61507 .52835 L F
.50691 .53954 m .51758 .51318 L .53052 .53231 L .645 .668 .857 r
F
.50691 .53954 m .49387 .51993 L .51758 .51318 L F
.36322 .56825 m .37209 .54797 L .38621 .56132 L .651 .753 .924 r
F
.36322 .56825 m .34897 .55502 L .37209 .54797 L F
.69988 .57124 m .71295 .55102 L .72435 .56435 L .65 .753 .925 r
F
.69988 .57124 m .68834 .55802 L .71295 .55102 L F
.82014 .56687 m .8343 .54214 L .84503 .55879 L .666 .708 .879 r
F
.82014 .56687 m .80926 .55018 L .8343 .54214 L F
.42319 .56757 m .43281 .54727 L .44646 .56063 L .651 .753 .924 r
F
.42319 .56757 m .40941 .55432 L .43281 .54727 L F
.7601 .57063 m .77393 .5504 L .78485 .56375 L .65 .753 .925 r
F
.7601 .57063 m .74903 .55741 L .77393 .5504 L F
.66358 .55612 m .67597 .53062 L .68786 .54812 L .662 .696 .871 r
F
.66358 .55612 m .65156 .53846 L .67597 .53062 L F
.47038 .52647 m .48067 .50023 L .49387 .51993 L .632 .656 .856 r
F
.47038 .52647 m .45711 .50617 L .48067 .50023 L F
.48324 .5669 m .49363 .54658 L .5068 .55996 L .65 .753 .924 r
F
.48324 .5669 m .46994 .55364 L .49363 .54658 L F
.82041 .57005 m .83501 .5498 L .84545 .56316 L .65 .753 .925 r
F
.82041 .57005 m .80982 .5568 L .83501 .5498 L F
.88058 .56719 m .89546 .54269 L .90574 .55913 L .666 .711 .882 r
F
.88058 .56719 m .87014 .55073 L .89546 .54269 L F
.56702 .54366 m .57837 .51766 L .59094 .536 L .654 .682 .864 r
F
.56702 .54366 m .55434 .52501 L .57837 .51766 L F
.36081 .47269 m .36974 .44963 L .38355 .47194 L .523 .575 .849 r
F
.36081 .47269 m .34704 .44895 L .36974 .44963 L F
.54339 .56625 m .55453 .54591 L .56722 .5593 L .65 .753 .925 r
F
.54339 .56625 m .53056 .55296 L .55453 .54591 L F
.88082 .56948 m .89618 .54922 L .90613 .56259 L F
.88082 .56948 m .8707 .55622 L .89618 .54922 L F
.72394 .55738 m .73704 .53221 L .7485 .54934 L .664 .702 .875 r
F
.72394 .55738 m .71234 .54016 L .73704 .53221 L F
.43379 .51164 m .44368 .48579 L .45711 .50617 L .613 .64 .854 r
F
.43379 .51164 m .42031 .49048 L .44368 .48579 L F
.94112 .56736 m .95672 .54305 L .96656 .55932 L .667 .714 .884 r
F
.94112 .56736 m .93113 .55109 L .95672 .54305 L F
.39721 .4942 m .40666 .46925 L .42031 .49048 L .581 .616 .852 r
F
.39721 .4942 m .38355 .47194 L .40666 .46925 L F
.26598 .56272 m .27366 .54229 L .28862 .55572 L .651 .753 .924 r
F
.26598 .56272 m .25091 .54939 L .27366 .54229 L F
.60362 .5656 m .61552 .54524 L .62773 .55866 L .65 .753 .925 r
F
.60362 .5656 m .59126 .5523 L .61552 .54524 L F
.94131 .56892 m .95744 .54865 L .96692 .56204 L .649 .752 .925 r
F
.94131 .56892 m .93168 .55565 L .95744 .54865 L F
.31113 .41844 m .31904 .40146 L .33312 .42521 L .34 .458 .834 r
F
.31113 .41844 m .29721 .39266 L .31904 .40146 L F
.78443 .55823 m .79824 .53333 L .80926 .55018 L .665 .706 .878 r
F
.78443 .55823 m .77326 .54133 L .79824 .53333 L F
.32605 .56201 m .33449 .54157 L .34897 .55502 L .651 .753 .924 r
F
.32605 .56201 m .31146 .54867 L .33449 .54157 L F
.62736 .54632 m .63939 .52068 L .65156 .53846 L .659 .692 .87 r
F
.62736 .54632 m .61507 .52835 L .63939 .52068 L F
.66394 .56497 m .6766 .5446 L .68834 .55802 L .65 .753 .925 r
F
.66394 .56497 m .65206 .55166 L .6766 .5446 L F
.53052 .53231 m .5415 .50625 L .55434 .52501 L .647 .675 .863 r
F
.53052 .53231 m .51758 .51318 L .5415 .50625 L F
.38621 .56132 m .39541 .54085 L .40941 .55432 L .651 .753 .924 r
F
.38621 .56132 m .37209 .54797 L .39541 .54085 L F
.72435 .56435 m .73778 .54396 L .74903 .55741 L .65 .753 .925 r
F
.72435 .56435 m .71295 .55102 L .73778 .54396 L F
.84503 .55879 m .85956 .53412 L .87014 .55073 L .665 .71 .881 r
F
.84503 .55879 m .8343 .54214 L .85956 .53412 L F
.26713 .34224 m .28315 .36693 L .27213 .35478 L 0 .066 .629 r
F
.44646 .56063 m .45642 .54015 L .46994 .55364 L .651 .753 .924 r
F
.44646 .56063 m .43281 .54727 L .45642 .54015 L F
.68786 .54812 m .70059 .52278 L .71234 .54016 L .661 .699 .874 r
F
.68786 .54812 m .67597 .53062 L .70059 .52278 L F
.78485 .56375 m .79905 .54335 L .80982 .5568 L .65 .753 .925 r
F
.78485 .56375 m .77393 .5504 L .79905 .54335 L F
.90574 .55913 m .921 .53465 L .93113 .55109 L .666 .713 .883 r
F
.90574 .55913 m .89546 .54269 L .921 .53465 L F
.5068 .55996 m .51752 .53947 L .53056 .55296 L .65 .753 .924 r
F
.5068 .55996 m .49363 .54658 L .51752 .53947 L F
.84545 .56316 m .86042 .54275 L .8707 .55622 L .65 .753 .925 r
F
.84545 .56316 m .83501 .5498 L .86042 .54275 L F
.49387 .51993 m .50447 .49394 L .51758 .51318 L .637 .666 .862 r
F
.49387 .51993 m .48067 .50023 L .50447 .49394 L F
.59094 .536 m .60261 .51024 L .61507 .52835 L .654 .687 .869 r
F
.59094 .536 m .57837 .51766 L .60261 .51024 L F
.7485 .54934 m .76194 .52428 L .77326 .54133 L .663 .704 .878 r
F
.7485 .54934 m .73704 .53221 L .76194 .52428 L F
.56722 .5593 m .57871 .53879 L .59126 .5523 L .65 .753 .925 r
F
.56722 .5593 m .55453 .54591 L .57871 .53879 L F
.22835 .55644 m .23559 .53586 L .25091 .54939 L .651 .753 .924 r
F
.22835 .55644 m .21292 .54302 L .23559 .53586 L F
.90613 .56259 m .92188 .54216 L .93168 .55565 L .649 .753 .925 r
F
.90613 .56259 m .89618 .54922 L .92188 .54216 L F
.34704 .44895 m .35576 .42728 L .36974 .44963 L .492 .562 .854 r
F
.34704 .44895 m .33312 .42521 L .35576 .42728 L F
.28862 .55572 m .29662 .53512 L .31146 .54867 L .651 .753 .924 r
F
.28862 .55572 m .27366 .54229 L .29662 .53512 L F
.62773 .55866 m .63999 .53813 L .65206 .55166 L .65 .753 .925 r
F
.62773 .55866 m .61552 .54524 L .63999 .53813 L F
.45711 .50617 m .46731 .48044 L .48067 .50023 L .622 .654 .86 r
F
.45711 .50617 m .44368 .48579 L .46731 .48044 L F
.80926 .55018 m .82343 .52534 L .8343 .54214 L .664 .708 .881 r
F
.80926 .55018 m .79824 .53333 L .82343 .52534 L F
.65156 .53846 m .66393 .51299 L .67597 .53062 L .658 .695 .873 r
F
.65156 .53846 m .63939 .52068 L .66393 .51299 L F
.29721 .39266 m .3048 .37768 L .31904 .40146 L .273 .421 .829 r
F
.29721 .39266 m .28315 .36693 L .3048 .37768 L F
.34897 .55502 m .35774 .5344 L .37209 .54797 L .651 .753 .924 r
F
.34897 .55502 m .33449 .54157 L .35774 .5344 L F
.68834 .55802 m .70137 .53748 L .71295 .55102 L .65 .753 .925 r
F
.68834 .55802 m .6766 .5446 L .70137 .53748 L F
.42031 .49048 m .43008 .46532 L .44368 .48579 L .599 .636 .859 r
F
.42031 .49048 m .40666 .46925 L .43008 .46532 L F
.38355 .47194 m .39285 .44796 L .40666 .46925 L .562 .609 .858 r
F
.38355 .47194 m .36974 .44963 L .39285 .44796 L F
.55434 .52501 m .56563 .49919 L .57837 .51766 L .648 .681 .867 r
F
.55434 .52501 m .5415 .50625 L .56563 .49919 L F
.87014 .55073 m .88503 .52609 L .89546 .54269 L .665 .712 .883 r
F
.87014 .55073 m .85956 .53412 L .88503 .52609 L F
.40941 .55432 m .41894 .53368 L .43281 .54727 L .651 .753 .924 r
F
.40941 .55432 m .39541 .54085 L .41894 .53368 L F
.74903 .55741 m .76283 .53685 L .77393 .5504 L .65 .753 .925 r
F
.74903 .55741 m .73778 .54396 L .76283 .53685 L F
.71234 .54016 m .72542 .51493 L .73704 .53221 L .661 .702 .877 r
F
.71234 .54016 m .70059 .52278 L .72542 .51493 L F
.46994 .55364 m .48024 .53298 L .49363 .54658 L .65 .753 .924 r
F
.46994 .55364 m .45642 .54015 L .48024 .53298 L F
.80982 .5568 m .8244 .53623 L .83501 .5498 L .65 .753 .925 r
F
.80982 .5568 m .79905 .54335 L .8244 .53623 L F
.93113 .55109 m .94675 .52661 L .95672 .54305 L .665 .714 .885 r
F
.93113 .55109 m .921 .53465 L .94675 .52661 L F
.53056 .55296 m .54163 .53229 L .55453 .54591 L .65 .753 .925 r
F
.53056 .55296 m .51752 .53947 L .54163 .53229 L F
.8707 .55622 m .88606 .53563 L .89618 .54922 L F
.8707 .55622 m .86042 .54275 L .88606 .53563 L F
.61507 .52835 m .62706 .50275 L .63939 .52068 L .655 .691 .872 r
F
.61507 .52835 m .60261 .51024 L .62706 .50275 L F
.51758 .51318 m .52848 .48737 L .5415 .50625 L .64 .674 .866 r
F
.51758 .51318 m .50447 .49394 L .52848 .48737 L F
.77326 .54133 m .78706 .51633 L .79824 .53333 L .662 .706 .88 r
F
.77326 .54133 m .76194 .52428 L .78706 .51633 L F
.25091 .54939 m .25846 .52863 L .27366 .54229 L .651 .753 .924 r
F
.25091 .54939 m .23559 .53586 L .25846 .52863 L F
.59126 .5523 m .60311 .53161 L .61552 .54524 L .65 .753 .925 r
F
.59126 .5523 m .57871 .53879 L .60311 .53161 L F
.93168 .55565 m .94782 .53505 L .95744 .54865 L .649 .752 .925 r
F
.93168 .55565 m .92188 .54216 L .94782 .53505 L F
.26713 .34224 m .26894 .34122 L .28315 .36693 L 0 .066 .629 r
F
.26544 .33675 m .26894 .34122 L .26713 .34224 L F
.31146 .54867 m .31978 .5279 L .33449 .54157 L .651 .753 .924 r
F
.31146 .54867 m .29662 .53512 L .31978 .5279 L F
.8343 .54214 m .84883 .51734 L .85956 .53412 L .663 .71 .883 r
F
.8343 .54214 m .82343 .52534 L .84883 .51734 L F
.65206 .55166 m .66468 .53095 L .6766 .5446 L .65 .753 .925 r
F
.65206 .55166 m .63999 .53813 L .66468 .53095 L F
.67597 .53062 m .68868 .50526 L .70059 .52278 L .658 .699 .876 r
F
.67597 .53062 m .66393 .51299 L .68868 .50526 L F
.33312 .42521 m .34161 .40487 L .35576 .42728 L .458 .546 .859 r
F
.33312 .42521 m .31904 .40146 L .34161 .40487 L F
.48067 .50023 m .49118 .47459 L .50447 .49394 L .628 .664 .866 r
F
.48067 .50023 m .46731 .48044 L .49118 .47459 L F
.37209 .54797 m .38119 .52717 L .39541 .54085 L .651 .753 .924 r
F
.37209 .54797 m .35774 .5344 L .38119 .52717 L F
.71295 .55102 m .72635 .5303 L .73778 .54396 L .65 .753 .925 r
F
.71295 .55102 m .70137 .53748 L .72635 .5303 L F
.28315 .36693 m .29039 .35386 L .3048 .37768 L .2 .38 .818 r
F
.28315 .36693 m .26894 .34122 L .29039 .35386 L F
.57837 .51766 m .58998 .49199 L .60261 .51024 L .649 .687 .871 r
F
.57837 .51766 m .56563 .49919 L .58998 .49199 L F
.89546 .54269 m .91073 .51805 L .921 .53465 L .664 .713 .885 r
F
.89546 .54269 m .88503 .52609 L .91073 .51805 L F
.43281 .54727 m .44268 .52645 L .45642 .54015 L .651 .753 .924 r
F
.43281 .54727 m .41894 .53368 L .44268 .52645 L F
.77393 .5504 m .78811 .52967 L .79905 .54335 L .65 .753 .925 r
F
.77393 .5504 m .76283 .53685 L .78811 .52967 L F
.73704 .53221 m .75047 .50707 L .76194 .52428 L .661 .704 .879 r
F
.73704 .53221 m .72542 .51493 L .75047 .50707 L F
.44368 .48579 m .45377 .46053 L .46731 .48044 L .612 .651 .865 r
F
.44368 .48579 m .43008 .46532 L .45377 .46053 L F
.49363 .54658 m .50427 .52575 L .51752 .53947 L .65 .753 .924 r
F
.49363 .54658 m .48024 .53298 L .50427 .52575 L F
.36974 .44963 m .37886 .42658 L .39285 .44796 L .541 .602 .863 r
F
.36974 .44963 m .35576 .42728 L .37886 .42658 L F
.83501 .5498 m .84997 .52905 L .86042 .54275 L .65 .753 .925 r
F
.83501 .5498 m .8244 .53623 L .84997 .52905 L F
.40666 .46925 m .4163 .44476 L .43008 .46532 L .585 .632 .864 r
F
.40666 .46925 m .39285 .44796 L .4163 .44476 L F
.26077 .32662 m .26894 .34122 L .26544 .33675 L 0 .013 .584 r
F
.63939 .52068 m .65172 .4952 L .66393 .51299 L .655 .695 .875 r
F
.63939 .52068 m .62706 .50275 L .65172 .4952 L F
.55453 .54591 m .56595 .52506 L .57871 .53879 L .65 .753 .925 r
F
.55453 .54591 m .54163 .53229 L .56595 .52506 L F
.21292 .54302 m .22002 .5221 L .23559 .53586 L .651 .753 .924 r
F
.21292 .54302 m .19724 .52938 L .22002 .5221 L F
.79824 .53333 m .8124 .50837 L .82343 .52534 L .662 .708 .882 r
F
.79824 .53333 m .78706 .51633 L .8124 .50837 L F
.89618 .54922 m .91193 .52845 L .92188 .54216 L .649 .753 .925 r
F
.89618 .54922 m .88606 .53563 L .91193 .52845 L F
.5415 .50625 m .55272 .48058 L .56563 .49919 L .643 .68 .871 r
F
.5415 .50625 m .52848 .48737 L .55272 .48058 L F
.27366 .54229 m .28154 .52135 L .29662 .53512 L .651 .753 .924 r
F
.27366 .54229 m .25846 .52863 L .28154 .52135 L F
.61552 .54524 m .62772 .52438 L .63999 .53813 L .65 .753 .925 r
F
.61552 .54524 m .60311 .53161 L .62772 .52438 L F
.85956 .53412 m .87446 .50932 L .88503 .52609 L .663 .712 .884 r
F
.85956 .53412 m .84883 .51734 L .87446 .50932 L F
.33449 .54157 m .34315 .52061 L .35774 .5344 L .651 .753 .924 r
F
.33449 .54157 m .31978 .5279 L .34315 .52061 L F
.6766 .5446 m .68959 .52371 L .70137 .53748 L .65 .753 .925 r
F
.6766 .5446 m .66468 .53095 L .68959 .52371 L F
.70059 .52278 m .71365 .4975 L .72542 .51493 L .658 .702 .879 r
F
.70059 .52278 m .68868 .50526 L .71365 .4975 L F
.39541 .54085 m .40484 .51988 L .41894 .53368 L .651 .753 .924 r
F
.39541 .54085 m .38119 .52717 L .40484 .51988 L F
.73778 .54396 m .75155 .52306 L .76283 .53685 L .65 .753 .925 r
F
.73778 .54396 m .72635 .5303 L .75155 .52306 L F
.50447 .49394 m .51529 .46836 L .52848 .48737 L .633 .673 .87 r
F
.50447 .49394 m .49118 .47459 L .51529 .46836 L F
.921 .53465 m .93664 .51 L .94675 .52661 L .663 .715 .886 r
F
.921 .53465 m .91073 .51805 L .93664 .51 L F
.60261 .51024 m .61456 .48468 L .62706 .50275 L .65 .691 .875 r
F
.60261 .51024 m .58998 .49199 L .61456 .48468 L F
.26894 .34122 m .2758 .33 L .29039 .35386 L .121 .333 .8 r
F
.2587 .31834 m .26894 .34122 L .26077 .32662 L F
.2587 .31834 m .2758 .33 L .26894 .34122 L F
.31904 .40146 m .32728 .38239 L .34161 .40487 L .422 .529 .862 r
F
.31904 .40146 m .3048 .37768 L .32728 .38239 L F
.45642 .54015 m .46663 .51916 L .48024 .53298 L .65 .753 .924 r
F
.45642 .54015 m .44268 .52645 L .46663 .51916 L F
.76194 .52428 m .77574 .49917 L .78706 .51633 L .66 .707 .882 r
F
.76194 .52428 m .75047 .50707 L .77574 .49917 L F
.79905 .54335 m .81361 .52243 L .8244 .53623 L .65 .753 .925 r
F
.79905 .54335 m .78811 .52967 L .81361 .52243 L F
.51752 .53947 m .52852 .51845 L .54163 .53229 L F
.51752 .53947 m .50427 .52575 L .52852 .51845 L F
.86042 .54275 m .87577 .52182 L .88606 .53563 L F
.86042 .54275 m .84997 .52905 L .87577 .52182 L F
.46731 .48044 m .47772 .45511 L .49118 .47459 L .62 .662 .869 r
F
.46731 .48044 m .45377 .46053 L .47772 .45511 L F
.82343 .52534 m .83796 .50039 L .84883 .51734 L .661 .71 .884 r
F
.82343 .52534 m .8124 .50837 L .83796 .50039 L F
.66393 .51299 m .67661 .48758 L .68868 .50526 L .655 .699 .878 r
F
.66393 .51299 m .65172 .4952 L .67661 .48758 L F
.23559 .53586 m .24302 .51476 L .25846 .52863 L .651 .753 .924 r
F
.23559 .53586 m .22002 .5221 L .24302 .51476 L F
.57871 .53879 m .59049 .51776 L .60311 .53161 L .65 .753 .925 r
F
.57871 .53879 m .56595 .52506 L .59049 .51776 L F
.92188 .54216 m .93803 .52122 L .94782 .53505 L .649 .752 .925 r
F
.92188 .54216 m .91193 .52845 L .93803 .52122 L F
.56563 .49919 m .57719 .4736 L .58998 .49199 L .645 .686 .874 r
F
.56563 .49919 m .55272 .48058 L .57719 .4736 L F
.35576 .42728 m .3647 .40511 L .37886 .42658 L .519 .593 .868 r
F
.35576 .42728 m .34161 .40487 L .3647 .40511 L F
.43008 .46532 m .44005 .44051 L .45377 .46053 L .601 .648 .869 r
F
.43008 .46532 m .4163 .44476 L .44005 .44051 L F
.29662 .53512 m .30482 .514 L .31978 .5279 L .651 .753 .924 r
F
.29662 .53512 m .28154 .52135 L .30482 .514 L F
.63999 .53813 m .65256 .51708 L .66468 .53095 L .65 .753 .925 r
F
.63999 .53813 m .62772 .52438 L .65256 .51708 L F
.88503 .52609 m .90031 .50128 L .91073 .51805 L .662 .713 .886 r
F
.88503 .52609 m .87446 .50932 L .90031 .50128 L F
.39285 .44796 m .40234 .42408 L .4163 .44476 L .571 .627 .869 r
F
.39285 .44796 m .37886 .42658 L .40234 .42408 L F
.72542 .51493 m .73884 .48969 L .75047 .50707 L .658 .704 .881 r
F
.72542 .51493 m .71365 .4975 L .73884 .48969 L F
.35774 .5344 m .36672 .51326 L .38119 .52717 L .651 .753 .924 r
F
.35774 .5344 m .34315 .52061 L .36672 .51326 L F
.70137 .53748 m .71473 .51641 L .72635 .5303 L .65 .753 .925 r
F
.70137 .53748 m .68959 .52371 L .71473 .51641 L F
.41894 .53368 m .42872 .51252 L .44268 .52645 L .651 .753 .924 r
F
.41894 .53368 m .40484 .51988 L .42872 .51252 L F
.76283 .53685 m .77699 .51577 L .78811 .52967 L .65 .753 .925 r
F
.76283 .53685 m .75155 .52306 L .77699 .51577 L F
.62706 .50275 m .63935 .47726 L .65172 .4952 L .651 .695 .878 r
F
.62706 .50275 m .61456 .48468 L .63935 .47726 L F
.52848 .48737 m .53964 .46183 L .55272 .48058 L .637 .68 .874 r
F
.52848 .48737 m .51529 .46836 L .53964 .46183 L F
.78706 .51633 m .80122 .49124 L .8124 .50837 L .66 .709 .884 r
F
.78706 .51633 m .77574 .49917 L .80122 .49124 L F
.48024 .53298 m .4908 .5118 L .50427 .52575 L .65 .753 .924 r
F
.48024 .53298 m .46663 .51916 L .4908 .5118 L F
.8244 .53623 m .83935 .51513 L .84997 .52905 L .65 .753 .925 r
F
.8244 .53623 m .81361 .52243 L .83935 .51513 L F
.3048 .37768 m .31278 .35983 L .32728 .38239 L .382 .51 .863 r
F
.3048 .37768 m .29039 .35386 L .31278 .35983 L F
.54163 .53229 m .55298 .51109 L .56595 .52506 L .65 .753 .925 r
F
.54163 .53229 m .52852 .51845 L .55298 .51109 L F
.19724 .52938 m .2042 .50812 L .22002 .5221 L .651 .753 .924 r
F
.19724 .52938 m .1813 .51552 L .2042 .50812 L F
.88606 .53563 m .90181 .51452 L .91193 .52845 L .649 .753 .925 r
F
.88606 .53563 m .87577 .52182 L .90181 .51452 L F
.84883 .51734 m .86374 .49238 L .87446 .50932 L .661 .712 .886 r
F
.84883 .51734 m .83796 .50039 L .86374 .49238 L F
.68868 .50526 m .70171 .4799 L .71365 .4975 L .655 .702 .881 r
F
.68868 .50526 m .67661 .48758 L .70171 .4799 L F
.49118 .47459 m .50192 .44921 L .51529 .46836 L .627 .671 .873 r
F
.49118 .47459 m .47772 .45511 L .50192 .44921 L F
.25846 .52863 m .26621 .50735 L .28154 .52135 L .651 .753 .924 r
F
.25846 .52863 m .24302 .51476 L .26621 .50735 L F
.60311 .53161 m .61525 .5104 L .62772 .52438 L .65 .753 .925 r
F
.60311 .53161 m .59049 .51776 L .61525 .5104 L F
.58998 .49199 m .60188 .46645 L .61456 .48468 L .646 .691 .877 r
F
.58998 .49199 m .57719 .4736 L .60188 .46645 L F
.31978 .5279 m .32832 .50659 L .34315 .52061 L .651 .753 .924 r
F
.31978 .5279 m .30482 .514 L .32832 .50659 L F
.91073 .51805 m .92639 .49321 L .93664 .51 L .662 .715 .888 r
F
.91073 .51805 m .90031 .50128 L .92639 .49321 L F
.66468 .53095 m .67762 .50972 L .68959 .52371 L .65 .753 .925 r
F
.66468 .53095 m .65256 .51708 L .67762 .50972 L F
.25652 .31267 m .2758 .33 L .2587 .31834 L .038 .281 .776 r
F
.75047 .50707 m .76425 .48183 L .77574 .49917 L .658 .707 .883 r
F
.75047 .50707 m .73884 .48969 L .76425 .48183 L F
.45377 .46053 m .46408 .4355 L .47772 .45511 L .612 .661 .873 r
F
.45377 .46053 m .44005 .44051 L .46408 .4355 L F
.38119 .52717 m .39051 .50584 L .40484 .51988 L .651 .753 .924 r
F
.38119 .52717 m .36672 .51326 L .39051 .50584 L F
.72635 .5303 m .74009 .50905 L .75155 .52306 L .65 .753 .925 r
F
.72635 .5303 m .71473 .51641 L .74009 .50905 L F
.34161 .40487 m .35035 .38354 L .3647 .40511 L .496 .584 .873 r
F
.34161 .40487 m .32728 .38239 L .35035 .38354 L F
.44268 .52645 m .4528 .50511 L .46663 .51916 L .65 .753 .924 r
F
.44268 .52645 m .42872 .51252 L .4528 .50511 L F
.78811 .52967 m .80265 .50841 L .81361 .52243 L .65 .753 .925 r
F
.78811 .52967 m .77699 .51577 L .80265 .50841 L F
.65172 .4952 m .66436 .46974 L .67661 .48758 L .652 .699 .88 r
F
.65172 .4952 m .63935 .47726 L .66436 .46974 L F
.4163 .44476 m .42615 .42036 L .44005 .44051 L .59 .645 .873 r
F
.4163 .44476 m .40234 .42408 L .42615 .42036 L F
.8124 .50837 m .82693 .48327 L .83796 .50039 L .66 .711 .886 r
F
.8124 .50837 m .80122 .49124 L .82693 .48327 L F
.37886 .42658 m .3882 .40329 L .40234 .42408 L .555 .622 .874 r
F
.37886 .42658 m .3647 .40511 L .3882 .40329 L F
.55272 .48058 m .56421 .45505 L .57719 .4736 L .64 .685 .877 r
F
.55272 .48058 m .53964 .46183 L .56421 .45505 L F
.50427 .52575 m .51519 .50438 L .52852 .51845 L .65 .753 .925 r
F
.50427 .52575 m .4908 .5118 L .51519 .50438 L F
.84997 .52905 m .86532 .50778 L .87577 .52182 L F
.84997 .52905 m .83935 .51513 L .86532 .50778 L F
.22002 .5221 m .22731 .50065 L .24302 .51476 L .651 .753 .924 r
F
.22002 .5221 m .2042 .50812 L .22731 .50065 L F
.56595 .52506 m .57766 .50367 L .59049 .51776 L .65 .753 .925 r
F
.56595 .52506 m .55298 .51109 L .57766 .50367 L F
.87446 .50932 m .88975 .48432 L .90031 .50128 L .661 .714 .887 r
F
.87446 .50932 m .86374 .49238 L .88975 .48432 L F
.25652 .31267 m .26103 .30607 L .2758 .33 L .038 .281 .776 r
F
.25236 .29937 m .26103 .30607 L .25652 .31267 L F
.91193 .52845 m .92808 .50716 L .93803 .52122 L .649 .752 .925 r
F
.91193 .52845 m .90181 .51452 L .92808 .50716 L F
.71365 .4975 m .72704 .47214 L .73884 .48969 L .655 .704 .883 r
F
.71365 .4975 m .70171 .4799 L .72704 .47214 L F
.28154 .52135 m .28962 .49987 L .30482 .514 L .651 .753 .924 r
F
.28154 .52135 m .26621 .50735 L .28962 .49987 L F
.62772 .52438 m .64024 .50298 L .65256 .51708 L .65 .753 .925 r
F
.62772 .52438 m .61525 .5104 L .64024 .50298 L F
.29039 .35386 m .29808 .33718 L .31278 .35983 L .34 .489 .862 r
F
.29039 .35386 m .2758 .33 L .29808 .33718 L F
.51529 .46836 m .52637 .44293 L .53964 .46183 L .631 .679 .877 r
F
.51529 .46836 m .50192 .44921 L .52637 .44293 L F
.61456 .48468 m .6268 .45915 L .63935 .47726 L .648 .695 .88 r
F
.61456 .48468 m .60188 .46645 L .6268 .45915 L F
.34315 .52061 m .35202 .49911 L .36672 .51326 L .651 .753 .924 r
F
.34315 .52061 m .32832 .50659 L .35202 .49911 L F
.68959 .52371 m .70291 .5023 L .71473 .51641 L .65 .753 .925 r
F
.68959 .52371 m .67762 .50972 L .70291 .5023 L F
.77574 .49917 m .78988 .47392 L .80122 .49124 L .658 .709 .885 r
F
.77574 .49917 m .76425 .48183 L .78988 .47392 L F
.40484 .51988 m .41452 .49836 L .42872 .51252 L .651 .753 .924 r
F
.40484 .51988 m .39051 .50584 L .41452 .49836 L F
.75155 .52306 m .76568 .50163 L .77699 .51577 L .65 .753 .925 r
F
.75155 .52306 m .74009 .50905 L .76568 .50163 L F
.47772 .45511 m .48837 .42991 L .50192 .44921 L .62 .67 .877 r
F
.47772 .45511 m .46408 .4355 L .48837 .42991 L F
.46663 .51916 m .47711 .49763 L .4908 .5118 L .65 .753 .924 r
F
.46663 .51916 m .4528 .50511 L .47711 .49763 L F
.81361 .52243 m .82855 .50098 L .83935 .51513 L .65 .753 .925 r
F
.81361 .52243 m .80265 .50841 L .82855 .50098 L F
.67661 .48758 m .6896 .46213 L .70171 .4799 L .652 .702 .883 r
F
.67661 .48758 m .66436 .46974 L .6896 .46213 L F
.83796 .50039 m .85287 .47525 L .86374 .49238 L .659 .712 .887 r
F
.83796 .50039 m .82693 .48327 L .85287 .47525 L F
.57719 .4736 m .58902 .44806 L .60188 .46645 L .642 .69 .88 r
F
.57719 .4736 m .56421 .45505 L .58902 .44806 L F
.52852 .51845 m .53979 .4969 L .55298 .51109 L .65 .753 .925 r
F
.52852 .51845 m .51519 .50438 L .53979 .4969 L F
.1813 .51552 m .18811 .4939 L .2042 .50812 L .651 .753 .924 r
F
.1813 .51552 m .16509 .50143 L .18811 .4939 L F
.87577 .52182 m .89152 .50035 L .90181 .51452 L .649 .753 .925 r
F
.87577 .52182 m .86532 .50778 L .89152 .50035 L F
.32728 .38239 m .33581 .36186 L .35035 .38354 L .472 .574 .876 r
F
.32728 .38239 m .31278 .35983 L .33581 .36186 L F
.44005 .44051 m .45025 .41575 L .46408 .4355 L .603 .658 .877 r
F
.44005 .44051 m .42615 .42036 L .45025 .41575 L F
.90031 .50128 m .916 .47623 L .92639 .49321 L .66 .715 .889 r
F
.90031 .50128 m .88975 .48432 L .916 .47623 L F
.24302 .51476 m .25063 .49311 L .26621 .50735 L .651 .753 .924 r
F
.24302 .51476 m .22731 .50065 L .25063 .49311 L F
.59049 .51776 m .60257 .49619 L .61525 .5104 L .65 .753 .925 r
F
.59049 .51776 m .57766 .50367 L .60257 .49619 L F
.73884 .48969 m .7526 .46432 L .76425 .48183 L .656 .707 .885 r
F
.73884 .48969 m .72704 .47214 L .7526 .46432 L F
.40234 .42408 m .41205 .40008 L .42615 .42036 L .578 .642 .877 r
F
.40234 .42408 m .3882 .40329 L .41205 .40008 L F
.3647 .40511 m .37387 .38238 L .3882 .40329 L .539 .617 .878 r
F
.3647 .40511 m .35035 .38354 L .37387 .38238 L F
.30482 .514 m .31324 .49234 L .32832 .50659 L .651 .753 .924 r
F
.30482 .514 m .28962 .49987 L .31324 .49234 L F
.65256 .51708 m .66545 .49549 L .67762 .50972 L .65 .753 .925 r
F
.65256 .51708 m .64024 .50298 L .66545 .49549 L F
.63935 .47726 m .65194 .45173 L .66436 .46974 L .649 .698 .882 r
F
.63935 .47726 m .6268 .45915 L .65194 .45173 L F
.53964 .46183 m .55106 .43634 L .56421 .45505 L .635 .685 .879 r
F
.53964 .46183 m .52637 .44293 L .55106 .43634 L F
.36672 .51326 m .37594 .49157 L .39051 .50584 L .651 .753 .924 r
F
.36672 .51326 m .35202 .49911 L .37594 .49157 L F
.71473 .51641 m .72843 .49481 L .74009 .50905 L .65 .753 .925 r
F
.71473 .51641 m .70291 .5023 L .72843 .49481 L F
.80122 .49124 m .81575 .46596 L .82693 .48327 L .658 .711 .887 r
F
.80122 .49124 m .78988 .47392 L .81575 .46596 L F
.2758 .33 m .28319 .31444 L .29808 .33718 L .295 .466 .859 r
F
.2758 .33 m .26103 .30607 L .28319 .31444 L F
.42872 .51252 m .43874 .49082 L .4528 .50511 L .65 .753 .924 r
F
.42872 .51252 m .41452 .49836 L .43874 .49082 L F
.77699 .51577 m .79151 .49415 L .80265 .50841 L .65 .753 .925 r
F
.77699 .51577 m .76568 .50163 L .79151 .49415 L F
.24527 .28311 m .26103 .30607 L .25236 .29937 L 0 .226 .744 r
F
.86374 .49238 m .87904 .46718 L .88975 .48432 L .659 .714 .889 r
F
.86374 .49238 m .85287 .47525 L .87904 .46718 L F
.4908 .5118 m .50163 .49008 L .51519 .50438 L .65 .753 .925 r
F
.4908 .5118 m .47711 .49763 L .50163 .49008 L F
.70171 .4799 m .71507 .45442 L .72704 .47214 L .653 .704 .885 r
F
.70171 .4799 m .6896 .46213 L .71507 .45442 L F
.83935 .51513 m .85469 .4935 L .86532 .50778 L .65 .753 .925 r
F
.83935 .51513 m .82855 .50098 L .85469 .4935 L F
.50192 .44921 m .51291 .42387 L .52637 .44293 L .626 .678 .88 r
F
.50192 .44921 m .48837 .42991 L .51291 .42387 L F
.2042 .50812 m .21134 .4863 L .22731 .50065 L .651 .753 .924 r
F
.2042 .50812 m .18811 .4939 L .21134 .4863 L F
.55298 .51109 m .56462 .48935 L .57766 .50367 L .65 .753 .925 r
F
.55298 .51109 m .53979 .4969 L .56462 .48935 L F
.60188 .46645 m .61407 .44088 L .6268 .45915 L .644 .695 .882 r
F
.60188 .46645 m .58902 .44806 L .61407 .44088 L F
.90181 .51452 m .91797 .49287 L .92808 .50716 L .649 .752 .925 r
F
.90181 .51452 m .89152 .50035 L .91797 .49287 L F
.26621 .50735 m .27416 .48551 L .28962 .49987 L .651 .753 .924 r
F
.26621 .50735 m .25063 .49311 L .27416 .48551 L F
.61525 .5104 m .62771 .48864 L .64024 .50298 L .65 .753 .925 r
F
.61525 .5104 m .60257 .49619 L .62771 .48864 L F
.76425 .48183 m .77838 .45643 L .78988 .47392 L .656 .709 .887 r
F
.76425 .48183 m .7526 .46432 L .77838 .45643 L F
.46408 .4355 m .47462 .41046 L .48837 .42991 L .613 .669 .88 r
F
.46408 .4355 m .45025 .41575 L .47462 .41046 L F
.32832 .50659 m .33708 .48473 L .35202 .49911 L .651 .753 .924 r
F
.32832 .50659 m .31324 .49234 L .33708 .48473 L F
.67762 .50972 m .6909 .48794 L .70291 .5023 L .65 .753 .925 r
F
.67762 .50972 m .66545 .49549 L .6909 .48794 L F
.31278 .35983 m .32108 .34006 L .33581 .36186 L .447 .563 .879 r
F
.31278 .35983 m .29808 .33718 L .32108 .34006 L F
.66436 .46974 m .67732 .44418 L .6896 .46213 L .65 .702 .884 r
F
.66436 .46974 m .65194 .45173 L .67732 .44418 L F
.39051 .50584 m .40008 .48397 L .41452 .49836 L .651 .753 .924 r
F
.39051 .50584 m .37594 .49157 L .40008 .48397 L F
.82693 .48327 m .84184 .45793 L .85287 .47525 L .658 .713 .889 r
F
.82693 .48327 m .81575 .46596 L .84184 .45793 L F
.74009 .50905 m .75419 .48726 L .76568 .50163 L .65 .753 .925 r
F
.74009 .50905 m .72843 .49481 L .75419 .48726 L F
.56421 .45505 m .57598 .4295 L .58902 .44806 L .638 .69 .882 r
F
.56421 .45505 m .55106 .43634 L .57598 .4295 L F
.42615 .42036 m .43622 .39585 L .45025 .41575 L .594 .656 .88 r
F
.42615 .42036 m .41205 .40008 L .43622 .39585 L F
.4528 .50511 m .46319 .48321 L .47711 .49763 L .65 .753 .924 r
F
.4528 .50511 m .43874 .49082 L .46319 .48321 L F
.35035 .38354 m .35934 .36134 L .37387 .38238 L .523 .611 .882 r
F
.35035 .38354 m .33581 .36186 L .35934 .36134 L F
.80265 .50841 m .81757 .4866 L .82855 .50098 L .65 .753 .925 r
F
.80265 .50841 m .79151 .49415 L .81757 .4866 L F
.3882 .40329 m .39777 .37965 L .41205 .40008 L .567 .638 .881 r
F
.3882 .40329 m .37387 .38238 L .39777 .37965 L F
.88975 .48432 m .90545 .45907 L .916 .47623 L .659 .715 .89 r
F
.88975 .48432 m .87904 .46718 L .90545 .45907 L F
.51519 .50438 m .52639 .48247 L .53979 .4969 L .65 .753 .925 r
F
.51519 .50438 m .50163 .49008 L .52639 .48247 L F
.72704 .47214 m .74078 .44662 L .7526 .46432 L .653 .707 .887 r
F
.72704 .47214 m .71507 .45442 L .74078 .44662 L F
.16509 .50143 m .17176 .47944 L .18811 .4939 L .651 .753 .924 r
F
.16509 .50143 m .14862 .4871 L .17176 .47944 L F
.86532 .50778 m .88106 .48595 L .89152 .50035 L .649 .753 .925 r
F
.86532 .50778 m .85469 .4935 L .88106 .48595 L F
.26103 .30607 m .26811 .29158 L .28319 .31444 L .248 .44 .854 r
F
.26103 .30607 m .24607 .28208 L .26811 .29158 L F
.24527 .28311 m .24607 .28208 L .26103 .30607 L 0 .226 .744 r
F
.22731 .50065 m .23479 .47864 L .25063 .49311 L .651 .753 .924 r
F
.22731 .50065 m .21134 .4863 L .23479 .47864 L F
.57766 .50367 m .58968 .48174 L .60257 .49619 L .65 .753 .925 r
F
.57766 .50367 m .56462 .48935 L .58968 .48174 L F
.52637 .44293 m .53771 .41747 L .55106 .43634 L .63 .684 .882 r
F
.52637 .44293 m .51291 .42387 L .53771 .41747 L F
.6268 .45915 m .63935 .43353 L .65194 .45173 L .646 .698 .884 r
F
.6268 .45915 m .61407 .44088 L .63935 .43353 L F
.28962 .49987 m .29791 .47785 L .31324 .49234 L .651 .753 .924 r
F
.28962 .49987 m .27416 .48551 L .29791 .47785 L F
.78988 .47392 m .8044 .44846 L .81575 .46596 L .656 .711 .888 r
F
.78988 .47392 m .77838 .45643 L .8044 .44846 L F
.64024 .50298 m .65308 .48103 L .66545 .49549 L .65 .753 .925 r
F
.64024 .50298 m .62771 .48864 L .65308 .48103 L F
.35202 .49911 m .36113 .47707 L .37594 .49157 L .651 .753 .924 r
F
.35202 .49911 m .33708 .48473 L .36113 .47707 L F
.70291 .5023 m .71658 .48033 L .72843 .49481 L .65 .753 .925 r
F
.70291 .5023 m .6909 .48794 L .71658 .48033 L F
.48837 .42991 m .49927 .40465 L .51291 .42387 L .62 .677 .882 r
F
.48837 .42991 m .47462 .41046 L .49927 .40465 L F
.6896 .46213 m .70293 .43651 L .71507 .45442 L .65 .704 .886 r
F
.6896 .46213 m .67732 .44418 L .70293 .43651 L F
.85287 .47525 m .86818 .44985 L .87904 .46718 L .657 .714 .89 r
F
.85287 .47525 m .84184 .45793 L .86818 .44985 L F
.41452 .49836 m .42444 .4763 L .43874 .49082 L .65 .753 .924 r
F
.41452 .49836 m .40008 .48397 L .42444 .4763 L F
.76568 .50163 m .78018 .47965 L .79151 .49415 L .65 .753 .925 r
F
.76568 .50163 m .75419 .48726 L .78018 .47965 L F
.58902 .44806 m .60115 .42242 L .61407 .44088 L .641 .694 .884 r
F
.58902 .44806 m .57598 .4295 L .60115 .42242 L F
.24435 .2806 m .24607 .28208 L .24527 .28311 L 0 .226 .744 r
F
.47711 .49763 m .48785 .47554 L .50163 .49008 L .65 .753 .925 r
F
.47711 .49763 m .46319 .48321 L .48785 .47554 L F
.82855 .50098 m .84388 .47898 L .85469 .4935 L F
.82855 .50098 m .81757 .4866 L .84388 .47898 L F
.29808 .33718 m .30614 .31813 L .32108 .34006 L .42 .551 .881 r
F
.29808 .33718 m .28319 .31444 L .30614 .31813 L F
.45025 .41575 m .46068 .39085 L .47462 .41046 L .606 .667 .883 r
F
.45025 .41575 m .43622 .39585 L .46068 .39085 L F
.7526 .46432 m .76671 .43874 L .77838 .45643 L .654 .709 .888 r
F
.7526 .46432 m .74078 .44662 L .76671 .43874 L F
.18811 .4939 m .19511 .47172 L .21134 .4863 L .651 .753 .924 r
F
.18811 .4939 m .17176 .47944 L .19511 .47172 L F
.53979 .4969 m .55136 .47479 L .56462 .48935 L .65 .753 .925 r
F
.53979 .4969 m .52639 .48247 L .55136 .47479 L F
.89152 .50035 m .90768 .47834 L .91797 .49287 L .649 .752 .925 r
F
.89152 .50035 m .88106 .48595 L .90768 .47834 L F
.24183 .27533 m .24607 .28208 L .24435 .2806 L 0 .208 .734 r
F
.25063 .49311 m .25844 .47091 L .27416 .48551 L .651 .753 .924 r
F
.25063 .49311 m .23479 .47864 L .25844 .47091 L F
.60257 .49619 m .61497 .47406 L .62771 .48864 L .65 .753 .925 r
F
.60257 .49619 m .58968 .48174 L .61497 .47406 L F
.41205 .40008 m .422 .37579 L .43622 .39585 L .585 .654 .884 r
F
.41205 .40008 m .39777 .37965 L .422 .37579 L F
.65194 .45173 m .66486 .42604 L .67732 .44418 L .647 .702 .886 r
F
.65194 .45173 m .63935 .43353 L .66486 .42604 L F
.33581 .36186 m .34461 .34015 L .35934 .36134 L .506 .605 .885 r
F
.33581 .36186 m .32108 .34006 L .34461 .34015 L F
.55106 .43634 m .56276 .41076 L .57598 .4295 L .634 .689 .884 r
F
.55106 .43634 m .53771 .41747 L .56276 .41076 L F
.24607 .28208 m .25282 .2686 L .26811 .29158 L .198 .412 .845 r
F
.23722 .26106 m .24607 .28208 L .24183 .27533 L F
.23722 .26106 m .25282 .2686 L .24607 .28208 L F
.81575 .46596 m .83066 .44042 L .84184 .45793 L .656 .713 .89 r
F
.81575 .46596 m .8044 .44846 L .83066 .44042 L F
.37387 .38238 m .38328 .35908 L .39777 .37965 L .555 .635 .885 r
F
.37387 .38238 m .35934 .36134 L .38328 .35908 L F
.31324 .49234 m .32188 .47011 L .33708 .48473 L .651 .753 .924 r
F
.31324 .49234 m .29791 .47785 L .32188 .47011 L F
.66545 .49549 m .67868 .47335 L .6909 .48794 L .65 .753 .925 r
F
.66545 .49549 m .65308 .48103 L .67868 .47335 L F
.37594 .49157 m .3854 .46933 L .40008 .48397 L .651 .753 .924 r
F
.37594 .49157 m .36113 .47707 L .3854 .46933 L F
.72843 .49481 m .74249 .47265 L .75419 .48726 L .65 .753 .925 r
F
.72843 .49481 m .71658 .48033 L .74249 .47265 L F
.87904 .46718 m .89475 .4417 L .90545 .45907 L .657 .716 .891 r
F
.87904 .46718 m .86818 .44985 L .89475 .4417 L F
.71507 .45442 m .72878 .42873 L .74078 .44662 L .651 .707 .888 r
F
.71507 .45442 m .70293 .43651 L .72878 .42873 L F
.43874 .49082 m .44903 .46856 L .46319 .48321 L .65 .753 .924 r
F
.43874 .49082 m .42444 .4763 L .44903 .46856 L F
.79151 .49415 m .80641 .47197 L .81757 .4866 L .65 .753 .925 r
F
.79151 .49415 m .78018 .47965 L .80641 .47197 L F
.51291 .42387 m .52417 .39842 L .53771 .41747 L .626 .683 .885 r
F
.51291 .42387 m .49927 .40465 L .52417 .39842 L F
.61407 .44088 m .62656 .41515 L .63935 .43353 L .643 .698 .886 r
F
.61407 .44088 m .60115 .42242 L .62656 .41515 L F
.50163 .49008 m .51275 .4678 L .52639 .48247 L .65 .753 .925 r
F
.50163 .49008 m .48785 .47554 L .51275 .4678 L F
.14862 .4871 m .15513 .46474 L .17176 .47944 L .651 .753 .924 r
F
.14862 .4871 m .13187 .47253 L .15513 .46474 L F
.85469 .4935 m .87043 .4713 L .88106 .48595 L .649 .753 .925 r
F
.85469 .4935 m .84388 .47898 L .87043 .4713 L F
.77838 .45643 m .79289 .43077 L .8044 .44846 L .654 .711 .89 r
F
.77838 .45643 m .76671 .43874 L .79289 .43077 L F
.21134 .4863 m .21867 .46392 L .23479 .47864 L .651 .753 .924 r
F
.21134 .4863 m .19511 .47172 L .21867 .46392 L F
.56462 .48935 m .57657 .46705 L .58968 .48174 L .65 .753 .925 r
F
.56462 .48935 m .55136 .47479 L .57657 .46705 L F
.47462 .41046 m .48543 .38525 L .49927 .40465 L .614 .676 .885 r
F
.47462 .41046 m .46068 .39085 L .48543 .38525 L F
.27416 .48551 m .28232 .46311 L .29791 .47785 L .651 .753 .924 r
F
.27416 .48551 m .25844 .47091 L .28232 .46311 L F
.62771 .48864 m .6405 .46632 L .65308 .48103 L .65 .753 .925 r
F
.62771 .48864 m .61497 .47406 L .6405 .46632 L F
.28319 .31444 m .291 .29606 L .30614 .31813 L .392 .538 .883 r
F
.28319 .31444 m .26811 .29158 L .291 .29606 L F
.67732 .44418 m .69062 .41841 L .70293 .43651 L .648 .704 .888 r
F
.67732 .44418 m .66486 .42604 L .69062 .41841 L F
.84184 .45793 m .85715 .43231 L .86818 .44985 L .656 .714 .891 r
F
.84184 .45793 m .83066 .44042 L .85715 .43231 L F
.33708 .48473 m .34606 .46231 L .36113 .47707 L .651 .753 .924 r
F
.33708 .48473 m .32188 .47011 L .34606 .46231 L F
.57598 .4295 m .58805 .40378 L .60115 .42242 L .637 .694 .886 r
F
.57598 .4295 m .56276 .41076 L .58805 .40378 L F
.6909 .48794 m .70452 .4656 L .71658 .48033 L .65 .753 .925 r
F
.6909 .48794 m .67868 .47335 L .70452 .4656 L F
.43622 .39585 m .44654 .37106 L .46068 .39085 L .599 .666 .886 r
F
.43622 .39585 m .422 .37579 L .44654 .37106 L F
.40008 .48397 m .4099 .46152 L .42444 .4763 L .65 .753 .924 r
F
.40008 .48397 m .3854 .46933 L .4099 .46152 L F
.75419 .48726 m .76865 .4649 L .78018 .47965 L .65 .753 .925 r
F
.75419 .48726 m .74249 .47265 L .76865 .4649 L F
.74078 .44662 m .75487 .42085 L .76671 .43874 L .652 .709 .89 r
F
.74078 .44662 m .72878 .42873 L .75487 .42085 L F
.32108 .34006 m .32968 .31882 L .34461 .34015 L .489 .598 .889 r
F
.32108 .34006 m .30614 .31813 L .32968 .31882 L F
.46319 .48321 m .47384 .46075 L .48785 .47554 L .65 .753 .925 r
F
.46319 .48321 m .44903 .46856 L .47384 .46075 L F
.81757 .4866 m .83289 .46422 L .84388 .47898 L F
.81757 .4866 m .80641 .47197 L .83289 .46422 L F
.39777 .37965 m .40757 .35556 L .422 .37579 L .576 .651 .887 r
F
.39777 .37965 m .38328 .35908 L .40757 .35556 L F
.35934 .36134 m .36858 .33834 L .38328 .35908 L .543 .631 .888 r
F
.35934 .36134 m .34461 .34015 L .36858 .33834 L F
.63935 .43353 m .65222 .40771 L .66486 .42604 L .644 .701 .888 r
F
.63935 .43353 m .62656 .41515 L .65222 .40771 L F
.17176 .47944 m .1786 .45688 L .19511 .47172 L .651 .753 .924 r
F
.17176 .47944 m .15513 .46474 L .1786 .45688 L F
.52639 .48247 m .53788 .45999 L .55136 .47479 L .65 .753 .925 r
F
.52639 .48247 m .51275 .4678 L .53788 .45999 L F
.53771 .41747 m .54934 .39183 L .56276 .41076 L .63 .689 .886 r
F
.53771 .41747 m .52417 .39842 L .54934 .39183 L F
.88106 .48595 m .89722 .46356 L .90768 .47834 L .649 .752 .925 r
F
.88106 .48595 m .87043 .4713 L .89722 .46356 L F
.8044 .44846 m .8193 .42271 L .83066 .44042 L .654 .713 .891 r
F
.8044 .44846 m .79289 .43077 L .8193 .42271 L F
.23479 .47864 m .24246 .45606 L .25844 .47091 L .651 .753 .924 r
F
.23479 .47864 m .21867 .46392 L .24246 .45606 L F
.58968 .48174 m .60202 .45924 L .61497 .47406 L .65 .753 .925 r
F
.58968 .48174 m .57657 .46705 L .60202 .45924 L F
.29791 .47785 m .30642 .45524 L .32188 .47011 L .651 .753 .924 r
F
.29791 .47785 m .28232 .46311 L .30642 .45524 L F
.65308 .48103 m .66626 .4585 L .67868 .47335 L .65 .753 .925 r
F
.65308 .48103 m .6405 .46632 L .66626 .4585 L F
.70293 .43651 m .71661 .41064 L .72878 .42873 L .649 .707 .89 r
F
.70293 .43651 m .69062 .41841 L .71661 .41064 L F
.23366 .25266 m .25282 .2686 L .23722 .26106 L .147 .383 .835 r
F
.86818 .44985 m .88389 .42413 L .89475 .4417 L .656 .716 .892 r
F
.86818 .44985 m .85715 .43231 L .88389 .42413 L F
.49927 .40465 m .51044 .37918 L .52417 .39842 L .621 .683 .887 r
F
.49927 .40465 m .48543 .38525 L .51044 .37918 L F
.36113 .47707 m .37047 .45444 L .3854 .46933 L .651 .753 .924 r
F
.36113 .47707 m .34606 .46231 L .37047 .45444 L F
.71658 .48033 m .73061 .45779 L .74249 .47265 L .65 .753 .925 r
F
.71658 .48033 m .70452 .4656 L .73061 .45779 L F
.60115 .42242 m .61359 .39658 L .62656 .41515 L .639 .698 .888 r
F
.60115 .42242 m .58805 .40378 L .61359 .39658 L F
.42444 .4763 m .43463 .45365 L .44903 .46856 L .65 .753 .924 r
F
.42444 .4763 m .4099 .46152 L .43463 .45365 L F
.78018 .47965 m .79505 .45709 L .80641 .47197 L .65 .753 .925 r
F
.78018 .47965 m .76865 .4649 L .79505 .45709 L F
.26811 .29158 m .27565 .27385 L .291 .29606 L .363 .525 .883 r
F
.26811 .29158 m .25282 .2686 L .27565 .27385 L F
.76671 .43874 m .7812 .41287 L .79289 .43077 L .652 .711 .891 r
F
.76671 .43874 m .75487 .42085 L .7812 .41287 L F
.48785 .47554 m .49889 .45287 L .51275 .4678 L .65 .753 .925 r
F
.48785 .47554 m .47384 .46075 L .49889 .45287 L F
.13187 .47253 m .13821 .44979 L .15513 .46474 L .651 .753 .924 r
F
.13187 .47253 m .11483 .45772 L .13821 .44979 L F
.46068 .39085 m .47138 .36568 L .48543 .38525 L .609 .675 .888 r
F
.46068 .39085 m .44654 .37106 L .47138 .36568 L F
.84388 .47898 m .85961 .4564 L .87043 .4713 L .649 .753 .925 r
F
.84388 .47898 m .83289 .46422 L .85961 .4564 L F
.19511 .47172 m .20229 .44895 L .21867 .46392 L .651 .753 .924 r
F
.19511 .47172 m .1786 .45688 L .20229 .44895 L F
.55136 .47479 m .56324 .45211 L .57657 .46705 L .65 .753 .925 r
F
.55136 .47479 m .53788 .45999 L .56324 .45211 L F
.66486 .42604 m .67811 .4001 L .69062 .41841 L .646 .704 .89 r
F
.66486 .42604 m .65222 .40771 L .67811 .4001 L F
.56276 .41076 m .57476 .38495 L .58805 .40378 L .634 .694 .888 r
F
.56276 .41076 m .54934 .39183 L .57476 .38495 L F
.83066 .44042 m .84596 .41457 L .85715 .43231 L .654 .715 .892 r
F
.83066 .44042 m .8193 .42271 L .84596 .41457 L F
.422 .37579 m .4322 .3511 L .44654 .37106 L .592 .664 .889 r
F
.422 .37579 m .40757 .35556 L .4322 .3511 L F
.25844 .47091 m .26646 .44812 L .28232 .46311 L .651 .753 .924 r
F
.25844 .47091 m .24246 .45606 L .26646 .44812 L F
.61497 .47406 m .6277 .45136 L .6405 .46632 L .65 .753 .925 r
F
.61497 .47406 m .60202 .45924 L .6277 .45136 L F
.30614 .31813 m .31453 .29732 L .32968 .31882 L .471 .591 .891 r
F
.30614 .31813 m .291 .29606 L .31453 .29732 L F
.32188 .47011 m .33074 .4473 L .34606 .46231 L .651 .753 .924 r
F
.32188 .47011 m .30642 .45524 L .33074 .4473 L F
.67868 .47335 m .69226 .45062 L .70452 .4656 L .65 .753 .925 r
F
.67868 .47335 m .66626 .4585 L .69226 .45062 L F
.38328 .35908 m .39294 .33516 L .40757 .35556 L .567 .649 .89 r
F
.38328 .35908 m .36858 .33834 L .39294 .33516 L F
.23366 .25266 m .23732 .2455 L .25282 .2686 L .147 .383 .835 r
F
.22948 .2413 m .23732 .2455 L .23366 .25266 L F
.34461 .34015 m .35368 .31744 L .36858 .33834 L .53 .627 .892 r
F
.34461 .34015 m .32968 .31882 L .35368 .31744 L F
.72878 .42873 m .74285 .40276 L .75487 .42085 L .65 .709 .891 r
F
.72878 .42873 m .71661 .41064 L .74285 .40276 L F
.3854 .46933 m .39511 .4465 L .4099 .46152 L .65 .753 .924 r
F
.3854 .46933 m .37047 .45444 L .39511 .4465 L F
.74249 .47265 m .75693 .4499 L .76865 .4649 L .65 .753 .925 r
F
.74249 .47265 m .73061 .45779 L .75693 .4499 L F
.52417 .39842 m .53572 .37271 L .54934 .39183 L .626 .688 .889 r
F
.52417 .39842 m .51044 .37918 L .53572 .37271 L F
.62656 .41515 m .63938 .38918 L .65222 .40771 L .641 .701 .89 r
F
.62656 .41515 m .61359 .39658 L .63938 .38918 L F
.44903 .46856 m .45959 .4457 L .47384 .46075 L .65 .753 .925 r
F
.44903 .46856 m .43463 .45365 L .45959 .4457 L F
.80641 .47197 m .8217 .4492 L .83289 .46422 L F
.80641 .47197 m .79505 .45709 L .8217 .4492 L F
.79289 .43077 m .80778 .40479 L .8193 .42271 L .652 .713 .892 r
F
.79289 .43077 m .7812 .41287 L .80778 .40479 L F
.15513 .46474 m .1618 .44179 L .1786 .45688 L .651 .753 .924 r
F
.15513 .46474 m .13821 .44979 L .1618 .44179 L F
.51275 .4678 m .52416 .44492 L .53788 .45999 L .65 .753 .925 r
F
.51275 .4678 m .49889 .45287 L .52416 .44492 L F
.87043 .4713 m .88659 .44852 L .89722 .46356 L .649 .752 .925 r
F
.87043 .4713 m .85961 .4564 L .88659 .44852 L F
.21867 .46392 m .2262 .44095 L .24246 .45606 L .651 .753 .924 r
F
.21867 .46392 m .20229 .44895 L .2262 .44095 L F
.57657 .46705 m .58884 .44416 L .60202 .45924 L .65 .753 .925 r
F
.57657 .46705 m .56324 .45211 L .58884 .44416 L F
.48543 .38525 m .4965 .35975 L .51044 .37918 L .616 .682 .889 r
F
.48543 .38525 m .47138 .36568 L .4965 .35975 L F
.69062 .41841 m .70426 .39235 L .71661 .41064 L .647 .707 .891 r
F
.69062 .41841 m .67811 .4001 L .70426 .39235 L F
.85715 .43231 m .87287 .40634 L .88389 .42413 L .654 .716 .894 r
F
.85715 .43231 m .84596 .41457 L .87287 .40634 L F
.25282 .2686 m .26007 .25148 L .27565 .27385 L .333 .51 .882 r
F
.25282 .2686 m .23732 .2455 L .26007 .25148 L F
.58805 .40378 m .60043 .37781 L .61359 .39658 L .636 .698 .89 r
F
.58805 .40378 m .57476 .38495 L .60043 .37781 L F
.28232 .46311 m .29069 .44012 L .30642 .45524 L .651 .753 .924 r
F
.28232 .46311 m .26646 .44812 L .29069 .44012 L F
.6405 .46632 m .65362 .44341 L .66626 .4585 L .65 .753 .925 r
F
.6405 .46632 m .6277 .45136 L .65362 .44341 L F
.34606 .46231 m .35529 .43929 L .37047 .45444 L .651 .753 .924 r
F
.34606 .46231 m .33074 .4473 L .35529 .43929 L F
.70452 .4656 m .71851 .44267 L .73061 .45779 L .65 .753 .925 r
F
.70452 .4656 m .69226 .45062 L .71851 .44267 L F
.44654 .37106 m .45713 .34591 L .47138 .36568 L .603 .673 .89 r
F
.44654 .37106 m .4322 .3511 L .45713 .34591 L F
.75487 .42085 m .76934 .39476 L .7812 .41287 L .65 .711 .892 r
F
.75487 .42085 m .74285 .40276 L .76934 .39476 L F
.4099 .46152 m .41998 .43849 L .43463 .45365 L .65 .753 .924 r
F
.4099 .46152 m .39511 .4465 L .41998 .43849 L F
.76865 .4649 m .78351 .44195 L .79505 .45709 L .65 .753 .925 r
F
.76865 .4649 m .75693 .4499 L .78351 .44195 L F
.22111 .2232 m .23732 .2455 L .22948 .2413 L .094 .351 .821 r
F
.65222 .40771 m .66542 .38159 L .67811 .4001 L .643 .704 .891 r
F
.65222 .40771 m .63938 .38918 L .66542 .38159 L F
.291 .29606 m .29916 .27565 L .31453 .29732 L .452 .583 .894 r
F
.291 .29606 m .27565 .27385 L .29916 .27565 L F
.47384 .46075 m .48478 .43769 L .49889 .45287 L .65 .753 .925 r
F
.47384 .46075 m .45959 .4457 L .48478 .43769 L F
.11483 .45772 m .121 .43458 L .13821 .44979 L .651 .753 .924 r
F
.11483 .45772 m .0975 .44265 L .121 .43458 L F
.40757 .35556 m .41764 .33095 L .4322 .3511 L .584 .662 .892 r
F
.40757 .35556 m .39294 .33516 L .41764 .33095 L F
.54934 .39183 m .56126 .36591 L .57476 .38495 L .63 .693 .89 r
F
.54934 .39183 m .53572 .37271 L .56126 .36591 L F
.83289 .46422 m .84861 .44125 L .85961 .4564 L .649 .753 .925 r
F
.83289 .46422 m .8217 .4492 L .84861 .44125 L F
.8193 .42271 m .8346 .39661 L .84596 .41457 L .653 .715 .894 r
F
.8193 .42271 m .80778 .40479 L .8346 .39661 L F
.1786 .45688 m .18562 .43372 L .20229 .44895 L .651 .753 .924 r
F
.1786 .45688 m .1618 .44179 L .18562 .43372 L F
.53788 .45999 m .54968 .43691 L .56324 .45211 L .65 .753 .925 r
F
.53788 .45999 m .52416 .44492 L .54968 .43691 L F
.36858 .33834 m .37809 .31458 L .39294 .33516 L .558 .646 .893 r
F
.36858 .33834 m .35368 .31744 L .37809 .31458 L F
.32968 .31882 m .33855 .29636 L .35368 .31744 L .518 .622 .895 r
F
.32968 .31882 m .31453 .29732 L .33855 .29636 L F
.24246 .45606 m .25033 .43288 L .26646 .44812 L .651 .753 .924 r
F
.24246 .45606 m .2262 .44095 L .25033 .43288 L F
.60202 .45924 m .61468 .43614 L .6277 .45136 L .65 .753 .925 r
F
.60202 .45924 m .58884 .44416 L .61468 .43614 L F
.71661 .41064 m .73065 .38445 L .74285 .40276 L .648 .709 .892 r
F
.71661 .41064 m .70426 .39235 L .73065 .38445 L F
.51044 .37918 m .52189 .35339 L .53572 .37271 L .622 .688 .891 r
F
.51044 .37918 m .4965 .35975 L .52189 .35339 L F
.30642 .45524 m .31515 .43204 L .33074 .4473 L .651 .753 .924 r
F
.30642 .45524 m .29069 .44012 L .31515 .43204 L F
.66626 .4585 m .67979 .43538 L .69226 .45062 L .65 .753 .925 r
F
.66626 .4585 m .65362 .44341 L .67979 .43538 L F
.61359 .39658 m .62636 .37044 L .63938 .38918 L .639 .701 .891 r
F
.61359 .39658 m .60043 .37781 L .62636 .37044 L F
.37047 .45444 m .38007 .43121 L .39511 .4465 L .65 .753 .924 r
F
.37047 .45444 m .35529 .43929 L .38007 .43121 L F
.73061 .45779 m .74501 .43465 L .75693 .4499 L .65 .753 .925 r
F
.73061 .45779 m .71851 .44267 L .74501 .43465 L F
.7812 .41287 m .79608 .38665 L .80778 .40479 L .651 .713 .894 r
F
.7812 .41287 m .76934 .39476 L .79608 .38665 L F
.23732 .2455 m .24427 .22894 L .26007 .25148 L .302 .494 .88 r
F
.23732 .2455 m .22161 .22225 L .24427 .22894 L F
.22111 .2232 m .22161 .22225 L .23732 .2455 L .094 .351 .821 r
F
.43463 .45365 m .44509 .4304 L .45959 .4457 L .65 .753 .925 r
F
.43463 .45365 m .41998 .43849 L .44509 .4304 L F
.79505 .45709 m .81033 .43393 L .8217 .4492 L F
.79505 .45709 m .78351 .44195 L .81033 .43393 L F
.47138 .36568 m .48235 .34013 L .4965 .35975 L .611 .681 .892 r
F
.47138 .36568 m .45713 .34591 L .48235 .34013 L F
.13821 .44979 m .14472 .42644 L .1618 .44179 L .651 .753 .924 r
F
.13821 .44979 m .121 .43458 L .14472 .42644 L F
.49889 .45287 m .51021 .4296 L .52416 .44492 L .65 .753 .925 r
F
.49889 .45287 m .48478 .43769 L .51021 .4296 L F
.67811 .4001 m .69172 .37384 L .70426 .39235 L .644 .707 .892 r
F
.67811 .4001 m .66542 .38159 L .69172 .37384 L F
.85961 .4564 m .87576 .43323 L .88659 .44852 L .649 .752 .925 r
F
.85961 .4564 m .84861 .44125 L .87576 .43323 L F
.57476 .38495 m .58706 .35882 L .60043 .37781 L .633 .697 .892 r
F
.57476 .38495 m .56126 .36591 L .58706 .35882 L F
.84596 .41457 m .86168 .38833 L .87287 .40634 L .653 .716 .895 r
F
.84596 .41457 m .8346 .39661 L .86168 .38833 L F
.20229 .44895 m .20966 .42558 L .2262 .44095 L .651 .753 .924 r
F
.20229 .44895 m .18562 .43372 L .20966 .42558 L F
.56324 .45211 m .57544 .42882 L .58884 .44416 L .65 .753 .925 r
F
.56324 .45211 m .54968 .43691 L .57544 .42882 L F
.4322 .3511 m .44266 .32594 L .45713 .34591 L .597 .672 .893 r
F
.4322 .3511 m .41764 .33095 L .44266 .32594 L F
.26646 .44812 m .2747 .42473 L .29069 .44012 L .651 .753 .924 r
F
.26646 .44812 m .25033 .43288 L .2747 .42473 L F
.6277 .45136 m .64077 .42805 L .65362 .44341 L .65 .753 .925 r
F
.6277 .45136 m .61468 .43614 L .64077 .42805 L F
.74285 .40276 m .7573 .37643 L .76934 .39476 L .648 .711 .894 r
F
.74285 .40276 m .73065 .38445 L .7573 .37643 L F
.27565 .27385 m .28356 .25381 L .29916 .27565 L .433 .575 .896 r
F
.27565 .27385 m .26007 .25148 L .28356 .25381 L F
.33074 .4473 m .33984 .42389 L .35529 .43929 L .651 .753 .924 r
F
.33074 .4473 m .31515 .43204 L .33984 .42389 L F
.69226 .45062 m .70621 .42729 L .71851 .44267 L .65 .753 .925 r
F
.69226 .45062 m .67979 .43538 L .70621 .42729 L F
.39294 .33516 m .40286 .3106 L .41764 .33095 L .577 .66 .894 r
F
.39294 .33516 m .37809 .31458 L .40286 .3106 L F
.63938 .38918 m .65254 .36286 L .66542 .38159 L .641 .704 .893 r
F
.63938 .38918 m .62636 .37044 L .65254 .36286 L F
.53572 .37271 m .54756 .34666 L .56126 .36591 L .627 .693 .892 r
F
.53572 .37271 m .52189 .35339 L .54756 .34666 L F
.39511 .4465 m .40508 .42306 L .41998 .43849 L .65 .753 .924 r
F
.39511 .4465 m .38007 .43121 L .40508 .42306 L F
.31453 .29732 m .32321 .27509 L .33855 .29636 L .505 .618 .897 r
F
.31453 .29732 m .29916 .27565 L .32321 .27509 L F
.35368 .31744 m .36301 .2938 L .37809 .31458 L .549 .643 .896 r
F
.35368 .31744 m .33855 .29636 L .36301 .2938 L F
.75693 .4499 m .77176 .42655 L .78351 .44195 L .65 .753 .925 r
F
.75693 .4499 m .74501 .43465 L .77176 .42655 L F
.80778 .40479 m .82307 .37842 L .8346 .39661 L .651 .715 .895 r
F
.80778 .40479 m .79608 .38665 L .82307 .37842 L F
.45959 .4457 m .47043 .42224 L .48478 .43769 L .65 .753 .925 r
F
.45959 .4457 m .44509 .4304 L .47043 .42224 L F
.0975 .44265 m .10349 .41911 L .121 .43458 L .651 .753 .924 r
F
.0975 .44265 m .07988 .42732 L .10349 .41911 L F
.8217 .4492 m .83741 .42583 L .84861 .44125 L .649 .753 .925 r
F
.8217 .4492 m .81033 .43393 L .83741 .42583 L F
.22045 .22157 m .22161 .22225 L .22111 .2232 L .094 .351 .821 r
F
.1618 .44179 m .16866 .41823 L .18562 .43372 L .651 .753 .924 r
F
.1618 .44179 m .14472 .42644 L .16866 .41823 L F
.52416 .44492 m .53588 .42144 L .54968 .43691 L .65 .753 .925 r
F
.52416 .44492 m .51021 .4296 L .53588 .42144 L F
.70426 .39235 m .71826 .36593 L .73065 .38445 L .646 .709 .894 r
F
.70426 .39235 m .69172 .37384 L .71826 .36593 L F
.4965 .35975 m .50786 .33386 L .52189 .35339 L .618 .687 .893 r
F
.4965 .35975 m .48235 .34013 L .50786 .33386 L F
.21858 .2178 m .22161 .22225 L .22045 .22157 L .061 .348 .823 r
F
.2262 .44095 m .23392 .41736 L .25033 .43288 L .651 .753 .924 r
F
.2262 .44095 m .20966 .42558 L .23392 .41736 L F
.58884 .44416 m .60144 .42065 L .61468 .43614 L .65 .753 .925 r
F
.58884 .44416 m .57544 .42882 L .60144 .42065 L F
.60043 .37781 m .61313 .35148 L .62636 .37044 L .636 .701 .893 r
F
.60043 .37781 m .58706 .35882 L .61313 .35148 L F
.22161 .22225 m .22824 .20623 L .24427 .22894 L .27 .478 .877 r
F
.21231 .20103 m .22161 .22225 L .21858 .2178 L F
.21231 .20103 m .22824 .20623 L .22161 .22225 L F
.29069 .44012 m .29929 .41651 L .31515 .43204 L .651 .753 .924 r
F
.29069 .44012 m .2747 .42473 L .29929 .41651 L F
.65362 .44341 m .6671 .41988 L .67979 .43538 L .65 .753 .925 r
F
.65362 .44341 m .64077 .42805 L .6671 .41988 L F
.76934 .39476 m .7842 .36828 L .79608 .38665 L .649 .713 .895 r
F
.76934 .39476 m .7573 .37643 L .7842 .36828 L F
.45713 .34591 m .46798 .32029 L .48235 .34013 L .606 .68 .894 r
F
.45713 .34591 m .44266 .32594 L .46798 .32029 L F
.35529 .43929 m .36476 .41566 L .38007 .43121 L .65 .753 .924 r
F
.35529 .43929 m .33984 .42389 L .36476 .41566 L F
.71851 .44267 m .73288 .41913 L .74501 .43465 L .65 .753 .925 r
F
.71851 .44267 m .70621 .42729 L .73288 .41913 L F
.66542 .38159 m .67898 .3551 L .69172 .37384 L .642 .707 .894 r
F
.66542 .38159 m .65254 .36286 L .67898 .3551 L F
.41998 .43849 m .43034 .41483 L .44509 .4304 L .65 .753 .925 r
F
.41998 .43849 m .40508 .42306 L .43034 .41483 L F
.78351 .44195 m .79876 .41839 L .81033 .43393 L F
.78351 .44195 m .77176 .42655 L .79876 .41839 L F
.56126 .36591 m .57349 .33962 L .58706 .35882 L .63 .697 .893 r
F
.56126 .36591 m .54756 .34666 L .57349 .33962 L F
.8346 .39661 m .85031 .3701 L .86168 .38833 L .652 .716 .896 r
F
.8346 .39661 m .82307 .37842 L .85031 .3701 L F
.41764 .33095 m .42797 .30576 L .44266 .32594 L .591 .671 .895 r
F
.41764 .33095 m .40286 .3106 L .42797 .30576 L F
.121 .43458 m .12733 .41083 L .14472 .42644 L .651 .753 .924 r
F
.121 .43458 m .10349 .41911 L .12733 .41083 L F
.48478 .43769 m .49601 .41401 L .51021 .4296 L .65 .753 .925 r
F
.48478 .43769 m .47043 .42224 L .49601 .41401 L F
.84861 .44125 m .86475 .41767 L .87576 .43323 L .649 .752 .925 r
F
.84861 .44125 m .83741 .42583 L .86475 .41767 L F
.26007 .25148 m .26773 .23178 L .28356 .25381 L .413 .567 .897 r
F
.26007 .25148 m .24427 .22894 L .26773 .23178 L F
.18562 .43372 m .19283 .40994 L .20966 .42558 L .651 .753 .924 r
F
.18562 .43372 m .16866 .41823 L .19283 .40994 L F
.54968 .43691 m .5618 .41321 L .57544 .42882 L .65 .753 .925 r
F
.54968 .43691 m .53588 .42144 L .5618 .41321 L F
.73065 .38445 m .74507 .35787 L .7573 .37643 L .647 .712 .895 r
F
.73065 .38445 m .71826 .36593 L .74507 .35787 L F
.37809 .31458 m .38786 .29005 L .40286 .3106 L .57 .658 .897 r
F
.37809 .31458 m .36301 .2938 L .38786 .29005 L F
.29916 .27565 m .30763 .25363 L .32321 .27509 L .492 .613 .9 r
F
.29916 .27565 m .28356 .25381 L .30763 .25363 L F
.25033 .43288 m .25842 .40907 L .2747 .42473 L .651 .753 .924 r
F
.25033 .43288 m .23392 .41736 L .25842 .40907 L F
.61468 .43614 m .62769 .41242 L .64077 .42805 L .65 .753 .925 r
F
.61468 .43614 m .60144 .42065 L .62769 .41242 L F
.33855 .29636 m .34771 .27282 L .36301 .2938 L .539 .64 .899 r
F
.33855 .29636 m .32321 .27509 L .34771 .27282 L F
.52189 .35339 m .53364 .3272 L .54756 .34666 L .623 .693 .894 r
F
.52189 .35339 m .50786 .33386 L .53364 .3272 L F
.62636 .37044 m .63946 .34391 L .65254 .36286 L .638 .704 .894 r
F
.62636 .37044 m .61313 .35148 L .63946 .34391 L F
.31515 .43204 m .32412 .40821 L .33984 .42389 L .651 .753 .924 r
F
.31515 .43204 m .29929 .41651 L .32412 .40821 L F
.67979 .43538 m .69369 .41164 L .70621 .42729 L .65 .753 .925 r
F
.67979 .43538 m .6671 .41988 L .69369 .41164 L F
.79608 .38665 m .81135 .36001 L .82307 .37842 L .65 .715 .896 r
F
.79608 .38665 m .7842 .36828 L .81135 .36001 L F
.38007 .43121 m .38992 .40736 L .40508 .42306 L .65 .753 .924 r
F
.38007 .43121 m .36476 .41566 L .38992 .40736 L F
.74501 .43465 m .7598 .41089 L .77176 .42655 L .65 .753 .925 r
F
.74501 .43465 m .73288 .41913 L .7598 .41089 L F
.44509 .4304 m .45583 .40653 L .47043 .42224 L F
.44509 .4304 m .43034 .41483 L .45583 .40653 L F
.07988 .42732 m .08568 .40337 L .10349 .41911 L .651 .753 .924 r
F
.07988 .42732 m .06194 .41172 L .08568 .40337 L F
.48235 .34013 m .4936 .31412 L .50786 .33386 L .614 .687 .895 r
F
.48235 .34013 m .46798 .32029 L .4936 .31412 L F
.81033 .43393 m .82602 .41015 L .83741 .42583 L .649 .753 .925 r
F
.81033 .43393 m .79876 .41839 L .82602 .41015 L F
.69172 .37384 m .70568 .34717 L .71826 .36593 L .644 .709 .895 r
F
.69172 .37384 m .67898 .3551 L .70568 .34717 L F
.58706 .35882 m .59969 .33229 L .61313 .35148 L .633 .701 .894 r
F
.58706 .35882 m .57349 .33962 L .59969 .33229 L F
.14472 .42644 m .1514 .40247 L .16866 .41823 L .651 .753 .924 r
F
.14472 .42644 m .12733 .41083 L .1514 .40247 L F
.51021 .4296 m .52184 .40571 L .53588 .42144 L .65 .753 .925 r
F
.51021 .4296 m .49601 .41401 L .52184 .40571 L F
.20966 .42558 m .21723 .40158 L .23392 .41736 L .651 .753 .924 r
F
.20966 .42558 m .19283 .40994 L .21723 .40158 L F
.57544 .42882 m .58796 .4049 L .60144 .42065 L .65 .753 .925 r
F
.57544 .42882 m .5618 .41321 L .58796 .4049 L F
.44266 .32594 m .45339 .30023 L .46798 .32029 L .602 .679 .896 r
F
.44266 .32594 m .42797 .30576 L .45339 .30023 L F
.7573 .37643 m .77213 .34968 L .7842 .36828 L .648 .713 .896 r
F
.7573 .37643 m .74507 .35787 L .77213 .34968 L F
.2747 .42473 m .28315 .4007 L .29929 .41651 L .651 .753 .924 r
F
.2747 .42473 m .25842 .40907 L .28315 .4007 L F
.64077 .42805 m .65419 .40411 L .6671 .41988 L .65 .753 .925 r
F
.64077 .42805 m .62769 .41242 L .65419 .40411 L F
.65254 .36286 m .66605 .33614 L .67898 .3551 L .64 .707 .895 r
F
.65254 .36286 m .63946 .34391 L .66605 .33614 L F
.24427 .22894 m .25167 .20954 L .26773 .23178 L .393 .558 .898 r
F
.24427 .22894 m .22824 .20623 L .25167 .20954 L F
.33984 .42389 m .34919 .39984 L .36476 .41566 L .65 .753 .924 r
F
.33984 .42389 m .32412 .40821 L .34919 .39984 L F
.54756 .34666 m .55971 .32019 L .57349 .33962 L .627 .697 .895 r
F
.54756 .34666 m .53364 .3272 L .55971 .32019 L F
.70621 .42729 m .72053 .40333 L .73288 .41913 L .65 .753 .925 r
F
.70621 .42729 m .69369 .41164 L .72053 .40333 L F
.40286 .3106 m .41305 .28537 L .42797 .30576 L .585 .67 .897 r
F
.40286 .3106 m .38786 .29005 L .41305 .28537 L F
.82307 .37842 m .83877 .35162 L .85031 .3701 L .65 .717 .897 r
F
.82307 .37842 m .81135 .36001 L .83877 .35162 L F
.40508 .42306 m .41532 .39899 L .43034 .41483 L .65 .753 .925 r
F
.40508 .42306 m .38992 .40736 L .41532 .39899 L F
.77176 .42655 m .78698 .40257 L .79876 .41839 L F
.77176 .42655 m .7598 .41089 L .78698 .40257 L F
.36301 .2938 m .37262 .26928 L .38786 .29005 L .563 .656 .899 r
F
.36301 .2938 m .34771 .27282 L .37262 .26928 L F
.28356 .25381 m .29181 .23196 L .30763 .25363 L .478 .608 .902 r
F
.28356 .25381 m .26773 .23178 L .29181 .23196 L F
.10349 .41911 m .10965 .39493 L .12733 .41083 L .651 .753 .924 r
F
.10349 .41911 m .08568 .40337 L .10965 .39493 L F
.47043 .42224 m .48157 .39815 L .49601 .41401 L .65 .753 .925 r
F
.47043 .42224 m .45583 .40653 L .48157 .39815 L F
.83741 .42583 m .85355 .40183 L .86475 .41767 L .649 .752 .925 r
F
.83741 .42583 m .82602 .41015 L .85355 .40183 L F
.32321 .27509 m .33218 .25163 L .34771 .27282 L .529 .637 .901 r
F
.32321 .27509 m .30763 .25363 L .33218 .25163 L F
.71826 .36593 m .73265 .33908 L .74507 .35787 L .645 .712 .896 r
F
.71826 .36593 m .70568 .34717 L .73265 .33908 L F
.16866 .41823 m .1757 .39403 L .19283 .40994 L .651 .753 .924 r
F
.16866 .41823 m .1514 .40247 L .1757 .39403 L F
.50786 .33386 m .51951 .30751 L .53364 .3272 L .62 .692 .896 r
F
.50786 .33386 m .4936 .31412 L .51951 .30751 L F
.53588 .42144 m .54792 .39732 L .5618 .41321 L .65 .753 .925 r
F
.53588 .42144 m .52184 .40571 L .54792 .39732 L F
.61313 .35148 m .62617 .32472 L .63946 .34391 L .636 .704 .895 r
F
.61313 .35148 m .59969 .33229 L .62617 .32472 L F
.23392 .41736 m .24186 .39314 L .25842 .40907 L .651 .753 .924 r
F
.23392 .41736 m .21723 .40158 L .24186 .39314 L F
.60144 .42065 m .61438 .39651 L .62769 .41242 L .65 .753 .925 r
F
.60144 .42065 m .58796 .4049 L .61438 .39651 L F
.7842 .36828 m .79946 .34135 L .81135 .36001 L .648 .715 .897 r
F
.7842 .36828 m .77213 .34968 L .79946 .34135 L F
.29929 .41651 m .30812 .39226 L .32412 .40821 L .651 .753 .924 r
F
.29929 .41651 m .28315 .4007 L .30812 .39226 L F
.6671 .41988 m .68095 .39572 L .69369 .41164 L .65 .753 .925 r
F
.6671 .41988 m .65419 .40411 L .68095 .39572 L F
.46798 .32029 m .47913 .29414 L .4936 .31412 L .61 .686 .897 r
F
.46798 .32029 m .45339 .30023 L .47913 .29414 L F
.36476 .41566 m .37449 .39139 L .38992 .40736 L .65 .753 .924 r
F
.36476 .41566 m .34919 .39984 L .37449 .39139 L F
.73288 .41913 m .74763 .39494 L .7598 .41089 L .65 .753 .925 r
F
.73288 .41913 m .72053 .40333 L .74763 .39494 L F
.67898 .3551 m .6929 .32818 L .70568 .34717 L .642 .709 .896 r
F
.67898 .3551 m .66605 .33614 L .6929 .32818 L F
.57349 .33962 m .58605 .31288 L .59969 .33229 L .631 .701 .896 r
F
.57349 .33962 m .55971 .32019 L .58605 .31288 L F
.43034 .41483 m .44097 .39053 L .45583 .40653 L .65 .753 .925 r
F
.43034 .41483 m .41532 .39899 L .44097 .39053 L F
.06194 .41172 m .06755 .38734 L .08568 .40337 L .651 .753 .924 r
F
.06194 .41172 m .04369 .39585 L .06755 .38734 L F
.79876 .41839 m .81443 .39418 L .82602 .41015 L .649 .753 .925 r
F
.79876 .41839 m .78698 .40257 L .81443 .39418 L F
.42797 .30576 m .43858 .27995 L .45339 .30023 L .597 .678 .898 r
F
.42797 .30576 m .41305 .28537 L .43858 .27995 L F
.12733 .41083 m .13384 .38643 L .1514 .40247 L .651 .753 .924 r
F
.12733 .41083 m .10965 .39493 L .13384 .38643 L F
.49601 .41401 m .50755 .38969 L .52184 .40571 L .65 .753 .925 r
F
.49601 .41401 m .48157 .39815 L .50755 .38969 L F
.74507 .35787 m .75987 .33084 L .77213 .34968 L .646 .714 .897 r
F
.74507 .35787 m .73265 .33908 L .75987 .33084 L F
.19283 .40994 m .20023 .38552 L .21723 .40158 L .651 .753 .924 r
F
.19283 .40994 m .1757 .39403 L .20023 .38552 L F
.5618 .41321 m .57425 .38886 L .58796 .4049 L .65 .753 .925 r
F
.5618 .41321 m .54792 .39732 L .57425 .38886 L F
.63946 .34391 m .65291 .31693 L .66605 .33614 L .638 .707 .896 r
F
.63946 .34391 m .62617 .32472 L .65291 .31693 L F
.38786 .29005 m .3979 .26475 L .41305 .28537 L .579 .668 .9 r
F
.38786 .29005 m .37262 .26928 L .3979 .26475 L F
.53364 .3272 m .54571 .30052 L .55971 .32019 L .624 .697 .897 r
F
.53364 .3272 m .51951 .30751 L .54571 .30052 L F
.25842 .40907 m .26673 .38462 L .28315 .4007 L .651 .753 .924 r
F
.25842 .40907 m .24186 .39314 L .26673 .38462 L F
.62769 .41242 m .64105 .38805 L .65419 .40411 L .65 .753 .925 r
F
.62769 .41242 m .61438 .39651 L .64105 .38805 L F
.81135 .36001 m .82705 .3329 L .83877 .35162 L .649 .717 .898 r
F
.81135 .36001 m .79946 .34135 L .82705 .3329 L F
.26773 .23178 m .27575 .21007 L .29181 .23196 L .465 .603 .904 r
F
.26773 .23178 m .25167 .20954 L .27575 .21007 L F
.32412 .40821 m .33333 .38373 L .34919 .39984 L .65 .753 .924 r
F
.32412 .40821 m .30812 .39226 L .33333 .38373 L F
.34771 .27282 m .35715 .24829 L .37262 .26928 L .555 .654 .901 r
F
.34771 .27282 m .33218 .25163 L .35715 .24829 L F
.69369 .41164 m .70797 .38726 L .72053 .40333 L .65 .753 .925 r
F
.69369 .41164 m .68095 .39572 L .70797 .38726 L F
.30763 .25363 m .3164 .23023 L .33218 .25163 L .52 .634 .903 r
F
.30763 .25363 m .29181 .23196 L .3164 .23023 L F
.38992 .40736 m .40005 .38286 L .41532 .39899 L .65 .753 .925 r
F
.38992 .40736 m .37449 .39139 L .40005 .38286 L F
.7598 .41089 m .775 .38648 L .78698 .40257 L F
.7598 .41089 m .74763 .39494 L .775 .38648 L F
.70568 .34717 m .72003 .32004 L .73265 .33908 L .643 .712 .897 r
F
.70568 .34717 m .6929 .32818 L .72003 .32004 L F
.4936 .31412 m .50516 .28758 L .51951 .30751 L .616 .692 .897 r
F
.4936 .31412 m .47913 .29414 L .50516 .28758 L F
.08568 .40337 m .09164 .37876 L .10965 .39493 L .651 .753 .924 r
F
.08568 .40337 m .06755 .38734 L .09164 .37876 L F
.45583 .40653 m .46686 .382 L .48157 .39815 L .65 .753 .925 r
F
.45583 .40653 m .44097 .39053 L .46686 .382 L F
.82602 .41015 m .84214 .38572 L .85355 .40183 L .649 .752 .925 r
F
.82602 .41015 m .81443 .39418 L .84214 .38572 L F
.59969 .33229 m .61267 .3053 L .62617 .32472 L .634 .704 .897 r
F
.59969 .33229 m .58605 .31288 L .61267 .3053 L F
.1514 .40247 m .15827 .37784 L .1757 .39403 L .651 .753 .924 r
F
.1514 .40247 m .13384 .38643 L .15827 .37784 L F
.52184 .40571 m .53379 .38116 L .54792 .39732 L .65 .753 .925 r
F
.52184 .40571 m .50755 .38969 L .53379 .38116 L F
.77213 .34968 m .78737 .32245 L .79946 .34135 L .647 .715 .898 r
F
.77213 .34968 m .75987 .33084 L .78737 .32245 L F
.21723 .40158 m .225 .37692 L .24186 .39314 L .651 .753 .924 r
F
.21723 .40158 m .20023 .38552 L .225 .37692 L F
.58796 .4049 m .60083 .38033 L .61438 .39651 L .65 .753 .925 r
F
.58796 .4049 m .57425 .38886 L .60083 .38033 L F
.45339 .30023 m .46442 .27393 L .47913 .29414 L .606 .685 .898 r
F
.45339 .30023 m .43858 .27995 L .46442 .27393 L F
.28315 .4007 m .29184 .37602 L .30812 .39226 L .651 .753 .924 r
F
.28315 .4007 m .26673 .38462 L .29184 .37602 L F
.65419 .40411 m .66799 .37951 L .68095 .39572 L .65 .753 .925 r
F
.65419 .40411 m .64105 .38805 L .66799 .37951 L F
.66605 .33614 m .67992 .30894 L .6929 .32818 L .64 .709 .897 r
F
.66605 .33614 m .65291 .31693 L .67992 .30894 L F
.55971 .32019 m .57219 .29322 L .58605 .31288 L .628 .701 .897 r
F
.55971 .32019 m .54571 .30052 L .57219 .29322 L F
.34919 .39984 m .35879 .37513 L .37449 .39139 L .65 .753 .924 r
F
.34919 .39984 m .33333 .38373 L .35879 .37513 L F
.72053 .40333 m .73525 .37871 L .74763 .39494 L .65 .753 .925 r
F
.72053 .40333 m .70797 .38726 L .73525 .37871 L F
.41305 .28537 m .42353 .25943 L .43858 .27995 L .592 .677 .9 r
F
.41305 .28537 m .3979 .26475 L .42353 .25943 L F
.41532 .39899 m .42585 .37426 L .44097 .39053 L .65 .753 .925 r
F
.41532 .39899 m .40005 .38286 L .42585 .37426 L F
.78698 .40257 m .80263 .37794 L .81443 .39418 L .649 .753 .925 r
F
.78698 .40257 m .775 .38648 L .80263 .37794 L F
.73265 .33908 m .74742 .31174 L .75987 .33084 L .644 .714 .898 r
F
.73265 .33908 m .72003 .32004 L .74742 .31174 L F
.10965 .39493 m .11597 .3701 L .13384 .38643 L .651 .753 .924 r
F
.10965 .39493 m .09164 .37876 L .11597 .3701 L F
.48157 .39815 m .49301 .37339 L .50755 .38969 L .65 .753 .925 r
F
.48157 .39815 m .46686 .382 L .49301 .37339 L F
.37262 .26928 m .38252 .2439 L .3979 .26475 L .574 .667 .902 r
F
.37262 .26928 m .35715 .24829 L .38252 .2439 L F
.51951 .30751 m .53148 .28062 L .54571 .30052 L .621 .696 .898 r
F
.51951 .30751 m .50516 .28758 L .53148 .28062 L F
.62617 .32472 m .63956 .29748 L .65291 .31693 L .636 .707 .898 r
F
.62617 .32472 m .61267 .3053 L .63956 .29748 L F
.1757 .39403 m .18294 .36917 L .20023 .38552 L .651 .753 .924 r
F
.1757 .39403 m .15827 .37784 L .18294 .36917 L F
.54792 .39732 m .56029 .37254 L .57425 .38886 L .65 .753 .925 r
F
.54792 .39732 m .53379 .38116 L .56029 .37254 L F
.33218 .25163 m .34144 .22707 L .35715 .24829 L .548 .652 .904 r
F
.33218 .25163 m .3164 .23023 L .34144 .22707 L F
.29181 .23196 m .30038 .20859 L .3164 .23023 L .51 .631 .906 r
F
.29181 .23196 m .27575 .21007 L .30038 .20859 L F
.79946 .34135 m .81514 .31393 L .82705 .3329 L .648 .717 .899 r
F
.79946 .34135 m .78737 .32245 L .81514 .31393 L F
.24186 .39314 m .25001 .36825 L .26673 .38462 L .651 .753 .924 r
F
.24186 .39314 m .225 .37692 L .25001 .36825 L F
.61438 .39651 m .62768 .37171 L .64105 .38805 L .65 .753 .925 r
F
.61438 .39651 m .60083 .38033 L .62768 .37171 L F
.30812 .39226 m .3172 .36734 L .33333 .38373 L .65 .753 .924 r
F
.30812 .39226 m .29184 .37602 L .3172 .36734 L F
.68095 .39572 m .69518 .37089 L .70797 .38726 L .65 .753 .925 r
F
.68095 .39572 m .66799 .37951 L .69518 .37089 L F
.6929 .32818 m .70721 .30075 L .72003 .32004 L .642 .712 .898 r
F
.6929 .32818 m .67992 .30894 L .70721 .30075 L F
.47913 .29414 m .49058 .26741 L .50516 .28758 L .613 .691 .899 r
F
.47913 .29414 m .46442 .27393 L .49058 .26741 L F
.37449 .39139 m .38449 .36645 L .40005 .38286 L .65 .753 .925 r
F
.37449 .39139 m .35879 .37513 L .38449 .36645 L F
.58605 .31288 m .59895 .28562 L .61267 .3053 L .631 .704 .898 r
F
.58605 .31288 m .57219 .29322 L .59895 .28562 L F
.74763 .39494 m .7628 .37009 L .775 .38648 L .65 .753 .925 r
F
.74763 .39494 m .73525 .37871 L .7628 .37009 L F
.44097 .39053 m .4519 .36557 L .46686 .382 L F
.44097 .39053 m .42585 .37426 L .4519 .36557 L F
.81443 .39418 m .83054 .36931 L .84214 .38572 L .649 .752 .925 r
F
.81443 .39418 m .80263 .37794 L .83054 .36931 L F
.75987 .33084 m .77509 .30329 L .78737 .32245 L .646 .715 .899 r
F
.75987 .33084 m .74742 .31174 L .77509 .30329 L F
.43858 .27995 m .44948 .25348 L .46442 .27393 L .602 .685 .9 r
F
.43858 .27995 m .42353 .25943 L .44948 .25348 L F
.13384 .38643 m .14053 .36135 L .15827 .37784 L .651 .753 .924 r
F
.13384 .38643 m .11597 .3701 L .14053 .36135 L F
.50755 .38969 m .51941 .3647 L .53379 .38116 L .65 .753 .925 r
F
.50755 .38969 m .49301 .37339 L .51941 .3647 L F
.20023 .38552 m .20784 .36042 L .225 .37692 L .651 .753 .924 r
F
.20023 .38552 m .18294 .36917 L .20784 .36042 L F
.57425 .38886 m .58704 .36385 L .60083 .38033 L .65 .753 .925 r
F
.57425 .38886 m .56029 .37254 L .58704 .36385 L F
.65291 .31693 m .66673 .28944 L .67992 .30894 L .638 .709 .899 r
F
.65291 .31693 m .63956 .29748 L .66673 .28944 L F
.54571 .30052 m .5581 .27331 L .57219 .29322 L .626 .7 .899 r
F
.54571 .30052 m .53148 .28062 L .5581 .27331 L F
.26673 .38462 m .27527 .35949 L .29184 .37602 L .651 .753 .924 r
F
.26673 .38462 m .25001 .36825 L .27527 .35949 L F
.64105 .38805 m .65479 .36301 L .66799 .37951 L .65 .753 .925 r
F
.64105 .38805 m .62768 .37171 L .65479 .36301 L F
.3979 .26475 m .40824 .23867 L .42353 .25943 L .587 .676 .902 r
F
.3979 .26475 m .38252 .2439 L .40824 .23867 L F
.33333 .38373 m .3428 .35858 L .35879 .37513 L .65 .753 .924 r
F
.33333 .38373 m .3172 .36734 L .3428 .35858 L F
.70797 .38726 m .72265 .3622 L .73525 .37871 L .65 .753 .925 r
F
.70797 .38726 m .69518 .37089 L .72265 .3622 L F
.72003 .32004 m .73477 .29239 L .74742 .31174 L .643 .714 .899 r
F
.72003 .32004 m .70721 .30075 L .73477 .29239 L F
.35715 .24829 m .36688 .2228 L .38252 .2439 L .568 .665 .904 r
F
.35715 .24829 m .34144 .22707 L .36688 .2228 L F
.40005 .38286 m .41045 .35768 L .42585 .37426 L .65 .753 .925 r
F
.40005 .38286 m .38449 .36645 L .41045 .35768 L F
.775 .38648 m .79062 .36139 L .80263 .37794 L .649 .753 .925 r
F
.775 .38648 m .7628 .37009 L .79062 .36139 L F
.50516 .28758 m .51703 .26046 L .53148 .28062 L .619 .696 .9 r
F
.50516 .28758 m .49058 .26741 L .51703 .26046 L F
.61267 .3053 m .62599 .27777 L .63956 .29748 L .634 .707 .899 r
F
.61267 .3053 m .59895 .28562 L .62599 .27777 L F
.3164 .23023 m .32547 .2056 L .34144 .22707 L .54 .65 .906 r
F
.3164 .23023 m .30038 .20859 L .32547 .2056 L F
.46686 .382 m .47821 .3568 L .49301 .37339 L .65 .753 .925 r
F
.46686 .382 m .4519 .36557 L .47821 .3568 L F
.15827 .37784 m .16533 .35252 L .18294 .36917 L .651 .753 .924 r
F
.15827 .37784 m .14053 .36135 L .16533 .35252 L F
.53379 .38116 m .54608 .35593 L .56029 .37254 L .65 .753 .925 r
F
.53379 .38116 m .51941 .3647 L .54608 .35593 L F
.78737 .32245 m .80303 .29469 L .81514 .31393 L .646 .717 .9 r
F
.78737 .32245 m .77509 .30329 L .80303 .29469 L F
.225 .37692 m .233 .35158 L .25001 .36825 L .651 .753 .924 r
F
.225 .37692 m .20784 .36042 L .233 .35158 L F
.60083 .38033 m .61406 .35507 L .62768 .37171 L .65 .753 .925 r
F
.60083 .38033 m .58704 .36385 L .61406 .35507 L F
.46442 .27393 m .47576 .24698 L .49058 .26741 L .61 .691 .901 r
F
.46442 .27393 m .44948 .25348 L .47576 .24698 L F
.67992 .30894 m .69418 .2812 L .70721 .30075 L .64 .712 .899 r
F
.67992 .30894 m .66673 .28944 L .69418 .2812 L F
.29184 .37602 m .30077 .35066 L .3172 .36734 L .65 .753 .924 r
F
.29184 .37602 m .27527 .35949 L .30077 .35066 L F
.57219 .29322 m .58501 .26569 L .59895 .28562 L .629 .704 .899 r
F
.57219 .29322 m .5581 .27331 L .58501 .26569 L F
.66799 .37951 m .68216 .35424 L .69518 .37089 L .65 .753 .925 r
F
.66799 .37951 m .65479 .36301 L .68216 .35424 L F
.35879 .37513 m .36866 .34974 L .38449 .36645 L F
.35879 .37513 m .3428 .35858 L .36866 .34974 L F
.73525 .37871 m .75038 .35342 L .7628 .37009 L F
.73525 .37871 m .72265 .3622 L .75038 .35342 L F
.42353 .25943 m .4343 .23277 L .44948 .25348 L .598 .684 .902 r
F
.42353 .25943 m .40824 .23867 L .4343 .23277 L F
.74742 .31174 m .76261 .28387 L .77509 .30329 L .644 .716 .9 r
F
.74742 .31174 m .73477 .29239 L .76261 .28387 L F
.42585 .37426 m .43666 .34884 L .4519 .36557 L .65 .753 .925 r
F
.42585 .37426 m .41045 .35768 L .43666 .34884 L F
.80263 .37794 m .81872 .35261 L .83054 .36931 L .649 .752 .925 r
F
.80263 .37794 m .79062 .36139 L .81872 .35261 L F
.49301 .37339 m .50478 .34795 L .51941 .3647 L .65 .753 .925 r
F
.49301 .37339 m .47821 .3568 L .50478 .34795 L F
.63956 .29748 m .65332 .26968 L .66673 .28944 L .636 .709 .9 r
F
.63956 .29748 m .62599 .27777 L .65332 .26968 L F
.53148 .28062 m .54378 .25313 L .5581 .27331 L .623 .7 .9 r
F
.53148 .28062 m .51703 .26046 L .54378 .25313 L F
.38252 .2439 m .3927 .21765 L .40824 .23867 L .583 .675 .904 r
F
.38252 .2439 m .36688 .2228 L .3927 .21765 L F
.18294 .36917 m .19038 .34361 L .20784 .36042 L .651 .753 .924 r
F
.18294 .36917 m .16533 .35252 L .19038 .34361 L F
.56029 .37254 m .573 .34707 L .58704 .36385 L .65 .753 .925 r
F
.56029 .37254 m .54608 .35593 L .573 .34707 L F
.25001 .36825 m .2584 .34267 L .27527 .35949 L .651 .753 .924 r
F
.25001 .36825 m .233 .35158 L .2584 .34267 L F
.62768 .37171 m .64135 .34622 L .65479 .36301 L .65 .753 .925 r
F
.62768 .37171 m .61406 .35507 L .64135 .34622 L F
.34144 .22707 m .35099 .20145 L .36688 .2228 L .562 .664 .906 r
F
.34144 .22707 m .32547 .2056 L .35099 .20145 L F
.70721 .30075 m .72191 .27277 L .73477 .29239 L .641 .714 .9 r
F
.70721 .30075 m .69418 .2812 L .72191 .27277 L F
.3172 .36734 m .32653 .34173 L .3428 .35858 L .65 .753 .924 r
F
.3172 .36734 m .30077 .35066 L .32653 .34173 L F
.69518 .37089 m .70981 .34538 L .72265 .3622 L .65 .753 .925 r
F
.69518 .37089 m .68216 .35424 L .70981 .34538 L F
.49058 .26741 m .50234 .24003 L .51703 .26046 L .616 .696 .901 r
F
.49058 .26741 m .47576 .24698 L .50234 .24003 L F
.59895 .28562 m .6122 .25779 L .62599 .27777 L .632 .707 .9 r
F
.59895 .28562 m .58501 .26569 L .6122 .25779 L F
.38449 .36645 m .39478 .34081 L .41045 .35768 L .65 .753 .925 r
F
.38449 .36645 m .36866 .34974 L .39478 .34081 L F
.7628 .37009 m .77839 .34455 L .79062 .36139 L .649 .753 .925 r
F
.7628 .37009 m .75038 .35342 L .77839 .34455 L F
.4519 .36557 m .46313 .33991 L .47821 .3568 L .65 .753 .925 r
F
.4519 .36557 m .43666 .34884 L .46313 .33991 L F
.77509 .30329 m .79073 .27518 L .80303 .29469 L .645 .717 .9 r
F
.77509 .30329 m .76261 .28387 L .79073 .27518 L F
.44948 .25348 m .46069 .22629 L .47576 .24698 L .606 .69 .902 r
F
.44948 .25348 m .4343 .23277 L .46069 .22629 L F
.51941 .3647 m .53161 .33901 L .54608 .35593 L .65 .753 .925 r
F
.51941 .3647 m .50478 .34795 L .53161 .33901 L F
.66673 .28944 m .68093 .26138 L .69418 .2812 L .638 .712 .9 r
F
.66673 .28944 m .65332 .26968 L .68093 .26138 L F
.20784 .36042 m .21567 .33462 L .233 .35158 L .651 .753 .924 r
F
.20784 .36042 m .19038 .34361 L .21567 .33462 L F
.5581 .27331 m .57084 .24548 L .58501 .26569 L .627 .704 .901 r
F
.5581 .27331 m .54378 .25313 L .57084 .24548 L F
.58704 .36385 m .6002 .33814 L .61406 .35507 L .65 .753 .925 r
F
.58704 .36385 m .573 .34707 L .6002 .33814 L F
.27527 .35949 m .28405 .33366 L .30077 .35066 L .65 .753 .924 r
F
.27527 .35949 m .2584 .34267 L .28405 .33366 L F
.65479 .36301 m .66891 .33728 L .68216 .35424 L .65 .753 .925 r
F
.65479 .36301 m .64135 .34622 L .66891 .33728 L F
.40824 .23867 m .41887 .21179 L .4343 .23277 L .594 .683 .904 r
F
.40824 .23867 m .3927 .21765 L .41887 .21179 L F
.3428 .35858 m .35254 .33273 L .36866 .34974 L .65 .753 .925 r
F
.3428 .35858 m .32653 .34173 L .35254 .33273 L F
.73477 .29239 m .74992 .26417 L .76261 .28387 L .643 .716 .901 r
F
.73477 .29239 m .72191 .27277 L .74992 .26417 L F
.72265 .3622 m .73774 .33643 L .75038 .35342 L .65 .753 .925 r
F
.72265 .3622 m .70981 .34538 L .73774 .33643 L F
.41045 .35768 m .42115 .3318 L .43666 .34884 L F
.41045 .35768 m .39478 .34081 L .42115 .3318 L F
.62599 .27777 m .63969 .24965 L .65332 .26968 L .635 .709 .901 r
F
.62599 .27777 m .6122 .25779 L .63969 .24965 L F
.51703 .26046 m .52923 .23269 L .54378 .25313 L .621 .7 .901 r
F
.51703 .26046 m .50234 .24003 L .52923 .23269 L F
.79062 .36139 m .80668 .33561 L .81872 .35261 L .649 .752 .925 r
F
.79062 .36139 m .77839 .34455 L .80668 .33561 L F
.36688 .2228 m .3769 .19637 L .3927 .21765 L .578 .674 .905 r
F
.36688 .2228 m .35099 .20145 L .3769 .19637 L F
.47821 .3568 m .48987 .33089 L .50478 .34795 L .65 .753 .925 r
F
.47821 .3568 m .46313 .33991 L .48987 .33089 L F
.54608 .35593 m .55871 .32999 L .573 .34707 L F
.54608 .35593 m .53161 .33901 L .55871 .32999 L F
.69418 .2812 m .70883 .25288 L .72191 .27277 L .64 .714 .901 r
F
.69418 .2812 m .68093 .26138 L .70883 .25288 L F
.233 .35158 m .24122 .32553 L .2584 .34267 L .651 .753 .924 r
F
.233 .35158 m .21567 .33462 L .24122 .32553 L F
.61406 .35507 m .62767 .32911 L .64135 .34622 L .65 .753 .925 r
F
.61406 .35507 m .6002 .33814 L .62767 .32911 L F
.47576 .24698 m .48741 .21934 L .50234 .24003 L .613 .695 .902 r
F
.47576 .24698 m .46069 .22629 L .48741 .21934 L F
.58501 .26569 m .59818 .23754 L .6122 .25779 L .63 .707 .901 r
F
.58501 .26569 m .57084 .24548 L .59818 .23754 L F
.30077 .35066 m .30996 .32458 L .32653 .34173 L .65 .753 .924 r
F
.30077 .35066 m .28405 .33366 L .30996 .32458 L F
.68216 .35424 m .69674 .32825 L .70981 .34538 L .65 .753 .925 r
F
.68216 .35424 m .66891 .33728 L .69674 .32825 L F
.36866 .34974 m .37881 .32363 L .39478 .34081 L F
.36866 .34974 m .35254 .33273 L .37881 .32363 L F
.75038 .35342 m .76594 .32741 L .77839 .34455 L .649 .753 .925 r
F
.75038 .35342 m .73774 .33643 L .76594 .32741 L F
.76261 .28387 m .77822 .2554 L .79073 .27518 L .644 .717 .901 r
F
.76261 .28387 m .74992 .26417 L .77822 .2554 L F
.4343 .23277 m .44538 .20533 L .46069 .22629 L .603 .69 .904 r
F
.4343 .23277 m .41887 .21179 L .44538 .20533 L F
.43666 .34884 m .44779 .3227 L .46313 .33991 L .65 .753 .925 r
F
.43666 .34884 m .42115 .3318 L .44779 .3227 L F
.65332 .26968 m .66747 .24128 L .68093 .26138 L .637 .712 .901 r
F
.65332 .26968 m .63969 .24965 L .66747 .24128 L F
.54378 .25313 m .55643 .225 L .57084 .24548 L .625 .704 .902 r
F
.54378 .25313 m .52923 .23269 L .55643 .225 L F
.50478 .34795 m .51687 .32179 L .53161 .33901 L .65 .753 .925 r
F
.50478 .34795 m .48987 .33089 L .51687 .32179 L F
.573 .34707 m .58608 .32089 L .6002 .33814 L F
.573 .34707 m .55871 .32999 L .58608 .32089 L F
.3927 .21765 m .40318 .19054 L .41887 .21179 L .59 .683 .905 r
F
.3927 .21765 m .3769 .19637 L .40318 .19054 L F
.2584 .34267 m .26702 .31636 L .28405 .33366 L .65 .753 .924 r
F
.2584 .34267 m .24122 .32553 L .26702 .31636 L F
.64135 .34622 m .65541 .32 L .66891 .33728 L .65 .753 .925 r
F
.64135 .34622 m .62767 .32911 L .65541 .32 L F
.72191 .27277 m .73702 .24419 L .74992 .26417 L .641 .716 .902 r
F
.72191 .27277 m .70883 .25288 L .73702 .24419 L F
.32653 .34173 m .33613 .3154 L .35254 .33273 L .65 .753 .925 r
F
.32653 .34173 m .30996 .32458 L .33613 .3154 L F
.50234 .24003 m .51444 .21197 L .52923 .23269 L .618 .7 .903 r
F
.50234 .24003 m .48741 .21934 L .51444 .21197 L F
.70981 .34538 m .72486 .31914 L .73774 .33643 L .65 .753 .925 r
F
.70981 .34538 m .69674 .32825 L .72486 .31914 L F
.6122 .25779 m .62583 .22934 L .63969 .24965 L .633 .709 .902 r
F
.6122 .25779 m .59818 .23754 L .62583 .22934 L F
.39478 .34081 m .40535 .31445 L .42115 .3318 L .65 .753 .925 r
F
.39478 .34081 m .37881 .32363 L .40535 .31445 L F
.77839 .34455 m .79443 .31829 L .80668 .33561 L .649 .752 .925 r
F
.77839 .34455 m .76594 .32741 L .79443 .31829 L F
.46313 .33991 m .47469 .31352 L .48987 .33089 L .65 .753 .925 r
F
.46313 .33991 m .44779 .3227 L .47469 .31352 L F
.68093 .26138 m .69554 .23269 L .70883 .25288 L .639 .714 .902 r
F
.68093 .26138 m .66747 .24128 L .69554 .23269 L F
.46069 .22629 m .47222 .19836 L .48741 .21934 L .61 .695 .904 r
F
.46069 .22629 m .44538 .20533 L .47222 .19836 L F
.53161 .33901 m .54415 .3126 L .55871 .32999 L .65 .753 .925 r
F
.53161 .33901 m .51687 .32179 L .54415 .3126 L F
.57084 .24548 m .58393 .21701 L .59818 .23754 L .628 .707 .902 r
F
.57084 .24548 m .55643 .225 L .58393 .21701 L F
.6002 .33814 m .61373 .31169 L .62767 .32911 L .65 .753 .925 r
F
.6002 .33814 m .58608 .32089 L .61373 .31169 L F
.28405 .33366 m .29308 .3071 L .30996 .32458 L .65 .753 .924 r
F
.28405 .33366 m .26702 .31636 L .29308 .3071 L F
.66891 .33728 m .68343 .31081 L .69674 .32825 L .65 .753 .925 r
F
.66891 .33728 m .65541 .32 L .68343 .31081 L F
.74992 .26417 m .7655 .23532 L .77822 .2554 L .643 .717 .902 r
F
.74992 .26417 m .73702 .24419 L .7655 .23532 L F
.41887 .21179 m .42981 .18409 L .44538 .20533 L .6 .689 .905 r
F
.41887 .21179 m .40318 .19054 L .42981 .18409 L F
.35254 .33273 m .36256 .30613 L .37881 .32363 L .65 .753 .925 r
F
.35254 .33273 m .33613 .3154 L .36256 .30613 L F
.73774 .33643 m .75326 .30994 L .76594 .32741 L .649 .753 .925 r
F
.73774 .33643 m .72486 .31914 L .75326 .30994 L F
.63969 .24965 m .65377 .22089 L .66747 .24128 L .635 .712 .902 r
F
.63969 .24965 m .62583 .22934 L .65377 .22089 L F
.52923 .23269 m .54178 .20423 L .55643 .225 L .623 .703 .903 r
F
.52923 .23269 m .51444 .21197 L .54178 .20423 L F
.42115 .3318 m .43215 .30518 L .44779 .3227 L .65 .753 .925 r
F
.42115 .3318 m .40535 .31445 L .43215 .30518 L F
.48987 .33089 m .50187 .30424 L .51687 .32179 L F
.48987 .33089 m .47469 .31352 L .50187 .30424 L F
.55871 .32999 m .5717 .30332 L .58608 .32089 L F
.55871 .32999 m .54415 .3126 L .5717 .30332 L F
.70883 .25288 m .7239 .22391 L .73702 .24419 L .64 .716 .902 r
F
.70883 .25288 m .69554 .23269 L .7239 .22391 L F
.62767 .32911 m .64166 .30241 L .65541 .32 L .65 .753 .925 r
F
.62767 .32911 m .61373 .31169 L .64166 .30241 L F
.48741 .21934 m .49939 .19096 L .51444 .21197 L .616 .699 .904 r
F
.48741 .21934 m .47222 .19836 L .49939 .19096 L F
.59818 .23754 m .61173 .20873 L .62583 .22934 L .631 .709 .903 r
F
.59818 .23754 m .58393 .21701 L .61173 .20873 L F
.30996 .32458 m .3194 .29775 L .33613 .3154 L .65 .753 .925 r
F
.30996 .32458 m .29308 .3071 L .3194 .29775 L F
.69674 .32825 m .71174 .30152 L .72486 .31914 L F
.69674 .32825 m .68343 .31081 L .71174 .30152 L F
.37881 .32363 m .38926 .29678 L .40535 .31445 L F
.37881 .32363 m .36256 .30613 L .38926 .29678 L F
.76594 .32741 m .78195 .30065 L .79443 .31829 L .649 .752 .925 r
F
.76594 .32741 m .75326 .30994 L .78195 .30065 L F
.44538 .20533 m .45678 .1771 L .47222 .19836 L .607 .695 .905 r
F
.44538 .20533 m .42981 .18409 L .45678 .1771 L F
.44779 .3227 m .45923 .29582 L .47469 .31352 L .65 .753 .925 r
F
.44779 .3227 m .43215 .30518 L .45923 .29582 L F
.66747 .24128 m .68201 .21221 L .69554 .23269 L .637 .714 .903 r
F
.66747 .24128 m .65377 .22089 L .68201 .21221 L F
.55643 .225 m .56943 .19617 L .58393 .21701 L .626 .707 .903 r
F
.55643 .225 m .54178 .20423 L .56943 .19617 L F
.51687 .32179 m .52932 .29488 L .54415 .3126 L .65 .753 .925 r
F
.51687 .32179 m .50187 .30424 L .52932 .29488 L F
.58608 .32089 m .59954 .29395 L .61373 .31169 L F
.58608 .32089 m .5717 .30332 L .59954 .29395 L F
.73702 .24419 m .75257 .21494 L .7655 .23532 L .642 .718 .903 r
F
.73702 .24419 m .7239 .22391 L .75257 .21494 L F
.65541 .32 m .66987 .29304 L .68343 .31081 L .65 .753 .925 r
F
.65541 .32 m .64166 .30241 L .66987 .29304 L F
.62583 .22934 m .63984 .2002 L .65377 .22089 L .634 .712 .903 r
F
.62583 .22934 m .61173 .20873 L .63984 .2002 L F
.33613 .3154 m .346 .28831 L .36256 .30613 L .65 .753 .925 r
F
.33613 .3154 m .3194 .29775 L .346 .28831 L F
.51444 .21197 m .52688 .18317 L .54178 .20423 L .621 .703 .904 r
F
.51444 .21197 m .49939 .19096 L .52688 .18317 L F
.72486 .31914 m .74034 .29215 L .75326 .30994 L .649 .753 .925 r
F
.72486 .31914 m .71174 .30152 L .74034 .29215 L F
.40535 .31445 m .41623 .28733 L .43215 .30518 L .65 .753 .925 r
F
.40535 .31445 m .38926 .29678 L .41623 .28733 L F
.47469 .31352 m .48658 .28637 L .50187 .30424 L F
.47469 .31352 m .45923 .29582 L .48658 .28637 L F
.69554 .23269 m .71056 .20333 L .7239 .22391 L .639 .716 .903 r
F
.69554 .23269 m .68201 .21221 L .71056 .20333 L F
.54415 .3126 m .55705 .28542 L .5717 .30332 L .65 .753 .925 r
F
.54415 .3126 m .52932 .29488 L .55705 .28542 L F
.47222 .19836 m .48408 .16965 L .49939 .19096 L .613 .699 .905 r
F
.47222 .19836 m .45678 .1771 L .48408 .16965 L F
.58393 .21701 m .5974 .18782 L .61173 .20873 L .629 .709 .904 r
F
.58393 .21701 m .56943 .19617 L .5974 .18782 L F
.61373 .31169 m .62765 .28449 L .64166 .30241 L .65 .753 .925 r
F
.61373 .31169 m .59954 .29395 L .62765 .28449 L F
.68343 .31081 m .69838 .28358 L .71174 .30152 L F
.68343 .31081 m .66987 .29304 L .69838 .28358 L F
.36256 .30613 m .37286 .27878 L .38926 .29678 L F
.36256 .30613 m .346 .28831 L .37286 .27878 L F
.75326 .30994 m .76923 .28268 L .78195 .30065 L .649 .752 .925 r
F
.75326 .30994 m .74034 .29215 L .76923 .28268 L F
.65377 .22089 m .66826 .19143 L .68201 .21221 L .636 .714 .904 r
F
.65377 .22089 m .63984 .2002 L .66826 .19143 L F
.54178 .20423 m .55469 .17504 L .56943 .19617 L .624 .706 .904 r
F
.54178 .20423 m .52688 .18317 L .55469 .17504 L F
.43215 .30518 m .44348 .27779 L .45923 .29582 L .65 .753 .925 r
F
.43215 .30518 m .41623 .28733 L .44348 .27779 L F
.50187 .30424 m .51421 .27682 L .52932 .29488 L F
.50187 .30424 m .48658 .28637 L .51421 .27682 L F
.7239 .22391 m .73941 .19425 L .75257 .21494 L .64 .718 .904 r
F
.7239 .22391 m .71056 .20333 L .73941 .19425 L F
.5717 .30332 m .58507 .27587 L .59954 .29395 L .65 .753 .925 r
F
.5717 .30332 m .55705 .28542 L .58507 .27587 L F
.61173 .20873 m .62568 .1792 L .63984 .2002 L .632 .712 .904 r
F
.61173 .20873 m .5974 .18782 L .62568 .1792 L F
.49939 .19096 m .51172 .1618 L .52688 .18317 L .618 .703 .905 r
F
.49939 .19096 m .48408 .16965 L .51172 .1618 L F
.64166 .30241 m .65606 .27494 L .66987 .29304 L .65 .753 .925 r
F
.64166 .30241 m .62765 .28449 L .65606 .27494 L F
.71174 .30152 m .72718 .27402 L .74034 .29215 L .649 .753 .925 r
F
.71174 .30152 m .69838 .28358 L .72718 .27402 L F
.38926 .29678 m .4 .26915 L .41623 .28733 L .65 .753 .925 r
F
.38926 .29678 m .37286 .27878 L .4 .26915 L F
.68201 .21221 m .69699 .18244 L .71056 .20333 L .638 .716 .904 r
F
.68201 .21221 m .66826 .19143 L .69699 .18244 L F
.45923 .29582 m .471 .26816 L .48658 .28637 L .65 .753 .925 r
F
.45923 .29582 m .44348 .27779 L .471 .26816 L F
.56943 .19617 m .58281 .1666 L .5974 .18782 L .628 .709 .905 r
F
.56943 .19617 m .55469 .17504 L .58281 .1666 L F
.52932 .29488 m .54213 .26719 L .55705 .28542 L .65 .753 .925 r
F
.52932 .29488 m .51421 .27682 L .54213 .26719 L F
.59954 .29395 m .61338 .26623 L .62765 .28449 L F
.59954 .29395 m .58507 .27587 L .61338 .26623 L F
.66987 .29304 m .68476 .26529 L .69838 .28358 L F
.66987 .29304 m .65606 .27494 L .68476 .26529 L F
.63984 .2002 m .65427 .17033 L .66826 .19143 L .634 .714 .905 r
F
.63984 .2002 m .62568 .1792 L .65427 .17033 L F
.52688 .18317 m .53968 .15359 L .55469 .17504 L .623 .706 .905 r
F
.52688 .18317 m .51172 .1618 L .53968 .15359 L F
.74034 .29215 m .75627 .26437 L .76923 .28268 L .649 .752 .925 r
F
.74034 .29215 m .72718 .27402 L .75627 .26437 L F
.41623 .28733 m .42742 .25942 L .44348 .27779 L .65 .753 .925 r
F
.41623 .28733 m .4 .26915 L .42742 .25942 L F
.48658 .28637 m .49882 .25843 L .51421 .27682 L F
.48658 .28637 m .471 .26816 L .49882 .25843 L F
.71056 .20333 m .72602 .17324 L .73941 .19425 L .639 .718 .904 r
F
.71056 .20333 m .69699 .18244 L .72602 .17324 L F
.55705 .28542 m .57034 .25745 L .58507 .27587 L .65 .753 .925 r
F
.55705 .28542 m .54213 .26719 L .57034 .25745 L F
.5974 .18782 m .61126 .15788 L .62568 .1792 L .631 .712 .905 r
F
.5974 .18782 m .58281 .1666 L .61126 .15788 L F
.62765 .28449 m .64199 .25649 L .65606 .27494 L .65 .753 .925 r
F
.62765 .28449 m .61338 .26623 L .64199 .25649 L F
.69838 .28358 m .71376 .25555 L .72718 .27402 L .649 .753 .925 r
F
.69838 .28358 m .68476 .26529 L .71376 .25555 L F
.66826 .19143 m .68317 .16123 L .69699 .18244 L .636 .716 .905 r
F
.66826 .19143 m .65427 .17033 L .68317 .16123 L F
.55469 .17504 m .56797 .14505 L .58281 .1666 L .626 .709 .906 r
F
.55469 .17504 m .53968 .15359 L .56797 .14505 L F
.44348 .27779 m .45513 .2496 L .471 .26816 L .65 .753 .925 r
F
.44348 .27779 m .42742 .25942 L .45513 .2496 L F
.51421 .27682 m .52692 .2486 L .54213 .26719 L F
.51421 .27682 m .49882 .25843 L .52692 .2486 L F
.58507 .27587 m .59884 .24762 L .61338 .26623 L F
.58507 .27587 m .57034 .25745 L .59884 .24762 L F
.62568 .1792 m .64003 .1489 L .65427 .17033 L .633 .714 .905 r
F
.62568 .1792 m .61126 .15788 L .64003 .1489 L F
.65606 .27494 m .67089 .24666 L .68476 .26529 L .65 .753 .925 r
F
.65606 .27494 m .64199 .25649 L .67089 .24666 L F
.72718 .27402 m .74307 .24571 L .75627 .26437 L .649 .752 .925 r
F
.72718 .27402 m .71376 .25555 L .74307 .24571 L F
.69699 .18244 m .7124 .15191 L .72602 .17324 L .638 .718 .905 r
F
.69699 .18244 m .68317 .16123 L .7124 .15191 L F
.471 .26816 m .48313 .23968 L .49882 .25843 L .65 .753 .925 r
F
.471 .26816 m .45513 .2496 L .48313 .23968 L F
.58281 .1666 m .59659 .13623 L .61126 .15788 L .629 .712 .906 r
F
.58281 .1666 m .56797 .14505 L .59659 .13623 L F
.54213 .26719 m .55532 .23868 L .57034 .25745 L .65 .753 .925 r
F
.54213 .26719 m .52692 .2486 L .55532 .23868 L F
.61338 .26623 m .62764 .23769 L .64199 .25649 L F
.61338 .26623 m .59884 .24762 L .62764 .23769 L F
.68476 .26529 m .70009 .23672 L .71376 .25555 L .649 .753 .925 r
F
.68476 .26529 m .67089 .24666 L .70009 .23672 L F
.65427 .17033 m .66911 .13968 L .68317 .16123 L .635 .716 .906 r
F
.65427 .17033 m .64003 .1489 L .66911 .13968 L F
.49882 .25843 m .51142 .22966 L .52692 .2486 L .65 .753 .925 r
F
.49882 .25843 m .48313 .23968 L .51142 .22966 L F
.61126 .15788 m .62553 .12713 L .64003 .1489 L .632 .714 .906 r
F
.61126 .15788 m .59659 .13623 L .62553 .12713 L F
.57034 .25745 m .58402 .22865 L .59884 .24762 L .65 .753 .925 r
F
.57034 .25745 m .55532 .23868 L .58402 .22865 L F
.64199 .25649 m .65675 .22766 L .67089 .24666 L F
.64199 .25649 m .62764 .23769 L .65675 .22766 L F
.71376 .25555 m .72961 .22669 L .74307 .24571 L .649 .752 .925 r
F
.71376 .25555 m .70009 .23672 L .72961 .22669 L F
.68317 .16123 m .69853 .13023 L .7124 .15191 L .637 .718 .906 r
F
.68317 .16123 m .66911 .13968 L .69853 .13023 L F
.52692 .2486 m .54001 .21954 L .55532 .23868 L .65 .753 .925 r
F
.52692 .2486 m .51142 .22966 L .54001 .21954 L F
.59884 .24762 m .61302 .21853 L .62764 .23769 L F
.59884 .24762 m .58402 .22865 L .61302 .21853 L F
.64003 .1489 m .6548 .11778 L .66911 .13968 L .634 .716 .906 r
F
.64003 .1489 m .62553 .12713 L .6548 .11778 L F
.67089 .24666 m .68616 .21753 L .70009 .23672 L .649 .753 .925 r
F
.67089 .24666 m .65675 .22766 L .68616 .21753 L F
.55532 .23868 m .5689 .20932 L .58402 .22865 L .65 .753 .925 r
F
.55532 .23868 m .54001 .21954 L .5689 .20932 L F
.62764 .23769 m .64233 .2083 L .65675 .22766 L F
.62764 .23769 m .61302 .21853 L .64233 .2083 L F
.66911 .13968 m .68441 .10819 L .69853 .13023 L .636 .718 .907 r
F
.66911 .13968 m .6548 .11778 L .68441 .10819 L F
.70009 .23672 m .71589 .2073 L .72961 .22669 L .649 .752 .925 r
F
.70009 .23672 m .68616 .21753 L .71589 .2073 L F
.58402 .22865 m .59811 .19899 L .61302 .21853 L .65 .753 .925 r
F
.58402 .22865 m .5689 .20932 L .59811 .19899 L F
.65675 .22766 m .67195 .19797 L .68616 .21753 L .649 .753 .925 r
F
.65675 .22766 m .64233 .2083 L .67195 .19797 L F
.61302 .21853 m .62763 .18856 L .64233 .2083 L .65 .753 .925 r
F
.61302 .21853 m .59811 .19899 L .62763 .18856 L F
.68616 .21753 m .7019 .18753 L .71589 .2073 L .649 .752 .925 r
F
.68616 .21753 m .67195 .19797 L .7019 .18753 L F
.64233 .2083 m .65746 .17802 L .67195 .19797 L .649 .753 .925 r
F
.64233 .2083 m .62763 .18856 L .65746 .17802 L F
.67195 .19797 m .68763 .16737 L .7019 .18753 L .649 .752 .925 r
F
.67195 .19797 m .65746 .17802 L .68763 .16737 L F
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.05093 .24975 m
.0557 .25425 L
s
[(0)] .04138 .24075 1 .94269 Mshowa
.19287 .19417 m
.19742 .1989 L
s
[(0.5)] .18378 .18471 .96152 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(1)] .3345 .12542 .86223 1 Mshowa
.50225 .07302 m
.50623 .07824 L
s
[(1.5)] .49429 .06259 .76295 1 Mshowa
.67126 .00684 m
.67489 .01231 L
s
[(2)] .664 -0.00409 .66367 1 Mshowa
.125 Mabswid
.07869 .23888 m
.08153 .2416 L
s
.10676 .22788 m
.10957 .23064 L
s
.13514 .21677 m
.13793 .21955 L
s
.16384 .20553 m
.1666 .20834 L
s
.22223 .18267 m
.22493 .18554 L
s
.25192 .17104 m
.25459 .17394 L
s
.28195 .15928 m
.28459 .16221 L
s
.31233 .14739 m
.31494 .15034 L
s
.37416 .12318 m
.37669 .12619 L
s
.40562 .11086 m
.40812 .1139 L
s
.43745 .0984 m
.43991 .10147 L
s
.46966 .08579 m
.47208 .08889 L
s
.53524 .06011 m
.53759 .06327 L
s
.56863 .04703 m
.57093 .05022 L
s
.60242 .0338 m
.60468 .03702 L
s
.63663 .0204 m
.63885 .02365 L
s
gsave
.29165 .07573 -70.3112 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{280, 203.5},
  ImageMargins->{{30, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004H0000ba000`40O003h00Oogoo6Goo002kOol4
001IOol00;]oo`03001oogoo05Yoo`00_7oo00<007ooOol0FGoo002mOol00`00Oomoo`1HOol00;]o
o`04001oogoo001IOol00;aoo`8005Yoo`00ogoo6Goo003oOolIOol00?mooaUoo`00`goo0P00Dgoo
0031Ool200000goo0000001BOol00;ioo`<000=oo`80059oo`00_7oo0P000goo00H007ooOol007oo
001AOol00;Uoo`<000Qoo`04001oogoo001@Ool00;Ioo`@000Yoo`04001oogoo001@Ool008Uoo`D0
009oo`8000Aoo`8001aoo`8000ioo`05001oogooOol0001?Ool008]oo`03001oogoo00Moo`04001o
ogoo000HOol3000@Ool00`00Oomoo`02Ool00`00Oomoo`1<Ool0069oo`800003Ool0000002Aoo`03
001oogoo00Yoo`03001oogoo01Aoo`<001=oo`05001oogooOol0001>Ool006=oo`03001oo`0002Eo
o`03001oogoo00Qoo`8001Aoo`<001Ioo`03001oogoo009oo`03001oogoo04]oo`00I7oo00<007oo
Ool097oo00<007ooOol027oo00<007ooOol04Goo0P006Goo00<007ooOol00goo00<007ooOol0BWoo
001ROol200000goo0000000SOol2000:Ool3000>Ool3000KOol00`00Oomoo`03Ool00`00Oomoo`1:
Ool00:Aoo`<001ioo`03001oogoo00Aoo`03001oogoo04Uoo`00XWoo0P008Goo00<007ooOol017oo
0P00BWoo002OOol4000ROol00`00Oomoo`05Ool00`00Oomoo`18Ool009eoo`8002Ioo`03001oogoo
00Ioo`03001oogoo04Moo`00VWoo0`00:7oo00<007ooOol01goo00<007ooOol02Woo1000>7oo002H
Ool3000ZOol00`00Oomoo`07Ool00`00Oomoo`0:Ool00`00Oomoo`0iOol009Eoo`<000=oo`03001o
ogoo02Moo`03001oogoo00Qoo`03001oogoo00Yoo`03001oogoo03Qoo`00TWoo0`00<7oo00<007oo
Ool02Goo00<007ooOol00Woo100017oo00<007ooOol0=goo002@Ool4000aOol00`00Oomoo`09Ool0
0`00Oomoo`08Ool01000Oomoo`00>7oo001_Ool5000IOol3000eOol00`00Oomoo`0:Ool00`00Oomo
o`08Ool2000iOol0075oo`03001oogoo01Moo`8003Uoo`03001oogoo00Qoo`03001oo`0004Aoo`00
LGoo00<007ooOol057oo1000>Woo00<007ooOol02Woo00<007ooOol0@Woo001aOol00`00Oomoo`0B
Ool2000nOol00`00Oomoo`0;Ool00`00Oomoo`11Ool0075oo`03001oogoo00moo`<0041oo`03001o
ogoo00aoo`03001oogoo041oo`00L7oo0P003Woo0`0000=oo`00Ool0>goo00=>_5;LC]`00Woo00<0
07ooOol037oo00<007ooOol0@7oo001nOol2000mOol8C]`00goo001oo`0>Ool00`00Oomoo`0oOol0
07]oo`<003eoo`0<C[]Bg4kLD]a>_5;LC]aBg4jlD]aoo`0047oo00<007ooOol0?Woo001iOol20002
Ool00`00Oomoo`0fOol@C]`00`00Oomoo`0>Ool00`00Oomoo`0nOol007Ioo`<003]oo`0CC]a>^e;L
C]aBg4jkD]a>g5;LC[]Bg4kLD]a>_5;LC]aBg4jl000047oo0P00?goo001dOol2000iOolFC]`00e;L
001>g00AOol00`00Oomoo`0lOol0075oo`<0009oo`03001oogoo03Aoo`0KC[a>g4jkD]a>_4kLC[]B
g4jlC]a>^e;LC]aBg4jkD]a>g5;LC[]Bg4kLD]a>^e;LC]`004jk015oo`03001oogoo03aoo`00KWoo
0`00>7oo6TkL00IBg4kLC]`005;LC]`AOol00`00Oomoo`0kOol0045oo`8000Aoo`8000Aoo`8001eo
o`@003Moo`0RC[a>g4jkD]a>_4kLC[]Bg4jlC]a>^e;LC[a>g4jkD]a>_4kLC[]Bg4kLD]a>^e;LC]aB
g4jkD]a>g5;LC[/004kLD]`BOol00`00Oomoo`0jOol0041oo`04001oogoo0008Ool01000Oomoo`00
6Goo0`00=Woo00E>_4kLC]a>g4jl01i>g005D]`004kLC]aBg00AOol00`00Oomoo`0jOol0041oo`04
001oogoo000;Ool00`00Oomoo`0EOol2000gOol0:dkLC[a>g4jkC]a>_4kLC[]>g4jlC]a>^e;LC[a>
g4jkD]a>_4kLC[]Bg4jlD]a>^e;LC[aBg4jkD]a>g5;LC[]Bg4kLD]a>^e;LC]aBg000D]a>g5;L015o
o`03001oogoo03Uoo`00@7oo00@007ooOol000Uoo`8001Eoo`<00003Ool007oo039oo`09C[a>g4jl
C]a>_4kLC[a>g4jl00=>g003C[a>g4kL01Q>g005D]a>g4kLC]`00003C]`BOol00`00Oomoo`0hOol0
041oo`04001oogoo0009Ool00`00Oomoo`0BOol2000fOol0<TkLB[a>g4ZkC]a>_4kLB[]>g4jlC]a>
^dkLC[a>g4jkC]a>_4kLC[]Bg4jlC]a>^e;LC[aBg4jkD]a>_5;LC[]Bg4jlD]a>^e;LC]aBg4jkD]a>
g5;LC[]Bg000D]a>^e;LC]`AOol2000iOol0045oo`8000Yoo`<000moo`<003Aoo`=>_00>C]a>_4jl
C[a>g4jlC]a>_4kLC[a>g4jlC]a>_0=>g003C[a>g4kL01E>g008D_aBoE;lD]a>g000C]aBg09>g15o
o`8003Uoo`00G7oo0`000Woo00<007ooOol0:goo03i:^dkLB[a>g4ZkC]a:_4kLB[]>g4ZlC]a:^dkL
B[a>g4ZkC]a>_4kLB[]>g4jlC]a>^dkLC[a>g4jkC]a>_4kLC[]Bg4jlC]a>^e;LC[aBg4jkD]a>_5;L
C[]Bg4jlD]a>^e;mC_aBoDklD_e>g5;L001Bg4kLD]a>^e;L4Woo00<007ooOol0=Woo001JOol2000a
Ool2B[`02DjlB[a>_4ZlC[a:_4jlB[a>g003C[`03TkLC[a>_4jlC]a>_4kLC[a>g4jlC]a>_4kLC[`3
C]`00djlC]a>g00>C]`02e;mD_aBoE;lD_eBo5;mD_aBoDkL00000dkL00=Bg4kLC]`04Goo00<007oo
Ool0=Woo001GOol4000^Ool0ATZkC]a:_4jlB[]>g4ZlC[a:^dkLB[a>g4ZkC]a:_4kLB[]>g4ZlC]a:
^dkLC[a>g4ZkC]a>_4kLB[]>g4jlC]a>^dkLC[a>g4jkC]a>_4kLC[]Bg4jlC]a>^e;LC[aBg4jkD]a>
o5;mC_aBoDklD_e>o5;mC_aBoDklD]`005;LC[]Bg4kLD]a>^e;L4Goo00<007ooOol0=Goo001EOol2
000`Ool6B[`02TjlB[a:_4ZlC[a:_4jlB[a>_4Zl0Tjl00E>g4jlC[a>_4kL00=>_006C]a>_4kLC[a>
g4jl0dkL00E>_4kLC]a>g4jl00M>g00DD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000
C]aBg0=>g003D]a>g7oo015oo`03001oogoo03Aoo`00DWoo0`00;Woo00I:^djlB[a:_4ZkC[`2B[`0
ADZkC]a:_4jlB[]>g4ZlC]a:^dkLB[a>g4ZkC]a:_4kLB[]>g4ZlC]a:^dkLC[a>g4ZkC]a>_4kLB[]>
g4jlC]a>^dkLC[a>g4jkD]a>_4kLC[]BoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aB
o@00D]a>g5;LC[]Bg4kLD]a>^`0AOol00`00Oomoo`0AOol4000OOol0051oo`80009oo`03001oogoo
02Ioo`i:_005C[a:_4ZlB[a>_003B[`00djlB[a>_002C[`014ZlC[a>_4kL0djl00Y>g4jlC]a>_4kL
C[a>g4jlC]a>_0=>g00MC[a>g4kLC]aBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;l001Bo002C]`01U;LC]a>g4kLD]a>g15oo`03001oogoo00moo`04001oogoo000POol0
04eoo`<002Moo`0@AYa:_4JKB[a6W4ZlAY]:_4ZLB[a6VdZlBYa:_4ZkC[`2B[`0B4ZkC[a:_4jlB[]>
g4ZlC[a:^dkLB[a>g4ZkC]a:_4kLB[]>g4ZlC]a:^dkLB[a>g4ZkC]a>_4kLB[]>g4jlC]a>^e;LC[a>
g4jkD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_d005;mC_aB
g4kLD]a>^e;LC]aBg19oo`03001oogoo00ioo`04001oogoo000POol002aoo`8001aoo`<000]oo`8Q
f`037M]oogoo01Aoo`Q6W006B[a6W4JlAYa:_4JL3TZl00I>_4ZlC[a:_4jlB[`3C[`01DZlC[a>_4jl
B[`00Tjl02i>g4jlC[a>_4kLC[a>g4jlC]a>_4kLC[a>g4jlC]aBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo09>g005D]a>g4kLC]aBg00@Ool2
000?Ool200000goo0000000POol002]oo`04001oogoo000IOol20003Ool00`00Oomoo`08Ool0227k
7M/QnagK<S`^6c8l;Q/<Ool02DJL@Wa6W49kAYa2O4JL@Y]6_002AY`0Fd:KA[a6W4ZlAY]:_4JLB[a6
VdZlBYa:_4JKB[a:W4ZlB[]>_4ZlC[a:^djlB[a>_4ZkC]a:_4jlB[]>g4ZlC]a:^dkLB[a>g4ZkC]a>
_4kLB[]>g4jlC]a:^dkLC[a>g4jkC]a>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>
o5;mC_aBoDklD_e>o5;mC_aBoDklD_d005;mC_aBoDklD]a>g5;LC[]Bg4kL019oo`03001oogoo035o
o`00:goo00@007ooOol001Ioo`<0015oo`<Qf`057M/b?2hl<S`^>`06>U`6?W`6@Y`6AY`01TJlAYa:
_4JLA[a6W11:_006C[a:_4jlB[a>_4Zl0djl00A:_4jlC[a>g0=>_00]C]a>_4jlC[a>g4jlC]a>_5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_`005;lD_eBo5;m00=>g004D]a>g4kLC]`BOol00`00Oomoo`05Ool2000YOol002]oo`04001oogoo
000DOol200000goo001oo`0AOol06AgK8O/Mfb7k;Q/b?2hK<S`^6cYl>U`jO3IK>W`jG49l?W]2W3il
@Wa2NdJL@Wa6W49k00=6W01O@Y]6_4JLAYa2VdZlAYa:_4JKB[a6W4ZlBY]:_4ZLB[a:VdZlBYa>_4Zk
C[a:_4jlB[]>_4ZlC[a:^dkLB[a>_4ZkC]a:_4kLB[]>g4ZlC]a:^dkLC[a>g4ZkD_e>o5;mC_aBoDkl
D_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDkl
D_e>o000C_aBoDklD_e>^e;LC]aBg4jkD]a>g00AOol00`00Oomoo`04Ool01000Oomoo`00:7oo000[
Ool01000Oomoo`004Goo0`005Woo00<5FAgK8M/00R7K00@^>c8l;S`b?0HjG0HnO0I2W0M6W006B[a:
W4ZlAYa:_4ZL3TZl00Q>_4ZlC[a:_4jlB[a>_4Zl0Tjl00E>g4jlC[a>_4kL009>_00dD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_d005;mD_aBoE;lD]a>g5;LC]aBg4kLD]`BOol00`00Oomoo`03Ool01000Oomoo`00
:7oo000/Ool2000@Ool2000JOol06PUJ8M/Uo27K9O/^6c8l;Q/b?3IK>W`jG3Yl=U/jO3il@W`nNd:L
?Wa6W49kAYa2O4JL@W/2AY`04TJlAY]:_4JLA[a6VdZlAYa:_4JKB[a6W4ZlBY]:_4ZLB[a:V`9:_01;
C[a:^djlB[a>_4ZkC]a:^djlB[]>g4ZkC[a:^dkLB[a>g4ZkC]a:_5;mC_aBoDklD_e>o5;mC_aBoDkl
D_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDkl
D_e>o000C_aBoDklD_e>o5;LC[]Bg4kLD]a>^e;L015oo`03001oogoo00=oo`04001oogoo000XOol0
03]oo`<0009oo`03001oogoo01Moo`032ETUnb7k00<Un`04<S/b?38l<S`6>U`5?W`01TJL@Ya6W4:L
AYa2W0Q6W006B[a:W4ZlAYa:_4ZL24Zl00a>_4ZlB[a:_4jlB[a>_4ZlC[a:_4jlB[`4C[`0>TkLD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD]a>g5;LC]aBg4kL4Woo00<007oo
Ool00Woo00@007ooOol002Qoo`00>7oo0`0087oo00l9FBGk8M/Uo27K<S`b>cIL<S/b?3YK?W`jFcil
>U/00Sil00Y2W3ik@Y`nO4JL@W]6W49lAYa2N`96W01NA[a6VdZlAYa6_4JKB[a6W4ZlAY]:_4ZLB[a:
VdZlBYa:_4ZKC[a:^djlB[]>_4ZkC[a:^dkLB[]>_4ZkC]a:^djlB[]BoDklD_e>o5;mC_aBoDklD_e>
o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>
o5;mC_aBoDklD_e>o000C_aBoDklD_e>o5;mC_aBg4jkD]a>g5;LC[/BOol00`00Oomoo`02Ool2000Y
Ool003Ioo`800003Ool007oo021oo`042ETUnbGk8O/29O/00c8l<S/b?002<S`3>U`00cYl>Ua2O002
@W`02Cil@Wa2O4JL@Ya6W4:LAYa2W006AY`01TZlAYa:_4ZLB[a6W0Y:_01:C[a:_4ZlB[a>_4ZlC[a:
_5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_e>
g5;LC]aBg4kLD]a>g11oo`8002moo`00<goo0`009Goo06`=NA6J8M/Unb7K9O`b>c8l<S/fG38k?W`j
Fcil>U/nO3YK@Y`nO4:L?W]2W49lAYa2NdJL@Wa6W49kB[a6W4JlAY]:_4JLB[a6VdZlAY]:_4JKB[a:
^dZlBY]>_4ZkB[a:VdjlB[]>_4ZkC[a:^djlC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>
o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>
o5;mC_aBoDklD_d200003dklD_e>o5;mC_aBoDklD_e>fe;LC[]Bg4kKD]a>^`0AOol00`00Oomoo`0/
Ool0035oo`8002Uoo`063GTANRWk9O/QnbGk0S8l00@b>c8l<S`jO0<jG003>W`nO49l0092O009?Wa2
O4:LAYa2W4JL@Ya6W4:L00I6W003B[a:W4Zl009:_003BYa:_4Zl00Q:_00eD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@0300004E;mD_`005;lD_eBo5;mD_aBoE;lD_e>
g5;LC]aBg4kLD]`04Woo00<007ooOol0:goo000_Ool20002Ool2000WOol0IA6J3GTAVRGk:Q/UncIL
<S/b?38k=U`b>cil>U/nO3YK?W`nNd:L?Wa2W3ik@Ya2VdJL@W]6W4:KAYa2NdZlAY]:_4JKB[a6VdZl
AY]:_4JKB[a6VdZlB[]:_4ZKC[a:^dZlC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;m
C_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;m
C_aBoDklD_d00`0001EBoDklD_e>o5;m001BoDklD_e>o5;mC_aBoDklD_e>fe;LC[]Bg4kKD]`04Goo
00<007ooOol0:goo000_Ool2000/Ool00a5j3GTYn`02:O/01BGk=S`f?3IL=S/00SHl00DnO3YL?W`n
G3il00=2O003@Ya2O49l00a6W09:_005BYa:_4ZlB[a:W002B[`0=E;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d00`0001UBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;l
D_eBo5;mD_aBg4kLD]a>g5;LC]aBg00AOol00`00Oomoo`0ZOol002moo`03001oo`0002]oo`1O3GTA
VPei:Q`UnbXK9O/fG38k=U`b>cIL>U/nO3YK?W`jFcil?W]2W49k@Y`nNd:L@Y]6W49kAYa2VdJLAY]:
_4JKB[a6VdZlAY]:_4JKB[a6VdZlC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aB
oDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aB
oDklD_e>o002000075;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;m001BoDklD_e>o5;mC_aBoDklD]a>
fe;LC[]Bg4kK4Woo00<007ooOol0:Goo000_Ool200000goo001oo`0YOol45IX3:O/033Hk=S`f?3IL
=S/f?3iL?W`jG3il?Ua2W0=2O003@Ya2O4JL00a6W09:_00eBYaBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo00300007e;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
001BoE;lD_eBo5;mD_aBoE;lD]a>g5;LC]aBg4kL015oo`03001oogoo02Uoo`00;Woo00<007ooOol0
0Woo00<007ooOol0:7oo05PI^QFJ6IXEVRhL9O/Z6c8k=U`b>cIL<S/nO3YK?W`jFcil>U]2W3ik@Ya2
Nd:L?W]6W4:KAYa2NdJL@Y]:_4JKB[a6VdZlAY]BoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>
o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>
o5;mC_aBoDklD_e>o0<0000RC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_`004kl
D_e>o5;mC_aBoDklD_e>^e;LC]]Bg4jkD]`AOol2000ZOol002ioo`<000=oo`03001oogoo02Moo`@E
VP05:Q/^6bXK;Q/f>`02=S`02CIL=S/nO3iL?W`jG3il?Ua2W003@W`00d:L@Wa6W005AY`0=TZlAYa:
W5;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo0<0000VD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aBoE;lD_eBo5;mD_aBoDkLD]a>g5;L
C]aBg19oo`03001oogoo02Moo`00;Woo00<007ooOol017oo00<007ooOol09goo054EVQVj5IXIVRWk
;Q`YnbhL=S/jG3Hk>U`f>d9l?U/nO3iK@W`nFd:L@W]6W49k@Ya2NdJLAY]6W4IkD_e>o5;mC_aBoDkl
D_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDkl
D_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_`00`0002Y>o5;mC_aBoDklD_e>o5;mC_aBoDkl
D_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_`004klD_e>o5;mC_aBoDklD]a>^e;LC]]Bg4jk
D]`AOol00`00Oomoo`0WOol002Qoo`8000Aoo`8000Ioo`8002Moo`@EVP0:;Q/Z6bhK:Q/jG3Hk=U`f
FcYL=S/3?W`013ik?Wa2O4:L0d9l03I2W4JLAYaBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_`30000:E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;LC]`00e;L00=>g5;LOol047oo00<007oo
Ool09Woo000WOol01000Oomoo`000goo00<007ooOol01goo00<007ooOol09Goo04XM^aFJ6KXEVRhL
:O/^72Wk>U`f>cYL=S/jG3iK@W`nFcil?U]2O49k@Ya2Ne;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;m
C_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;m
C_aBoDklD_e>o5;mC_aBoDkl0`00035>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>
o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBo@00D_e>o5;mC_aBoDklD_e>o5;LC[]Bg4kKD]a>
^`0BOol00`00Oomoo`0UOol002Yoo`04001oogooOol20009Ool00`00Oomoo`0TOol03`3G7KXM^Qfj
:Q/^6bXK;Q/fFcYL=S/fG3IK>U`nN`03?W`0=Cik@WaBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_`00`00035Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoE;lD]a>g003
D]`00dkLOomoo`0?Ool00`00Oomoo`0UOol0025oo`@000=oo`8000Aoo`03001oogoo00Uoo`03001o
ogoo02Aoo`147KXM^aVj7K/^6c8L;Q/b?3Hk>U`f>cYL=S/jG3iKD_e>o5;mC_aBoDklD_e>o5;mC_aB
oDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aB
oDklD_e>o5;mC_aBoDklD_e>o5;mC_aBo@80000hC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDkl
D_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;m001BoDkl
D_e>o5;mC_aBoDkKD]a>^e;LC]]Bg19oo`03001oogoo02Aoo`00:7oo00<007ooOol00Woo00<007oo
Ool02goo00<007ooOol08goo00<561fj7KX00Qfj03`^6c8K;Q/b6cYK>U`jFcYLD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d30000=E;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_`005;lD_eBo5;mD_aBoE;lD_d00U;L00A>g5;LD]aBg19oo`03001oogoo02=oo`00:7oo0`00
0Woo0P003Goo00<007ooOol08goo03d561fj7K/I^S8l;Q/b72hKD_e>o5;mC_aBoDklD_e>o5;mC_aB
oDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aB
oDklD_e>o5;mC_aBoDklD_e>o5;mC_aBo@030000?U;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aB
oDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aB
oDklD_e>o000C_aBoDklD_e>o5;mC_aBoDkKD]a>^e;LC]/AOol2000UOol002eoo`03001oogoo00eo
o`03001oogoo029oo`85600h8MXM^Qfj<Q]Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBo@<0000mD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`0
05;lD_eBo5;mD_aBoE;lD_d00U;L00=>g5;LD]`04Woo00<007ooOol08Woo000]Ool2000?Ool00`00
Oomoo`0QOol0=`DH1?MBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;m
C_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;m
00<00015D_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;m
C_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o000
C_aBoDklD_e>o5;mC_aBg4kKD]a>^e;L01=oo`03001oogoo025oo`00;Goo00<007ooOol03goo00<0
07ooOol087oo03ABo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@<00014
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00
D_eBo5;mD_aBoE;lD_eBo0=Bg003C]aBg7oo015oo`03001oogoo025oo`00;Goo0P004Goo00<007oo
Ool06goo03EBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDkl
D_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;m00<0001=
D_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDkl
D_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDkl
D_e>o5;m001BoDklD_e>o5;mC_aBoDklD]a>fe;LC[]Bg00BOol00`00Oomoo`0POol002aoo`03001o
ogoo019oo`03001oogoo01Qoo`0dD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_d30000C5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aBoDkL0e;L00=>g7ooOol04Goo00<0
07ooOol07goo000IOol40003Ool20004Ool20004Ool2000DOol00`00Oomoo`0EOol0=5;mC_aBoDkl
D_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDkl
D_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDkl0P0005ABoDklD_e>o5;mC_aBoDklD_e>
o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>
o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>
o000C_aBoDklD_e>o5;mC_aBoDjkD]a>fe;LC[/BOol00`00Oomoo`0OOol001Uoo`03001oogoo00Uo
o`04001oogoo0003Ool00`00Oomoo`0DOol00`00Oomoo`0BOol0<e;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo0030000De;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;m
D_aBoE;lD_eBo5;LC]`00e;L00=BfgooOol03goo0P0087oo000JOol00`00Oomoo`0;Ool01000Oomo
ogoo0P005Woo0P0047oo039BoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>
o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDkl0`00
05]>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDkl
D_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDkl
D_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDkl001>o5;mC_aBoDklD_e>o5;LC[]Bg4kK
D]a>^`0BOol00`00Oomoo`04Ool4000EOol001=oo`@000Aoo`03001oogoo00Qoo`8000Aoo`03001o
ogoo01Moo`03001oogoo00Uoo`0cD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;l00<0001KD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aB
oE;lD_eBo5;LD]/00e;L4Woo00<007ooOol017oo00<007ooOol05Woo000IOol01000Oomoo`002Goo
00<007ooOol00goo0P006Goo00<007ooOol01Woo039BoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDkl
D_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDkl
D_e>o5;mC_aBoDkl0`00069>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aB
oDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aB
oDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aB
oDklD_d005;mC_aBoDklD_e>o5;mC]]Bg4jkD]a>fe;L4Woo00<007ooOol017oo00<007ooOol05Goo
000JOol2000:Ool30003Ool00`00Oomoo`0IOol00`00Oomoo`02Ool0<U;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`30000H5;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aBo@9Bg003D]]Bg5;L01=oo`03001o
ogoo00Aoo`03001oogoo01Aoo`00:goo00<007ooOol06goo03<007ooC_aBoDklD_e>o5;mC_aBoDkl
D_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDkl
D_e>o5;mC_aBoDklD_e>o5;mC_`00`0006U>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDkl
D_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDkl
D_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDkl
D_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;m001BoDklD_e>o5;mC_aBoDkKD]a>^e;LC]/04Woo
00<007ooOol00Woo00@007ooOol001Eoo`00:goo0P006Woo039BoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;l0`0006QBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;m0U;L00=Bfe;L
Ool04Woo00<007ooOol00Woo0P005Woo000[Ool00`00Oomoo`0GOol0<TklD_e>o5;mC_aBoDklD_e>
o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>
o5;mC_aBoDklD_e>o5;mC_aBoDklD_d20000L4klD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;m
C_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;m
C_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;m
C_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o000C_aBoDklD_e>o5;m
C_aBoDkKD]a>^e;L47oo0P0000=oo`00Ool06Woo000[Ool2000DOol0<e;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@030000Ke;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo000D_aB
oE;lD_eBo5;mD_aBo@02D]`00e;KOomoo`0AOol00`00Oomoo`0IOol002]oo`03001oogoo015oo`0b
C_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;m
C_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBo@<0001fD_e>o5;mC_aBoDklD_e>
o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>
o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>
o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>
o5;mC_aBoDklD_e>o5;mC_`004klD_e>o5;mC_aBoDklD_e>fe;LC[/COol00`00Oomoo`0HOol002Ao
o`8000Eoo`8000moo`0bD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@<0001f
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD_`3D]`0
0e;KOomoo`0AOol00`00Oomoo`0GOol002=oo`04001oogoo0004Ool00`00Oomoo`0<Ool0<E;mC_aB
oDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aB
oDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;m00<0001mD_e>o5;mC_aBoDklD_e>o5;mC_aB
oDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aB
oDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aB
oDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aB
oDklD_e>o5;mC_aBoDklD_e>o5;mC_aBo@00D_e>o5;mC_aBoDklD_e>o5;LC]]Bg00COol00`00Oomo
o`0GOol002=oo`04001oogoo0003Ool2000:Ool0<U;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_d30000OU;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBo0=Bg1=oo`03001oogoo01Ioo`008goo00@007ooOol0
00=oo`03001oogoo00Moo`0aD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;m
C_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_d00`00
08EBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;m
C_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;m
C_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;m
C_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;m
C_aBo@00D_e>o5;mC_aBoDklD_e>^e;LD]]Bg00AOol3000GOol000Qoo`@001Moo`04001oogoo0003
Ool00`00Oomoo`04Ool0<E;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m00<00026
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_`005;lD_eBo5;mD_aBoE;lD_eBf`=Bg19oo`03001oogoo01Eoo`001goo00@007ooOol0
01Uoo`8000Aoo`8000Ioo`0^D_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;m
C_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_`20000S5;mC_aB
oDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aB
oDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aB
oDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aB
oDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aB
oDklD_e>o5;mC_`004klD_e>o5;mC_aBoDklD]a>^e;LD]/COol00`00Oomoo`0DOol000Moo`04001o
ogoo000OOol00`00Oomoo`07Ool0:E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`00`0008eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;LD]/00U;L4goo00<007ooOol04goo0006Ool20000
0goo00000004Ool00`00Oomoo`0HOol00`00Oomoo`08Ool09DklD_e>o5;mC_aBoDklD_e>o5;mC_aB
oDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDkl00<0002CC_aB
oDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aB
oDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aB
oDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aB
oDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aB
oDklD_e>o5;mC_aBoDklD_e>o5;mC_aBo@00D_e>o5;mC_aBoDklD_e>o5;LC[]Bg5;K019oo`03001o
ogoo01=oo`003goo00<007ooOol067oo00<007ooOol02Goo025Bo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`00`0009IBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD]]Bg5;KD]`COol00`00Oomo
o`0BOol000moo`03001oogoo01Moo`<000]oo`0MC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDkl
D_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o0030000VTklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDkl
D_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDkl
D_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDkl
D_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDkl
D_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDkl
D_e>o5;mC_aBoDklD_e>o5;m001BoDklD_e>o5;mC_aBoE;KD]a>^e;L4Woo0P004goo000YOol00`00
Oomoo`0<Ool06E;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
00<0002MD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00
D_eBo5;mD_aBoE;lD_eBfe;LD]/04Woo0P004goo000EOol40003Ool20004Ool20005Ool00`00Oomo
o`0=Ool05DklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o0030000XDklD_e>
o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>
o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>
o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>
o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>
o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_`004klD_e>
o5;mC_aBoDklD]aBfe;LC[/04Woo0P004Woo000EOol00`00Oomoo`09Ool01000Oomoo`0017oo0P00
3goo015Bo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l00<0002UD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aB
oE;lD_eBo5;LD]]Bg5;K00ioo`<00003Ool007oo015oo`005Woo00<007ooOol02goo00<007ooOol0
0Woo00<007ooOol047oo00eBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBo@020000Z4klD_e>o5;mC_aB
oDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aB
oDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aB
oDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aB
oDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aB
oDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aB
oDkl001>o5;mC_aBoDklD_e>o5;LD]]Bg0Yoo`@000Aoo`03001oogoo011oo`005goo00<007ooOol0
27oo0P0017oo0P004goo00UBoE;lD_eBo5;mD_aBoE;lD_d00`000:]BoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o000D_aBoE;lD_eBo5;mD_aBg5;KD]`01Woo0`0027oo00<007ooOol047oo000EOol01000Oomoo`00
2Goo00<007ooOol00goo00<007ooOol04goo00EBoDklD_e>o5;m00<0002_D_e>o5;mC_aBoDklD_e>
o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>
o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>
o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>
o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>
o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>
o5;mC_aBoDklD_d005;mC_aBoDklD_e>o5;mC[]Bg5;KD]`00Woo0`0037oo00<007ooOol03goo000F
Ool2000:Ool30003Ool2000EOol0]U;m00000000D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBo@00D_eBo5;mD_aBoE;lD_eBfe;LD]/2000?Ool00`00Oomoo`0?Ool002Qoo`03001oogoo019o
o`<0002fD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;m
C_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;m
C_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;m
C_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;m
C_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;m
C_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;m001BoDklD_e>o5;m
C_aBoE:kD]aBfa1oo`03001oogoo00moo`00:7oo00<007ooOol03goo0`0017oo0;EBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;LD]]Bg00@Ool00`00
Oomoo`0?Ool002Qoo`8000eoo`<000Qoo`2eD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aB
oDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aB
oDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aB
oDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aB
oDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aB
oDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aB
oDklD_e>o000C_aBoDklD_e>o5;mC_aBg5:kD]`03goo00<007ooOol03goo000XOol00`00Oomoo`09
Ool3000=Ool0/e;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;l
D_eBo5;LD]/03goo00<007ooOol03goo000WOol30008Ool2000AOol0/dklD_e>o5;mC_aBoDklD_e>
o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>
o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>
o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>
o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>
o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>
o5;mC_aBoDklD_e>o5;mC_aBoDkl001>o5;mC_aBoDklD_e>o5;LD[/03Woo00<007ooOol03goo000W
Ool00`00Oomoo`05Ool3000DOol0/U;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00
D_eBo5;mD_aBoE;lD_eBo5;L3Woo00<007ooOol03goo000QOol20004Ool00`00Oomoo`02Ool3000I
Ool0/E;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDkl
D_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDkl
D_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDkl
D_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDkl
D_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDkl
D_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_d005;mC_aBoDklD_e>o5;mC_aBg00>
Ool00`00Oomoo`0>Ool0021oo`04001oogoo0003Ool5000MOol0/E;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD]]Bg00=Ool00`00Oomoo`0>Ool002=oo`04001o
ogooOol2000QOol0/5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>
o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>
o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>
o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>
o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>
o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_d005;mC_aBoDklD_e>
o5;mD]/=Ool00`00Oomoo`0>Ool0025oo`8000Eoo`03001oogoo021oo`2^D_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBoE;l0U;K37oo00<007ooOol03Woo000QOol00`00
Oomoo`05Ool2000QOol0/5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDkl
D_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDkl
D_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDkl
D_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDkl
D_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDkl
D_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDkl001>o5;mC_aBoDkl
D_e>o5KLD]/;Ool00`00Oomoo`0>Ool0025oo`<000Moo`03001oogoo01moo`2]D_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_`005;lD_eBo5;mD_aBo@02D]/;Ool00`00Oomoo`0>Ool002aoo`03
001oogoo01moo`2_D_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDkl
D_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDkl
D_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDkl
D_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDkl
D_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDkl
D_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;m001BoDklD_e>o5;mC_aBoE:k
E]`02Woo00<007ooOol03Woo000]Ool00`00Oomoo`0OOol0[U;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBo@00D_eBo5;mD_aBoE;lD_eBf`]oo`03001oogoo00eoo`00;Woo00<007ooOol07goo0:iB
oDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aB
oDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aB
oDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aB
oDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aB
oDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aB
oDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_d005;mC_aBoDklD_e>o5;mD[/:Ool00`00Oomoo`0=
Ool002moo`80021oo`2^D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m001BoE;lD_eBo5;mD_aB
oE;K2Goo00<007ooOol03Goo000aOol00`00Oomoo`0OOol0[DklD_e>o5;mC_aBoDklD_e>o5;mC_aB
oDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aB
oDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aB
oDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aB
oDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aB
oDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aB
oDkl001>o5;mC_aBoDklD_e>o5;mD[/027oo00<007ooOol03Goo000bOol00`00Oomoo`0OOol0Ze;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo002D]/7Ool00`00Oomoo`0=Ool0
03=oo`03001oogoo01moo`2/C_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDkl
D_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDkl
D_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDkl
D_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDkl
D_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDkl
D_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_`004klD_e>o5;mC_aBoDkl
E]`7Ool00`00Oomoo`0=Ool003Aoo`80025oo`2[D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBo@00D_eBo5;m
D_aBoE;lD_eBo5;K00Ioo`03001oogoo00eoo`00=Woo00<007ooOol07goo0:YBoDklD_e>o5;mC_aB
oDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aB
oDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aB
oDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aB
oDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aB
oDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aB
oDklD_e>o5;m001BoDklD_e>o5;mC_aBoE:k1goo00<007ooOol037oo000gOol00`00Oomoo`0OOol0
ZU;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mD_aBoE;lD_eBo5;mD_aBoE;lD_d005;mD_aBoE;lD_eBo5;mD]/6Ool00`00Oomoo`0<Ool003Qo
o`03001oogoo01moo`2YD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aB
oDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aB
oDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aB
oDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aB
oDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aB
oDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBo@00D_e>o5;mC_aBoDklE]`01Woo00<0
07ooOol037oo000iOol2000POol0ZE;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l001Bo5;mD_aBoE;lD_eBo5;K
00Eoo`03001oogoo00aoo`00>goo00<007ooOol07Woo0:QBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aB
oDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aB
oDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aB
oDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aB
oDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aB
oDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o000C_aB
oDklD_e>o5;mD[/5Ool00`00Oomoo`0<Ool003aoo`03001oogoo01moo`2VD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;l001Bo5;mD_aBoE;lD_d5Ool00`00Oomoo`0<Ool003eoo`03001oogoo01moo`2PC_aBoDklD_e>
o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>
o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>
o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>
o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>
o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>
o5;mC_aBoDkl000:Ool00`00Oomoo`0<Ool003ioo`03001oogoo01moo`2LD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aB
oE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m0Woo
00<007ooOol027oo00<007ooOol037oo000oOol2000POol0TDklD_e>o5;mC_aBoDklD_e>o5;mC_aB
oDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aB
oDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aB
oDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aB
oDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aB
oDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDkl00=Bo@03C_aBoDkl00Moo`03001oogoo00Qoo`03001o
ogoo00]oo`00@Goo00<007ooOol07Woo07mBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo006D]/02U;mD_aBoE;lD_eBo5;m
D_aFfe:k0U;K00=Ffe;KOol02Woo00<007ooOol01goo00<007ooOol02goo0012Ool00`00Oomoo`0N
Ool0IdklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;m
C_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;m
C_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;m
C_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDkl00UBo@03C_aBoDkl00MBo@0FC_aFfe:kE]]B^UKK
D[]Ffe:jE]]B^eKKD[YFfe:kE]]B^eKKD[]Ffe:kE]/=Ool00`00Oomoo`07Ool00`00Oomoo`0;Ool0
04=oo`03001oogoo01ioo`1KD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5JkD[X01U:k00IBoE;lD_eBo5;mD_`2D[/06UJkD[YB^e:kE[]B^eJkD[]F
fe:kE[]B^eKKD[]Bfe:kE]]B^eKKD[]Ffe:kE]]B^eKKD[/2D]/015KKD[]Bfe;K57oo00<007ooOol0
1Woo00<007ooOol02goo0014Ool2000OOol0QTklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;m
C_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;m
C_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;m
D[YBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aF^e:jE]]B^UJkD[YFfe:jE]]B^UKKD[YFfe:jE]]B^UKK
D[YFfe:jE]]B^UKKD[YFfe:jE]]B^eKKD[YFfe:jE]]B^UKKD[]Ffe:jE]]B^eKKD[YFfe:kE]/GOol0
0`00Oomoo`05Ool00`00Oomoo`0;Ool004Ioo`03001oogoo01eoo`0mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;l
D_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`02E;m00=Bo5JjE[X00eJj
03EB^UJjD[YF^U:jE[YB^UJjD[YF^e:jE[YB^UJkD[YF^U:jE[]B^UJjD[YF^e:jE[]B^UJkD[YF^e:k
E[]B^UJkD[]Ffe:kE[]B^eKKD[]F^e:kE]]B^eJkD[]Ffe:kE]]B^eKKD[]Ffe:k01aoo`03001oogoo
00Aoo`03001oogoo00]oo`00Agoo00<007ooOol07Woo02aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aB
oDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBoDklEWQ>o5;mC_aBoDklD_e>o5;mC_aB
oDkl1E;m00=>o5;mD_d01E;m04ABVE;mDYUF^U:IE[YBVUJjDYUF^U:JE[YBVUJkDYYF^U:JE[]B^UJj
DYYF^e:jE[]B^UJkD[YF^e:jE[]B^UJkD[YFfe:jE[]B^UKKD[YFfe:jE]]B^UKKD[YFfe:jE]]B^UKK
D[YFfe:jE]]B^UKKD[YFfe:jE]]B^UKKD[YFfe:jE]]B^eKK7Woo00<007ooOol017oo00<007ooOol0
2goo0018Ool00`00Oomoo`0NOol085;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;m
D_aBoE;lD_eBo5;mD_aBoE;lD_eBo5;mD_`3D_d07e;lD_eBo5;mD_aBoE9iEYUBVEJIDWUFVE:IEYYB
VEJIDYUFVU:IEYYFVEJJDYUFVUJIE[YBVUJjDYYF^U:J00=F^P0=DYYF^UJjE[YBVUJjD[YF^U:jE[YB
^UJjD[X00eJj02AB^UJjD[YF^e:jE[YB^UJkD[YF^eJjE[]B^UJkE[YF^e:jE[]B^eJkD[YF^e:kE]]B
^UJkD[]Ffe:jE[]B^eKKD[]F^e:kE]/ROol00`00Oomoo`04Ool00`00Oomoo`0:Ool004Uoo`8001mo
o`06D_e>o5;mC_aBoDkl0e;m00]>o5;mC_aBoDklD_e>o5;mC_aBoDkl00MBo@1KDUQFN59HEWQBF5Ih
DUQFNE9hEWUBN5JIDWQFVE9hEYUBNEJIDWQFVU:IEYYBNEJJDYUFVE:IE[YBVEJjDYUF^U:IE[YBVEJj
DYYF^U:IE[YBVUJjDYYF^U:JE[YBVUJkD[YF^U:JE[YB^UJkD[YF^e:jE[]B^UJkD[YF^e:jE]]B^UJk
D[YFfe:jE]]B^UKKD[YFfe:jE]]B^UKKD[YFfe:jE]]B^UKKD[YFfe:jE]]B^UKKD[X09Goo00<007oo
Ool00goo00<007ooOol02Woo001;Ool00`00Oomoo`0MOol03e;mD_aBoE;lD_eBo5;mD_aBoE;lD_eB
o5;mBMABo@03CQH00eHfD_eFE`03DUL01EIGDUMBF59HDWP00e9H00EBN5IhEWQFN5Ii009FN007DYUF
VE9iEYUBVEJIDWT01eJI00EBVEJJEYUFVU:I009FVP06E[YFVUJjEYYF^UJJ0eJj00=BVUJjE[X02EJj
00EB^UJjE[YF^U:j009F^P0IE[]B^UJjE[YF^e:jE[]F^UJkD[YF^eJjE[]B^UJkE[YF^e:jE[]B^eKK
D[YF^e:kE]/0:Goo00<007ooOol00goo00<007ooOol02Woo001<Ool00`00Oomoo`0MOol0KTEa@E15
LDEAAG51D4gEBKA=eDVdCME9]4hGBOI>5dhFESIB5EHfDSMFEe8gEUMB=eIGDSMFN59HEWQBF5IhEUMF
N59hEYUBN5IiDWQFVE9iEYUBN5JIDWUFVEIhEYYBVEJIDYUFVU:IE[YBVEJjDYUF^U:IE[YBVEJjDYUF
^U:IE[YBVEJjDYYF^U:JE[YFVUJjDYYF^U:jE[YBVUJjD[YF^e:jE[]B^UJjD[YFfe:jE[]B^UKKD[YF
^e:jE]]B^UKKD[YFfe:jE]]B^UKKD[YFfe:jE]]B^UKKD[X/Ool00`00Oomoo`02Ool00`00Oomoo`0:
Ool004eoo`03001oogoo01aoo`03AE55LDEA0095D@03AG59e4WD00E9e003CQIB=UHf009F=P04DSIB
Ee9GEUL3DUL00eIGDUQBF002EWP015IGEWQFN5Ii0eIh00IFNEIhEYUBVEJIEWT:EYT03UJJEYUFVEJI
EYYFVEJjEYYF^UJJE[YFVUJjEYXFE[X01EJkD[YF^UJjE[/00eJj00YF^eJjE[YF^UJkD[YF^eJjE[]B
^S1oo`05001oogooOol0000<Ool004ioo`03001oogoo01]oo`1YAG55DDEa@E15LDEACME9]4gEBKA=
eDVdCMEB5EHfDQEF=U8EESIB5EIGDSMFEe8gEUMB=eIhDUMFN5IGEWQBEeIhEUMFNE9hEYUBN5IiDWQF
VEIhEYUFN5JIEWQFVE:IEYYBVEJIDYUJVEJIE[YBVEJjEYUF^U:IE[YBVEJjDYUF^UJIE[YBVEJjEYYF
^U:IE[YFVUJjDYYF^U:jE[YBVUJjD[YF^U:jE[]B^UJjD[YFfe:jE[]B^UKKD[YFfe:jE]]B^UKKD[YF
fe:jE]]B^UKK03=oo`04001oogoo000<Ool004moo`8001]oo`=5D@04AG55DDEAAE45BM@01EHDESIF
=UHfDSH00eHf0e9G00IFEe9GEUMFEeIhEUL3EWP015IGEWQFN5Ii0eIh00=FV5IhEYT00UJI00=FNEJI
EYT025JI00AFVUJIEYUFV@9FVP06E[YFVUJjEYUF^UJI75Jj00IF^eJjE[YF^UJkE[XgOol01000Oomo
o`0037oo001AOol00`00Oomoo`0HOol08TEa@E15LDEAAG51D4EaBKA=eDVdCME9]5HDEO=F=U8EESIB
5EHfDQEF=U8gEUMFEUYGEUIJMeIGEWQBEeIhEUMFN59G0UIh00aJV5IhFYUFN5ZHEWQFVEIhEYUFN5JI
EWP2EYT065ZIEYUFVEJIFYUFVEJjDYUF^UJIE[YFVEJjEYUF^UJIE[YFVEJjDYUF^UJJE[YFV@=F^P09
DYYF^UJjE[YBVUJkD[YF^U:j00=F^P0:D[YFfe:jE[]B^UKKD[YFfe:jE]/jOol00`00Ool0000<Ool0
059oo`03001oogoo01Moo`03AE55LDEA0095D@03AG55DDWD00=9e0=F5005DSIF=UHfESIB=P02ESH0
0eIGEUIFE`02EUL01EIFEUMFN5IhEUL00eIh00AFMeIhEWQFV0=FN003EYQFNEJI009FV@03EWUFVEJH
00QFV@0<EYYFVEJIEYUF^EJIE[YFVEJjEYUF^UJI6eJj?Woo00<007oo00002goo001COol00`00Oomo
o`0FOol0<DEaAE55LD5@AG55DDEaBKA=eDVdEQAEleXDEOAF=U8EESIB5EHfDQEJEUIFFUMFEUYgEUIJ
EeIFEWQFEeIhDUMJN5IgFWQFEeZIEWQJV5IhFYUFN5JIEWQFVEIhFYUFN5ZI00=FV@0HFYUFVEJIEYUJ
^UJIE[UFVEZjEYUF^EJIE[YFVEJjEYUF^UJIE[YFVEJjEYUF^UJI0eJj00EBVUJjE[YF^UJI00=F^P07
D[YF^UJjE[]B^UKKD[X0@Goo0P002goo001DOol2000FOol3AE401TEaAE55DDEAAG59e0IF5005ESIB
=UHfESIJE@02FSD2EUL01EIFEUMFEeIGEUH00UIh00EJN5IgFWMFMeYh00=FN00:EYQFN5IhEWQFVEJH
EYUFV5JIEYP6EYT01EZIEYUFVEJIE[T00eJI00MF^UJIE[YFVEJjEYUF^@0EE[Y4Ool2000;Ool005Io
o`03001oogoo01=oo`0cAG51D4EaAE55LD5@AG55DDgEEO=J55GdEQAEleXDDQEF=U8EESIJ=EYFESEJ
MeIFFUMFEUYgEUIJEeIGFWQFMeYhEUMJN5IgFYQFN5ZIEWQJV5IgFYQFN5ZIEWQJVEIhFYUFN5ZI009F
V@0IEYQJ^EJHFYUFVEZjEYUF^EJIF[YFVEJjEYUJ^UJIE[YFVEZjEYUF^UJIE[YFVEJjEYT00eJj00EF
VEJjE[YF^U:j00=F^TIoo`8000]oo`00Egoo00<007ooOol04Woo00=5DDEaAE400TEA00=5LDEAAE40
1eHD0eHf0eXe00=JEEXeEUL00UIG01UFEUIGFUIJMUIgFWMFMeYhEWMJMeIgEYQFN5ZHFWQJV5IhFYQF
V5JIEYQFVEJHEYUFV002EYT01EZIEYUFVEJIFYT00eJI00YF^EJIEYUFVEJjEYUF^EJIE[YFV@EF^P03
E[UF^UJj00IF^TIoo`@000eoo`00F7oo00<007ooOol04Goo0515LDEAAG51D4EaAE55LD5@FQAEm5HD
EO=J55GdEQAEleHfFSEJEUHeFUIJ=EYFEUIJMeIFFUMJEUigFUIJN5IGFWQFMeYhEUMJN5IhFYQFMeZH
EWQJV5IgFYQFN5ZIEWQJVEIhFYUFN5ZiEYQJVEJHF[UFV5JiEYUJ^UJIF[UFVEZiEYUF^UJIF[YFVEJj
EYUJ^UJIE[YFVEZjEYUF^UJI0eJj00=FVGooOol0@Goo10004Goo001IOol2000@Ool01DEaAE55DDEA
AG400dEA00=5LEHDEQ@01UHD0eXe00IJEEXeFSEJ=EYEEUH2FUH02EYfFUIJEUYFFWQFMeYgEWMJN002
FWL02eYhFYQFN5ZHFWQJV5IhEYUFV5JIEYP00eZH0eJI00EJVEJIEYUFVEZi00=FV@06F[UFVEJIEYUF
^UJI0UJi00QJ^EJIE[YF^EJjE[UF^UJi0eJj@Goo10005Goo001KOol00`00Oomoo`0=Ool094EAAG51
D4EaAE55LD5@AG55DEHDEO=J55GdEQAEleXDEOAJEUHeFUIJ=EYFESEJEUXeFWMJEUigFUIJMeYFGWMF
MeYhEUMJN0=JM`0ZFYQFN5ZHEWMJV5IhFYQFMeZIEYQJVEIhFYUFV5ZIEYQJ^EJHFYUFV5ZiEYQJ^EJI
F[UFVEZiEYUJ^EJIF[YFVEZjEYUJ^UJIF[YFVEJjEYUJ^UJI?goo10006Goo001LOol00`00Oomoo`0<
Ool2AE401TEaAE55DDEAAG55D@9Ml@IF509N<`09FUEJ=EXeFSEJEEXeGUEJEUYf00=JEP04FWIJEUYF
EWL6FWL025ZHFWQJV5IhFYQJN5ZHEYP3FYP015JHFYQJV5ZI0UJI0UZI00AFV5ZIFYUJ^@=FV@06F[UF
VEJiE[UJ^EJI0UJi00EJ^EJiE[YF^EJj03eoo`@001eoo`00GGoo00<007ooOol02goo0291D4EaAE55
LD5@AG55DDEaFO5N4UGdEQAEleXDEOAF55XCGSAJ=EYFESEJEUXeFUIJE5iEFUIJMeYFGWMJEUYgFUIN
U`=JM`0WGYMJMeYgEWMJV5IhFYQJMejHFWMJV5IhFYUFV5ZIEWQJVEJHFYUFV5ZiEYQJVEJHF[UFVEZi
EYUJ^EJIF[UFV5ZjEYUJ^UJIF[YFVEZj03eoo`<0025oo`00GWoo00<007ooOol02Woo00E5LDEAAE55
DDEa00=5D@9Ml@EF5003GS=N=5hc009J=@03FUEJ=EXe00=NE@9JEP06FWIJEUYFFUINMUiF25Yg00QJ
V5YhFYQJMeZHFWQJV5JH1UZH00=JVEJHFYT00UZI00EFV5ZIFYUJ^EJI009JV@06F[UFVEJiE[UJ^EJI
>goo100097oo001OOol2000:Ool05dEAAG51D4EaAE55LD5@AG5IlEhBEO=J55GdEQAElehdGS=N=5XC
FUIJ=EYFESD00eiE00YJE5igFUIJMeYFGWIJEUifFWMNU`=JM`0<GYMJMUjGFWMNV5YgFYQJMejHFWMJ
VEIh0eZH019JN5ZHEYQJVEJHF[UFV5ZIEYQJ^EJIF[UFV5ZiEYUJ^EJIF[XiOol4000XOol0065oo`03
001oogoo00Moo`95D@06AG55DDEAAE55LDEA0Uga15HD00EN=5hcGS=N<ehd00=J=@ENE@=JEP03FWIN
EUif009NMPEJM`9NM`06FYQJMeZHFWQJV5Yg2EZH0UZI0eZH00IJVEZHFYUJVEZiEYT2FYTgOol4000/
Ool0069oo`03001oogoo00Ioo`0E@E15LDEAAG51D4EaAE55LEWaGQ9Em5HDEO=J55hcGSAJ4ehdGS=J
EUHe00=NE@0;FUANEEiEFWMJEUigFUINMUYEGWIJEP02FWL03EjGFWINUeYfGYMJMUZHFWMNV5YgFYQJ
MejH009JV00AFWQJV5ZHFYQJN5ZiFYQJVEJHF[UJV5ZIEYQJ^EJIF[UFV00dOol4000`Ool006=oo`03
001oogoo00Eoo`05AG55DDEAAE55L@02AE43GO43EQ@3GS<01EhdGS=N<ehcFUD01eiE00=JMUiFGWH0
0Uif00=NEUifGWH00UYg0eig00UJMeigFWQJV5YgFYQJUejHFWL02UZH00MJVEZHFYQJV5ZIEYUJV@0b
Ool4000dOol006Aoo`8000Eoo`0DAE55LD5@AG55DDEa@E1N4UWaGQ9EleXDEOAN=5XCGSAN<ehdFQ=N
=09NE@0MFUANEEiEGUEJE5iEFUINMUYEGWIJEUifFUENMUYfGYMJMUjGFWINUeYfGYMJMejHFWMNV5Yg
GYQJM`03FYP02eYhGYQJUejHEYQJ^EZHFYUFV5ZiFYP0<Goo0`00>7oo001VOol00`00Oomoo`07Ool0
0dEAAG5Ml@03GO4015HDGS=N<ehd0ehc00=N=5hcGUD01UiE00ENE5ifGWINMUiF00=NMP05GWENMUig
GWMJM`03GWL01EYgFYMJUejHFWL00UZG00=NV5ZHFYP02EZH00=JVEZHOol0;Goo1000>goo001WOol0
0`00Oomoo`08Ool03UhBFO5N4UWaEQAJ4ehdGS=N=5XCGSAN<f9CHS<3GUD09UYDGUENEF9eGUANMUYF
GWIJEEifFUIRMUiEGYMJMUjGFWINUeYfGYMNMUjHFWMNV5YgGYQJMejHFYMNV5ZGGYQJUejHFYMJVEJH
F[T/Ool4000oOol006Qoo`03001oogoo00Uoo`9Ml@03GS=N=5hc009N<`03GSAN<ehc009RD`ENE@04
HUERE69EGUH3GWH01EiFGWINMUifGWD00eig00EJMeifGWINUeYg009JU`03GYQJMeZG009NU`MJV2Yo
o`@004=oo`00JGoo0P002Woo00eIlFHaGS=N=5XCGSAN<ehdFQ=RDf8cGUEJE003GUD08EiDHWENE69e
FUENMUYFHWINEF9fGWERMUYfGYMJMUjGGWINUeifGYMJMejHFWMNV5YgGYQJMejHFYMNV5ZGGYQJU`0W
Ool40017Ool006]oo`03001oogoo00Qoo`04IS5N<ehcGS@3GS<00f9CHS=RD`04GUD01f9DHUENE69E
HUANMUiF00=NMP05GWENMUifGWIJM`02GWH01ejGGWINMUifGYQJMeZG00ENU`AJV2Aoo`@004]oo`00
K7oo00<007ooOol03Woo00AR<f9CHS=RD`9NE@0PGUARMEiDHWENE69eGUANMUiEHWINMF9fGUERMUie
GYMNMUjGGWINUeifGYMNMUjHFWMNV5YgGYMJMejHFYMNV2=oo`<004moo`00KGoo00<007ooOol03Woo
0V9C00YR<eiEGUEREEiDHUERE69EGUARE@9NMP05GWENMUifGWINM@02GWH01EjGGWINMUifGYL00Uif
25jG87oo1000DWoo001^Ool00`00Oomoo`0@Ool085YDHWENE69eGUARMEiDHWENE69fGWERMUiEHWIN
MF9fGWERUUifGYMNMUjGGWINUeifHYMJMejGFWMNV5YgGYLMOol4001FOol006moo`80019oo`08001o
ogooGUAREF9DHWARE0=NMP03GWENMUif009RM@9NMP06GYMNMUifGWIRUUif1EjG6Woo1000FWoo001a
Ool00`00Oomoo`0?Ool00`00Oomoo`03Ool05V9DIWANEF9fGWERMUiEHYINMF9fGWENUeifGYMNMV:G
GWIRUUifGYQJMejG5goo1000GWoo001bOol00`00Oomoo`0>Ool00`00Oomoo`05Ool00eifGWENMP02
GWH4HWD3GWH01F:FGWINUUifHYH00UjG57oo1000HWoo001cOol00`00Oomoo`0<Ool00`00Oomoo`0:
Ool03UieHWINMF:FGWERMUifHYMNMV:FGWIRUeifHYHBOol3001VOol007Aoo`8000aoo`03001oogoo
00eoo`ARM@06GWINUUifHYINMUjF3goo1000JGoo001fOol00`00Oomoo`09Ool00`00Oomoo`0?Ool0
26JEHWERUUifHYMNMV:FGWH;Ool4001]Ool007Moo`03001oogoo00Qoo`03001oogoo01Aoo`03GYIN
MWoo00Moo`@0075oo`00N7oo00<007ooOol01goo00<007ooOol06Woo1000MGoo001iOol20007Ool0
0`00Oomoo`0FOol4001iOol007]oo`03001oogoo00Aoo`03001oogoo01=oo`<007eoo`00O7oo00<0
07ooOol00goo00<007ooOol03goo1000P7oo001mOol00`00Oomoo`02Ool00`00Oomoo`0;Ool40024
Ool007ioo`05001oogooOol00009Ool40028Ool007moo`800003Ool007oo00Aoo`@008aoo`00PGoo
0P0000=oo`0000000P00T7oo0022Ool2002DOol00?mooaUoo`00ogoo6Goo003oOolIOol00?mooaUo
o`00ogoo6Goo003oOolIOol00001\
\>"],
  ImageRangeCache->{{{0, 279}, {202.5, 0}} -> {-0.163453, 0.0233871, \
0.00416106, 0.00416106}}],

Cell[TextData[{
  StyleBox["Figure 4.1.",
    FontFamily->"B Times Bold"],
  "  Intersection of the two integrals for ",
  StyleBox["c",
    FontSlant->"Italic"],
  "1 = ",
  StyleBox["c",
    FontSlant->"Italic"],
  "2 = ",
  Cell[BoxData[
      \(TraditionalForm\`1\)]],
  ". The parameters \[Alpha] and \[Beta] take the values ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha] = 1/10\)]],
  " and \[Beta]=1. The intersecting line represents the solution of the \
equation if we project the intersection to the ",
  Cell[BoxData[
      \(TraditionalForm\`\((x, u)\)\)]],
  "-plane."
}], "SmallText",
  TextJustification->1],

Cell[TextData[{
  "Since we know two first integrals, we are able to eliminate the \
derivatives from the two integrals analytically. We solve the first relation \
with respect to ",
  Cell[BoxData[
      \(TraditionalForm\`u'\)]],
  ":"
}], "Text",
  CellTags->"first integral"],

Cell[CellGroupData[{

Cell[BoxData[
    \(sol1\  = \ 
      Solve[integrals\[LeftDoubleBracket]1\[RightDoubleBracket], 
          \(u'\)[x]] // Simplify\)], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{
          RowBox[{
            SuperscriptBox["u", "\[Prime]",
              MultilineFunction->None], "[", "x", "]"}], "\[Rule]", 
          \(\(\(-1\) + E\^\(\[Alpha]\ \((\(-c1\)\ \[Beta] + u[x])\)\)\)\/\(x\ 
                \[Alpha]\)\)}], "}"}], "}"}]], "Output"]
}, Open  ]],

Cell["\<\
Substituting this result into both integral expressions \
delivers\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(int21\  = \ 
      \(integrals\  /. sol1\[LeftDoubleBracket]1, 1\[RightDoubleBracket] // 
          PowerExpand\) // Simplify\)], "Input"],

Cell[BoxData[
    \({True, 
      \(1 - E\^\(c1\ \[Alpha]\ \[Beta] - \[Alpha]\ u[x]\)\)\/\(x\ 
            \[Alpha]\) == c2}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The resulting list contains the identity and an implicit representation of \
the solution. The explicit solution follows from the second relation if we \
solve it with respect to ",
  Cell[BoxData[
      \(TraditionalForm\`u\)]],
  ":"
}], "Text",
  CellTags->"implicit representation of a solution"],

Cell[CellGroupData[{

Cell[BoxData[
    \(solution\  = \ 
      Solve[int21\[LeftDoubleBracket]2\[RightDoubleBracket], u[x]]\)], "Input"],

Cell[BoxData[
    \({{u[x] \[Rule] 
          \(-\(\(\(-c1\)\ \[Alpha]\ \[Beta] + 
                  Log[x\ \((\(-c2\) + 1\/\(x\ \[Alpha]\))\)\ \[Alpha]]
                    \)\/\[Alpha]\)\)}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The constants ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          FormBox["c",
            "TraditionalForm"], "1"], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`c\_2\)]],
  " denote constants of integration. \[Alpha] and \[Beta] are the model \
parameter and the introduced group parameter, respectively. The occurrence of \
the group parameter \[Beta] as a multiplier reminds us of the fact that the \
additive integration constant ",
  Cell[BoxData[
      \(TraditionalForm\`c\_1\)]],
  " is related to the group of translations."
}], "Text",
  CellTags->"translation"],

Cell[TextData[{
  "The solution steps so far discussed are collected in the ",
  StyleBox["MathLie",
    FontSlant->"Italic"],
  " function ",
  StyleBox["SecondOrderIntegrate[]", "MmaText"],
  ". The application of this function to a second-order ODE is similar to the \
use of ",
  StyleBox["DSolve[]", "MmaText"],
  ". The function needs the equation under discussion, the dependent and \
independent variables, and the parameters contained in the ODE. The example \
discussed above is solved by"
}], "Text",
  CellTags->{"SecondOrderIntegrate[]", "second-order ODE", "DSolve[]"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(sol\  = \ SecondOrderIntegrate[firstExample, u, \ x, {\[Alpha]}]\ 
    \)\)], "Input"],

Cell[BoxData[
    \({u \[Rule] Function[x, \(-\(Log[\(-x\)\ CI[1] - CI[2]]\/\[Alpha]\)\)]}
      \)], "Output"]
}, Open  ]],

Cell[TextData[{
  "where ",
  StyleBox["CI\[ThinSpace]",
    FontSlant->"Italic"],
  "[",
  StyleBox["1",
    FontSlant->"Italic"],
  StyleBox["]",
    PrivateFontOptions->{"FontPostScriptName"->Automatic}],
  " and ",
  StyleBox["CI\[ThinSpace]",
    FontSlant->"Italic"],
  "[",
  StyleBox["2",
    FontSlant->"Italic"],
  "] are constants of integration. The solution obtained looks different in \
comparison with the solution presented above. However, the extraction of the \
multiplier ",
  StyleBox["CI\[ThinSpace]",
    FontSlant->"Italic"],
  "[",
  StyleBox["1",
    FontSlant->"Italic"],
  "] and a rescaling of ",
  StyleBox["CI\[ThinSpace]",
    FontSlant->"Italic"],
  "[",
  StyleBox["2",
    FontSlant->"Italic"],
  "] will create the same representation of the solution. The same solution \
as found by the manual calculation is derived by the function ",
  StyleBox["DSolve[]:", "MmaText"]
}], "Text",
  CellTags->"DSolve[]"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DSolve[firstExample == 0, u, x]\)], "Input"],

Cell[BoxData[
    \({{u \[Rule] \((C[2] - Log[#1\ \[Alpha] - C[1]]\/\[Alpha]&)\)}}\)], 
  "Output"]
}, Open  ]],

Cell[TextData[{
  "Again, a constant is extracted from the argument of the logarithm. This \
example shows that the solution steps of Lie\[CloseCurlyQuote]s method of \
first integrals result in the same solution as that of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ".\[ThickSpace]\[EmptySquare]"
}], "Text",
  CellTags->"Lie's method of first integrals"],

Cell["Example 2", "Example"],

Cell["\<\
The second example for a second-order ODE is related to the problem \
of a suspended cable equation:\
\>", "Text",
  CellTags->"generalized suspended cable equation"],

Cell[BoxData[
    \(TraditionalForm
    \`u\_\(x, x\)\  - \ \[Alpha]\ \((1\  - u\_x\%2)\)\^\(1/2\)\  = 0. \)], 
  "NumberedEquation"],

Cell[TextData[{
  "The problem of the suspended cable is discussed by ",
  ButtonBox["Ames [1968]",
    ButtonData:>"Ames-68",
    ButtonStyle->"Hyperlink"],
  ". We examine here a generalization of the cable equation by introducing an \
arbitrary power \[Nu] in the second term of the ODE:"
}], "Text",
  CellTags->"suspended cable"],

Cell[BoxData[
    \(TraditionalForm
    \`u\_\(x, x\)\  - \ \[Alpha]\ \(\((1\  - u\_x\%2)\)\^\[Vee]\)\  = 0. \)], 
  "NumberedEquation"],

Cell[TextData[{
  "The original model follows from our model with ",
  Cell[BoxData[
      \(TraditionalForm\`\[Nu] = 1/2\)]],
  ". The present problem is similar to the first example we discussed. The \
difference is that we added \[Alpha] to the square of the derivative and \
raised the second term to the \[Nu]th power. These small changes lead to \
substantial variations in the solution:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(secondExample\  = \ 
      \[PartialD]\_\(x, x\)u[x]\  - 
          \[Alpha] \((1 + \ \((\[PartialD]\_x u[x])\)\^2)\)\^\[Nu]\  == 0; 
    secondExample // LTF\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {\(\(-\[Alpha]\)\ \((1 + u\_x\%2)\)\^\[Nu] + u\_\(x, x\) == 0\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output"]
}, Open  ]],

Cell[TextData[
"In applying Lie\[CloseCurlyQuote]s algorithm to this equation, we first \
calculate the point symmetries of this equation for arbitrary \[Nu]. "], 
  "Text",
  CellTags->{"Lie's integration algorithm", "point symmetries"}],

Cell[TextData[{
  "The infinitesimals follow by applying the ",
  StyleBox["MathLie",
    FontSlant->"Italic"],
  " function ",
  StyleBox["Infinitesimals[]", "MmaText"],
  " to the equation:"
}], "Text",
  CellTags->{"infinitesimals", "Infinitesimals[]"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(infi\  = \ 
      Infinitesimals[secondExample, u, x, {\[Alpha], \[Nu]}, 
        SubstitutionRules \[Rule] {\[PartialD]\_{x, 2}u[x]}]; infi // LTF\)], 
  "Input"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\(\[Phi]\_1 == k1\)},
          {\(\[Xi]\_1 == k2\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {
        Equal[ 
          Subscript[ \[Phi], 1], k1], 
        Equal[ 
          Subscript[ \[Xi], 1], k2]}]]], "Output"]
}, Open  ]],

Cell["\<\
The result is a two-dimensional symmetry transformation which \
itself is solvable. The symmetries represent translations in the independent \
and dependent variables. The first difference in comparison to Example 1 is \
that the group is smaller. This reduction of the group order has consequences \
with regard to the solutions.\
\>", "Text",
  PageWidth->PaperWidth,
  ShowCellBracket->False,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}}],

Cell[TextData[{
  "The two subgroups necessary for integration are derived by independently \
setting each of the group parameters ",
  StyleBox["k1 ",
    FontSlant->"Italic"],
  "or ",
  StyleBox["k2",
    FontSlant->"Italic"],
  " to unity. Since the symmetry group is two dimensional, we know from Lie \
that the algebra is always solvable. In the worst case, the solution may in \
the end be represented by an implicit representation. The infinitesimals for \
the two subgroups follow from"
}], "Text",
  CellTags->{"solvable", "infinitesimals"}],

Cell[BoxData[
    \(\(inf1\  = \ 
      \(\({{\(xi[1]\)[x, u]}, {\(phi[1]\)[x, u]}}\  /. infi\) /. {
            k1 \[Rule] 1, k2 \[Rule] 0}\)\  /. u \[Rule] u[x]; \)\)], "Input"],

Cell[BoxData[
    \(\(inf2\  = \ 
      \(\({{\(xi[1]\)[x, u]}, {\(phi[1]\)[x, u]}}\  /. infi\) /. {
            k1 \[Rule] 0, k2 \[Rule] 1}\)\  /. u \[Rule] u[x]; \)\)], "Input"],

Cell[TextData[{
  "So far, we put no restrictions on the exponent \[Nu]. The following \
derivation of the solution however assumes a specific value for \[Nu]. We \
arbitrarily choose ",
  Cell[BoxData[
      \(TraditionalForm\`\[Nu] = 3\)]],
  ". The related Lie matrix for this case is calculated by"
}], "Text",
  CellTags->"Lie matrix"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[CapitalDelta]matrix = 
      DeltaMatrix[x, u, 
        \[Alpha] \((1 + \ \((\[PartialD]\_x u[x])\)\^2)\)\^3\ , 
        2, {inf1, inf2}]; 
    TableForm[\[CapitalDelta]matrix] // LieTraditionalForm\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"0", "1", "0"},
          {"1", "0", "0"},
          {"1", \(u\_x\), \(\[Alpha]\ \((1 + u\_x\%2)\)\^3\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output"]
}, Open  ]],

Cell[TextData[{
  "The determinant of this matrix is given by a polynomial of sixth order in \
",
  Cell[BoxData[
      \(TraditionalForm\`u'\)]],
  ":"
}], "Text",
  CellTags->"determinant"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Det[\[CapitalDelta]matrix] // LieTraditionalForm\)], "Input"],

Cell[BoxData[
    \(\(-\[Alpha]\) - 3\ \[Alpha]\ u\_x\%2 - 3\ \[Alpha]\ u\_x\%4 - 
      \[Alpha]\ u\_x\%6\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The first integrals for the generalized cable equation with ",
  Cell[BoxData[
      \(TraditionalForm\`\[Nu] = 3\)]],
  " follow from"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(integrals\  = \ 
      Thread[FirstIntegral[x, u, \[CapitalDelta]matrix, {1, 2}] == 
          \ {c1, c2}]; \(integrals // LieTraditionalForm\) // TableForm\)], 
  "Input"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {
            RowBox[{
              RowBox[{"u", "+", 
                StyleBox[\(1\/\(4\ \[Alpha]\ \((1 + u\_x\%2)\)\^2\)\),
                  ScriptLevel->0]}], "==", "c1"}]},
          {
            RowBox[{
              RowBox[{"x", "-", 
                StyleBox[\(\(3\ ArcTan[u\_x]\)\/\(8\ \[Alpha]\)\),
                  ScriptLevel->0], "-", 
                StyleBox[\(u\_x\/\(4\ \[Alpha]\ \((1 + u\_x\%2)\)\^2\)\),
                  ScriptLevel->0], "-", 
                StyleBox[\(\(3\ u\_x\)\/\(8\ \[Alpha]\ \((1 + u\_x\%2)\)\)\),
                  ScriptLevel->0]}], "==", "c2"}]}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {
        Equal[ 
          Plus[ u, 
            Times[ 
              Rational[ 1, 4], 
              Power[ \[Alpha], -1], 
              Power[ 
                Plus[ 1, 
                  Power[ 
                    Subscript[ u, x], 2]], -2]]], c1], 
        Equal[ 
          Plus[ x, 
            Times[ 
              Rational[ -3, 8], 
              Power[ \[Alpha], -1], 
              ArcTan[ 
                Subscript[ u, x]]], 
            Times[ 
              Rational[ -1, 4], 
              Power[ \[Alpha], -1], 
              Subscript[ u, x], 
              Power[ 
                Plus[ 1, 
                  Power[ 
                    Subscript[ u, x], 2]], -2]], 
            Times[ 
              Rational[ -3, 8], 
              Power[ \[Alpha], -1], 
              Subscript[ u, x], 
              Power[ 
                Plus[ 1, 
                  Power[ 
                    Subscript[ u, x], 2]], -1]]], c2]}]]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Solving the first relation with respect to ",
  Cell[BoxData[
      \(TraditionalForm\`u'\)]],
  " allows us to eliminate this term in the second integral:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(sol1\  = \ 
      Solve[integrals\[LeftDoubleBracket]1\[RightDoubleBracket], 
          \(u'\)[x]] // Simplify\)], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{
            RowBox[{
              SuperscriptBox["u", "\[Prime]",
                MultilineFunction->None], "[", "x", "]"}], "\[Rule]", 
            \(-\@\(\(2\ c1 + \@\(c1 - u[x]\)\/\@\[Alpha] - 
                      2\ u[x]\)\/\(\(-2\)\ c1 + 2\ u[x]\)\)\)}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{
              SuperscriptBox["u", "\[Prime]",
                MultilineFunction->None], "[", "x", "]"}], "\[Rule]", 
            \(\@\(\(2\ c1 + \@\(c1 - u[x]\)\/\@\[Alpha] - 
                      2\ u[x]\)\/\(\(-2\)\ c1 + 2\ u[x]\)\)\)}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{
              SuperscriptBox["u", "\[Prime]",
                MultilineFunction->None], "[", "x", "]"}], "\[Rule]", 
            \(-\(\@\(\(\(-2\)\ c1 + \@\(c1 - u[x]\)\/\@\[Alpha] + 
                          2\ u[x]\)\/\(c1 - u[x]\)\)\/\@2\)\)}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{
              SuperscriptBox["u", "\[Prime]",
                MultilineFunction->None], "[", "x", "]"}], "\[Rule]", 
            \(\@\(\(\(-2\)\ c1 + \@\(c1 - u[x]\)\/\@\[Alpha] + 
                        2\ u[x]\)\/\(c1 - u[x]\)\)\/\@2\)}], "}"}]}], "}"}]], 
  "Output"]
}, Open  ]],

Cell[TextData[{
  "The solution for ",
  Cell[BoxData[
      \(TraditionalForm\`u'\)]],
  " consists of four expressions containing square roots of ",
  Cell[BoxData[
      \(TraditionalForm\`u\)]],
  ". The differences in the four solutions are the signs in front of the \
first and second terms. Inserting, for example, the second solution into the \
second first integral, we get the final solution in an implicit \
representation:"
}], "Text",
  CellTags->"first integral"],

Cell[CellGroupData[{

Cell[BoxData[
    \(int21\  = \ 
      integrals\[LeftDoubleBracket]2\[RightDoubleBracket]\  /. 
        sol1\[LeftDoubleBracket]2, 1\[RightDoubleBracket]\)], "Input"],

Cell[BoxData[
    \(x - 
        \(3\ ArcTan[
              \@\(\(2\ c1 + \@\(c1 - u[x]\)\/\@\[Alpha] - 
                      2\ u[x]\)\/\(\(-2\)\ c1 + 2\ u[x]\)\)]\)\/\(8\ 
            \[Alpha]\) - 
        \@\(\(2\ c1 + \@\(c1 - u[x]\)\/\@\[Alpha] - 2\ u[x]\)\/\(\(-2\)\ c1 + 
                  2\ u[x]\)\)\/\(4\ \[Alpha]\ 
            \((1 + \(2\ c1 + \@\(c1 - u[x]\)\/\@\[Alpha] - 
                      2\ u[x]\)\/\(\(-2\)\ c1 + 2\ u[x]\))\)\^2\) - 
        \(3\ \@\(\(2\ c1 + \@\(c1 - u[x]\)\/\@\[Alpha] - 
                    2\ u[x]\)\/\(\(-2\)\ c1 + 2\ u[x]\)\)\)\/\(8\ \[Alpha]\ 
            \((1 + \(2\ c1 + \@\(c1 - u[x]\)\/\@\[Alpha] - 
                    2\ u[x]\)\/\(\(-2\)\ c1 + 2\ u[x]\))\)\) == c2\)], 
  "Output"]
}, Open  ]],

Cell["\<\
An explicit solution of this expression is impossible since it \
contains transcendental functions:\
\>", "Text",
  CellTags->"transcendental function"],

Cell[CellGroupData[{

Cell[BoxData[
    \(solution\  = \ Solve[int21, u[x]]\)], "Input"],

Cell[BoxData[
    \(Solve::"tdep" \( : \ \) 
      "The equations appear to involve transcendental functions of the \
variables in an essentially non-algebraic way."\)], "Message"],

Cell[BoxData[
    \(Solve[
      x - \(3\ ArcTan[
                \@\(\(2\ c1 + \@\(c1 - u[x]\)\/\@\[Alpha] - 
                        2\ u[x]\)\/\(\(-2\)\ c1 + 2\ u[x]\)\)]\)\/\(8\ 
              \[Alpha]\) - 
          \@\(\(2\ c1 + \@\(c1 - u[x]\)\/\@\[Alpha] - 
                    2\ u[x]\)\/\(\(-2\)\ c1 + 2\ u[x]\)\)\/\(4\ \[Alpha]\ 
              \((1 + \(2\ c1 + \@\(c1 - u[x]\)\/\@\[Alpha] - 
                        2\ u[x]\)\/\(\(-2\)\ c1 + 2\ u[x]\))\)\^2\) - 
          \(3\ \@\(\(2\ c1 + \@\(c1 - u[x]\)\/\@\[Alpha] - 
                      2\ u[x]\)\/\(\(-2\)\ c1 + 2\ u[x]\)\)\)\/\(8\ \[Alpha]\ 
              \((1 + \(2\ c1 + \@\(c1 - u[x]\)\/\@\[Alpha] - 
                      2\ u[x]\)\/\(\(-2\)\ c1 + 2\ u[x]\))\)\) == c2, u[x]]
      \)], "Output"]
}, Open  ]],

Cell["\<\
At this point, we have to accept that the solution can only be \
represented in an implicit form. The solution of the original equation \
follows in one shot by\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(sol\  = \ 
      SecondOrderIntegrate[secondExample\  /. \[Nu] \[Rule] 3, u, \ 
        x, {\[Alpha]}]\ \)\)], "Input",
  CellTags->"SecondOrderIntegrate[]"],

Cell[BoxData[
    \(Solve::"tdep" \( : \ \) 
      "The equations appear to involve transcendental functions of the  \
variables in an essentially non-algebraic way."\)], "Message"],

Cell[BoxData[
    \(\(1\/\(8\ \[Alpha]\)\) 
        \((8\ x\ \[Alpha] + 
            3\ ArcTan[
                \@\(\(2\ CI[1] + \@\(CI[1] - u[x]\)\/\@\[Alpha] - 
                        2\ u[x]\)\/\(\(-2\)\ CI[1] + 2\ u[x]\)\)] + 
            4\ \[Alpha]\ CI[1]\ 
              \@\(\(4\ CI[1] + \(2\ \@\(CI[1] - u[x]\)\)\/\@\[Alpha] - 
                      4\ u[x]\)\/\(\(-CI[1]\) + u[x]\)\) - 
            4\ \[Alpha]\ u[x]\ 
              \@\(\(4\ CI[1] + \(2\ \@\(CI[1] - u[x]\)\)\/\@\[Alpha] - 
                      4\ u[x]\)\/\(\(-CI[1]\) + u[x]\)\) - 
            3\ \@2\ \@\[Alpha]\ \@\(CI[1] - u[x]\)\ 
              \@\(\(2\ CI[1] + \@\(CI[1] - u[x]\)\/\@\[Alpha] - 
                      2\ u[x]\)\/\(\(-CI[1]\) + u[x]\)\))\) == CI[2]\)], 
  "Output"]
}, Open  ]],

Cell[TextData[{
  "The result is an implicit representation of the solution. ",
  StyleBox["CI\[ThinSpace]",
    FontSlant->"Italic"],
  "[",
  StyleBox["1",
    FontSlant->"Italic"],
  "] and ",
  StyleBox["CI\[ThinSpace]",
    FontSlant->"Italic"],
  "[",
  StyleBox["2",
    FontSlant->"Italic"],
  "] are the constants of integration. Trying to solve the original equation \
by ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", we learn that ",
  StyleBox["DSolve[]", "InlineFormula"],
  " is not capable of resolving the relation for the first integral. A glance \
at the result of ",
  StyleBox["DSolve[]", "MmaText"],
  " explains the reason:"
}], "Text",
  CellTags->"DSolve[]"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DSolve[secondExample\  /. \ \[Nu] \[Rule] 3, u, x]\)], "Input"],

Cell[BoxData[
    \(Solve::"dinv" \( : \ \) 
      "The expression \!\(\((1 - \(I\\ \(\(\\[LeftSkeleton] 30 \
\\[RightSkeleton]\)[x]\)\))\)\^\(\(\(\\[LeftSkeleton] 30 \
\\[RightSkeleton]\)[x]\)\^2\\ \((2 + \(\\[LeftSkeleton] 1 \\[RightSkeleton]\)\
\^2)\)\)\) involves unknowns in more than one argument, so inverse functions \
cannot be used."\)], "Message"],

Cell[BoxData[
    \(Solve::"dinv" \( : \ \) 
      "The expression \!\(\((1 - \(I\\ \(\(\\[LeftSkeleton] 30 \
\\[RightSkeleton]\)[x]\)\))\)\^\(\(\(\\[LeftSkeleton] 30 \
\\[RightSkeleton]\)[x]\)\^2\\ \((2 + \(\\[LeftSkeleton] 1 \\[RightSkeleton]\)\
\^2)\)\)\) involves unknowns in more than one argument, so inverse functions \
cannot be used."\)], "Message"],

Cell[BoxData[
    RowBox[{
    \(Solve::"dinv"\), \( : \ \), 
      "\<\"The expression \\!\\(\\((1 - \\(I\\\\ \
\\(\\(\\*SuperscriptBox[\\\"u\\\", \\\"\\\\[Prime]\\\", \
Rule[MultilineFunction, \
None]]\\)[x]\\)\\))\\)\\^\\(\\(\\(\\*SuperscriptBox[\\\"u\\\", \
\\\"\\\\[Prime]\\\", Rule[MultilineFunction, None]]\\)[x]\\)\\^2\\\\ \\((2 + \
\\(\\\\[LeftSkeleton] 1 \\\\[RightSkeleton]\\)\\^2)\\)\\)\\) involves \
unknowns in more than one argument, so inverse functions cannot be \
used.\"\>"}]], "Message"],

Cell[BoxData[
    \(General::"stop" \( : \ \) 
      "Further output of \!\(Solve :: \"dinv\"\) will be suppressed during \
this calculation."\)], "Message"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"Solve", "[", 
        RowBox[{
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"3", " ", 
                    RowBox[{"ArcTan", "[", 
                      RowBox[{
                        SuperscriptBox["u", "\[Prime]",
                          MultilineFunction->None], "[", "#1", "]"}], 
                      "]"}]}], "-", \(8\ \[Alpha]\ #1\), "+", 
                  RowBox[{"5", " ", 
                    RowBox[{
                      SuperscriptBox["u", "\[Prime]",
                        MultilineFunction->None], "[", "#1", "]"}]}], "+", 
                  RowBox[{"6", " ", 
                    RowBox[{"ArcTan", "[", 
                      RowBox[{
                        SuperscriptBox["u", "\[Prime]",
                          MultilineFunction->None], "[", "#1", "]"}], "]"}], 
                    " ", 
                    SuperscriptBox[
                      RowBox[{
                        SuperscriptBox["u", "\[Prime]",
                          MultilineFunction->None], "[", "#1", "]"}], "2"]}], 
                  "-", 
                  RowBox[{"16", " ", "\[Alpha]", " ", "#1", " ", 
                    SuperscriptBox[
                      RowBox[{
                        SuperscriptBox["u", "\[Prime]",
                          MultilineFunction->None], "[", "#1", "]"}], "2"]}], 
                  "+", 
                  RowBox[{"3", " ", 
                    SuperscriptBox[
                      RowBox[{
                        SuperscriptBox["u", "\[Prime]",
                          MultilineFunction->None], "[", "#1", "]"}], "3"]}], 
                  "+", 
                  RowBox[{"3", " ", 
                    RowBox[{"ArcTan", "[", 
                      RowBox[{
                        SuperscriptBox["u", "\[Prime]",
                          MultilineFunction->None], "[", "#1", "]"}], "]"}], 
                    " ", 
                    SuperscriptBox[
                      RowBox[{
                        SuperscriptBox["u", "\[Prime]",
                          MultilineFunction->None], "[", "#1", "]"}], "4"]}], 
                  "-", 
                  RowBox[{"8", " ", "\[Alpha]", " ", "#1", " ", 
                    SuperscriptBox[
                      RowBox[{
                        SuperscriptBox["u", "\[Prime]",
                          MultilineFunction->None], "[", "#1", "]"}], 
                      "4"]}]}], ")"}], "/", 
              RowBox[{"(", 
                RowBox[{"8", " ", 
                  SuperscriptBox[
                    RowBox[{"(", 
                      RowBox[{"1", "+", 
                        SuperscriptBox[
                          RowBox[{
                            SuperscriptBox["u", "\[Prime]",
                              MultilineFunction->None], "[", "#1", "]"}], 
                          "2"]}], ")"}], "2"]}], ")"}]}], "==", \(C[1]\)}], 
          ",", 
          RowBox[{"{", 
            RowBox[{
              SuperscriptBox["u", "\[Prime]",
                MultilineFunction->None], "[", "#1", "]"}], "}"}]}], "]"}], 
      "}"}]], "Output"]
}, Open  ]],

Cell[TextData[
"The above result shows that a transcendental function is given in an \
essential non-algebraic way. The steps presented above demonstrate that the \
solution of the generalized cable equation is solvable in an implicit form.\
\[ThickSpace]\[EmptySquare]"], "Text",
  CellTags->{"transcendental function", "generalized cable equation"}],

Cell[TextData[{
  "The two examples demonstrate that the technique of an integrating factor \
can be generalized to second-order equations. We also realize that the \
presented procedure is capable of deriving solutions for cases in which ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " fails. In S",
  ButtonBox["ection 4.4.3.1, ",
    ButtonData:>{"symmet4.nb", "Integrating factor method"},
    ButtonStyle->"Hyperlink"],
  "we will discuss the extension of the integrating factor technique to a \
general ",
  StyleBox["n",
    FontSlant->"Italic"],
  "th-order ODE. Lie called this procedure the ",
  StyleBox["method of generalized multipliers. ",
    FontSlant->"Italic"],
  "In the following section, we discuss another solution procedure helpful in \
solving second-order ODEs. This method is related to canonical variables and \
the skeleton introduced in Sections ",
  ButtonBox["4.3.4",
    ButtonData:>{"symmet11.nb", "Canonical variables"},
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["4.4.1.1",
    ButtonData:>{"symmet2.nb", 
      "The skeleton of an ordinary differential equation"},
    ButtonStyle->"Hyperlink"],
  " for first-order ODEs. The following method uses the canonical variables \
to integrate the equation."
}], "Text",
  CellTags->{
  "method of generalized multipliers", "technique of integrating factor", 
    "canonical variables", "skeleton"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["4.4.2.2 Method of Canonical Variables", "Subsection",
  CellTags->"Method of canonical variables"],

Cell[TextData[{
  "Here, we demonstrate by a single example that the term skeleton is also \
useful for the case of second-order equations. The combination of canonical \
variables and the method of first integrals serves to derive an explicit \
solution for an ODE for which only an implicit representation of the solution \
is known (cf. ",
  ButtonBox["Ibragimov [1994]",
    ButtonData:>{"Literat.nb", "Ibragimov-1994"},
    ButtonStyle->"Hyperlink"],
  "). The considerations serve to demonstrate that a proper combination of \
different methods will lead to a solution of the ODE."
}], "Text",
  CellTags->{
  "skeleton", "second-order equation", "canonical variables", 
    "method of first integrals"}],

Cell["Example 1", "Example"],

Cell[TextData[{
  "Again, we use the equation from ",
  ButtonBox["Example 1",
    ButtonData:>"Example 1",
    ButtonStyle->"Hyperlink"],
  " of Section 4.4.2.1. This second-order ODE serves to show how canonical \
variables simplify the skeleton and the solution steps. The specific example \
we discuss is given by the equation"
}], "Text",
  CellTags->"canonical variables"],

Cell[CellGroupData[{

Cell[BoxData[
    \(firstExample\  = \ 
      \[PartialD]\_\(x, x\)u[x]\  - \((\[PartialD]\_x u[x])\)\/u[x]\^2\  + \ 
        1\/\(x\ u[x]\)\ ; firstExample // LTF\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {
            RowBox[{
              RowBox[{
                StyleBox[\(1\/\(u\ x\)\),
                  ScriptLevel->0], "-", 
                StyleBox[\(u\_x\/u\^2\),
                  ScriptLevel->0], "+", \(u\_\(x, x\)\)}], "==", "0"}]}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output"]
}, Open  ]],

Cell["This second-order equation admits the symmetries", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(infinites\  = 
      Infinitesimals[firstExample, u, x, 
        SubstitutionRules \[Rule] {\[PartialD]\_\(x, x\)u[x]}]; 
    infinites // LTF\)], "Input"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {
            RowBox[{\(\[Phi]\_1\), "==", 
              RowBox[{
                StyleBox[\(1\/2\),
                  ScriptLevel->0], " ", "u", " ", \((k1 + 2\ k2\ x)\)}]}]},
          {\(\[Xi]\_1 == x\ \((k1 + k2\ x)\)\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {
        Equal[ 
          Subscript[ \[Phi], 1], 
          Times[ 
            Rational[ 1, 2], u, 
            Plus[ k1, 
              Times[ 2, k2, x]]]], 
        Equal[ 
          Subscript[ \[Xi], 1], 
          Times[ x, 
            Plus[ k1, 
              Times[ k2, x]]]]}]]], "Output"]
}, Open  ]],

Cell[TextData[{
  "representing a two-dimensional group of scaling and projections. The \
skeleton of this equation exists in a four-dimensional manifold ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalM] = {x, u, u' = p, \(u'\)' = q}\)]],
  ". Since the dimension of the manifold \[GothicCapitalM] is larger than \
three, we cannot directly represent the skeleton as a surface. However, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " with its animation capabilities offers the opportunity to represent the \
fourth dimension in a sequence of figures. The combination of these figures  \
in an animation allows us to represent the manifold \[GothicCapitalM] in a \
special way if one of the coordinates of \[GothicCapitalM] is smoothly \
changed. The resulting sequence creates the impression of an evolution of the \
manifold if one moves along the distinguished coordinate. For the above \
equation, we define the skeleton in the form"
}], "Text",
  CellTags->{
  "group of scaling", "group of projection", "skeleton", "manifold"}],

Cell[BoxData[
    \(skeleton[u_, x_, p_] := p\/u\^2\  - \ 1\/\(x\ u\)\)], "Input"],

Cell[TextData[{
  "representing the surface for ",
  Cell[BoxData[
      \(TraditionalForm\`\(u'\)' = q\)]],
  " in an explicit form. For our animation, we select the ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  "-axis as the distinguished coordinate. The three-dimensional surface \
represents the submanifold ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalM]\_s = {u, u' = p, \(u'\)' = q}\)]],
  " for certain values of ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ". The different pictures are created by"
}], "Text",
  CellTags->{"animation", "submanifold"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(Map[
      Plot3D[skeleton[u, #, p], {u, 0.1, 1}, {p, \(-3\), 3}, 
          PlotRange \[Rule] {\(-200\), 200}, \n\t\tTicks \[Rule] False, 
          PlotPoints \[Rule] 35, Mesh \[Rule] False, 
          AxesLabel \[Rule] {"\<u\>", "\<p\>", "\<q\>"}, 
          ViewPoint -> {0.717, \ \(-2.988\), \ 1.417}, 
          PlotLabel \[Rule] StringJoin["\<x=\>", ToString[#]]]&, 
      Table[i, {i,  .01,  .1,  .01}]]\)], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .70824 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1.10169 -0.148196 1.10169 [
[.5 .72074 -20 0 ]
[.5 .72074 20 15 ]
[.44797 -0.02478 -4.90556 -15 ]
[.44797 -0.02478 5.09444 0 ]
[.15892 .66839 -5.31917 0 ]
[.15892 .66839 4.68083 15 ]
[-0.06694 .27471 -10 -6.62571 ]
[-0.06694 .27471 0 8.37429 ]
[ 0 0 0 0 ]
[ 1 .70824 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .72074 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.437500 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(=) show
75.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
99.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math1Mono
%%DocumentNeededResources: + font Courier
%%DocumentNeededFonts: Math1Mono
%%DocumentNeededFont: + Courier
%%DocumentFonts: font Math1Mono
%%DocumentFonts: + font Courier
grestore
.25 Mabswid
.02946 .11175 m
.89362 0 L
s
gsave
.44797 -0.02478 -65.9056 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(u) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
0 .4272 m
.29069 .70824 L
s
gsave
.15892 .66839 -66.3192 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(p) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.02946 .11175 m
0 .4272 L
s
gsave
-0.06694 .27471 -71 -10.6257 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(q) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.02946 .11175 m
0 .4272 L
s
0 .4272 m
.29069 .70824 L
s
.29069 .70824 m
.30155 .45044 L
s
.30155 .45044 m
.02946 .11175 L
s
.89362 0 m
.98022 .38351 L
s
.98022 .38351 m
1 .65325 L
s
1 .65325 m
.91448 .33294 L
s
.91448 .33294 m
.89362 0 L
s
.02946 .11175 m
0 .4272 L
s
0 .4272 m
.91448 .33294 L
s
.91448 .33294 m
.89362 0 L
s
.89362 0 m
.02946 .11175 L
s
.30155 .45044 m
.98022 .38351 L
s
.98022 .38351 m
1 .65325 L
s
1 .65325 m
.29069 .70824 L
s
.29069 .70824 m
.30155 .45044 L
s
0 0 m
1 0 L
1 .70824 L
0 .70824 L
closepath
clip
newpath
.617 .786 .963 r
.29526 .44261 .30155 .45044 .32048 .44857 .31431 .44072 Mtetra
.31431 .44072 .32048 .44857 .33948 .44669 .33342 .43882 Mtetra
.33342 .43882 .33948 .44669 .35853 .44482 .35259 .43692 Mtetra
.35259 .43692 .35853 .44482 .37765 .44293 .37182 .43501 Mtetra
.37182 .43501 .37765 .44293 .39682 .44104 .39111 .43309 Mtetra
.39111 .43309 .39682 .44104 .41606 .43914 .41047 .43117 Mtetra
.41047 .43117 .41606 .43914 .43535 .43724 .42988 .42925 Mtetra
.42988 .42925 .43535 .43724 .45471 .43533 .44935 .42731 Mtetra
.44935 .42731 .45471 .43533 .47412 .43342 .46889 .42537 Mtetra
.46889 .42537 .47412 .43342 .4936 .4315 .48849 .42342 Mtetra
.48849 .42342 .4936 .4315 .51314 .42957 .50815 .42147 Mtetra
.50815 .42147 .51314 .42957 .53274 .42764 .52787 .41951 Mtetra
.52787 .41951 .53274 .42764 .5524 .4257 .54766 .41755 Mtetra
.613 .784 .963 r
.54766 .41755 .5524 .4257 .57213 .42441 .56751 .41573 Mtetra
.446 .672 .959 r
.56751 .41573 .57213 .42441 .59197 .4287 .58746 .42009 Mtetra
.464 .685 .962 r
.58746 .42009 .59197 .4287 .6119 .43243 .60751 .42386 Mtetra
.478 .695 .963 r
.60751 .42386 .6119 .43243 .63193 .43566 .62767 .42713 Mtetra
.491 .705 .965 r
.62767 .42713 .63193 .43566 .65205 .43845 .64791 .42996 Mtetra
.502 .712 .966 r
.64791 .42996 .65205 .43845 .67226 .44087 .66825 .4324 Mtetra
.511 .719 .966 r
.66825 .4324 .67226 .44087 .69255 .44295 .68867 .43449 Mtetra
.52 .725 .967 r
.68867 .43449 .69255 .44295 .71293 .44472 .70918 .43629 Mtetra
.527 .73 .967 r
.70918 .43629 .71293 .44472 .7334 .44623 .72977 .43781 Mtetra
.533 .735 .968 r
.72977 .43781 .7334 .44623 .75394 .4475 .75045 .43908 Mtetra
.539 .739 .968 r
.75045 .43908 .75394 .4475 .77457 .44856 .77121 .44014 Mtetra
.544 .743 .968 r
.77121 .44014 .77457 .44856 .79528 .44941 .79205 .441 Mtetra
.548 .746 .968 r
.79205 .441 .79528 .44941 .81606 .45009 .81297 .44168 Mtetra
.552 .749 .969 r
.81297 .44168 .81606 .45009 .83693 .45061 .83397 .44219 Mtetra
.555 .752 .969 r
.83397 .44219 .83693 .45061 .85787 .45097 .85505 .44256 Mtetra
.559 .754 .969 r
.85505 .44256 .85787 .45097 .87889 .4512 .87621 .44278 Mtetra
.561 .756 .969 r
.87621 .44278 .87889 .4512 .89998 .45131 .89745 .44288 Mtetra
.564 .758 .969 r
.89745 .44288 .89998 .45131 .92116 .4513 .91876 .44286 Mtetra
.566 .76 .969 r
.91876 .44286 .92116 .4513 .94241 .45119 .94016 .44274 Mtetra
.569 .762 .969 r
.94016 .44274 .94241 .45119 .96374 .45097 .96163 .44251 Mtetra
.571 .763 .969 r
.96163 .44251 .96374 .45097 .98514 .45067 .98318 .4422 Mtetra
.617 .786 .963 r
.2889 .43469 .29526 .44261 .31431 .44072 .30806 .43277 Mtetra
.30806 .43277 .31431 .44072 .33342 .43882 .32729 .43085 Mtetra
.32729 .43085 .33342 .43882 .35259 .43692 .34658 .42892 Mtetra
.34658 .42892 .35259 .43692 .37182 .43501 .36592 .42699 Mtetra
.36592 .42699 .37182 .43501 .39111 .43309 .38533 .42505 Mtetra
.38533 .42505 .39111 .43309 .41047 .43117 .4048 .4231 Mtetra
.4048 .4231 .41047 .43117 .42988 .42925 .42434 .42114 Mtetra
.42434 .42114 .42988 .42925 .44935 .42731 .44393 .41918 Mtetra
.44393 .41918 .44935 .42731 .46889 .42537 .46359 .41722 Mtetra
.46359 .41722 .46889 .42537 .48849 .42342 .48331 .41525 Mtetra
.48331 .41525 .48849 .42342 .50815 .42147 .50309 .41327 Mtetra
.50309 .41327 .50815 .42147 .52787 .41951 .52294 .41128 Mtetra
.52294 .41128 .52787 .41951 .54766 .41755 .54285 .40929 Mtetra
.54285 .40929 .54766 .41755 .56751 .41573 .56282 .40729 Mtetra
.444 .68 .965 r
.56282 .40729 .56751 .41573 .58746 .42009 .5829 .41136 Mtetra
.462 .684 .962 r
.5829 .41136 .58746 .42009 .60751 .42386 .60307 .41518 Mtetra
.477 .695 .963 r
.60307 .41518 .60751 .42386 .62767 .42713 .62335 .41848 Mtetra
.49 .704 .965 r
.62335 .41848 .62767 .42713 .64791 .42996 .64372 .42134 Mtetra
.501 .712 .966 r
.64372 .42134 .64791 .42996 .66825 .4324 .66418 .42381 Mtetra
.511 .719 .966 r
.66418 .42381 .66825 .4324 .68867 .43449 .68473 .42593 Mtetra
.519 .725 .967 r
.68473 .42593 .68867 .43449 .70918 .43629 .70537 .42773 Mtetra
.526 .73 .967 r
.70537 .42773 .70918 .43629 .72977 .43781 .7261 .42927 Mtetra
.533 .735 .968 r
.7261 .42927 .72977 .43781 .75045 .43908 .74691 .43055 Mtetra
.538 .739 .968 r
.74691 .43055 .75045 .43908 .77121 .44014 .7678 .43161 Mtetra
.543 .742 .968 r
.7678 .43161 .77121 .44014 .79205 .441 .78878 .43248 Mtetra
.548 .746 .968 r
.78878 .43248 .79205 .441 .81297 .44168 .80984 .43315 Mtetra
.552 .749 .969 r
.80984 .43315 .81297 .44168 .83397 .44219 .83097 .43367 Mtetra
.555 .751 .969 r
.83097 .43367 .83397 .44219 .85505 .44256 .85219 .43402 Mtetra
.558 .754 .969 r
.85219 .43402 .85505 .44256 .87621 .44278 .87349 .43424 Mtetra
.561 .756 .969 r
.87349 .43424 .87621 .44278 .89745 .44288 .89487 .43434 Mtetra
.564 .758 .969 r
.89487 .43434 .89745 .44288 .91876 .44286 .91633 .43431 Mtetra
.566 .76 .969 r
.91633 .43431 .91876 .44286 .94016 .44274 .93787 .43417 Mtetra
.568 .762 .969 r
.93787 .43417 .94016 .44274 .96163 .44251 .95949 .43394 Mtetra
.57 .763 .969 r
.95949 .43394 .96163 .44251 .98318 .4422 .98118 .43361 Mtetra
.617 .786 .963 r
.28245 .42666 .2889 .43469 .30806 .43277 .30173 .42472 Mtetra
.30173 .42472 .30806 .43277 .32729 .43085 .32107 .42277 Mtetra
.32107 .42277 .32729 .43085 .34658 .42892 .34048 .42082 Mtetra
.34048 .42082 .34658 .42892 .36592 .42699 .35994 .41886 Mtetra
.35994 .41886 .36592 .42699 .38533 .42505 .37947 .41689 Mtetra
.37947 .41689 .38533 .42505 .4048 .4231 .39906 .41492 Mtetra
.39906 .41492 .4048 .4231 .42434 .42114 .41872 .41294 Mtetra
.41872 .41294 .42434 .42114 .44393 .41918 .43843 .41095 Mtetra
.43843 .41095 .44393 .41918 .46359 .41722 .45821 .40896 Mtetra
.45821 .40896 .46359 .41722 .48331 .41525 .47806 .40696 Mtetra
.47806 .40696 .48331 .41525 .50309 .41327 .49797 .40495 Mtetra
.49797 .40495 .50309 .41327 .52294 .41128 .51794 .40294 Mtetra
.51794 .40294 .52294 .41128 .54285 .40929 .53797 .40092 Mtetra
.53797 .40092 .54285 .40929 .56282 .40729 .55808 .3989 Mtetra
.454 .691 .968 r
.55808 .3989 .56282 .40729 .5829 .41136 .57827 .40251 Mtetra
.461 .683 .962 r
.57827 .40251 .5829 .41136 .60307 .41518 .59857 .40638 Mtetra
.476 .694 .963 r
.59857 .40638 .60307 .41518 .62335 .41848 .61897 .40972 Mtetra
.489 .703 .965 r
.61897 .40972 .62335 .41848 .64372 .42134 .63947 .41261 Mtetra
.5 .711 .965 r
.63947 .41261 .64372 .42134 .66418 .42381 .66006 .4151 Mtetra
.51 .718 .966 r
.66006 .4151 .66418 .42381 .68473 .42593 .68074 .41724 Mtetra
.518 .724 .967 r
.68074 .41724 .68473 .42593 .70537 .42773 .70151 .41907 Mtetra
.526 .73 .967 r
.70151 .41907 .70537 .42773 .7261 .42927 .72237 .42061 Mtetra
.532 .734 .968 r
.72237 .42061 .7261 .42927 .74691 .43055 .74332 .4219 Mtetra
.538 .738 .968 r
.74332 .4219 .74691 .43055 .7678 .43161 .76435 .42297 Mtetra
.543 .742 .968 r
.76435 .42297 .7678 .43161 .78878 .43248 .78546 .42383 Mtetra
.547 .745 .968 r
.78546 .42383 .78878 .43248 .80984 .43315 .80666 .42451 Mtetra
.551 .748 .969 r
.80666 .42451 .80984 .43315 .83097 .43367 .82794 .42502 Mtetra
.555 .751 .969 r
.82794 .42502 .83097 .43367 .85219 .43402 .8493 .42537 Mtetra
.558 .754 .969 r
.8493 .42537 .85219 .43402 .87349 .43424 .87074 .42559 Mtetra
.561 .756 .969 r
.87074 .42559 .87349 .43424 .89487 .43434 .89226 .42567 Mtetra
.564 .758 .969 r
.89226 .42567 .89487 .43434 .91633 .43431 .91387 .42564 Mtetra
.566 .76 .969 r
.91387 .42564 .91633 .43431 .93787 .43417 .93555 .42549 Mtetra
.568 .762 .969 r
.93555 .42549 .93787 .43417 .95949 .43394 .95732 .42524 Mtetra
.57 .763 .969 r
.95732 .42524 .95949 .43394 .98118 .43361 .97916 .4249 Mtetra
.617 .786 .963 r
.27591 .41853 .28245 .42666 .30173 .42472 .29531 .41656 Mtetra
.29531 .41656 .30173 .42472 .32107 .42277 .31477 .41458 Mtetra
.31477 .41458 .32107 .42277 .34048 .42082 .3343 .4126 Mtetra
.3343 .4126 .34048 .42082 .35994 .41886 .35388 .41062 Mtetra
.35388 .41062 .35994 .41886 .37947 .41689 .37353 .40862 Mtetra
.37353 .40862 .37947 .41689 .39906 .41492 .39325 .40662 Mtetra
.39325 .40662 .39906 .41492 .41872 .41294 .41302 .40462 Mtetra
.41302 .40462 .41872 .41294 .43843 .41095 .43286 .4026 Mtetra
.43286 .4026 .43843 .41095 .45821 .40896 .45277 .40059 Mtetra
.45277 .40059 .45821 .40896 .47806 .40696 .47274 .39856 Mtetra
.47274 .39856 .47806 .40696 .49797 .40495 .49277 .39653 Mtetra
.49277 .39653 .49797 .40495 .51794 .40294 .51287 .39449 Mtetra
.51287 .39449 .51794 .40294 .53797 .40092 .53303 .39244 Mtetra
.53303 .39244 .53797 .40092 .55808 .3989 .55326 .39039 Mtetra
.469 .7 .969 r
.55326 .39039 .55808 .3989 .57827 .40251 .57358 .39354 Mtetra
.459 .682 .961 r
.57358 .39354 .57827 .40251 .59857 .40638 .594 .39746 Mtetra
.475 .693 .963 r
.594 .39746 .59857 .40638 .61897 .40972 .61453 .40084 Mtetra
.488 .703 .964 r
.61453 .40084 .61897 .40972 .63947 .41261 .63516 .40376 Mtetra
.499 .711 .965 r
.63516 .40376 .63947 .41261 .66006 .4151 .65588 .40628 Mtetra
.509 .718 .966 r
.65588 .40628 .66006 .4151 .68074 .41724 .67669 .40844 Mtetra
.518 .724 .967 r
.67669 .40844 .68074 .41724 .70151 .41907 .6976 .41028 Mtetra
.525 .729 .967 r
.6976 .41028 .70151 .41907 .72237 .42061 .71859 .41183 Mtetra
.532 .734 .968 r
.71859 .41183 .72237 .42061 .74332 .4219 .73968 .41313 Mtetra
.537 .738 .968 r
.73968 .41313 .74332 .4219 .76435 .42297 .76084 .4142 Mtetra
.542 .742 .968 r
.76084 .4142 .76435 .42297 .78546 .42383 .7821 .41507 Mtetra
.547 .745 .968 r
.7821 .41507 .78546 .42383 .80666 .42451 .80344 .41575 Mtetra
.551 .748 .969 r
.80344 .41575 .80666 .42451 .82794 .42502 .82486 .41625 Mtetra
.555 .751 .969 r
.82486 .41625 .82794 .42502 .8493 .42537 .84636 .4166 Mtetra
.558 .754 .969 r
.84636 .4166 .8493 .42537 .87074 .42559 .86795 .41681 Mtetra
.561 .756 .969 r
.86795 .41681 .87074 .42559 .89226 .42567 .88962 .41689 Mtetra
.563 .758 .969 r
.88962 .41689 .89226 .42567 .91387 .42564 .91137 .41684 Mtetra
.566 .76 .969 r
.91137 .41684 .91387 .42564 .93555 .42549 .9332 .41668 Mtetra
.568 .762 .969 r
.9332 .41668 .93555 .42549 .95732 .42524 .95512 .41642 Mtetra
.57 .763 .969 r
.95512 .41642 .95732 .42524 .97916 .4249 .97711 .41606 Mtetra
.617 .786 .963 r
.26929 .41028 .27591 .41853 .29531 .41656 .28881 .40829 Mtetra
.28881 .40829 .29531 .41656 .31477 .41458 .30839 .40629 Mtetra
.30839 .40629 .31477 .41458 .3343 .4126 .32804 .40428 Mtetra
.32804 .40428 .3343 .4126 .35388 .41062 .34774 .40227 Mtetra
.34774 .40227 .35388 .41062 .37353 .40862 .36752 .40025 Mtetra
.36752 .40025 .37353 .40862 .39325 .40662 .38735 .39822 Mtetra
.38735 .39822 .39325 .40662 .41302 .40462 .40725 .39619 Mtetra
.40725 .39619 .41302 .40462 .43286 .4026 .42722 .39415 Mtetra
.42722 .39415 .43286 .4026 .45277 .40059 .44725 .3921 Mtetra
.44725 .3921 .45277 .40059 .47274 .39856 .46734 .39005 Mtetra
.46734 .39005 .47274 .39856 .49277 .39653 .48751 .38799 Mtetra
.48751 .38799 .49277 .39653 .51287 .39449 .50773 .38592 Mtetra
.50773 .38592 .51287 .39449 .53303 .39244 .52803 .38384 Mtetra
.52803 .38384 .53303 .39244 .55326 .39039 .54839 .38176 Mtetra
.483 .709 .97 r
.54839 .38176 .55326 .39039 .57358 .39354 .56883 .38445 Mtetra
.458 .681 .961 r
.56883 .38445 .57358 .39354 .594 .39746 .58938 .38842 Mtetra
.474 .692 .963 r
.58938 .38842 .594 .39746 .61453 .40084 .61003 .39184 Mtetra
.487 .702 .964 r
.61003 .39184 .61453 .40084 .63516 .40376 .63079 .3948 Mtetra
.499 .71 .965 r
.63079 .3948 .63516 .40376 .65588 .40628 .65164 .39734 Mtetra
.508 .717 .966 r
.65164 .39734 .65588 .40628 .67669 .40844 .67259 .39951 Mtetra
.517 .723 .967 r
.67259 .39951 .67669 .40844 .6976 .41028 .69363 .40137 Mtetra
.525 .729 .967 r
.69363 .40137 .6976 .41028 .71859 .41183 .71477 .40293 Mtetra
.531 .734 .968 r
.71477 .40293 .71859 .41183 .73968 .41313 .73599 .40424 Mtetra
.537 .738 .968 r
.73599 .40424 .73968 .41313 .76084 .4142 .75729 .40532 Mtetra
.542 .742 .968 r
.75729 .40532 .76084 .4142 .7821 .41507 .77869 .40618 Mtetra
.547 .745 .968 r
.77869 .40618 .7821 .41507 .80344 .41575 .80017 .40686 Mtetra
.551 .748 .969 r
.80017 .40686 .80344 .41575 .82486 .41625 .82173 .40736 Mtetra
.554 .751 .969 r
.82173 .40736 .82486 .41625 .84636 .4166 .84338 .40771 Mtetra
.558 .753 .969 r
.84338 .40771 .84636 .4166 .86795 .41681 .86512 .40791 Mtetra
.561 .756 .969 r
.86512 .40791 .86795 .41681 .88962 .41689 .88693 .40797 Mtetra
.563 .758 .969 r
.88693 .40797 .88962 .41689 .91137 .41684 .90883 .40792 Mtetra
.566 .76 .969 r
.90883 .40792 .91137 .41684 .9332 .41668 .93082 .40775 Mtetra
.568 .761 .969 r
.93082 .40775 .9332 .41668 .95512 .41642 .95288 .40748 Mtetra
.57 .763 .969 r
.95288 .40748 .95512 .41642 .97711 .41606 .97503 .4071 Mtetra
.617 .786 .963 r
.26258 .40193 .26929 .41028 .28881 .40829 .28222 .39991 Mtetra
.28222 .39991 .28881 .40829 .30839 .40629 .30192 .39788 Mtetra
.30192 .39788 .30839 .40629 .32804 .40428 .32169 .39584 Mtetra
.32169 .39584 .32804 .40428 .34774 .40227 .34152 .3938 Mtetra
.34152 .3938 .34774 .40227 .36752 .40025 .36142 .39176 Mtetra
.36142 .39176 .36752 .40025 .38735 .39822 .38138 .3897 Mtetra
.38138 .3897 .38735 .39822 .40725 .39619 .4014 .38764 Mtetra
.4014 .38764 .40725 .39619 .42722 .39415 .4215 .38557 Mtetra
.4215 .38557 .42722 .39415 .44725 .3921 .44165 .3835 Mtetra
.44165 .3835 .44725 .3921 .46734 .39005 .46188 .38142 Mtetra
.46188 .38142 .46734 .39005 .48751 .38799 .48217 .37933 Mtetra
.48217 .37933 .48751 .38799 .50773 .38592 .50252 .37723 Mtetra
.50252 .37723 .50773 .38592 .52803 .38384 .52295 .37513 Mtetra
.52295 .37513 .52803 .38384 .54839 .38176 .54344 .37302 Mtetra
.498 .718 .97 r
.54344 .37302 .54839 .38176 .56883 .38445 .56401 .37524 Mtetra
.456 .68 .961 r
.56401 .37524 .56883 .38445 .58938 .38842 .58469 .37925 Mtetra
.472 .692 .963 r
.58469 .37925 .58938 .38842 .61003 .39184 .60547 .38272 Mtetra
.486 .701 .964 r
.60547 .38272 .61003 .39184 .63079 .3948 .62636 .3857 Mtetra
.498 .71 .965 r
.62636 .3857 .63079 .3948 .65164 .39734 .64735 .38827 Mtetra
.508 .717 .966 r
.64735 .38827 .65164 .39734 .67259 .39951 .66843 .39047 Mtetra
.516 .723 .967 r
.66843 .39047 .67259 .39951 .69363 .40137 .68961 .39233 Mtetra
.524 .729 .967 r
.68961 .39233 .69363 .40137 .71477 .40293 .71088 .39391 Mtetra
.531 .733 .968 r
.71088 .39391 .71477 .40293 .73599 .40424 .73224 .39523 Mtetra
.536 .738 .968 r
.73224 .39523 .73599 .40424 .75729 .40532 .75369 .39631 Mtetra
.542 .741 .968 r
.75369 .39631 .75729 .40532 .77869 .40618 .77523 .39717 Mtetra
.546 .745 .968 r
.77523 .39717 .77869 .40618 .80017 .40686 .79686 .39785 Mtetra
.55 .748 .969 r
.79686 .39785 .80017 .40686 .82173 .40736 .81857 .39835 Mtetra
.554 .751 .969 r
.81857 .39835 .82173 .40736 .84338 .40771 .84036 .39869 Mtetra
.557 .753 .969 r
.84036 .39869 .84338 .40771 .86512 .40791 .86225 .39888 Mtetra
.56 .756 .969 r
.86225 .39888 .86512 .40791 .88693 .40797 .88421 .39894 Mtetra
.563 .758 .969 r
.88421 .39894 .88693 .40797 .90883 .40792 .90626 .39887 Mtetra
.566 .76 .969 r
.90626 .39887 .90883 .40792 .93082 .40775 .9284 .39869 Mtetra
.568 .761 .969 r
.9284 .39869 .93082 .40775 .95288 .40748 .95062 .3984 Mtetra
.57 .763 .969 r
.95062 .3984 .95288 .40748 .97503 .4071 .97292 .39802 Mtetra
.617 .786 .963 r
.25578 .39346 .26258 .40193 .28222 .39991 .27554 .39141 Mtetra
.27554 .39141 .28222 .39991 .30192 .39788 .29536 .38936 Mtetra
.29536 .38936 .30192 .39788 .32169 .39584 .31525 .38729 Mtetra
.31525 .38729 .32169 .39584 .34152 .3938 .33521 .38522 Mtetra
.33521 .38522 .34152 .3938 .36142 .39176 .35523 .38315 Mtetra
.35523 .38315 .36142 .39176 .38138 .3897 .37532 .38107 Mtetra
.37532 .38107 .38138 .3897 .4014 .38764 .39547 .37898 Mtetra
.39547 .37898 .4014 .38764 .4215 .38557 .41569 .37688 Mtetra
.41569 .37688 .4215 .38557 .44165 .3835 .43598 .37478 Mtetra
.43598 .37478 .44165 .3835 .46188 .38142 .45633 .37267 Mtetra
.45633 .37267 .46188 .38142 .48217 .37933 .47676 .37055 Mtetra
.47676 .37055 .48217 .37933 .50252 .37723 .49724 .36842 Mtetra
.49724 .36842 .50252 .37723 .52295 .37513 .5178 .36629 Mtetra
.5178 .36629 .52295 .37513 .54344 .37302 .53843 .36415 Mtetra
.512 .727 .97 r
.53843 .36415 .54344 .37302 .56401 .37524 .55913 .3659 Mtetra
.455 .679 .961 r
.55913 .3659 .56401 .37524 .58469 .37925 .57993 .36996 Mtetra
.471 .691 .963 r
.57993 .36996 .58469 .37925 .60547 .38272 .60085 .37347 Mtetra
.485 .701 .964 r
.60085 .37347 .60547 .38272 .62636 .3857 .62187 .37648 Mtetra
.497 .709 .965 r
.62187 .37648 .62636 .3857 .64735 .38827 .643 .37907 Mtetra
.507 .716 .966 r
.643 .37907 .64735 .38827 .66843 .39047 .66422 .38129 Mtetra
.516 .723 .967 r
.66422 .38129 .66843 .39047 .68961 .39233 .68553 .38317 Mtetra
.523 .728 .967 r
.68553 .38317 .68961 .39233 .71088 .39391 .70695 .38476 Mtetra
.53 .733 .968 r
.70695 .38476 .71088 .39391 .73224 .39523 .72845 .38608 Mtetra
.536 .737 .968 r
.72845 .38608 .73224 .39523 .75369 .39631 .75004 .38717 Mtetra
.541 .741 .968 r
.75004 .38717 .75369 .39631 .77523 .39717 .77172 .38804 Mtetra
.546 .745 .968 r
.77172 .38804 .77523 .39717 .79686 .39785 .7935 .38871 Mtetra
.55 .748 .969 r
.7935 .38871 .79686 .39785 .81857 .39835 .81535 .3892 Mtetra
.554 .751 .969 r
.81535 .3892 .81857 .39835 .84036 .39869 .8373 .38954 Mtetra
.557 .753 .969 r
.8373 .38954 .84036 .39869 .86225 .39888 .85933 .38972 Mtetra
.56 .755 .969 r
.85933 .38972 .86225 .39888 .88421 .39894 .88145 .38977 Mtetra
.563 .757 .969 r
.88145 .38977 .88421 .39894 .90626 .39887 .90366 .38969 Mtetra
.565 .759 .969 r
.90366 .38969 .90626 .39887 .9284 .39869 .92595 .3895 Mtetra
.568 .761 .969 r
.92595 .3895 .9284 .39869 .95062 .3984 .94832 .3892 Mtetra
.57 .763 .969 r
.94832 .3892 .95062 .3984 .97292 .39802 .97078 .3888 Mtetra
.617 .786 .963 r
.24888 .38488 .25578 .39346 .27554 .39141 .26877 .3828 Mtetra
.26877 .3828 .27554 .39141 .29536 .38936 .28872 .38072 Mtetra
.28872 .38072 .29536 .38936 .31525 .38729 .30873 .37863 Mtetra
.30873 .37863 .31525 .38729 .33521 .38522 .32882 .37653 Mtetra
.32882 .37653 .33521 .38522 .35523 .38315 .34896 .37442 Mtetra
.34896 .37442 .35523 .38315 .37532 .38107 .36918 .37231 Mtetra
.36918 .37231 .37532 .38107 .39547 .37898 .38946 .37019 Mtetra
.38946 .37019 .39547 .37898 .41569 .37688 .40981 .36807 Mtetra
.40981 .36807 .41569 .37688 .43598 .37478 .43023 .36594 Mtetra
.43023 .36594 .43598 .37478 .45633 .37267 .45072 .3638 Mtetra
.45072 .3638 .45633 .37267 .47676 .37055 .47127 .36165 Mtetra
.47127 .36165 .47676 .37055 .49724 .36842 .49189 .35949 Mtetra
.49189 .35949 .49724 .36842 .5178 .36629 .51258 .35733 Mtetra
.51258 .35733 .5178 .36629 .53843 .36415 .53334 .35517 Mtetra
.526 .735 .97 r
.53334 .35517 .53843 .36415 .55913 .3659 .55417 .35644 Mtetra
.454 .678 .961 r
.55417 .35644 .55913 .3659 .57993 .36996 .57511 .36054 Mtetra
.47 .69 .963 r
.57511 .36054 .57993 .36996 .60085 .37347 .59616 .36409 Mtetra
.484 .7 .964 r
.59616 .36409 .60085 .37347 .62187 .37648 .61732 .36713 Mtetra
.496 .709 .965 r
.61732 .36713 .62187 .37648 .643 .37907 .63858 .36975 Mtetra
.506 .716 .966 r
.63858 .36975 .643 .37907 .66422 .38129 .65994 .37199 Mtetra
.515 .722 .967 r
.65994 .37199 .66422 .38129 .68553 .38317 .6814 .37389 Mtetra
.523 .728 .967 r
.6814 .37389 .68553 .38317 .70695 .38476 .70295 .37548 Mtetra
.53 .733 .968 r
.70295 .37548 .70695 .38476 .72845 .38608 .7246 .37681 Mtetra
.536 .737 .968 r
.7246 .37681 .72845 .38608 .75004 .38717 .74634 .3779 Mtetra
.541 .741 .968 r
.74634 .3779 .75004 .38717 .77172 .38804 .76817 .37877 Mtetra
.546 .744 .968 r
.76817 .37877 .77172 .38804 .7935 .38871 .79009 .37944 Mtetra
.55 .748 .969 r
.79009 .37944 .7935 .38871 .81535 .3892 .8121 .37993 Mtetra
.553 .75 .969 r
.8121 .37993 .81535 .3892 .8373 .38954 .83419 .38026 Mtetra
.557 .753 .969 r
.83419 .38026 .8373 .38954 .85933 .38972 .85638 .38043 Mtetra
.56 .755 .969 r
.85638 .38043 .85933 .38972 .88145 .38977 .87865 .38047 Mtetra
.563 .757 .969 r
.87865 .38047 .88145 .38977 .90366 .38969 .90101 .38038 Mtetra
.565 .759 .969 r
.90101 .38038 .90366 .38969 .92595 .3895 .92346 .38017 Mtetra
.567 .761 .969 r
.92346 .38017 .92595 .3895 .94832 .3892 .94599 .37986 Mtetra
.57 .763 .969 r
.94599 .37986 .94832 .3892 .97078 .3888 .96861 .37944 Mtetra
.617 .786 .963 r
.24189 .37618 .24888 .38488 .26877 .3828 .2619 .37407 Mtetra
.2619 .37407 .26877 .3828 .28872 .38072 .28198 .37196 Mtetra
.28198 .37196 .28872 .38072 .30873 .37863 .30212 .36984 Mtetra
.30212 .36984 .30873 .37863 .32882 .37653 .32233 .36771 Mtetra
.32233 .36771 .32882 .37653 .34896 .37442 .34261 .36558 Mtetra
.34261 .36558 .34896 .37442 .36918 .37231 .36295 .36344 Mtetra
.36295 .36344 .36918 .37231 .38946 .37019 .38337 .36129 Mtetra
.38337 .36129 .38946 .37019 .40981 .36807 .40385 .35913 Mtetra
.40385 .35913 .40981 .36807 .43023 .36594 .4244 .35697 Mtetra
.4244 .35697 .43023 .36594 .45072 .3638 .44502 .3548 Mtetra
.44502 .3548 .45072 .3638 .47127 .36165 .46571 .35262 Mtetra
.46571 .35262 .47127 .36165 .49189 .35949 .48646 .35044 Mtetra
.48646 .35044 .49189 .35949 .51258 .35733 .50729 .34825 Mtetra
.50729 .34825 .51258 .35733 .53334 .35517 .52819 .34605 Mtetra
.539 .743 .97 r
.52819 .34605 .53334 .35517 .55417 .35644 .54915 .34684 Mtetra
.452 .677 .961 r
.54915 .34684 .55417 .35644 .57511 .36054 .57023 .35099 Mtetra
.469 .689 .963 r
.57023 .35099 .57511 .36054 .59616 .36409 .59141 .35457 Mtetra
.483 .699 .964 r
.59141 .35457 .59616 .36409 .61732 .36713 .61271 .35765 Mtetra
.495 .708 .965 r
.61271 .35765 .61732 .36713 .63858 .36975 .6341 .3603 Mtetra
.506 .715 .966 r
.6341 .3603 .63858 .36975 .65994 .37199 .65561 .36255 Mtetra
.514 .722 .967 r
.65561 .36255 .65994 .37199 .6814 .37389 .67721 .36446 Mtetra
.522 .727 .967 r
.67721 .36446 .6814 .37389 .70295 .37548 .6989 .36607 Mtetra
.529 .732 .968 r
.6989 .36607 .70295 .37548 .7246 .37681 .72069 .36741 Mtetra
.535 .737 .968 r
.72069 .36741 .7246 .37681 .74634 .3779 .74258 .3685 Mtetra
.54 .741 .968 r
.74258 .3685 .74634 .3779 .76817 .37877 .76456 .36937 Mtetra
.545 .744 .968 r
.76456 .36937 .76817 .37877 .79009 .37944 .78663 .37003 Mtetra
.549 .747 .969 r
.78663 .37003 .79009 .37944 .8121 .37993 .80879 .37052 Mtetra
.553 .75 .969 r
.80879 .37052 .8121 .37993 .83419 .38026 .83104 .37084 Mtetra
.557 .753 .969 r
.83104 .37084 .83419 .38026 .85638 .38043 .85338 .37101 Mtetra
.56 .755 .969 r
.85338 .37101 .85638 .38043 .87865 .38047 .87581 .37103 Mtetra
.562 .757 .969 r
.87581 .37103 .87865 .38047 .90101 .38038 .89833 .37093 Mtetra
.565 .759 .969 r
.89833 .37093 .90101 .38038 .92346 .38017 .92093 .37071 Mtetra
.567 .761 .969 r
.92093 .37071 .92346 .38017 .94599 .37986 .94363 .37038 Mtetra
.569 .763 .969 r
.94363 .37038 .94599 .37986 .96861 .37944 .96641 .36995 Mtetra
.617 .786 .963 r
.2348 .36736 .24189 .37618 .2619 .37407 .25494 .36522 Mtetra
.25494 .36522 .2619 .37407 .28198 .37196 .27515 .36308 Mtetra
.27515 .36308 .28198 .37196 .30212 .36984 .29542 .36093 Mtetra
.29542 .36093 .30212 .36984 .32233 .36771 .31576 .35877 Mtetra
.31576 .35877 .32233 .36771 .34261 .36558 .33617 .35661 Mtetra
.33617 .35661 .34261 .36558 .36295 .36344 .35664 .35444 Mtetra
.35664 .35444 .36295 .36344 .38337 .36129 .37719 .35226 Mtetra
.37719 .35226 .38337 .36129 .40385 .35913 .3978 .35007 Mtetra
.3978 .35007 .40385 .35913 .4244 .35697 .41849 .34788 Mtetra
.41849 .34788 .4244 .35697 .44502 .3548 .43924 .34568 Mtetra
.43924 .34568 .44502 .3548 .46571 .35262 .46006 .34347 Mtetra
.46006 .34347 .46571 .35262 .48646 .35044 .48096 .34126 Mtetra
.48096 .34126 .48646 .35044 .50729 .34825 .50192 .33904 Mtetra
.50192 .33904 .50729 .34825 .52819 .34605 .52296 .3368 Mtetra
.552 .75 .969 r
.52296 .3368 .52819 .34605 .54915 .34684 .54406 .3371 Mtetra
.451 .676 .961 r
.54406 .3371 .54915 .34684 .57023 .35099 .56527 .34131 Mtetra
.468 .689 .963 r
.56527 .34131 .57023 .35099 .59141 .35457 .58659 .34493 Mtetra
.482 .699 .964 r
.58659 .34493 .59141 .35457 .61271 .35765 .60802 .34804 Mtetra
.494 .707 .965 r
.60802 .34804 .61271 .35765 .6341 .3603 .62956 .35071 Mtetra
.505 .715 .966 r
.62956 .35071 .6341 .3603 .65561 .36255 .65121 .35298 Mtetra
.514 .721 .967 r
.65121 .35298 .65561 .36255 .67721 .36446 .67295 .35491 Mtetra
.522 .727 .967 r
.67295 .35491 .67721 .36446 .6989 .36607 .69479 .35653 Mtetra
.529 .732 .968 r
.69479 .35653 .6989 .36607 .72069 .36741 .71673 .35787 Mtetra
.535 .737 .968 r
.71673 .35787 .72069 .36741 .74258 .3685 .73877 .35896 Mtetra
.54 .74 .968 r
.73877 .35896 .74258 .3685 .76456 .36937 .7609 .35983 Mtetra
.545 .744 .968 r
.7609 .35983 .76456 .36937 .78663 .37003 .78312 .36049 Mtetra
.549 .747 .969 r
.78312 .36049 .78663 .37003 .80879 .37052 .80544 .36097 Mtetra
.553 .75 .969 r
.80544 .36097 .80879 .37052 .83104 .37084 .82784 .36129 Mtetra
.556 .753 .969 r
.82784 .36129 .83104 .37084 .85338 .37101 .85034 .36144 Mtetra
.559 .755 .969 r
.85034 .36144 .85338 .37101 .87581 .37103 .87293 .36146 Mtetra
.562 .757 .969 r
.87293 .36146 .87581 .37103 .89833 .37093 .8956 .36135 Mtetra
.565 .759 .969 r
.8956 .36135 .89833 .37093 .92093 .37071 .91837 .36111 Mtetra
.567 .761 .969 r
.91837 .36111 .92093 .37071 .94363 .37038 .94123 .36077 Mtetra
.569 .763 .969 r
.94123 .36077 .94363 .37038 .96641 .36995 .96417 .36032 Mtetra
.617 .786 .963 r
.22762 .35841 .2348 .36736 .25494 .36522 .24788 .35625 Mtetra
.24788 .35625 .25494 .36522 .27515 .36308 .26822 .35407 Mtetra
.26822 .35407 .27515 .36308 .29542 .36093 .28862 .35189 Mtetra
.28862 .35189 .29542 .36093 .31576 .35877 .30909 .34971 Mtetra
.30909 .34971 .31576 .35877 .33617 .35661 .32963 .34751 Mtetra
.32963 .34751 .33617 .35661 .35664 .35444 .35024 .34531 Mtetra
.35024 .34531 .35664 .35444 .37719 .35226 .37092 .3431 Mtetra
.37092 .3431 .37719 .35226 .3978 .35007 .39167 .34089 Mtetra
.39167 .34089 .3978 .35007 .41849 .34788 .41249 .33866 Mtetra
.41249 .33866 .41849 .34788 .43924 .34568 .43338 .33643 Mtetra
.43338 .33643 .43924 .34568 .46006 .34347 .45434 .33419 Mtetra
.45434 .33419 .46006 .34347 .48096 .34126 .47537 .33194 Mtetra
.47537 .33194 .48096 .34126 .50192 .33904 .49648 .32969 Mtetra
.49648 .32969 .50192 .33904 .52296 .3368 .51766 .32743 Mtetra
.565 .758 .968 r
.51766 .32743 .52296 .3368 .54406 .3371 .5389 .32723 Mtetra
.449 .675 .961 r
.5389 .32723 .54406 .3371 .56527 .34131 .56024 .33148 Mtetra
.466 .688 .963 r
.56024 .33148 .56527 .34131 .58659 .34493 .5817 .33514 Mtetra
.481 .698 .964 r
.5817 .33514 .58659 .34493 .60802 .34804 .60328 .33829 Mtetra
.493 .707 .965 r
.60328 .33829 .60802 .34804 .62956 .35071 .62496 .34098 Mtetra
.504 .714 .966 r
.62496 .34098 .62956 .35071 .65121 .35298 .64674 .34327 Mtetra
.513 .721 .967 r
.64674 .34327 .65121 .35298 .67295 .35491 .66864 .34521 Mtetra
.521 .727 .967 r
.66864 .34521 .67295 .35491 .69479 .35653 .69063 .34684 Mtetra
.528 .732 .968 r
.69063 .34684 .69479 .35653 .71673 .35787 .71272 .34819 Mtetra
.534 .736 .968 r
.71272 .34819 .71673 .35787 .73877 .35896 .7349 .34928 Mtetra
.54 .74 .968 r
.7349 .34928 .73877 .35896 .7609 .35983 .75719 .35015 Mtetra
.545 .744 .968 r
.75719 .35015 .7609 .35983 .78312 .36049 .77956 .35081 Mtetra
.549 .747 .969 r
.77956 .35081 .78312 .36049 .80544 .36097 .80203 .35129 Mtetra
.553 .75 .969 r
.80203 .35129 .80544 .36097 .82784 .36129 .8246 .35159 Mtetra
.556 .752 .969 r
.8246 .35159 .82784 .36129 .85034 .36144 .84725 .35174 Mtetra
.559 .755 .969 r
.84725 .35174 .85034 .36144 .87293 .36146 .87 .35175 Mtetra
.562 .757 .969 r
.87 .35175 .87293 .36146 .8956 .36135 .89284 .35162 Mtetra
.565 .759 .969 r
.89284 .35162 .8956 .36135 .91837 .36111 .91577 .35137 Mtetra
.567 .761 .969 r
.91577 .35137 .91837 .36111 .94123 .36077 .93879 .35101 Mtetra
.569 .762 .969 r
.93879 .35101 .94123 .36077 .96417 .36032 .9619 .35054 Mtetra
.617 .786 .963 r
.22033 .34934 .22762 .35841 .24788 .35625 .24073 .34715 Mtetra
.24073 .34715 .24788 .35625 .26822 .35407 .26119 .34494 Mtetra
.26119 .34494 .26822 .35407 .28862 .35189 .28173 .34273 Mtetra
.28173 .34273 .28862 .35189 .30909 .34971 .30233 .34051 Mtetra
.30233 .34051 .30909 .34971 .32963 .34751 .32301 .33829 Mtetra
.32301 .33829 .32963 .34751 .35024 .34531 .34375 .33606 Mtetra
.34375 .33606 .35024 .34531 .37092 .3431 .36456 .33382 Mtetra
.36456 .33382 .37092 .3431 .39167 .34089 .38545 .33157 Mtetra
.38545 .33157 .39167 .34089 .41249 .33866 .40641 .32931 Mtetra
.40641 .32931 .41249 .33866 .43338 .33643 .42744 .32705 Mtetra
.42744 .32705 .43338 .33643 .45434 .33419 .44854 .32478 Mtetra
.44854 .32478 .45434 .33419 .47537 .33194 .46971 .3225 Mtetra
.46971 .3225 .47537 .33194 .49648 .32969 .49096 .32021 Mtetra
.49096 .32021 .49648 .32969 .51766 .32743 .51228 .31792 Mtetra
.577 .765 .967 r
.51228 .31792 .51766 .32743 .5389 .32723 .53367 .31722 Mtetra
.448 .675 .96 r
.53367 .31722 .5389 .32723 .56024 .33148 .55514 .32152 Mtetra
.465 .687 .963 r
.55514 .32152 .56024 .33148 .5817 .33514 .57674 .32522 Mtetra
.48 .697 .964 r
.57674 .32522 .5817 .33514 .60328 .33829 .59846 .3284 Mtetra
.493 .706 .965 r
.59846 .3284 .60328 .33829 .62496 .34098 .62028 .33111 Mtetra
.503 .714 .966 r
.62028 .33111 .62496 .34098 .64674 .34327 .64222 .33342 Mtetra
.513 .721 .967 r
.64222 .33342 .64674 .34327 .66864 .34521 .66426 .33538 Mtetra
.521 .726 .967 r
.66426 .33538 .66864 .34521 .69063 .34684 .6864 .33702 Mtetra
.528 .731 .968 r
.6864 .33702 .69063 .34684 .71272 .34819 .70864 .33837 Mtetra
.534 .736 .968 r
.70864 .33837 .71272 .34819 .7349 .34928 .73098 .33946 Mtetra
.539 .74 .968 r
.73098 .33946 .7349 .34928 .75719 .35015 .75342 .34033 Mtetra
.544 .744 .968 r
.75342 .34033 .75719 .35015 .77956 .35081 .77595 .34099 Mtetra
.549 .747 .969 r
.77595 .34099 .77956 .35081 .80203 .35129 .79858 .34146 Mtetra
.552 .75 .969 r
.79858 .34146 .80203 .35129 .8246 .35159 .8213 .34176 Mtetra
.556 .752 .969 r
.8213 .34176 .8246 .35159 .84725 .35174 .84412 .34189 Mtetra
.559 .755 .969 r
.84412 .34189 .84725 .35174 .87 .35175 .86703 .34189 Mtetra
.562 .757 .969 r
.86703 .34189 .87 .35175 .89284 .35162 .89003 .34175 Mtetra
.564 .759 .969 r
.89003 .34175 .89284 .35162 .91577 .35137 .91313 .34148 Mtetra
.567 .761 .969 r
.91313 .34148 .91577 .35137 .93879 .35101 .93632 .34111 Mtetra
.569 .762 .969 r
.93632 .34111 .93879 .35101 .9619 .35054 .9596 .34062 Mtetra
.617 .786 .963 r
.21294 .34014 .22033 .34934 .24073 .34715 .23347 .33792 Mtetra
.23347 .33792 .24073 .34715 .26119 .34494 .25407 .33568 Mtetra
.25407 .33568 .26119 .34494 .28173 .34273 .27474 .33344 Mtetra
.27474 .33344 .28173 .34273 .30233 .34051 .29547 .33119 Mtetra
.29547 .33119 .30233 .34051 .32301 .33829 .31628 .32893 Mtetra
.31628 .32893 .32301 .33829 .34375 .33606 .33716 .32667 Mtetra
.33716 .32667 .34375 .33606 .36456 .33382 .35812 .3244 Mtetra
.35812 .3244 .36456 .33382 .38545 .33157 .37914 .32212 Mtetra
.37914 .32212 .38545 .33157 .40641 .32931 .40024 .31983 Mtetra
.40024 .31983 .40641 .32931 .42744 .32705 .42141 .31753 Mtetra
.42141 .31753 .42744 .32705 .44854 .32478 .44265 .31523 Mtetra
.44265 .31523 .44854 .32478 .46971 .3225 .46397 .31292 Mtetra
.46397 .31292 .46971 .3225 .49096 .32021 .48536 .3106 Mtetra
.48536 .3106 .49096 .32021 .51228 .31792 .50682 .30827 Mtetra
.589 .771 .966 r
.50682 .30827 .51228 .31792 .53367 .31722 .52836 .30706 Mtetra
.446 .674 .96 r
.52836 .30706 .53367 .31722 .55514 .32152 .54997 .31141 Mtetra
.464 .686 .962 r
.54997 .31141 .55514 .32152 .57674 .32522 .57171 .31515 Mtetra
.479 .697 .964 r
.57171 .31515 .57674 .32522 .59846 .3284 .59357 .31836 Mtetra
.492 .706 .965 r
.59357 .31836 .59846 .3284 .62028 .33111 .61554 .3211 Mtetra
.503 .714 .966 r
.61554 .3211 .62028 .33111 .64222 .33342 .63763 .32343 Mtetra
.512 .72 .967 r
.63763 .32343 .64222 .33342 .66426 .33538 .65982 .3254 Mtetra
.52 .726 .967 r
.65982 .3254 .66426 .33538 .6864 .33702 .68211 .32705 Mtetra
.527 .731 .968 r
.68211 .32705 .6864 .33702 .70864 .33837 .7045 .3284 Mtetra
.533 .736 .968 r
.7045 .3284 .70864 .33837 .73098 .33946 .727 .3295 Mtetra
.539 .74 .968 r
.727 .3295 .73098 .33946 .75342 .34033 .74959 .33037 Mtetra
.544 .743 .968 r
.74959 .33037 .75342 .34033 .77595 .34099 .77229 .33102 Mtetra
.548 .747 .969 r
.77229 .33102 .77595 .34099 .79858 .34146 .79508 .33148 Mtetra
.552 .749 .969 r
.79508 .33148 .79858 .34146 .8213 .34176 .81796 .33177 Mtetra
.556 .752 .969 r
.81796 .33177 .8213 .34176 .84412 .34189 .84094 .3319 Mtetra
.559 .754 .969 r
.84094 .3319 .84412 .34189 .86703 .34189 .86402 .33188 Mtetra
.562 .757 .969 r
.86402 .33188 .86703 .34189 .89003 .34175 .88719 .33173 Mtetra
.564 .759 .969 r
.88719 .33173 .89003 .34175 .91313 .34148 .91045 .33145 Mtetra
.567 .761 .969 r
.91045 .33145 .91313 .34148 .93632 .34111 .93381 .33105 Mtetra
.569 .762 .969 r
.93381 .33105 .93632 .34111 .9596 .34062 .95726 .33055 Mtetra
.617 .786 .963 r
.20545 .33081 .21294 .34014 .23347 .33792 .22611 .32856 Mtetra
.22611 .32856 .23347 .33792 .25407 .33568 .24684 .32629 Mtetra
.24684 .32629 .25407 .33568 .27474 .33344 .26764 .32402 Mtetra
.26764 .32402 .27474 .33344 .29547 .33119 .28852 .32173 Mtetra
.28852 .32173 .29547 .33119 .31628 .32893 .30947 .31944 Mtetra
.30947 .31944 .31628 .32893 .33716 .32667 .33049 .31715 Mtetra
.33049 .31715 .33716 .32667 .35812 .3244 .35158 .31484 Mtetra
.35158 .31484 .35812 .3244 .37914 .32212 .37274 .31253 Mtetra
.37274 .31253 .37914 .32212 .40024 .31983 .39398 .31021 Mtetra
.39398 .31021 .40024 .31983 .42141 .31753 .41529 .30788 Mtetra
.41529 .30788 .42141 .31753 .44265 .31523 .43668 .30554 Mtetra
.43668 .30554 .44265 .31523 .46397 .31292 .45814 .30319 Mtetra
.45814 .30319 .46397 .31292 .48536 .3106 .47967 .30084 Mtetra
.47967 .30084 .48536 .3106 .50682 .30827 .50128 .29848 Mtetra
.601 .778 .965 r
.50128 .29848 .50682 .30827 .52836 .30706 .52297 .29676 Mtetra
.445 .673 .96 r
.52297 .29676 .52836 .30706 .54997 .31141 .54473 .30116 Mtetra
.463 .685 .962 r
.54473 .30116 .54997 .31141 .57171 .31515 .56661 .30494 Mtetra
.478 .696 .964 r
.56661 .30494 .57171 .31515 .59357 .31836 .58861 .30818 Mtetra
.491 .705 .965 r
.58861 .30818 .59357 .31836 .61554 .3211 .61073 .31094 Mtetra
.502 .713 .966 r
.61073 .31094 .61554 .3211 .63763 .32343 .63297 .31329 Mtetra
.511 .72 .967 r
.63297 .31329 .63763 .32343 .65982 .3254 .65531 .31527 Mtetra
.52 .726 .967 r
.65531 .31527 .65982 .3254 .68211 .32705 .67775 .31693 Mtetra
.527 .731 .968 r
.67775 .31693 .68211 .32705 .7045 .3284 .70031 .31829 Mtetra
.533 .735 .968 r
.70031 .31829 .7045 .3284 .727 .3295 .72296 .31939 Mtetra
.539 .739 .968 r
.72296 .31939 .727 .3295 .74959 .33037 .74571 .32025 Mtetra
.544 .743 .968 r
.74571 .32025 .74959 .33037 .77229 .33102 .76857 .3209 Mtetra
.548 .746 .969 r
.76857 .3209 .77229 .33102 .79508 .33148 .79152 .32136 Mtetra
.552 .749 .969 r
.79152 .32136 .79508 .33148 .81796 .33177 .81457 .32164 Mtetra
.555 .752 .969 r
.81457 .32164 .81796 .33177 .84094 .3319 .83772 .32175 Mtetra
.559 .754 .969 r
.83772 .32175 .84094 .3319 .86402 .33188 .86096 .32172 Mtetra
.561 .757 .969 r
.86096 .32172 .86402 .33188 .88719 .33173 .8843 .32155 Mtetra
.564 .759 .969 r
.8843 .32155 .88719 .33173 .91045 .33145 .90773 .32126 Mtetra
.566 .76 .969 r
.90773 .32126 .91045 .33145 .93381 .33105 .93126 .32085 Mtetra
.569 .762 .969 r
.93126 .32085 .93381 .33105 .95726 .33055 .95489 .32032 Mtetra
.617 .786 .963 r
.19785 .32135 .20545 .33081 .22611 .32856 .21864 .31906 Mtetra
.21864 .31906 .22611 .32856 .24684 .32629 .23951 .31676 Mtetra
.23951 .31676 .24684 .32629 .26764 .32402 .26045 .31446 Mtetra
.26045 .31446 .26764 .32402 .28852 .32173 .28146 .31214 Mtetra
.28146 .31214 .28852 .32173 .30947 .31944 .30255 .30982 Mtetra
.30255 .30982 .30947 .31944 .33049 .31715 .32371 .30749 Mtetra
.32371 .30749 .33049 .31715 .35158 .31484 .34494 .30515 Mtetra
.34494 .30515 .35158 .31484 .37274 .31253 .36625 .3028 Mtetra
.36625 .3028 .37274 .31253 .39398 .31021 .38763 .30045 Mtetra
.38763 .30045 .39398 .31021 .41529 .30788 .40909 .29808 Mtetra
.40909 .29808 .41529 .30788 .43668 .30554 .43062 .29571 Mtetra
.43062 .29571 .43668 .30554 .45814 .30319 .45222 .29333 Mtetra
.45222 .29333 .45814 .30319 .47967 .30084 .47391 .29094 Mtetra
.47391 .29094 .47967 .30084 .50128 .29848 .49567 .28855 Mtetra
.613 .784 .963 r
.49567 .28855 .50128 .29848 .52297 .29676 .5175 .28631 Mtetra
.443 .672 .96 r
.5175 .28631 .52297 .29676 .54473 .30116 .5394 .29076 Mtetra
.462 .685 .962 r
.5394 .29076 .54473 .30116 .56661 .30494 .56143 .29458 Mtetra
.477 .696 .964 r
.56143 .29458 .56661 .30494 .58861 .30818 .58358 .29785 Mtetra
.49 .705 .965 r
.58358 .29785 .58861 .30818 .61073 .31094 .60585 .30064 Mtetra
.501 .713 .966 r
.60585 .30064 .61073 .31094 .63297 .31329 .62824 .303 Mtetra
.511 .719 .967 r
.62824 .303 .63297 .31329 .65531 .31527 .65073 .305 Mtetra
.519 .725 .967 r
.65073 .305 .65531 .31527 .67775 .31693 .67334 .30666 Mtetra
.526 .731 .968 r
.67334 .30666 .67775 .31693 .70031 .31829 .69605 .30803 Mtetra
.533 .735 .968 r
.69605 .30803 .70031 .31829 .72296 .31939 .71886 .30913 Mtetra
.538 .739 .968 r
.71886 .30913 .72296 .31939 .74571 .32025 .74177 .30999 Mtetra
.543 .743 .968 r
.74177 .30999 .74571 .32025 .76857 .3209 .76479 .31063 Mtetra
.548 .746 .969 r
.76479 .31063 .76857 .3209 .79152 .32136 .78791 .31108 Mtetra
.552 .749 .969 r
.78791 .31108 .79152 .32136 .81457 .32164 .81112 .31135 Mtetra
.555 .752 .969 r
.81112 .31135 .81457 .32164 .83772 .32175 .83444 .31146 Mtetra
.558 .754 .969 r
.83444 .31146 .83772 .32175 .86096 .32172 .85785 .31141 Mtetra
.561 .756 .969 r
.85785 .31141 .86096 .32172 .8843 .32155 .88136 .31123 Mtetra
.564 .758 .969 r
.88136 .31123 .8843 .32155 .90773 .32126 .90497 .31091 Mtetra
.566 .76 .969 r
.90497 .31091 .90773 .32126 .93126 .32085 .92868 .31048 Mtetra
.568 .762 .969 r
.92868 .31048 .93126 .32085 .95489 .32032 .95248 .30994 Mtetra
.617 .786 .963 r
.19013 .31175 .19785 .32135 .21864 .31906 .21107 .30943 Mtetra
.21107 .30943 .21864 .31906 .23951 .31676 .23207 .3071 Mtetra
.23207 .3071 .23951 .31676 .26045 .31446 .25315 .30476 Mtetra
.25315 .30476 .26045 .31446 .28146 .31214 .27431 .30241 Mtetra
.27431 .30241 .28146 .31214 .30255 .30982 .29553 .30005 Mtetra
.29553 .30005 .30255 .30982 .32371 .30749 .31684 .29769 Mtetra
.31684 .29769 .32371 .30749 .34494 .30515 .33821 .29531 Mtetra
.33821 .29531 .34494 .30515 .36625 .3028 .35966 .29293 Mtetra
.35966 .29293 .36625 .3028 .38763 .30045 .38119 .29054 Mtetra
.38119 .29054 .38763 .30045 .40909 .29808 .40279 .28814 Mtetra
.40279 .28814 .40909 .29808 .43062 .29571 .42447 .28574 Mtetra
.42447 .28574 .43062 .29571 .45222 .29333 .44622 .28332 Mtetra
.44622 .28332 .45222 .29333 .47391 .29094 .46806 .2809 Mtetra
.46806 .2809 .47391 .29094 .49567 .28855 .48997 .27847 Mtetra
.48997 .27847 .49567 .28855 .5175 .28631 .51195 .27602 Mtetra
.443 .679 .964 r
.51195 .27602 .5175 .28631 .5394 .29076 .534 .2802 Mtetra
.46 .684 .962 r
.534 .2802 .5394 .29076 .56143 .29458 .55618 .28406 Mtetra
.476 .695 .964 r
.55618 .28406 .56143 .29458 .58358 .29785 .57848 .28736 Mtetra
.489 .704 .965 r
.57848 .28736 .58358 .29785 .60585 .30064 .6009 .29017 Mtetra
.5 .712 .966 r
.6009 .29017 .60585 .30064 .62824 .303 .62344 .29256 Mtetra
.51 .719 .967 r
.62344 .29256 .62824 .303 .65073 .305 .64609 .29457 Mtetra
.518 .725 .967 r
.64609 .29457 .65073 .305 .67334 .30666 .66885 .29624 Mtetra
.526 .73 .968 r
.66885 .29624 .67334 .30666 .69605 .30803 .69172 .29761 Mtetra
.532 .735 .968 r
.69172 .29761 .69605 .30803 .71886 .30913 .7147 .29871 Mtetra
.538 .739 .968 r
.7147 .29871 .71886 .30913 .74177 .30999 .73778 .29957 Mtetra
.543 .743 .968 r
.73778 .29957 .74177 .30999 .76479 .31063 .76096 .30021 Mtetra
.547 .746 .969 r
.76096 .30021 .76479 .31063 .78791 .31108 .78424 .30065 Mtetra
.551 .749 .969 r
.78424 .30065 .78791 .31108 .81112 .31135 .80763 .30091 Mtetra
.555 .752 .969 r
.80763 .30091 .81112 .31135 .83444 .31146 .83111 .301 Mtetra
.558 .754 .969 r
.83111 .301 .83444 .31146 .85785 .31141 .8547 .30094 Mtetra
.561 .756 .969 r
.8547 .30094 .85785 .31141 .88136 .31123 .87838 .30074 Mtetra
.564 .758 .969 r
.87838 .30074 .88136 .31123 .90497 .31091 .90217 .30041 Mtetra
.566 .76 .969 r
.90217 .30041 .90497 .31091 .92868 .31048 .92605 .29996 Mtetra
.568 .762 .969 r
.92605 .29996 .92868 .31048 .95248 .30994 .95003 .2994 Mtetra
.617 .786 .963 r
.18231 .30201 .19013 .31175 .21107 .30943 .20338 .29966 Mtetra
.20338 .29966 .21107 .30943 .23207 .3071 .22453 .29729 Mtetra
.22453 .29729 .23207 .3071 .25315 .30476 .24575 .29491 Mtetra
.24575 .29491 .25315 .30476 .27431 .30241 .26704 .29253 Mtetra
.26704 .29253 .27431 .30241 .29553 .30005 .28841 .29014 Mtetra
.28841 .29014 .29553 .30005 .31684 .29769 .30986 .28774 Mtetra
.30986 .28774 .31684 .29769 .33821 .29531 .33138 .28533 Mtetra
.33138 .28533 .33821 .29531 .35966 .29293 .35298 .28292 Mtetra
.35298 .28292 .35966 .29293 .38119 .29054 .37465 .28049 Mtetra
.37465 .28049 .38119 .29054 .40279 .28814 .3964 .27806 Mtetra
.3964 .27806 .40279 .28814 .42447 .28574 .41823 .27561 Mtetra
.41823 .27561 .42447 .28574 .44622 .28332 .44013 .27316 Mtetra
.44013 .27316 .44622 .28332 .46806 .2809 .46212 .2707 Mtetra
.46212 .2707 .46806 .2809 .48997 .27847 .48418 .26823 Mtetra
.48418 .26823 .48997 .27847 .51195 .27602 .50632 .26576 Mtetra
.452 .688 .967 r
.50632 .26576 .51195 .27602 .534 .2802 .52852 .26949 Mtetra
.459 .683 .962 r
.52852 .26949 .534 .2802 .55618 .28406 .55084 .27339 Mtetra
.475 .694 .964 r
.55084 .27339 .55618 .28406 .57848 .28736 .5733 .27672 Mtetra
.488 .704 .965 r
.5733 .27672 .57848 .28736 .6009 .29017 .59587 .27956 Mtetra
.5 .712 .966 r
.59587 .27956 .6009 .29017 .62344 .29256 .61857 .28196 Mtetra
.509 .719 .967 r
.61857 .28196 .62344 .29256 .64609 .29457 .64138 .28398 Mtetra
.518 .725 .967 r
.64138 .28398 .64609 .29457 .66885 .29624 .6643 .28566 Mtetra
.525 .73 .968 r
.6643 .28566 .66885 .29624 .69172 .29761 .68733 .28703 Mtetra
.532 .735 .968 r
.68733 .28703 .69172 .29761 .7147 .29871 .71047 .28813 Mtetra
.537 .739 .968 r
.71047 .28813 .7147 .29871 .73778 .29957 .73372 .28899 Mtetra
.543 .742 .968 r
.73372 .28899 .73778 .29957 .76096 .30021 .75707 .28962 Mtetra
.547 .746 .969 r
.75707 .28962 .76096 .30021 .78424 .30065 .78052 .29005 Mtetra
.551 .749 .969 r
.78052 .29005 .78424 .30065 .80763 .30091 .80408 .2903 Mtetra
.555 .751 .969 r
.80408 .2903 .80763 .30091 .83111 .301 .82774 .29038 Mtetra
.558 .754 .969 r
.82774 .29038 .83111 .301 .8547 .30094 .8515 .29031 Mtetra
.561 .756 .969 r
.8515 .29031 .8547 .30094 .87838 .30074 .87536 .29009 Mtetra
.564 .758 .969 r
.87536 .29009 .87838 .30074 .90217 .30041 .89932 .28974 Mtetra
.566 .76 .969 r
.89932 .28974 .90217 .30041 .92605 .29996 .92338 .28927 Mtetra
.568 .762 .969 r
.92338 .28927 .92605 .29996 .95003 .2994 .94755 .28869 Mtetra
.617 .786 .963 r
.17437 .29213 .18231 .30201 .20338 .29966 .19559 .28974 Mtetra
.19559 .28974 .20338 .29966 .22453 .29729 .21687 .28734 Mtetra
.21687 .28734 .22453 .29729 .24575 .29491 .23824 .28493 Mtetra
.23824 .28493 .24575 .29491 .26704 .29253 .25968 .28251 Mtetra
.25968 .28251 .26704 .29253 .28841 .29014 .28119 .28008 Mtetra
.28119 .28008 .28841 .29014 .30986 .28774 .30278 .27765 Mtetra
.30278 .27765 .30986 .28774 .33138 .28533 .32445 .27521 Mtetra
.32445 .27521 .33138 .28533 .35298 .28292 .34619 .27275 Mtetra
.34619 .27275 .35298 .28292 .37465 .28049 .36802 .27029 Mtetra
.36802 .27029 .37465 .28049 .3964 .27806 .38992 .26782 Mtetra
.38992 .26782 .3964 .27806 .41823 .27561 .4119 .26534 Mtetra
.4119 .26534 .41823 .27561 .44013 .27316 .43395 .26285 Mtetra
.43395 .26285 .44013 .27316 .46212 .2707 .45609 .26036 Mtetra
.45609 .26036 .46212 .2707 .48418 .26823 .47831 .25785 Mtetra
.47831 .25785 .48418 .26823 .50632 .26576 .50061 .25534 Mtetra
.465 .697 .968 r
.50061 .25534 .50632 .26576 .52852 .26949 .52295 .25862 Mtetra
.458 .682 .962 r
.52295 .25862 .52852 .26949 .55084 .27339 .54543 .26256 Mtetra
.474 .694 .964 r
.54543 .26256 .55084 .27339 .5733 .27672 .56804 .26592 Mtetra
.487 .703 .965 r
.56804 .26592 .5733 .27672 .59587 .27956 .59077 .26878 Mtetra
.499 .711 .966 r
.59077 .26878 .59587 .27956 .61857 .28196 .61362 .2712 Mtetra
.509 .718 .967 r
.61362 .2712 .61857 .28196 .64138 .28398 .63659 .27323 Mtetra
.517 .724 .967 r
.63659 .27323 .64138 .28398 .6643 .28566 .65968 .27492 Mtetra
.525 .73 .968 r
.65968 .27492 .6643 .28566 .68733 .28703 .68287 .27629 Mtetra
.531 .734 .968 r
.68287 .27629 .68733 .28703 .71047 .28813 .70618 .2774 Mtetra
.537 .738 .968 r
.70618 .2774 .71047 .28813 .73372 .28899 .72959 .27825 Mtetra
.542 .742 .968 r
.72959 .27825 .73372 .28899 .75707 .28962 .75311 .27887 Mtetra
.547 .746 .969 r
.75311 .27887 .75707 .28962 .78052 .29005 .77674 .2793 Mtetra
.551 .749 .969 r
.77674 .2793 .78052 .29005 .80408 .2903 .80047 .27953 Mtetra
.554 .751 .969 r
.80047 .27953 .80408 .2903 .82774 .29038 .82431 .2796 Mtetra
.558 .754 .969 r
.82431 .2796 .82774 .29038 .8515 .29031 .84825 .27951 Mtetra
.561 .756 .969 r
.84825 .27951 .8515 .29031 .87536 .29009 .87229 .27927 Mtetra
.563 .758 .969 r
.87229 .27927 .87536 .29009 .89932 .28974 .89643 .27891 Mtetra
.566 .76 .969 r
.89643 .27891 .89932 .28974 .92338 .28927 .92067 .27842 Mtetra
.568 .762 .969 r
.92067 .27842 .92338 .28927 .94755 .28869 .94502 .27781 Mtetra
.617 .786 .963 r
.16632 .28211 .17437 .29213 .19559 .28974 .18767 .27968 Mtetra
.18767 .27968 .19559 .28974 .21687 .28734 .2091 .27724 Mtetra
.2091 .27724 .21687 .28734 .23824 .28493 .23061 .2748 Mtetra
.23061 .2748 .23824 .28493 .25968 .28251 .2522 .27234 Mtetra
.2522 .27234 .25968 .28251 .28119 .28008 .27386 .26988 Mtetra
.27386 .26988 .28119 .28008 .30278 .27765 .2956 .26741 Mtetra
.2956 .26741 .30278 .27765 .32445 .27521 .31741 .26493 Mtetra
.31741 .26493 .32445 .27521 .34619 .27275 .33931 .26244 Mtetra
.33931 .26244 .34619 .27275 .36802 .27029 .36128 .25994 Mtetra
.36128 .25994 .36802 .27029 .38992 .26782 .38333 .25743 Mtetra
.38333 .25743 .38992 .26782 .4119 .26534 .40547 .25491 Mtetra
.40547 .25491 .4119 .26534 .43395 .26285 .42768 .25239 Mtetra
.42768 .25239 .43395 .26285 .45609 .26036 .44997 .24985 Mtetra
.44997 .24985 .45609 .26036 .47831 .25785 .47235 .24731 Mtetra
.47235 .24731 .47831 .25785 .50061 .25534 .4948 .24476 Mtetra
.478 .705 .969 r
.4948 .24476 .50061 .25534 .52295 .25862 .51731 .24758 Mtetra
.457 .682 .962 r
.51731 .24758 .52295 .25862 .54543 .26256 .53994 .25156 Mtetra
.473 .693 .964 r
.53994 .25156 .54543 .26256 .56804 .26592 .5627 .25495 Mtetra
.486 .702 .965 r
.5627 .25495 .56804 .26592 .59077 .26878 .58559 .25784 Mtetra
.498 .711 .966 r
.58559 .25784 .59077 .26878 .61362 .2712 .6086 .26028 Mtetra
.508 .718 .967 r
.6086 .26028 .61362 .2712 .63659 .27323 .63173 .26232 Mtetra
.517 .724 .967 r
.63173 .26232 .63659 .27323 .65968 .27492 .65498 .26401 Mtetra
.524 .729 .968 r
.65498 .26401 .65968 .27492 .68287 .27629 .67835 .26539 Mtetra
.531 .734 .968 r
.67835 .26539 .68287 .27629 .70618 .2774 .70182 .26649 Mtetra
.537 .738 .968 r
.70182 .26649 .70618 .2774 .72959 .27825 .72541 .26734 Mtetra
.542 .742 .968 r
.72541 .26734 .72959 .27825 .75311 .27887 .7491 .26796 Mtetra
.546 .745 .969 r
.7491 .26796 .75311 .27887 .77674 .2793 .7729 .26837 Mtetra
.551 .748 .969 r
.7729 .26837 .77674 .2793 .80047 .27953 .79681 .2686 Mtetra
.554 .751 .969 r
.79681 .2686 .80047 .27953 .82431 .2796 .82082 .26865 Mtetra
.558 .754 .969 r
.82082 .26865 .82431 .2796 .84825 .27951 .84494 .26854 Mtetra
.56 .756 .969 r
.84494 .26854 .84825 .27951 .87229 .27927 .86917 .26829 Mtetra
.563 .758 .969 r
.86917 .26829 .87229 .27927 .89643 .27891 .89349 .2679 Mtetra
.566 .76 .969 r
.89349 .2679 .89643 .27891 .92067 .27842 .91792 .26739 Mtetra
.568 .762 .969 r
.91792 .26739 .92067 .27842 .94502 .27781 .94246 .26676 Mtetra
.617 .786 .963 r
.15814 .27193 .16632 .28211 .18767 .27968 .17964 .26947 Mtetra
.17964 .26947 .18767 .27968 .2091 .27724 .20122 .26699 Mtetra
.20122 .26699 .2091 .27724 .23061 .2748 .22287 .26451 Mtetra
.22287 .26451 .23061 .2748 .2522 .27234 .24461 .26202 Mtetra
.24461 .26202 .2522 .27234 .27386 .26988 .26642 .25952 Mtetra
.26642 .25952 .27386 .26988 .2956 .26741 .2883 .25701 Mtetra
.2883 .25701 .2956 .26741 .31741 .26493 .31027 .25449 Mtetra
.31027 .25449 .31741 .26493 .33931 .26244 .33232 .25197 Mtetra
.33232 .25197 .33931 .26244 .36128 .25994 .35445 .24943 Mtetra
.35445 .24943 .36128 .25994 .38333 .25743 .37665 .24688 Mtetra
.37665 .24688 .38333 .25743 .40547 .25491 .39894 .24433 Mtetra
.39894 .24433 .40547 .25491 .42768 .25239 .42131 .24176 Mtetra
.42131 .24176 .42768 .25239 .44997 .24985 .44376 .23919 Mtetra
.44376 .23919 .44997 .24985 .47235 .24731 .46629 .23661 Mtetra
.46629 .23661 .47235 .24731 .4948 .24476 .48891 .23402 Mtetra
.491 .713 .969 r
.48891 .23402 .4948 .24476 .51731 .24758 .51157 .23638 Mtetra
.456 .681 .962 r
.51157 .23638 .51731 .24758 .53994 .25156 .53436 .2404 Mtetra
.472 .692 .964 r
.53436 .2404 .53994 .25156 .5627 .25495 .55728 .24382 Mtetra
.486 .702 .965 r
.55728 .24382 .5627 .25495 .58559 .25784 .58033 .24673 Mtetra
.497 .71 .966 r
.58033 .24673 .58559 .25784 .6086 .26028 .6035 .24918 Mtetra
.507 .717 .967 r
.6035 .24918 .6086 .26028 .63173 .26232 .6268 .25124 Mtetra
.516 .724 .967 r
.6268 .25124 .63173 .26232 .65498 .26401 .65022 .25294 Mtetra
.524 .729 .968 r
.65022 .25294 .65498 .26401 .67835 .26539 .67375 .25432 Mtetra
.53 .734 .968 r
.67375 .25432 .67835 .26539 .70182 .26649 .6974 .25542 Mtetra
.536 .738 .968 r
.6974 .25542 .70182 .26649 .72541 .26734 .72116 .25626 Mtetra
.541 .742 .968 r
.72116 .25626 .72541 .26734 .7491 .26796 .74503 .25687 Mtetra
.546 .745 .969 r
.74503 .25687 .7491 .26796 .7729 .26837 .769 .25728 Mtetra
.55 .748 .969 r
.769 .25728 .7729 .26837 .79681 .2686 .79309 .25749 Mtetra
.554 .751 .969 r
.79309 .25749 .79681 .2686 .82082 .26865 .81729 .25752 Mtetra
.557 .753 .969 r
.81729 .25752 .82082 .26865 .84494 .26854 .84159 .2574 Mtetra
.56 .756 .969 r
.84159 .2574 .84494 .26854 .86917 .26829 .866 .25713 Mtetra
.563 .758 .969 r
.866 .25713 .86917 .26829 .89349 .2679 .89051 .25672 Mtetra
.565 .76 .969 r
.89051 .25672 .89349 .2679 .91792 .26739 .91513 .25619 Mtetra
.568 .761 .969 r
.91513 .25619 .91792 .26739 .94246 .26676 .93985 .25554 Mtetra
.617 .786 .963 r
.14985 .2616 .15814 .27193 .17964 .26947 .17149 .2591 Mtetra
.17149 .2591 .17964 .26947 .20122 .26699 .19322 .25659 Mtetra
.19322 .25659 .20122 .26699 .22287 .26451 .21502 .25407 Mtetra
.21502 .25407 .22287 .26451 .24461 .26202 .2369 .25154 Mtetra
.2369 .25154 .24461 .26202 .26642 .25952 .25886 .249 Mtetra
.25886 .249 .26642 .25952 .2883 .25701 .2809 .24646 Mtetra
.2809 .24646 .2883 .25701 .31027 .25449 .30302 .2439 Mtetra
.30302 .2439 .31027 .25449 .33232 .25197 .32522 .24133 Mtetra
.32522 .24133 .33232 .25197 .35445 .24943 .34751 .23876 Mtetra
.34751 .23876 .35445 .24943 .37665 .24688 .36987 .23618 Mtetra
.36987 .23618 .37665 .24688 .39894 .24433 .39232 .23358 Mtetra
.39232 .23358 .39894 .24433 .42131 .24176 .41484 .23098 Mtetra
.41484 .23098 .42131 .24176 .44376 .23919 .43745 .22837 Mtetra
.43745 .22837 .44376 .23919 .46629 .23661 .46015 .22574 Mtetra
.46015 .22574 .46629 .23661 .48891 .23402 .48293 .22311 Mtetra
.504 .721 .97 r
.48293 .22311 .48891 .23402 .51157 .23638 .50575 .22501 Mtetra
.454 .68 .962 r
.50575 .22501 .51157 .23638 .53436 .2404 .52869 .22906 Mtetra
.471 .692 .963 r
.52869 .22906 .53436 .2404 .55728 .24382 .55177 .23252 Mtetra
.485 .701 .965 r
.55177 .23252 .55728 .24382 .58033 .24673 .57498 .23545 Mtetra
.497 .71 .966 r
.57498 .23545 .58033 .24673 .6035 .24918 .59833 .23792 Mtetra
.507 .717 .967 r
.59833 .23792 .6035 .24918 .6268 .25124 .62179 .23998 Mtetra
.516 .723 .967 r
.62179 .23998 .6268 .25124 .65022 .25294 .64538 .24169 Mtetra
.523 .729 .968 r
.64538 .24169 .65022 .25294 .67375 .25432 .66908 .24307 Mtetra
.53 .733 .968 r
.66908 .24307 .67375 .25432 .6974 .25542 .6929 .24417 Mtetra
.536 .738 .968 r
.6929 .24417 .6974 .25542 .72116 .25626 .71684 .24501 Mtetra
.541 .742 .968 r
.71684 .24501 .72116 .25626 .74503 .25687 .74089 .24561 Mtetra
.546 .745 .969 r
.74089 .24561 .74503 .25687 .769 .25728 .76504 .246 Mtetra
.55 .748 .969 r
.76504 .246 .769 .25728 .79309 .25749 .78931 .2462 Mtetra
.554 .751 .969 r
.78931 .2462 .79309 .25749 .81729 .25752 .81369 .24622 Mtetra
.557 .753 .969 r
.81369 .24622 .81729 .25752 .84159 .2574 .83818 .24608 Mtetra
.56 .756 .969 r
.83818 .24608 .84159 .2574 .866 .25713 .86277 .24579 Mtetra
.563 .758 .969 r
.86277 .24579 .866 .25713 .89051 .25672 .88748 .24536 Mtetra
.565 .76 .969 r
.88748 .24536 .89051 .25672 .91513 .25619 .91229 .24481 Mtetra
.568 .761 .969 r
.91229 .24481 .91513 .25619 .93985 .25554 .9372 .24413 Mtetra
.617 .786 .963 r
.14142 .25112 .14985 .2616 .17149 .2591 .16322 .24858 Mtetra
.16322 .24858 .17149 .2591 .19322 .25659 .18509 .24603 Mtetra
.18509 .24603 .19322 .25659 .21502 .25407 .20704 .24347 Mtetra
.20704 .24347 .21502 .25407 .2369 .25154 .22908 .2409 Mtetra
.22908 .2409 .2369 .25154 .25886 .249 .25119 .23833 Mtetra
.25119 .23833 .25886 .249 .2809 .24646 .27339 .23574 Mtetra
.27339 .23574 .2809 .24646 .30302 .2439 .29566 .23315 Mtetra
.29566 .23315 .30302 .2439 .32522 .24133 .31802 .23054 Mtetra
.31802 .23054 .32522 .24133 .34751 .23876 .34046 .22793 Mtetra
.34046 .22793 .34751 .23876 .36987 .23618 .36298 .2253 Mtetra
.36298 .2253 .36987 .23618 .39232 .23358 .38559 .22267 Mtetra
.38559 .22267 .39232 .23358 .41484 .23098 .40828 .22003 Mtetra
.40828 .22003 .41484 .23098 .43745 .22837 .43105 .21737 Mtetra
.43105 .21737 .43745 .22837 .46015 .22574 .45391 .21471 Mtetra
.45391 .21471 .46015 .22574 .48293 .22311 .47685 .21204 Mtetra
.517 .729 .97 r
.47685 .21204 .48293 .22311 .50575 .22501 .49984 .21346 Mtetra
.453 .679 .962 r
.49984 .21346 .50575 .22501 .52869 .22906 .52294 .21755 Mtetra
.47 .691 .963 r
.52294 .21755 .52869 .22906 .55177 .23252 .54618 .22104 Mtetra
.484 .701 .965 r
.54618 .22104 .55177 .23252 .57498 .23545 .56956 .22399 Mtetra
.496 .709 .966 r
.56956 .22399 .57498 .23545 .59833 .23792 .59307 .22648 Mtetra
.506 .716 .966 r
.59307 .22648 .59833 .23792 .62179 .23998 .6167 .22855 Mtetra
.515 .723 .967 r
.6167 .22855 .62179 .23998 .64538 .24169 .64046 .23027 Mtetra
.523 .728 .968 r
.64046 .23027 .64538 .24169 .66908 .24307 .66434 .23165 Mtetra
.53 .733 .968 r
.66434 .23165 .66908 .24307 .6929 .24417 .68834 .23275 Mtetra
.536 .737 .968 r
.68834 .23275 .6929 .24417 .71684 .24501 .71245 .23358 Mtetra
.541 .741 .968 r
.71245 .23358 .71684 .24501 .74089 .24561 .73668 .23417 Mtetra
.546 .745 .969 r
.73668 .23417 .74089 .24561 .76504 .246 .76102 .23455 Mtetra
.55 .748 .969 r
.76102 .23455 .76504 .246 .78931 .2462 .78548 .23473 Mtetra
.553 .751 .969 r
.78548 .23473 .78931 .2462 .81369 .24622 .81004 .23474 Mtetra
.557 .753 .969 r
.81004 .23474 .81369 .24622 .83818 .24608 .83472 .23458 Mtetra
.56 .755 .969 r
.83472 .23458 .83818 .24608 .86277 .24579 .8595 .23427 Mtetra
.563 .758 .969 r
.8595 .23427 .86277 .24579 .88748 .24536 .8844 .23382 Mtetra
.565 .759 .969 r
.8844 .23382 .88748 .24536 .91229 .24481 .9094 .23324 Mtetra
.567 .761 .969 r
.9094 .23324 .91229 .24481 .9372 .24413 .93451 .23254 Mtetra
.617 .786 .963 r
.13287 .24047 .14142 .25112 .16322 .24858 .15482 .2379 Mtetra
.15482 .2379 .16322 .24858 .18509 .24603 .17684 .23531 Mtetra
.17684 .23531 .18509 .24603 .20704 .24347 .19895 .23271 Mtetra
.19895 .23271 .20704 .24347 .22908 .2409 .22114 .2301 Mtetra
.22114 .2301 .22908 .2409 .25119 .23833 .2434 .22749 Mtetra
.2434 .22749 .25119 .23833 .27339 .23574 .26575 .22486 Mtetra
.26575 .22486 .27339 .23574 .29566 .23315 .28819 .22223 Mtetra
.28819 .22223 .29566 .23315 .31802 .23054 .3107 .21958 Mtetra
.3107 .21958 .31802 .23054 .34046 .22793 .3333 .21693 Mtetra
.3333 .21693 .34046 .22793 .36298 .2253 .35599 .21426 Mtetra
.35599 .21426 .36298 .2253 .38559 .22267 .37876 .21159 Mtetra
.37876 .21159 .38559 .22267 .40828 .22003 .40161 .2089 Mtetra
.40161 .2089 .40828 .22003 .43105 .21737 .42455 .20621 Mtetra
.42455 .20621 .43105 .21737 .45391 .21471 .44757 .2035 Mtetra
.44757 .2035 .45391 .21471 .47685 .21204 .47068 .20079 Mtetra
.529 .736 .97 r
.47068 .20079 .47685 .21204 .49984 .21346 .49384 .20173 Mtetra
.452 .678 .961 r
.49384 .20173 .49984 .21346 .52294 .21755 .5171 .20587 Mtetra
.469 .69 .963 r
.5171 .20587 .52294 .21755 .54618 .22104 .54051 .20938 Mtetra
.483 .7 .965 r
.54051 .20938 .54618 .22104 .56956 .22399 .56405 .21236 Mtetra
.495 .709 .966 r
.56405 .21236 .56956 .22399 .59307 .22648 .58773 .21486 Mtetra
.505 .716 .966 r
.58773 .21486 .59307 .22648 .6167 .22855 .61153 .21694 Mtetra
.514 .722 .967 r
.61153 .21694 .6167 .22855 .64046 .23027 .63547 .21866 Mtetra
.522 .728 .968 r
.63547 .21866 .64046 .23027 .66434 .23165 .65952 .22005 Mtetra
.529 .733 .968 r
.65952 .22005 .66434 .23165 .68834 .23275 .6837 .22114 Mtetra
.535 .737 .968 r
.6837 .22114 .68834 .23275 .71245 .23358 .70799 .22196 Mtetra
.54 .741 .968 r
.70799 .22196 .71245 .23358 .73668 .23417 .73241 .22255 Mtetra
.545 .745 .969 r
.73241 .22255 .73668 .23417 .76102 .23455 .75693 .22292 Mtetra
.549 .748 .969 r
.75693 .22292 .76102 .23455 .78548 .23473 .78157 .22308 Mtetra
.553 .75 .969 r
.78157 .22308 .78548 .23473 .81004 .23474 .80633 .22307 Mtetra
.557 .753 .969 r
.80633 .22307 .81004 .23474 .83472 .23458 .8312 .22289 Mtetra
.56 .755 .969 r
.8312 .22289 .83472 .23458 .8595 .23427 .85617 .22256 Mtetra
.562 .757 .969 r
.85617 .22256 .8595 .23427 .8844 .23382 .88127 .22209 Mtetra
.565 .759 .969 r
.88127 .22209 .8844 .23382 .9094 .23324 .90647 .22148 Mtetra
.567 .761 .969 r
.90647 .22148 .9094 .23324 .93451 .23254 .93178 .22076 Mtetra
.617 .786 .963 r
.12419 .22967 .13287 .24047 .15482 .2379 .14629 .22705 Mtetra
.14629 .22705 .15482 .2379 .17684 .23531 .16847 .22442 Mtetra
.16847 .22442 .17684 .23531 .19895 .23271 .19073 .22178 Mtetra
.19073 .22178 .19895 .23271 .22114 .2301 .21307 .21914 Mtetra
.21307 .21914 .22114 .2301 .2434 .22749 .2355 .21648 Mtetra
.2355 .21648 .2434 .22749 .26575 .22486 .25801 .21381 Mtetra
.25801 .21381 .26575 .22486 .28819 .22223 .2806 .21114 Mtetra
.2806 .21114 .28819 .22223 .3107 .21958 .30328 .20845 Mtetra
.30328 .20845 .3107 .21958 .3333 .21693 .32604 .20576 Mtetra
.32604 .20576 .3333 .21693 .35599 .21426 .34888 .20305 Mtetra
.34888 .20305 .35599 .21426 .37876 .21159 .37182 .20033 Mtetra
.37182 .20033 .37876 .21159 .40161 .2089 .39484 .1976 Mtetra
.39484 .1976 .40161 .2089 .42455 .20621 .41794 .19487 Mtetra
.41794 .19487 .42455 .20621 .44757 .2035 .44113 .19212 Mtetra
.44113 .19212 .44757 .2035 .47068 .20079 .46441 .18936 Mtetra
.541 .743 .969 r
.46441 .18936 .47068 .20079 .49384 .20173 .48775 .18982 Mtetra
.451 .678 .961 r
.48775 .18982 .49384 .20173 .5171 .20587 .51117 .19399 Mtetra
.468 .69 .963 r
.51117 .19399 .5171 .20587 .54051 .20938 .53474 .19754 Mtetra
.482 .7 .965 r
.53474 .19754 .54051 .20938 .56405 .21236 .55845 .20054 Mtetra
.494 .708 .966 r
.55845 .20054 .56405 .21236 .58773 .21486 .5823 .20305 Mtetra
.505 .716 .966 r
.5823 .20305 .58773 .21486 .61153 .21694 .60628 .20515 Mtetra
.514 .722 .967 r
.60628 .20515 .61153 .21694 .63547 .21866 .63039 .20687 Mtetra
.522 .728 .968 r
.63039 .20687 .63547 .21866 .65952 .22005 .65463 .20826 Mtetra
.529 .733 .968 r
.65463 .20826 .65952 .22005 .6837 .22114 .67899 .20934 Mtetra
.535 .737 .968 r
.67899 .20934 .6837 .22114 .70799 .22196 .70347 .21016 Mtetra
.54 .741 .968 r
.70347 .21016 .70799 .22196 .73241 .22255 .72806 .21074 Mtetra
.545 .744 .969 r
.72806 .21074 .73241 .22255 .75693 .22292 .75278 .21109 Mtetra
.549 .747 .969 r
.75278 .21109 .75693 .22292 .78157 .22308 .77761 .21124 Mtetra
.553 .75 .969 r
.77761 .21124 .78157 .22308 .80633 .22307 .80256 .21121 Mtetra
.556 .753 .969 r
.80256 .21121 .80633 .22307 .8312 .22289 .82762 .21101 Mtetra
.56 .755 .969 r
.82762 .21101 .8312 .22289 .85617 .22256 .85279 .21066 Mtetra
.562 .757 .969 r
.85279 .21066 .85617 .22256 .88127 .22209 .87808 .21016 Mtetra
.565 .759 .969 r
.87808 .21016 .88127 .22209 .90647 .22148 .90348 .20954 Mtetra
.567 .761 .969 r
.90348 .20954 .90647 .22148 .93178 .22076 .929 .20878 Mtetra
.617 .786 .963 r
.11538 .21869 .12419 .22967 .14629 .22705 .13763 .21604 Mtetra
.13763 .21604 .14629 .22705 .16847 .22442 .15996 .21337 Mtetra
.15996 .21337 .16847 .22442 .19073 .22178 .18238 .21069 Mtetra
.18238 .21069 .19073 .22178 .21307 .21914 .20488 .208 Mtetra
.20488 .208 .21307 .21914 .2355 .21648 .22747 .2053 Mtetra
.22747 .2053 .2355 .21648 .25801 .21381 .25014 .20259 Mtetra
.25014 .20259 .25801 .21381 .2806 .21114 .27289 .19988 Mtetra
.27289 .19988 .2806 .21114 .30328 .20845 .29573 .19715 Mtetra
.29573 .19715 .30328 .20845 .32604 .20576 .31866 .19441 Mtetra
.31866 .19441 .32604 .20576 .34888 .20305 .34167 .19166 Mtetra
.34167 .19166 .34888 .20305 .37182 .20033 .36477 .1889 Mtetra
.36477 .1889 .37182 .20033 .39484 .1976 .38796 .18613 Mtetra
.38796 .18613 .39484 .1976 .41794 .19487 .41123 .18335 Mtetra
.41123 .18335 .41794 .19487 .44113 .19212 .4346 .18056 Mtetra
.4346 .18056 .44113 .19212 .46441 .18936 .45805 .17776 Mtetra
.552 .75 .969 r
.45805 .17776 .46441 .18936 .48775 .18982 .48156 .17772 Mtetra
.449 .677 .961 r
.48156 .17772 .48775 .18982 .51117 .19399 .50514 .18193 Mtetra
.467 .689 .963 r
.50514 .18193 .51117 .19399 .53474 .19754 .52888 .18551 Mtetra
.481 .699 .965 r
.52888 .18551 .53474 .19754 .55845 .20054 .55277 .18853 Mtetra
.494 .708 .966 r
.55277 .18853 .55845 .20054 .5823 .20305 .57679 .19106 Mtetra
.504 .715 .966 r
.57679 .19106 .5823 .20305 .60628 .20515 .60095 .19317 Mtetra
.513 .722 .967 r
.60095 .19317 .60628 .20515 .63039 .20687 .62524 .19489 Mtetra
.521 .727 .967 r
.62524 .19489 .63039 .20687 .65463 .20826 .64966 .19628 Mtetra
.528 .732 .968 r
.64966 .19628 .65463 .20826 .67899 .20934 .6742 .19736 Mtetra
.534 .737 .968 r
.6742 .19736 .67899 .20934 .70347 .21016 .69886 .19817 Mtetra
.54 .741 .968 r
.69886 .19817 .70347 .21016 .72806 .21074 .72365 .19873 Mtetra
.545 .744 .969 r
.72365 .19873 .72806 .21074 .75278 .21109 .74856 .19907 Mtetra
.549 .747 .969 r
.74856 .19907 .75278 .21109 .77761 .21124 .77358 .19921 Mtetra
.553 .75 .969 r
.77358 .19921 .77761 .21124 .80256 .21121 .79872 .19916 Mtetra
.556 .753 .969 r
.79872 .19916 .80256 .21121 .82762 .21101 .82398 .19894 Mtetra
.559 .755 .969 r
.82398 .19894 .82762 .21101 .85279 .21066 .84936 .19856 Mtetra
.562 .757 .969 r
.84936 .19856 .85279 .21066 .87808 .21016 .87485 .19804 Mtetra
.565 .759 .969 r
.87485 .19804 .87808 .21016 .90348 .20954 .90045 .19739 Mtetra
.567 .761 .969 r
.90045 .19739 .90348 .20954 .929 .20878 .92617 .19661 Mtetra
.617 .786 .963 r
.10642 .20755 .11538 .21869 .13763 .21604 .12883 .20485 Mtetra
.12883 .20485 .13763 .21604 .15996 .21337 .15132 .20214 Mtetra
.15132 .20214 .15996 .21337 .18238 .21069 .1739 .19942 Mtetra
.1739 .19942 .18238 .21069 .20488 .208 .19656 .19669 Mtetra
.19656 .19669 .20488 .208 .22747 .2053 .21931 .19395 Mtetra
.21931 .19395 .22747 .2053 .25014 .20259 .24214 .1912 Mtetra
.24214 .1912 .25014 .20259 .27289 .19988 .26506 .18844 Mtetra
.26506 .18844 .27289 .19988 .29573 .19715 .28807 .18566 Mtetra
.28807 .18566 .29573 .19715 .31866 .19441 .31116 .18288 Mtetra
.31116 .18288 .31866 .19441 .34167 .19166 .33434 .18009 Mtetra
.33434 .18009 .34167 .19166 .36477 .1889 .35761 .17729 Mtetra
.35761 .17729 .36477 .1889 .38796 .18613 .38097 .17447 Mtetra
.38097 .17447 .38796 .18613 .41123 .18335 .40441 .17165 Mtetra
.40441 .17165 .41123 .18335 .4346 .18056 .42795 .16881 Mtetra
.42795 .16881 .4346 .18056 .45805 .17776 .45158 .16596 Mtetra
.564 .757 .968 r
.45158 .16596 .45805 .17776 .48156 .17772 .47527 .16543 Mtetra
.448 .676 .961 r
.47527 .16543 .48156 .17772 .50514 .18193 .49902 .16968 Mtetra
.466 .688 .963 r
.49902 .16968 .50514 .18193 .52888 .18551 .52293 .17329 Mtetra
.48 .699 .965 r
.52293 .17329 .52888 .18551 .55277 .18853 .54699 .17633 Mtetra
.493 .707 .966 r
.54699 .17633 .55277 .18853 .57679 .19106 .57119 .17887 Mtetra
.504 .715 .966 r
.57119 .17887 .57679 .19106 .60095 .19317 .59553 .18099 Mtetra
.513 .721 .967 r
.59553 .18099 .60095 .19317 .62524 .19489 .62 .18272 Mtetra
.521 .727 .967 r
.62 .18272 .62524 .19489 .64966 .19628 .6446 .1841 Mtetra
.528 .732 .968 r
.6446 .1841 .64966 .19628 .6742 .19736 .66933 .18518 Mtetra
.534 .736 .968 r
.66933 .18518 .6742 .19736 .69886 .19817 .69419 .18598 Mtetra
.539 .74 .968 r
.69419 .18598 .69886 .19817 .72365 .19873 .71917 .18653 Mtetra
.544 .744 .969 r
.71917 .18653 .72365 .19873 .74856 .19907 .74427 .18686 Mtetra
.549 .747 .969 r
.74427 .18686 .74856 .19907 .77358 .19921 .76949 .18698 Mtetra
.553 .75 .969 r
.76949 .18698 .77358 .19921 .79872 .19916 .79483 .18691 Mtetra
.556 .753 .969 r
.79483 .18691 .79872 .19916 .82398 .19894 .82029 .18667 Mtetra
.559 .755 .969 r
.82029 .18667 .82398 .19894 .84936 .19856 .84586 .18627 Mtetra
.562 .757 .969 r
.84586 .18627 .84936 .19856 .87485 .19804 .87156 .18572 Mtetra
.565 .759 .969 r
.87156 .18572 .87485 .19804 .90045 .19739 .89737 .18504 Mtetra
.567 .761 .969 r
.89737 .18504 .90045 .19739 .92617 .19661 .9233 .18423 Mtetra
.617 .786 .963 r
.09733 .19623 .10642 .20755 .12883 .20485 .1199 .19349 Mtetra
.1199 .19349 .12883 .20485 .15132 .20214 .14255 .19074 Mtetra
.14255 .19074 .15132 .20214 .1739 .19942 .16529 .18797 Mtetra
.16529 .18797 .1739 .19942 .19656 .19669 .18811 .1852 Mtetra
.18811 .1852 .19656 .19669 .21931 .19395 .21102 .18242 Mtetra
.21102 .18242 .21931 .19395 .24214 .1912 .23402 .17962 Mtetra
.23402 .17962 .24214 .1912 .26506 .18844 .25711 .17682 Mtetra
.25711 .17682 .26506 .18844 .28807 .18566 .28028 .174 Mtetra
.28028 .174 .28807 .18566 .31116 .18288 .30354 .17117 Mtetra
.30354 .17117 .31116 .18288 .33434 .18009 .32689 .16833 Mtetra
.32689 .16833 .33434 .18009 .35761 .17729 .35033 .16549 Mtetra
.35033 .16549 .35761 .17729 .38097 .17447 .37387 .16263 Mtetra
.37387 .16263 .38097 .17447 .40441 .17165 .39749 .15976 Mtetra
.39749 .15976 .40441 .17165 .42795 .16881 .4212 .15687 Mtetra
.4212 .15687 .42795 .16881 .45158 .16596 .44501 .15398 Mtetra
.575 .763 .968 r
.44501 .15398 .45158 .16596 .47527 .16543 .46888 .15295 Mtetra
.447 .675 .961 r
.46888 .15295 .47527 .16543 .49902 .16968 .4928 .15723 Mtetra
.465 .688 .963 r
.4928 .15723 .49902 .16968 .52293 .17329 .51688 .16087 Mtetra
.479 .698 .964 r
.51688 .16087 .52293 .17329 .54699 .17633 .54112 .16393 Mtetra
.492 .707 .966 r
.54112 .16393 .54699 .17633 .57119 .17887 .5655 .16649 Mtetra
.503 .714 .966 r
.5655 .16649 .57119 .17887 .59553 .18099 .59002 .16861 Mtetra
.512 .721 .967 r
.59002 .16861 .59553 .18099 .62 .18272 .61468 .17034 Mtetra
.52 .727 .967 r
.61468 .17034 .62 .18272 .6446 .1841 .63946 .17173 Mtetra
.527 .732 .968 r
.63946 .17173 .6446 .1841 .66933 .18518 .66438 .1728 Mtetra
.534 .736 .968 r
.66438 .1728 .66933 .18518 .69419 .18598 .68943 .17359 Mtetra
.539 .74 .968 r
.68943 .17359 .69419 .18598 .71917 .18653 .71461 .17413 Mtetra
.544 .744 .969 r
.71461 .17413 .71917 .18653 .74427 .18686 .7399 .17444 Mtetra
.548 .747 .969 r
.7399 .17444 .74427 .18686 .76949 .18698 .76532 .17454 Mtetra
.552 .75 .969 r
.76532 .17454 .76949 .18698 .79483 .18691 .79087 .17445 Mtetra
.556 .752 .969 r
.79087 .17445 .79483 .18691 .82029 .18667 .81653 .17419 Mtetra
.559 .755 .969 r
.81653 .17419 .82029 .18667 .84586 .18627 .84231 .17376 Mtetra
.562 .757 .969 r
.84231 .17376 .84586 .18627 .87156 .18572 .86821 .17319 Mtetra
.564 .759 .969 r
.86821 .17319 .87156 .18572 .89737 .18504 .89424 .17248 Mtetra
.567 .761 .969 r
.89424 .17248 .89737 .18504 .9233 .18423 .92038 .17164 Mtetra
.617 .786 .963 r
.0881 .18473 .09733 .19623 .1199 .19349 .11082 .18195 Mtetra
.11082 .18195 .1199 .19349 .14255 .19074 .13364 .17915 Mtetra
.13364 .17915 .14255 .19074 .16529 .18797 .15654 .17634 Mtetra
.15654 .17634 .16529 .18797 .18811 .1852 .17953 .17353 Mtetra
.17953 .17353 .18811 .1852 .21102 .18242 .2026 .1707 Mtetra
.2026 .1707 .21102 .18242 .23402 .17962 .22577 .16786 Mtetra
.22577 .16786 .23402 .17962 .25711 .17682 .24902 .16501 Mtetra
.24902 .16501 .25711 .17682 .28028 .174 .27237 .16215 Mtetra
.27237 .16215 .28028 .174 .30354 .17117 .2958 .15927 Mtetra
.2958 .15927 .30354 .17117 .32689 .16833 .31933 .15639 Mtetra
.31933 .15639 .32689 .16833 .35033 .16549 .34294 .1535 Mtetra
.34294 .1535 .35033 .16549 .37387 .16263 .36665 .15059 Mtetra
.36665 .15059 .37387 .16263 .39749 .15976 .39045 .14767 Mtetra
.39045 .14767 .39749 .15976 .4212 .15687 .41434 .14474 Mtetra
.41434 .14474 .4212 .15687 .44501 .15398 .43833 .1418 Mtetra
.586 .769 .967 r
.43833 .1418 .44501 .15398 .46888 .15295 .46238 .14026 Mtetra
.446 .674 .961 r
.46238 .14026 .46888 .15295 .4928 .15723 .48648 .14458 Mtetra
.463 .687 .963 r
.48648 .14458 .4928 .15723 .51688 .16087 .51074 .14824 Mtetra
.479 .697 .964 r
.51074 .14824 .51688 .16087 .54112 .16393 .53515 .15133 Mtetra
.491 .706 .966 r
.53515 .15133 .54112 .16393 .5655 .16649 .55971 .1539 Mtetra
.502 .714 .966 r
.55971 .1539 .5655 .16649 .59002 .16861 .58442 .15603 Mtetra
.512 .721 .967 r
.58442 .15603 .59002 .16861 .61468 .17034 .60926 .15776 Mtetra
.52 .726 .967 r
.60926 .15776 .61468 .17034 .63946 .17173 .63424 .15915 Mtetra
.527 .731 .968 r
.63424 .15915 .63946 .17173 .66438 .1728 .65936 .16021 Mtetra
.533 .736 .968 r
.65936 .16021 .66438 .1728 .68943 .17359 .6846 .16099 Mtetra
.539 .74 .968 r
.6846 .16099 .68943 .17359 .71461 .17413 .70997 .16152 Mtetra
.544 .744 .969 r
.70997 .16152 .71461 .17413 .7399 .17444 .73547 .16181 Mtetra
.548 .747 .969 r
.73547 .16181 .7399 .17444 .76532 .17454 .76109 .16189 Mtetra
.552 .75 .969 r
.76109 .16189 .76532 .17454 .79087 .17445 .78684 .16178 Mtetra
.556 .752 .969 r
.78684 .16178 .79087 .17445 .81653 .17419 .81271 .1615 Mtetra
.559 .755 .969 r
.81271 .1615 .81653 .17419 .84231 .17376 .8387 .16105 Mtetra
.562 .757 .969 r
.8387 .16105 .84231 .17376 .86821 .17319 .86481 .16045 Mtetra
.564 .759 .969 r
.86481 .16045 .86821 .17319 .89424 .17248 .89105 .15971 Mtetra
.567 .761 .969 r
.89105 .15971 .89424 .17248 .92038 .17164 .91741 .15884 Mtetra
.617 .786 .963 r
.07871 .17305 .0881 .18473 .11082 .18195 .1016 .17022 Mtetra
.1016 .17022 .11082 .18195 .13364 .17915 .12458 .16738 Mtetra
.12458 .16738 .13364 .17915 .15654 .17634 .14765 .16453 Mtetra
.14765 .16453 .15654 .17634 .17953 .17353 .17081 .16167 Mtetra
.17081 .16167 .17953 .17353 .2026 .1707 .19405 .15879 Mtetra
.19405 .15879 .2026 .1707 .22577 .16786 .21739 .15591 Mtetra
.21739 .15591 .22577 .16786 .24902 .16501 .24081 .15301 Mtetra
.24081 .15301 .24902 .16501 .27237 .16215 .26433 .1501 Mtetra
.26433 .1501 .27237 .16215 .2958 .15927 .28794 .14718 Mtetra
.28794 .14718 .2958 .15927 .31933 .15639 .31164 .14425 Mtetra
.31164 .14425 .31933 .15639 .34294 .1535 .33543 .14131 Mtetra
.33543 .14131 .34294 .1535 .36665 .15059 .35932 .13836 Mtetra
.35932 .13836 .36665 .15059 .39045 .14767 .3833 .13539 Mtetra
.3833 .13539 .39045 .14767 .41434 .14474 .40737 .13241 Mtetra
.40737 .13241 .41434 .14474 .43833 .1418 .43154 .12943 Mtetra
.596 .775 .965 r
.43154 .12943 .43833 .1418 .46238 .14026 .45578 .12736 Mtetra
.444 .673 .961 r
.45578 .12736 .46238 .14026 .48648 .14458 .48005 .13173 Mtetra
.462 .686 .963 r
.48005 .13173 .48648 .14458 .51074 .14824 .50449 .13542 Mtetra
.478 .697 .964 r
.50449 .13542 .51074 .14824 .53515 .15133 .52909 .13852 Mtetra
.491 .706 .965 r
.52909 .13852 .53515 .15133 .55971 .1539 .55383 .14111 Mtetra
.502 .714 .966 r
.55383 .14111 .55971 .1539 .58442 .15603 .57873 .14324 Mtetra
.511 .72 .967 r
.57873 .14324 .58442 .15603 .60926 .15776 .60376 .14498 Mtetra
.519 .726 .967 r
.60376 .14498 .60926 .15776 .63424 .15915 .62893 .14636 Mtetra
.527 .731 .968 r
.62893 .14636 .63424 .15915 .65936 .16021 .65424 .14741 Mtetra
.533 .736 .968 r
.65424 .14741 .65936 .16021 .6846 .16099 .67968 .14818 Mtetra
.538 .74 .968 r
.67968 .14818 .6846 .16099 .70997 .16152 .70526 .1487 Mtetra
.543 .743 .969 r
.70526 .1487 .70997 .16152 .73547 .16181 .73096 .14897 Mtetra
.548 .747 .969 r
.73096 .14897 .73547 .16181 .76109 .16189 .75678 .14904 Mtetra
.552 .749 .969 r
.75678 .14904 .76109 .16189 .78684 .16178 .78274 .1489 Mtetra
.555 .752 .969 r
.78274 .1489 .78684 .16178 .81271 .1615 .80882 .14859 Mtetra
.559 .754 .969 r
.80882 .14859 .81271 .1615 .8387 .16105 .83502 .14811 Mtetra
.561 .757 .969 r
.83502 .14811 .8387 .16105 .86481 .16045 .86135 .14748 Mtetra
.564 .759 .969 r
.86135 .14748 .86481 .16045 .89105 .15971 .88781 .14671 Mtetra
.566 .761 .969 r
.88781 .14671 .89105 .15971 .91741 .15884 .91438 .14581 Mtetra
.617 .786 .963 r
.06918 .16119 .07871 .17305 .1016 .17022 .09223 .15831 Mtetra
.09223 .15831 .1016 .17022 .12458 .16738 .11538 .15542 Mtetra
.11538 .15542 .12458 .16738 .14765 .16453 .13862 .15252 Mtetra
.13862 .15252 .14765 .16453 .17081 .16167 .16194 .14961 Mtetra
.16194 .14961 .17081 .16167 .19405 .15879 .18536 .14669 Mtetra
.18536 .14669 .19405 .15879 .21739 .15591 .20887 .14376 Mtetra
.20887 .14376 .21739 .15591 .24081 .15301 .23247 .14082 Mtetra
.23247 .14082 .24081 .15301 .26433 .1501 .25616 .13786 Mtetra
.25616 .13786 .26433 .1501 .28794 .14718 .27994 .13489 Mtetra
.27994 .13489 .28794 .14718 .31164 .14425 .30382 .13192 Mtetra
.30382 .13192 .31164 .14425 .33543 .14131 .3278 .12892 Mtetra
.3278 .12892 .33543 .14131 .35932 .13836 .35186 .12592 Mtetra
.35186 .12592 .35932 .13836 .3833 .13539 .37602 .12291 Mtetra
.37602 .12291 .3833 .13539 .40737 .13241 .40028 .11988 Mtetra
.40028 .11988 .40737 .13241 .43154 .12943 .42464 .11684 Mtetra
.607 .781 .964 r
.42464 .11684 .43154 .12943 .45578 .12736 .44908 .11426 Mtetra
.443 .673 .961 r
.44908 .11426 .45578 .12736 .48005 .13173 .47352 .11866 Mtetra
.461 .685 .963 r
.47352 .11866 .48005 .13173 .50449 .13542 .49814 .12238 Mtetra
.477 .696 .964 r
.49814 .12238 .50449 .13542 .52909 .13852 .52292 .1255 Mtetra
.49 .705 .965 r
.52292 .1255 .52909 .13852 .55383 .14111 .54785 .1281 Mtetra
.501 .713 .966 r
.54785 .1281 .55383 .14111 .57873 .14324 .57294 .13024 Mtetra
.511 .72 .967 r
.57294 .13024 .57873 .14324 .60376 .14498 .59817 .13198 Mtetra
.519 .726 .967 r
.59817 .13198 .60376 .14498 .62893 .14636 .62353 .13335 Mtetra
.526 .731 .968 r
.62353 .13335 .62893 .14636 .65424 .14741 .64904 .1344 Mtetra
.532 .735 .968 r
.64904 .1344 .65424 .14741 .67968 .14818 .67468 .13516 Mtetra
.538 .739 .968 r
.67468 .13516 .67968 .14818 .70526 .1487 .70046 .13566 Mtetra
.543 .743 .969 r
.70046 .13566 .70526 .1487 .73096 .14897 .72637 .13591 Mtetra
.548 .746 .969 r
.72637 .13591 .73096 .14897 .75678 .14904 .75241 .13596 Mtetra
.552 .749 .969 r
.75241 .13596 .75678 .14904 .78274 .1489 .77857 .1358 Mtetra
.555 .752 .969 r
.77857 .1358 .78274 .1489 .80882 .14859 .80487 .13546 Mtetra
.558 .754 .969 r
.80487 .13546 .80882 .14859 .83502 .14811 .83129 .13496 Mtetra
.561 .757 .969 r
.83129 .13496 .83502 .14811 .86135 .14748 .85783 .1343 Mtetra
.564 .759 .969 r
.85783 .1343 .86135 .14748 .88781 .14671 .88451 .1335 Mtetra
.566 .76 .969 r
.88451 .1335 .88781 .14671 .91438 .14581 .91131 .13256 Mtetra
.617 .786 .963 r
.05949 .14913 .06918 .16119 .09223 .15831 .08271 .1462 Mtetra
.08271 .1462 .09223 .15831 .11538 .15542 .10603 .14327 Mtetra
.10603 .14327 .11538 .15542 .13862 .15252 .12944 .14032 Mtetra
.12944 .14032 .13862 .15252 .16194 .14961 .15293 .13737 Mtetra
.15293 .13737 .16194 .14961 .18536 .14669 .17653 .1344 Mtetra
.17653 .1344 .18536 .14669 .20887 .14376 .20021 .13142 Mtetra
.20021 .13142 .20887 .14376 .23247 .14082 .22398 .12842 Mtetra
.22398 .12842 .23247 .14082 .25616 .13786 .24785 .12542 Mtetra
.24785 .12542 .25616 .13786 .27994 .13489 .27182 .1224 Mtetra
.27182 .1224 .27994 .13489 .30382 .13192 .29588 .11937 Mtetra
.29588 .11937 .30382 .13192 .3278 .12892 .32003 .11633 Mtetra
.32003 .11633 .3278 .12892 .35186 .12592 .34428 .11328 Mtetra
.34428 .11328 .35186 .12592 .37602 .12291 .36863 .11022 Mtetra
.36863 .11022 .37602 .12291 .40028 .11988 .39308 .10714 Mtetra
.39308 .10714 .40028 .11988 .42464 .11684 .41762 .10405 Mtetra
.41762 .10405 .42464 .11684 .44908 .11426 .44226 .10095 Mtetra
.442 .672 .961 r
.44226 .10095 .44908 .11426 .47352 .11866 .46689 .10537 Mtetra
.46 .685 .963 r
.46689 .10537 .47352 .11866 .49814 .12238 .49169 .10912 Mtetra
.476 .696 .964 r
.49169 .10912 .49814 .12238 .52292 .1255 .51665 .11226 Mtetra
.489 .705 .965 r
.51665 .11226 .52292 .1255 .54785 .1281 .54177 .11487 Mtetra
.5 .713 .966 r
.54177 .11487 .54785 .1281 .57294 .13024 .56705 .11702 Mtetra
.51 .719 .967 r
.56705 .11702 .57294 .13024 .59817 .13198 .59248 .11876 Mtetra
.518 .725 .967 r
.59248 .11876 .59817 .13198 .62353 .13335 .61804 .12012 Mtetra
.526 .731 .968 r
.61804 .12012 .62353 .13335 .64904 .1344 .64375 .12117 Mtetra
.532 .735 .968 r
.64375 .12117 .64904 .1344 .67468 .13516 .6696 .12191 Mtetra
.538 .739 .968 r
.6696 .12191 .67468 .13516 .70046 .13566 .69558 .12239 Mtetra
.543 .743 .969 r
.69558 .12239 .70046 .13566 .72637 .13591 .7217 .12263 Mtetra
.547 .746 .969 r
.7217 .12263 .72637 .13591 .75241 .13596 .74795 .12265 Mtetra
.551 .749 .969 r
.74795 .12265 .75241 .13596 .77857 .1358 .77433 .12247 Mtetra
.555 .752 .969 r
.77433 .12247 .77857 .1358 .80487 .13546 .80084 .12211 Mtetra
.558 .754 .969 r
.80084 .12211 .80487 .13546 .83129 .13496 .82748 .12157 Mtetra
.561 .756 .969 r
.82748 .12157 .83129 .13496 .85783 .1343 .85425 .12088 Mtetra
.564 .758 .969 r
.85425 .12088 .85783 .1343 .88451 .1335 .88115 .12005 Mtetra
.566 .76 .969 r
.88115 .12005 .88451 .1335 .91131 .13256 .90818 .11908 Mtetra
.617 .786 .963 r
.04964 .13687 .05949 .14913 .08271 .1462 .07304 .1339 Mtetra
.07304 .1339 .08271 .1462 .10603 .14327 .09653 .13092 Mtetra
.09653 .13092 .10603 .14327 .12944 .14032 .12011 .12792 Mtetra
.12011 .12792 .12944 .14032 .15293 .13737 .14378 .12492 Mtetra
.14378 .12492 .15293 .13737 .17653 .1344 .16755 .1219 Mtetra
.16755 .1219 .17653 .1344 .20021 .13142 .19141 .11887 Mtetra
.19141 .11887 .20021 .13142 .22398 .12842 .21536 .11582 Mtetra
.21536 .11582 .22398 .12842 .24785 .12542 .23941 .11277 Mtetra
.23941 .11277 .24785 .12542 .27182 .1224 .26356 .1097 Mtetra
.26356 .1097 .27182 .1224 .29588 .11937 .2878 .10663 Mtetra
.2878 .10663 .29588 .11937 .32003 .11633 .31214 .10354 Mtetra
.31214 .10354 .32003 .11633 .34428 .11328 .33658 .10043 Mtetra
.33658 .10043 .34428 .11328 .36863 .11022 .36112 .09732 Mtetra
.36112 .09732 .36863 .11022 .39308 .10714 .38575 .09419 Mtetra
.38575 .09419 .39308 .10714 .41762 .10405 .41048 .09105 Mtetra
.41048 .09105 .41762 .10405 .44226 .10095 .43532 .08789 Mtetra
.444 .682 .966 r
.43532 .08789 .44226 .10095 .46689 .10537 .46014 .09187 Mtetra
.459 .684 .963 r
.46014 .09187 .46689 .10537 .49169 .10912 .48512 .09564 Mtetra
.475 .695 .964 r
.48512 .09564 .49169 .10912 .51665 .11226 .51028 .0988 Mtetra
.488 .704 .965 r
.51028 .0988 .51665 .11226 .54177 .11487 .53559 .10142 Mtetra
.5 .712 .966 r
.53559 .10142 .54177 .11487 .56705 .11702 .56107 .10357 Mtetra
.509 .719 .967 r
.56107 .10357 .56705 .11702 .59248 .11876 .58669 .10531 Mtetra
.518 .725 .967 r
.58669 .10531 .59248 .11876 .61804 .12012 .61246 .10667 Mtetra
.525 .73 .968 r
.61246 .10667 .61804 .12012 .64375 .12117 .63837 .1077 Mtetra
.532 .735 .968 r
.63837 .1077 .64375 .12117 .6696 .12191 .66443 .10844 Mtetra
.537 .739 .968 r
.66443 .10844 .6696 .12191 .69558 .12239 .69062 .1089 Mtetra
.542 .743 .969 r
.69062 .1089 .69558 .12239 .7217 .12263 .71695 .10912 Mtetra
.547 .746 .969 r
.71695 .10912 .7217 .12263 .74795 .12265 .74342 .10912 Mtetra
.551 .749 .969 r
.74342 .10912 .74795 .12265 .77433 .12247 .77002 .10891 Mtetra
.555 .752 .969 r
.77002 .10891 .77433 .12247 .80084 .12211 .79675 .10852 Mtetra
.558 .754 .969 r
.79675 .10852 .80084 .12211 .82748 .12157 .82362 .10795 Mtetra
.561 .756 .969 r
.82362 .10795 .82748 .12157 .85425 .12088 .85061 .10723 Mtetra
.564 .758 .969 r
.85061 .10723 .85425 .12088 .88115 .12005 .87774 .10636 Mtetra
.566 .76 .969 r
.87774 .10636 .88115 .12005 .90818 .11908 .90499 .10536 Mtetra
.617 .786 .963 r
.03963 .12441 .04964 .13687 .07304 .1339 .0632 .12139 Mtetra
.0632 .12139 .07304 .1339 .09653 .13092 .08686 .11836 Mtetra
.08686 .11836 .09653 .13092 .12011 .12792 .11062 .11531 Mtetra
.11062 .11531 .12011 .12792 .14378 .12492 .13447 .11226 Mtetra
.13447 .11226 .14378 .12492 .16755 .1219 .15842 .10919 Mtetra
.15842 .10919 .16755 .1219 .19141 .11887 .18246 .10611 Mtetra
.18246 .10611 .19141 .11887 .21536 .11582 .2066 .10302 Mtetra
.2066 .10302 .21536 .11582 .23941 .11277 .23083 .09991 Mtetra
.23083 .09991 .23941 .11277 .26356 .1097 .25516 .09679 Mtetra
.25516 .09679 .26356 .1097 .2878 .10663 .27959 .09366 Mtetra
.27959 .09366 .2878 .10663 .31214 .10354 .30412 .09052 Mtetra
.30412 .09052 .31214 .10354 .33658 .10043 .32875 .08736 Mtetra
.32875 .08736 .33658 .10043 .36112 .09732 .35347 .0842 Mtetra
.35347 .0842 .36112 .09732 .38575 .09419 .3783 .08101 Mtetra
.3783 .08101 .38575 .09419 .41048 .09105 .40323 .07782 Mtetra
.40323 .07782 .41048 .09105 .43532 .08789 .42826 .07461 Mtetra
.456 .69 .967 r
.42826 .07461 .43532 .08789 .46014 .09187 .45327 .07813 Mtetra
.458 .683 .963 r
.45327 .07813 .46014 .09187 .48512 .09564 .47845 .08193 Mtetra
.474 .694 .964 r
.47845 .08193 .48512 .09564 .51028 .0988 .50379 .08511 Mtetra
.487 .704 .965 r
.50379 .08511 .51028 .0988 .53559 .10142 .52931 .08774 Mtetra
.499 .712 .966 r
.52931 .08774 .53559 .10142 .56107 .10357 .55498 .0899 Mtetra
.509 .719 .967 r
.55498 .0899 .56107 .10357 .58669 .10531 .5808 .09163 Mtetra
.517 .725 .967 r
.5808 .09163 .58669 .10531 .61246 .10667 .60678 .09299 Mtetra
.525 .73 .968 r
.60678 .09299 .61246 .10667 .63837 .1077 .6329 .09401 Mtetra
.531 .735 .968 r
.6329 .09401 .63837 .1077 .66443 .10844 .65917 .09473 Mtetra
.537 .739 .968 r
.65917 .09473 .66443 .10844 .69062 .1089 .68558 .09517 Mtetra
.542 .743 .969 r
.68558 .09517 .69062 .1089 .71695 .10912 .71212 .09537 Mtetra
.547 .746 .969 r
.71212 .09537 .71695 .10912 .74342 .10912 .73881 .09534 Mtetra
.551 .749 .969 r
.73881 .09534 .74342 .10912 .77002 .10891 .76563 .09511 Mtetra
.554 .751 .969 r
.76563 .09511 .77002 .10891 .79675 .10852 .79259 .09469 Mtetra
.558 .754 .969 r
.79259 .09469 .79675 .10852 .82362 .10795 .81968 .09409 Mtetra
.561 .756 .969 r
.81968 .09409 .82362 .10795 .85061 .10723 .8469 .09334 Mtetra
.563 .758 .969 r
.8469 .09334 .85061 .10723 .87774 .10636 .87426 .09244 Mtetra
.566 .76 .969 r
.87426 .09244 .87774 .10636 .90499 .10536 .90175 .0914 Mtetra
.617 .786 .963 r
.02946 .11175 .03963 .12441 .0632 .12139 .0532 .10868 Mtetra
.0532 .10868 .0632 .12139 .08686 .11836 .07704 .10559 Mtetra
.07704 .10559 .08686 .11836 .11062 .11531 .10098 .1025 Mtetra
.10098 .1025 .11062 .11531 .13447 .11226 .12501 .09939 Mtetra
.12501 .09939 .13447 .11226 .15842 .10919 .14914 .09627 Mtetra
.14914 .09627 .15842 .10919 .18246 .10611 .17336 .09314 Mtetra
.17336 .09314 .18246 .10611 .2066 .10302 .19768 .08999 Mtetra
.19768 .08999 .2066 .10302 .23083 .09991 .2221 .08683 Mtetra
.2221 .08683 .23083 .09991 .25516 .09679 .24662 .08366 Mtetra
.24662 .08366 .25516 .09679 .27959 .09366 .27124 .08048 Mtetra
.27124 .08048 .27959 .09366 .30412 .09052 .29596 .07728 Mtetra
.29596 .07728 .30412 .09052 .32875 .08736 .32078 .07407 Mtetra
.32078 .07407 .32875 .08736 .35347 .0842 .3457 .07085 Mtetra
.3457 .07085 .35347 .0842 .3783 .08101 .37072 .06762 Mtetra
.37072 .06762 .3783 .08101 .40323 .07782 .39585 .06437 Mtetra
.39585 .06437 .40323 .07782 .42826 .07461 .42108 .0611 Mtetra
.468 .698 .968 r
.42108 .0611 .42826 .07461 .45327 .07813 .44629 .06416 Mtetra
.457 .683 .962 r
.44629 .06416 .45327 .07813 .47845 .08193 .47166 .06798 Mtetra
.473 .694 .964 r
.47166 .06798 .47845 .08193 .50379 .08511 .4972 .07118 Mtetra
.487 .703 .965 r
.4972 .07118 .50379 .08511 .52931 .08774 .52291 .07382 Mtetra
.498 .711 .966 r
.52291 .07382 .52931 .08774 .55498 .0899 .54878 .07598 Mtetra
.508 .718 .967 r
.54878 .07598 .55498 .0899 .5808 .09163 .57482 .07772 Mtetra
.517 .724 .967 r
.57482 .07772 .5808 .09163 .60678 .09299 .601 .07907 Mtetra
.524 .73 .968 r
.601 .07907 .60678 .09299 .6329 .09401 .62733 .08007 Mtetra
.531 .734 .968 r
.62733 .08007 .6329 .09401 .65917 .09473 .65382 .08078 Mtetra
.537 .739 .968 r
.65382 .08078 .65917 .09473 .68558 .09517 .68044 .0812 Mtetra
.542 .742 .969 r
.68044 .0812 .68558 .09517 .71212 .09537 .70721 .08138 Mtetra
.546 .746 .969 r
.70721 .08138 .71212 .09537 .73881 .09534 .73412 .08133 Mtetra
.551 .749 .969 r
.73412 .08133 .73881 .09534 .76563 .09511 .76116 .08106 Mtetra
.554 .751 .969 r
.76116 .08106 .76563 .09511 .79259 .09469 .78835 .08061 Mtetra
.558 .754 .969 r
.78835 .08061 .79259 .09469 .81968 .09409 .81567 .07999 Mtetra
.561 .756 .969 r
.81567 .07999 .81968 .09409 .8469 .09334 .84313 .0792 Mtetra
.563 .758 .969 r
.84313 .0792 .8469 .09334 .87426 .09244 .87072 .07826 Mtetra
.566 .76 .969 r
.87072 .07826 .87426 .09244 .90175 .0914 .89845 .07718 Mtetra
0 g
.89362 0 m
.98022 .38351 L
s
.98022 .38351 m
1 .65325 L
s
1 .65325 m
.91448 .33294 L
s
.91448 .33294 m
.89362 0 L
s
.02946 .11175 m
0 .4272 L
s
0 .4272 m
.91448 .33294 L
s
.91448 .33294 m
.89362 0 L
s
.89362 0 m
.02946 .11175 L
s
.02946 .11175 m
.89362 0 L
s
gsave
.44797 -0.02478 -65.9056 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(u) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
0 .4272 m
.29069 .70824 L
s
gsave
.15892 .66839 -66.3192 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(p) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{261.5, 185.125},
  ImageMargins->{{29.5, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2104,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000450000^A000`40O003h00Oogoo1Woo003oOol6
Ool00?moo`Ioo`00ogoo1Woo003oOol6Ool00?moo`Ioo`00PWoo1000Ogoo0021Ool01000Oomoo`00
P7oo0021Ool01000Oomoo`00P7oo0020Ool200000goo00000020Ool00?moo`Ioo`00ogoo1Woo003o
Ool6Ool00?moo`Ioo`00ogoo1Woo003oOol6Ool00?moo`Ioo`00ogoo1Woo003oOol6Ool00?moo`Io
o`00g7oo10009Goo003DOol80003Ool00`00Oomoo`0SOol00<eoo`L000]oo`03001oogoo02=oo`00
aGoo20004Woo0P0097oo002nOol7000JOol2000TOol00;Ioo`P0025oo`8002Aoo`00[goo1`00:Goo
0P0097oo002XOol7000`Ool00`00Ool0000SOol00:1oo`P003Moo`03001oo`0002=oo`00VGoo1`00
@7oo0P008goo002AOol80017Ool2000SOol008Yoo`L004moo`8002=oo`00PWoo2000EWoo00<007oo
00008Woo001kOol7001NOol00`00Ool0000ROol007=oo`P00008Bae?7T/M>]hj_S[N=[djgUeoo`03
001oo`00029oo`00K7oo1`000dlN00E;7TlNCai?7T/N00=?7PHj_P04=[hj_SJn>[iHOol00`00Ool0
000ROol006Aoo`P0000VCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCahf_C[N>[hj
gSJm>[hfWCZn=Ydj_SZm>[hj_CkN>[hngSZm?]hj_Tioo`04001oogoo000QOol005eoo`L00005Bai?
7TlNCai;7P03Cah01D/NCai?7TlNBah00dlN00E;7TlNCai?7T/N00=?7P0=Bai?7TlN>[hf_SZn=[hj
_SJn>[hf_SZn=[h01SZn00@ngSZn?[hj_PXngSeoo`I6oP04001oogoo000QOol005Ioo`L0001bBae?
?T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?
7T/MCci;7CZn=[dj_SJn>[hfWCZn=Ydj_SJM?]hj_CZn>[dngSZn?]hj_CkN?[hngSZm?]hn_SkN?[e2
gSkN@]hn_D;n?]i2gSkM@_hngT;n?]e2oSkN@_hngD;n@]i2oSkMA_i2gT;n@]e6oT;NA_i2gTKn@]i6
oT;NA_i2gTKn@]i6oT;nA_i2gTKn@_i6oT;nA_i2oTKn@_i77T;nA_i2oTLN0TKn00=2oTLNA_h00TKn
00]77TKnAai6oTLNA_i77TKnAai6oP00009oo`03001oogoo01moo`00CWoo200000E;7TlNCai?7T/N
00=?7P05Bai?7TlNCai;7P03Cah01D/NCai?7TlNBah00dlN00E;7TlNCai?7T/N00=?7P05Bai?7TlN
Cai;7P03Cah02D/NCahf_SZn=[hj_SJn>[hf_P08>[h013kN>[hngSZn33kN00A2gSkN@]hngPI2gP06
@_i2gT;N@]i2oT;N0d;n00E2gT;n@_i2oT;N00I2oP03A_i2oTKn0096oP05@_i6oTKnA_i2oP0IA_h0
1000Oomoo`008Goo0017Ool70000BTlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7Dln
Bae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlN
Bae??SJN=[hfWCZn=Yhj_SJM>[hf_CZn>[dngSZm>[hj_CkN>[hngSZm?]hn_SkN>[d2?]h0=d;N?]e2
gSkN@]hngD;n?]i2gSkM@_hngT;n?]e2oT;N@_hngD;n@]i2oT;MA_i2gT;n@]e6oT;NA_i2gTKn@]i6
oT;NA_i2gTKn@]i6oT;nA_i2gTKn@_i6oT;nA_i2oTKn@_i77T;nA_i2oTLN0096oP0>@_i77TKnAai6
oTLNA_i77TKnAai6oTLNA_h000=oo`03001oogoo01ioo`00?goo200000=?7T/NCah00TlN00E;7TlN
Cai?7T/N00=?7P05Bai?7TlNCai;7P03Cah01D/NCai?7TlNBah00dlN00E;7TlNCai?7T/N00=?7P05
Bai?7TlNCai;7P03Cah01D/NCai?7TlNBah00dlN00I;7TlNCai?7T/NCah4=[h2>[h00cJn>[hj_P06
>[h013kN>[hngSZn2SkN00A2gSkN@]hngPI2gP08@_i2gT;n@]i2oT;N@_i2gPY2oP06A_i2oTKn@_i6
oT;n0dKn00E2oTKnA_i6oT;n01M6oP05001oogooOol0000POol003Qoo`L0002DBae?7T/MCci;7DlN
Bae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7Dln
Bae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlN
Badj_SJM=[hfWCZn=[dj_SJM>[hf_CZn>[dngSZm?]hj_CkN>[hngSZm?]hn_SkN>[e2gSkN@]hngD;N
?]i2gSkM@_hngT;N?]e2oSkN@_hngD;n@]i2oSkM@_i2gT;n@]e6oT;N@_i2gTKn@]i6oT;NA_i2gTKn
@]i6oT;NA_i2gTKn@_i6oT;nA_i2oTKn@_i6oT;nA_i2oTLN@_i6oT;nAah2A_h034;nAai6oTLNA_i7
7TKnAai6oTLNA_h000=oo`03001oogoo01ioo`00<7oo20000TlN00E;7TlNCai?7T/N00=?7P05Bai?
7TlNCai;7P03Cah01D/NCai?7TlNBah00dlN00E;7TlNCai?7T/N00=?7P05Bai?7TlNCai;7P03Cah0
1D/NCai?7TlNBah00dlN00E;7TlNCai?7T/N00=?7P05Bai?7TlNCai;7P03Cah01D/NCai?7TlNBah0
0dlN00E;7SJn=Yhf_SJN00<j_P03=[hj_SZn00@j_P04?]hj_SkN>[h<?]h014;N?]i2gSkN1T;N00A2
oT;N@_i2gP=2oP03@]i2oT;n00I2oP04A_i2oTKn@_h3A_h01D;nA_i6oTKn@_h00dKn00=2oTKnA_h0
4dKn00D007ooOomoo`00021oo`00;7oo10000:5??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;
7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;
7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;
7DlnBae?7T/MCci;7DlN=Ydj_SJM=[hfWCZn=[dj_SJM?]hj_C[N>[dngSZn?]hj_CkN>[hngSZm?]hn
_SkN?]e2gSkN@]hngD;N?]i2gSkM@_hngT;n?]e2oSkN@_i2gD;n@]i2oT;MA_i2gT;n@]e6oT;NA_i2
gTKn@]i6oT;NA_i2gTKn@]i6oT;nA_i2gTKn@_i6oT;nA_i2oTKn@_i77T;nA_i2oTLN0096oP03@_i7
7TKn0096oP0:Aai6oTLNA_i77TKnAai6oP00A_h2Ool00`00Oomoo`0NOol002aoo`05001?7TlNCai;
7P03Cah01D/NCai?7TlNBah00dlN00E;7TlNCai?7T/N00=?7P05Bai?7TlNCai;7P03Cah01D/NCai?
7TlNBah00dlN00E;7TlNCai?7T/N00=?7P05Bai?7TlNCai;7P03Cah01D/NCai?7TlNBah00dlN00E;
7TlNCai?7T/N00=?7P05Bai?7TlNCai;7P03Cah014/NCai;7TlN0d/N00A?7SJN=[hfWP8f_P<j_P03
=[hj_SZn00<j_P05?[hngSZn?]hn_P0:?]h014;N?]i2gSkN1T;N00I2oT;N@_i2gT;n@]h3@_h00d;N
@_i2oP06@_h014Kn@_i6oT;n0dKn00=2oTKnA_h06DKn00<004KnOol00Woo00<007ooOol07Goo000/
Ool0Y`00Oom??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/M
Cai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/M
Cci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNB_e?7T/M
=[hfWCZn=Ydf_SJM>[hf_CZn>[dngSZm>]hj_CkN>[hngSZm?]hn_SkN>[dngSjn?]hngD;N?]i2gSkM
@_hngT;N?]e2oSkN@_hngD;n@]i2oT;M@_i2gT;n@]e6oT;N@_i2gDKn@]i6oT;NA_i2gTKn@]i6oT;N
A_i2gTKn@_i6oT;NA_i2oTKn@_i6oT;nA_i2oTLN@_i6oT;nAah00TKn00e2oTLNA_i77TKnAai6oTLN
A_i77TKnAah00003Ool00`00Oomoo`0MOol002aoo`03001oo`0000=?7P05Bai?7TlNCai;7P03Cah0
1D/NCai?7TlNBah00dlN00E;7TlNCai?7T/N00=?7P05Bai?7TlNCai;7P03Cah01D/NCai?7TlNBah0
0dlN00E;7TlNCai?7T/N00=?7P05Bai?7TlNCai;7P03Cah01D/NCai?7TlNBah00dlN00E;7TlNCai?
7T/N00=?7P08Bai?7TlNCai;7TlNBai?7P=;7P04=[hfWSJn=Yh:>[h013kN?[hngSZn33kN00A2gSkN
@]hngP92gP0:@_i2gT;N@]i2oT;N@_i2gT;n@]h6@_h02TKn@_i2oT;nA_i2oTKn@_i6oT;n7TKn00D0
04KnOomoo`0001moo`00;7oo070007ooOol004lnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/M
Cci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/M
Cai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/M
Cci;7DlNBae;7T[nBai:oD/NB_hf_SJM>[hfWCZn=Ydj_SJm>[hj_CkN>[dngSZm?]hj_SkN>[dngSjn
?]hn_@8ngP0g@]hngD;N?]i2gSkM@_hngT;N?]e2oSkN@_hngD;n@]i2oT;M@_i2gT;n@]e6oT;N@_i2
gTKn@]i6oT;NA_i2gTKn@]i6oT;NA_i2gTKn@_i6oT;nA_i2oTKn@_i6oT;nA_i2oTLN@_i6oT;nAah0
0TKn00a2oTLNA_i77TKnAai6oTLNA_i77P00Aah2Ool00`00Oomoo`0MOol002aoo`05001oogooOol0
0003Cah01D/NCai?7TlNBah00dlN00E;7TlNCai?7T/N00=?7P05Bai?7TlNCai;7P03Cah01D/NCai?
7TlNBah00dlN00E;7TlNCai?7T/N00=?7P05Bai?7TlNCai;7P03Cah01D/NCai?7TlNBah00dlN00E;
7TlNCai?7T/N00=?7P05Bai?7TlNCai;7P03Cah014/NCai?7TlN1T/N00DfWSJn=Yhf_SJN00Xj_P04
?]hn_SkN>[h:?]h01D;N?]i2gSkN@_h00d;N00I2oT;N@_i2gT;n@]h3@_h014;N@_i2oTKn0d;n00I6
oT;nA_i2oTKn@_h3A_h00d;nA_i6oP0JA_h00`00A_ioo`02Ool00`00Oomoo`0LOol002]oo`03001o
ogoo00=oo`2R001??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae?
?T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?
7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7TKmBai6oT/NA_dj
_SJM>[hfWCZn=[dj_SJM>[hf_CkN>[dngSZm?]hj_CkN>[hngSjm?]hn_SkN?[e2gSkN@]hngD;N?]i2
gSkM@_hngT;n?]e2oSkN@_i2gD;n@]i2oT;M@_i2gT;n@]e6oT;NA_i2gTKn@]i6oT;NA_i2gTKn@]i6
oT;nA_i2gTKn@_i6oT;nA_i2oTKn@_i77T;nA_i2oTLN0TKn00i2oTLNA_i77TKnAai6oTLNA_i77TKn
Aah004LN0goo00<007ooOol077oo000[Ool00`00Oomoo`04Ool01@00Cai?7TlNBah00dlN00E;7TlN
Cai?7T/N00=?7P05Bai?7TlNCai;7P03Cah01D/NCai?7TlNBah00dlN00E;7TlNCai?7T/N00=?7P05
Bai?7TlNCai;7P03Cah01D/NCai?7TlNBah00dlN00E;7TlNCai?7T/N00=?7P05Bai?7TlNCai;7P03
Cah01D/NCai?7TlNBah00dlN00U:oT/NB_i;7T[n=[hfWSJn=Yh02SZn00@ngSZn?]hn_PXngP04@]hn
gT;N?]h2@]h02T;n@]i2gT;N@_i2gT;n@]i2oT;N0d;n00A2gT;n@_i6oP=2oP06A_i2oTKn@_i6oT;n
0dKn00=2oTKnA_h064Kn00<004KnOol00Woo00<007ooOol077oo000[Ool00`00Oomoo`05Ool0WP00
Cci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/M
Cai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/M
Cci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MBai6oD/NA_i;7SJM>[hfWCZn=Ydj_SJm
>[hfWCkN>[dngSZm?]hj_SkN>[dngSZn?]hn_CkN?[hngSkM@]hngT;N?]e2oSkN@]hngD;n?]i2oSkM
@_hngT;n@]e2oT;N@_i2gDKn@]i2oT;MA_i2gTKn@]i6oT;nA_i2gTKn@_i6oT;NA_i2oTKn@]i6oT;n
A_i2oTKn@_i6oT;nAah2A_h04D;nAai6oTKn@_i77TKnAai6oTLNA_i77TKnAah004LNA_h00Woo00<0
07ooOol077oo000[Ool00`00Oomoo`05Ool00`00Bai?7P02Cah01D/NCai?7TlNBah00dlN00E;7TlN
Cai?7T/N00=?7P05Bai?7TlNCai;7P03Cah01D/NCai?7TlNBah00dlN00E;7TlNCai?7T/N00=?7P05
Bai?7TlNCai;7P03Cah01D/NCai?7TlNBah00dlN00E;7TlNCai?7T/N00=?7P05Bai?7TlNCai;7P03
Cah014/NCai?7T/N0dKn00E;7SJN=[hfWSJn00Xj_P03?[hngSZn00`ngP04@]hngT;N?]h2@]h02T;n
@]i2gT;N@_i2gT;n@]i2oT;N0d;n00A2gT;n@_i6oP=2oP06A_i2oTKn@_i6oT;n0dKn00=2oTKnA_h0
5TKn00<004KnA_h00Woo00<007ooOol077oo000[Ool00`00Oomoo`06Ool0V`00Bae??T/MCai;7Dln
Bae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlN
Bae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7Dln
Bae?7T/MCci;7DlNBae??T/MCai;7DlnA_i;7TKmBai6oSZn=Ydj_SJM>[hf_CZn>[dj_SZm?]hj_CkN
>[dngSZn?]hj_CkN?[hngSjm?]hn_T;N?]e2gSkN@]hngD;n?]i2gSkM@_hngT;n?]e2oT;N@_i2gD;n
@]i2oT;MA_i2gT;n@]i6oT;NA_i2gTKn@_i6oT;NA_i2oTKn@]i6oT;nA_i2oTKn@_i6oT;nAah00TKn
00I2oTLNA_i6oT;nAah3A_h02TLNA_i77TKnAai6oTLN001;7TKn0goo00<007ooOol06goo000[Ool0
0`00Oomoo`07Ool00`00Bai?7P02Cah01D/NCai?7TlNBah00dlN00E;7TlNCai?7T/N00=?7P05Bai?
7TlNCai;7P03Cah01D/NCai?7TlNBah00dlN00E;7TlNCai?7T/N00=?7P05Bai?7TlNCai;7P03Cah0
1D/NCai?7TlNBah00dlN00E;7TlNCai?7T/N00=?7P05Bai?7TlNCai;7P03Cah014/NCai6oT/N0dKn
00@f_SJN=[hfWPXj_P04?]hn_SkN>[h6?]h01T;N?]hngSkN@]hngPI2gP0:@_i2gT;N@]i2oT;N@_i2
gT;n@]h6@_h01TKn@_i6oT;nA_i2oP=6oP03@_i6oTKn01Q6oP040016oTKnA_h2Ool00`00Oomoo`0K
Ool002]oo`03001oogoo00Qoo`1?001;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;
7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;
7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCch0
0TKn04Y6oDLNA_hj_SJM>[hj_CZn=[dj_SZm?]hj_CkN>[dngSZm?]hj_SkN>[dngSjn?]hn_D;N?]i2
gSkM@]hngT;N?]e2oSkN@]hngD;n?]i2oSkM@_i2gT;n@]e2oT;N@_i2gDKn@]i6oT;NA_i2gTKn@]i6
oT;nA_i2gTKn@_i6oT;NA_i2oTKn@_i6oT;nA_i2oTLN0TKn0192oTLNA_i6oT;nAai6oTLNA_i77TKn
Aai6oT/N00177TKnBah2Ool00`00Oomoo`0KOol002]oo`03001oogoo00Uoo`03001;7TlN009?7P05
Bai?7TlNCai;7P03Cah01D/NCai?7TlNBah00dlN00E;7TlNCai?7T/N00=?7P05Bai?7TlNCai;7P03
Cah01D/NCai?7TlNBah00dlN00E;7TlNCai?7T/N00=?7P05Bai?7TlNCai;7P03Cah01D/NCai?7TlN
Bah00dlN00E;7TlNCai?7T/N00=?7P03Bai6oTKn00=6oP8f_P03=Yhf_SZn00Pj_P04?]hj_SkN?[h8
?]h00d;N?]hngP02@]h013kN@]i2gT;n0d;N00I2oT;N@_i2gT;n@]h3@_h014;N@_i2oTKn0d;n00I6
oT;nA_i2oTKn@_h3A_h00d;nA_i6oP0FA_h01000A_i6oTKn0Woo00<007ooOol06goo000[Ool00`00
Oomoo`09Ool0F`00Cai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/M
Cai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/M
Cci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T;NA_i2oTKn@]hj_SJM
>[hfWCZn>[dj_SJm008j_P0;?]hj_CkN>[hngSZm?]hj_SkN?[e2gP02?]h0<SkM@]hngT;N?]e2oSkN
@_hngD;n?]i2oSkM@_hngT;n@]e2oT;N@_i2gDKn@]i2oT;MA_i2gTKn@]i6oT;NA_i2gTKn@_i6oT;N
A_i2oTKn@]i6oT;nA_i2oTKn@_i6oT;nAah2A_h044;nAai6oTKn@_i77TKnAai6oTLNA_i77P00Bai6
oTLN0goo00<007ooOol06Woo000[Ool00`00Oomoo`0:Ool00`00Cai;7P03Cah01D/NCai?7TlNBah0
0dlN00E;7TlNCai?7T/N00=?7P05Bai?7TlNCai;7P03Cah01D/NCai?7TlNBah00dlN00E;7TlNCai?
7T/N00=?7P05Bai?7TlNCai;7P03Cah01D/NCai?7TlNBah00dlN00E;7TlNCai?7T/N00=?7P05Bai?
7TlNCai;7P03Cah01D;nA_i6oTKn@_h00cJn00<fWSZn>[h023Zn00@ngSjn?]hn_PPngP03@]hngT;N
0092gP04?]i2gT;N@_h3@]h01T;n@]i2oT;N@_i2gP=2oP04@]i2oT;nA_h3@_h01TKn@_i6oT;nA_i2
oP=6oP03@_i6oTKn01A6oP040016oTKnA_h3Ool00`00Oomoo`0JOol002]oo`03001oogoo00]oo`1K
001?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlN
Bae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7Dln
Bae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DKn@]i6oT;nA_hfWCZn=Ydj_SJM>[hj_CZn
=[d00SZn00/ngSZm?]hj_SkN>[dngSZn?]hn_D;N008ngP0^?]e2gSkN@]hngD;n?]i2oSkM@_i2gT;n
?]e2oT;N@_i2gD;n@]i2oT;MA_i2gT;n@]i6oT;NA_i2gTKn@_i6oT;NA_i2oTKn@]i6oT;nA_i2oTKn
@_i6oT;nAah2A_h01T;nAai6oTKn@_i77P=6oP0:Aai6oTLNA_i;7P00Aai6oT/NA_h2Ool00`00Oomo
o`0JOol002Yoo`03001oogoo00eoo`9?7P05Bai?7TlNCai;7P03Cah01D/NCai?7TlNBah00dlN00E;
7TlNCai?7T/N00=?7P05Bai?7TlNCai;7P03Cah01D/NCai?7TlNBah00dlN00E;7TlNCai?7T/N00=?
7P05Bai?7TlNCai;7P03Cah01D/NCai?7TlNBah00dlN00E;7TlNCai?7T/N00=?7P03Bai?7TlN00E2
oP03=Yhf_SJn00Pj_P03?[hj_SZn008ngP03?[hngSkN00@ngP06@]hngSkN?]i2gSkN0d;N00@ngT;N
@]i2oP=2gP06@_i2gT;n@]i2oT;N1T;n00I6oT;nA_i2oTKn@_h3A_h00d;nA_i6oP0FA_h00`00A_i6
oP02A_h2Ool00`00Oomoo`0JOol002Yoo`03001oogoo00ioo`1SBae?7T/MCci;7DlNBae??T/MCai;
7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;
7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;
7DlnBae?7T/MCci;7DKn@]i6oT;N>[hfWCZn=Ydj_SJm>[hj_CZn>[dngSZn?]hj_CkN>[hngSZm00<n
gP0b?[e2gSkN@]hngD;N?]i2gSkM@_hngT;n?]e2oT;N@_hngD;n@]i2oT;M@_i2gTKn@]e6oT;NA_i2
gTKn@]i6oT;NA_i2oTKn@]i6oT;nA_i2gTKn@_i6oT;nA_i2oTKn@_i77P96oP0A@_i77TKnA_i2oTLN
A_i77TKnAai6oTLN001;7TKnAai6oP02Ool00`00Oomoo`0JOol002Yoo`03001oogoo00ioo`04001?
7TlNBah3Cah01D/NCai?7TlNBah00dlN00E;7TlNCai?7T/N00=?7P05Bai?7TlNCai;7P03Cah01D/N
Cai?7TlNBah00dlN00E;7TlNCai?7T/N00=?7P05Bai?7TlNCai;7P03Cah01D/NCai?7TlNBah00dlN
00E;7TlNCai?7T/N00=?7P05Bai?7TlNCai;7P02Cah01T;n@]i2oT;N>[hfWP8f_PPj_P03?]hj_SkN
008ngP03?[hngSkN00@ngP06@]hngSkN?]i2gSkN1T;N00I2oT;N@_i2gT;n@]h3@_h014;N@_i2oTKn
0d;n00I6oT;nA_i2oTKn@_h3A_h00d;nA_i6oP0DA_h00`00A_i6oP02A_h3Ool00`00Oomoo`0IOol0
02Yoo`03001oogoo00moo`1U001;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7Dln
Bae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlN
Bae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T;N@_hngT;n
=Ydj_SJM>[hfWCZn>[dj_SZm?]hj_CkN>[hngSZm?]hj_SkN>[e2gP02?]h0;Cjm@]hngT;N?]e2gSkN
@_hngD;n?]i2oSkM@_i2gT;n@]e2oT;N@_i2gDKn@]i6oT;MA_i2gTKn@]i6oT;NA_i2gTKn@_i6oT;N
A_i2oTKn@]i6oT;nA_i2oP03A_h01T;nAai6oTKn@_i77P96oP0;@_i77TKnAai6oTLNA_h004KnBai6
oP03Ool00`00Oomoo`0IOol002Yoo`03001oogoo011oo`=?7P05Bai?7TlNCai;7P03Cah01D/NCai?
7TlNBah00dlN00E;7TlNCai?7T/N00=?7P05Bai?7TlNCai;7P03Cah01D/NCai?7TlNBah00dlN00E;
7TlNCai?7T/N00=?7P05Bai?7TlNCai;7P03Cah01D/NCai?7TlNBah00dlN00E;7TlNCai?7T/N00=?
7P0:Bai2gSkN@]hngT;N=[hj_SJN=[h5>[h01SkN>[hj_SZn?]hn_PXngP03@]hngSkN0092gP04?]i2
gT;N@_h3@]h01T;n@]i2oT;N@_i2gP=2oP04@]i2oT;nA_h3@_h01TKn@_i6oT;nA_i2oQU6oP030016
oTKn0096oP9oo`03001oogoo01Uoo`00:Woo00<007ooOol04Goo05Q??T/MCai;7DlnBae?7T/MCci;
7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;
7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;
7DlNBae??T/MCai;7D;n?]i2oSkN@_hfWCZn=Ydj_SZm>[hj_@8j_P0;?]hj_CkN>[hngSZm?]hj_SkN
?[e2gP02?]h0;SkM@]hngT;N?]e2oSkN@_hngD;n@]i2oSkM@_i2gT;n@]e2oT;N@_i2gDKn@]i6oT;M
A_i2gTKn@]i6oT;nA_i2gTKn@_i6oT;NA_i2oTKn@_i6oT;nA_i2oTLN0TKn0192oTLNA_i6oT;nAai6
oTLNA_i77TKnAai6oP00A_i77TKnBah2Ool00`00Oomoo`0IOol002Yoo`03001oogoo019oo`=?7P05
Bai?7TlNCai;7P03Cah01D/NCai?7TlNBah00dlN00E;7TlNCai?7T/N00=?7P05Bai?7TlNCai;7P03
Cah01D/NCai?7TlNBah00dlN00E;7TlNCai?7T/N00=?7P05Bai?7TlNCai;7P03Cah01D/NCai?7TlN
Bah00dlN00E;7TlNCai?7T/N00=?7P05?]i2gSkN@]hngP02=[h00cZn=Yhj_P05>[h00ckN>[hj_P02
?]h00cjn?]hngP08?]h00d;N?]i2gP02@]h013kN@]i2gT;n0d;N00I2oT;N@_i2gT;n@]h6@_h01TKn
@_i6oT;nA_i2oP=6oP03@_i6oTKn01E6oP030016oTKn0096oP=oo`03001oogoo01Qoo`00:Woo00<0
07ooOol04goo04e??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae?
?T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?
7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCahngT;N00<ngP0@>[hfWCZn=Ydj
_SZm>[hj_CkN>[hngSZm?]hj_SkN>[d3?]h0<Sjm@]hngT;N?]e2gSkN@]hngD;n?]i2oSkM@_i2gT;n
?]e2oT;N@_i2gD;n@]i6oT;MA_i2gTKn@]i6oT;NA_i2gTKn@_i6oT;NA_i2oTKn@]i6oT;nA_i2oTKn
@_i6oT;nAah2A_h044;nAai6oTKn@_i77TKnAai6oTLNA_h004KnBai6oTLN0goo00<007ooOol067oo
000ZOol00`00Oomoo`0COol01@00Cai?7TlNBah00dlN00E;7TlNCai?7T/N00=?7P05Bai?7TlNCai;
7P03Cah01D/NCai?7TlNBah00dlN00E;7TlNCai?7T/N00=?7P05Bai?7TlNCai;7P03Cah01D/NCai?
7TlNBah00dlN00E;7TlNCai?7T/N00=?7P05Bai?7TlNCai;7P03Cah00d/NCai?7P05?]h01CJn>[hf
_SZn=[h01SZn00<ngSZn?]h00SkN00<n_SkN?]h013kN00I2gSkN?]hngT;N?]h6@]h01T;n@]i2oT;N
@_i2gP=2oP04@]i2oT;nA_h3@_h01TKn@_i6oT;nA_i2oP=6oP03@_i6oTKn01=6oP030016oTKn0096
oP=oo`03001oogoo01Qoo`00:Woo00<007ooOol057oo04h004lnBae?7T/MCci;7DlNBae??T/MCai;
7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;
7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;
7DlnBadngSZn?]h2>[h04SJM>[hfWCZn>[djgSZm>[hj_CkN>[hngSZm?]hn_SkN>[e2gP8ngP0b?[e2
gSkN@]hngD;n?]i2oSkM@_hngT;n?]e2oT;N@_hngDKn@]i2oT;MA_i2gTKn@]e6oT;NA_i2gTKn@]i6
oT;NA_i2oTKn@_i6oT;nA_i2oTKn@_i6oT;nA_i2oTKn@_i77P=6oP0>Aai6oTLNA_i77TKnAai6oP00
A_i77TKnBai6oP9oo`03001oogoo01Qoo`00:Woo00<007ooOol05Goo00D004lNCai?7T/N00=?7P05
Bai?7TlNCai;7P03Cah01D/NCai?7TlNBah00dlN00E;7TlNCai?7T/N00=?7P05Bai?7TlNCai;7P03
Cah01D/NCai?7TlNBah00dlN00E;7TlNCai?7T/N00=?7P05Bai?7TlNCai;7P03Cah01D/NCai?7TlN
Bah00dlN00E;7TlNCahngS[N008ngP04>[hf_SZn=[h6>[h013jn>[hngSjn0ckN00<n_SkN?]h013kN
00=2gSkN@]h00T;N00@ngT;N@]i2oP=2gP06@_i2gT;n@]i2oT;N0d;n00A2gT;n@_i6oP=2oP06A_i2
oTKn@_i6oT;n0dKn00=2oTKnA_h04DKn00<004KnA_h00dKn0Woo00<007ooOol067oo000YOol00`00
Oomoo`0GOol0HP00Cci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/M
Cci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/M
Cai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7CkN>[hngSJM>[hfWCZn=Ydj_SZm
>]hj_CZn>[dngSZn?]hj_CkN?[hngSjm@]h2?]h0;Sjm@_hngT;N?]e2oSkN@_hngD;n?]i2oSkM@_i2
gT;n@]e6oT;N@_i2gDKn@]i6oT;NA_i2gTKn@]i6oT;nA_i2gTKn@_i6oT;nA_i2oTKn@_i6oT;nA_i2
oTLN0TKn0192oTLNA_i77TKnAai6oTLNA_i77TKn0016oT/NA_i77TKnBah2Ool00`00Oomoo`0GOol0
02Uoo`03001oogoo01Qoo`05Bai?7TlNCai;7P03Cah01D/NCai?7TlNBah00dlN00E;7TlNCai?7T/N
00=?7P05Bai?7TlNCai;7P03Cah01D/NCai?7TlNBah00dlN00E;7TlNCai?7T/N00=?7P05Bai?7TlN
Cai;7P03Cah01D/NCai?7TlNBah00dlN00E;7TlNCai?7T/N00=?7P09Bai?7SZn>]hj_S[N=[hj_SJn
00Hj_P06?]hj_Sjn>[hngSjn23kN00A2gSkN@]hngP=2gP04?]i2gT;N@_h3@]h01T;n@]i2oT;N@_i2
gPI2oP06A_i2oTKn@_i6oT;n0dKn00=2oTKnA_h04dKn00<004KnA_h014Kn0Woo00<007ooOol05goo
000DOol3000BOol00`00Oomoo`0HOol0H`00Bae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;
7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;
7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??SZn>]hf
_CZn=Ydj_SJM>[hj_CZn>[dngSZm?]hj_CkN?[hngSZm?]hn_SkN?[e2gP02?]h0;SkM@_hngT;N?]e2
oSkN@_hngD;n@]i2oSkMA_i2gT;n@]e6oT;NA_i2gDKn@]i6oT;NA_i2gTKn@]i6oT;nA_i2gTKn@_i6
oT;nA_i2oTKn@_i6oT;nA_i2oTLN0dKn00m77TKnAai6oTLNA_i77TKn0016oTLNA_i;7TKnAah00Woo
00<007ooOol05goo000EOol00`00Oomoo`0AOol00`00Oomoo`0IOol00dlNBai?7P02Cah01D/NCai?
7TlNBah00dlN00E;7TlNCai?7T/N00=?7P05Bai?7TlNCai;7P03Cah01D/NCai?7TlNBah00dlN00E;
7TlNCai?7T/N00=?7P05Bai?7TlNCai;7P03Cah01D/NCai?7TlNBah00dlN00E;7TlNCai?7T/N00=?
7P05Bai?7TlNCai;7P07>[h00cJn>[hj_P04>[h00ckN>[hn_P09?]h014;N?]i2gSkN24;N00I2oT;N
@_i2gT;n@]h3@_h014;N@_i2oTKn0d;n00I6oT;nA_i2oTKn@_h3A_h00d;nA_i6oP0AA_h00`00A_i6
oP04A_h2Ool00`00Oomoo`0GOol001=oo`<001=oo`03001oogoo01Yoo`1NCai;7DlnBae?7T/MCci;
7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;
7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;
7DlNBae??T/MCahf_CZn=[hj_SJm>[hfWCZn=YdngSZm>[hj_CkN>[hngSZm?]hn_SkN>[d2?]h0;T;N
?[e2gSkN@]hngD;n?]i2gSkM@_hngT;n?]e2oT;N@_i2gDKn@]i2oT;MA_i2gTKn@]e6oT;NA_i2gTKn
@]i6oT;NA_i2oTKn@_i6oT;nA_i2oTKn@_i6oT;n0dKn0192oTLNA_i77TKnAai6oTLNA_i77TKn0016
oT/NA_i77TKnBah3Ool00`00Oomoo`0FOol0019oo`04001oogoo000COol00`00Oomoo`0KOol00dlN
Bai?7P02Cah01D/NCai?7TlNBah00dlN00E;7TlNCai?7T/N00=?7P05Bai?7TlNCai;7P03Cah01D/N
Cai?7TlNBah00dlN00E;7TlNCai?7T/N00=?7P05Bai?7TlNCai;7P03Cah01D/NCai?7TlNBah00dlN
00E;7TlNCai?7T/N00=?7P04Bai?7TlNCah3=[h00cZn=[hj_P07>[h013jn>[hngSZn2SkN00A2gSkN
@]hngPA2gP0:@_i2gT;N@]i2oT;N@_i2gT;n@]h3@_h014;N@_i2oTKn0d;n00=6oT;nA_h00TKn00E2
oTKnA_i6oT;n0156oP030016oTKn0096oP03Aai6oTKn009oo`03001oogoo01Ioo`004Woo00@007oo
Ool001=oo`03001oogoo01aoo`2?Cai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;
7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;
7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/M>[hf_CZn=[hj_SJM>[hf
WCZn>[dngSZm>[hj_CkN>[hngSZm?]hn_SkN>[e2gSkN@]hn_D;N?]i2gSkM@_hngT;n?]e2oT;N@_hn
gD;n@]i2oT;MA_i2gT;n@]e6oT;NA_i2gDKn@]i6oT;NA_i2oTKn@]i6oT;nA_i2oTKn@_i6oT;nAai2
oTKn@_i77P02A_h04D;nAai6oTLNA_i77TKnAai6oP00A_i77TKnBai6oTLNA_h00Woo00<007ooOol0
5Woo000COol4000BOol00`00Oomoo`0MOol00dlNBai?7P02Cah01D/NCai?7TlNBah00dlN00E;7TlN
Cai?7T/N00=?7P05Bai?7TlNCai;7P03Cah01D/NCai?7TlNBah00dlN00E;7TlNCai?7T/N00=?7P05
Bai?7TlNCai;7P03Cah01D/NCai?7TlNBah00dlN00E;7TlNCai?7T/N00=?7P05Bai?7TlN=[hfWP02
=[h00cZn=[hj_P07>[h00ckN>[hngP09?]h014;N?]i2gSkN1T;N00Y2oT;N@]i2gT;n@]i2oT;N@_i2
gP=2oP05@]i6oT;nA_i2oP03A_h01D;nA_i6oTKn@_h04dKn00@004KnA_i77P=6oP04Aaioogoo000H
Ool002Uoo`03001oogoo01eoo`2@001?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae?
?T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?
7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7Dln=Ydf_SJM>[hfWCZn=Ydj
_SJm>[hj_CkN>[dngSZm?]hj_SkN>[dngSjn?]hngD;N?]i2gSkM@_hngT;N?]e2oSkN@_hngD;n@]i2
oSkM@_i2gT;n@]e6oT;NA_i2gDKn@]i6oT;NA_i2gTKn@]i6oT;nA_i2gTKn@_i6oT;nA_i2oTKn@_i7
7T;nA_i2oTLN0dKn00i77TKnAai6oTLNA_h004KnAai6oTLNA_i;7TKn0goo00<007ooOol05Goo000Y
Ool00`00Oomoo`0NOol2Cah01D/NCai?7TlNBah00dlN00E;7TlNCai?7T/N00=?7P05Bai?7TlNCai;
7P03Cah01D/NCai?7TlNBah00dlN00E;7TlNCai?7T/N00=?7P05Bai?7TlNCai;7P03Cah01D/NCai?
7TlNBah00dlN00E;7TlNCai?7T/N00=?7P0:Bai?7T/NCai;7TlN=Yhf_SJM=[h2>[h00cJn>[hj_P04
>[h013kN>[hngSjn2SkN00A2gSkN@]hngPA2gP04@_i2gT;n@]h3@_h01D;N@_i2oTKn@]h00T;n00I6
oT;nA_i2oTKn@_h3A_h01D;nA_i6oTKn@_h04TKn00D004KnA_i6oTLN00=6oP9oo`03001oogoo01Eo
o`00:7oo00<007ooOol087oo08a;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7Dln
Bae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlN
Bae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlNBae?7T/M>[hfWCJn=Ydj_SJm>[hfWCkN
>[dngSZm?]hj_SkN>[dngSZn?]hj_CkN?[i2gSkM@]hngT;N?]e2oSkN@]hngD;n?]i2oT;M@_i2gT;n
@]e6oT;N@_i2gDKn@]i6oT;MA_i2gTKn@]i6oT;NA_i2gTKn@_i6oT;nA_i2oTKn@_i77T;nA_i2oTLN
0TKn0192oTLNA_i77TKnAai6oTLNA_i77P00Aai6oT/NA_i77TKnBah2Ool00`00Oomoo`0EOol002Qo
o`03001oogoo025oo`9?7P05Bai?7TlNCai;7P03Cah01D/NCai?7TlNBah00dlN00E;7TlNCai?7T/N
00=?7P05Bai?7TlNCai;7P03Cah01D/NCai?7TlNBah00dlN00E;7TlNCai?7T/N00=?7P05Bai?7TlN
Cai;7P03Cah01D/NCai?7TlNBah00dlN1D/N00@f_SJN=[hfW@Tj_P03?[hngSZn00XngP04@]hngT;N
?]h6@]h014;n@]i2oT;N0d;n00A2gT;n@_i6oP=2oP03A_i2oTKn0096oP03@_i6oTKn01I6oP030016
oTKn00=6oP05Aai6oWooOol0000GOol002Qoo`03001oogoo029oo`14Bae?7T/MCci;7DlNBae??T/M
Cai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/M
Cci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNB_e?7P9;
7P0EB_dj_SJM=[hfWCZn=[dj_SZm?]hj_CkN>[dngSZn?]hj_CkN?[hngSjm008ngP0_@]hngD;N?]i2
gSkM@_hngT;n?]e2oSkN@_i2gD;n@]i2oT;MA_i2gT;n@]e6oT;NA_i2gDKn@]i6oT;NA_i2oTKn@]i6
oT;nA_i2oTKn@_i6oT;nAai2oTKn@_i77P02A_h044;nAai6oTLNA_i77TKnAah004LNA_i77TKnBai6
oTLN0Woo00<007ooOol05Goo000XOol00`00Oomoo`0ROol01000Cai?7T/N0dlN00E;7TlNCai?7T/N
00=?7P05Bai?7TlNCai;7P03Cah01D/NCai?7TlNBah00dlN00E;7TlNCai?7T/N00=?7P05Bai?7TlN
Cai;7P03Cah01D/NCai?7TlNBah00dlN00E;7TlNCai?7T/N00=?7P05Bai?7TlNCai:oP03Bah014[n
=[hfWSJn2CZn00@ngSjn?]hj_PXngP05@]hngT;N@]i2oP03@]h01T;n@]i2oT;N@_i2gPI2oP06A_i2
oTKn@_i6oT;n0dKn00=2oTKnA_h054Kn00D004KnA_i6oTLN00=6oP=oo`03001oogoo01Aoo`00:7oo
00<007ooOol08goo08d004/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlN
Bae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7Dln
Bae?7T/MCci;7DlNBae??T/MCai;7DlnBae;7TKmBai6oT/N=Ydj_SJM>[hfWCZn=[dngSZm?]hj_CkN
>[dngSZn?]hj_CkN?[hngSjm@]hngT;N?]e2oSkN@]hngD;n?]i2oSkM@_i2gT;n@]e2oT;N@_i2gDKn
@]i6oT;MA_i2gTKn@]i6oT;NA_i2gTKn@_i6oT;NA_i2oTKn@_i6oT;nA_i2oTLN@_i6oT;nAah00dKn
00i77TKnAai6oTLN00177TKnAai6oTLNA_i;7TKn0Woo00<007ooOol057oo000XOol00`00Oomoo`0T
Ool3Cah01D/NCai?7TlNBah00dlN00E;7TlNCai?7T/N00=?7P05Bai?7TlNCai;7P03Cah01D/NCai?
7TlNBah00dlN00E;7TlNCai?7T/N00=?7P05Bai?7TlNCai;7P03Cah01D/NCai?7TlNBah00dlN00E;
7TlNCai?7T/N009?7P08Bai6oTKnA_i;7SJM=[hfWPXj_P03?]hn_SkN00TngP=2gP04?]i2gT;N@_h3
@]h00d;n@]i2oP02@_h014;N@_i2oTKn0d;n00I6oT;nA_i2oTKn@_h3A_h00d;nA_i6oP0BA_h00`00
A_i6oP03A_h00dLNA_i6oP02Ool00`00Oomoo`0DOol002Qoo`03001oogoo02Eoo`25Cci;7DlNBae?
?T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?
7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae?
?TKnBai6oD/NA_hj_SJM>[hfWCZn=Ydj_SZm?]hj_CkN>[dngSZm?]hj_SkN?[dngSjn?]hngD;N?]i2
gSkM@_hngT;N?]e2oSkN@_hngD;n@]i2oT;M@_i2gT;n@]e6oT;NA_i2gDKn@]i6oT;NA_i2gTKn@]i6
oT;nA_i2oTKn@_i6oT;nAah00TKn01E2oTLNA_i6oT;nAai6oTLNA_i77TKnAah004LNA_i77TKnBai6
oTLNA_h00Woo00<007ooOol057oo000XOol00`00Oomoo`0VOol3Cah01D/NCai?7TlNBah00dlN00E;
7TlNCai?7T/N00=?7P05Bai?7TlNCai;7P03Cah01D/NCai?7TlNBah00dlN00E;7TlNCai?7T/N00=?
7P05Bai?7TlNCai;7P03Cah01D/NCai?7TlNBah00dlN00I;7TlNCai?7T/NCah5A_h00cJn=Yhf_P09
>[h013kN?[hngSjn13kN00I2gSkN?]hngT;N?]h6@]h01T;n@]i2oT;N@_i2gP=2oP04@]i2oT;nA_h3
@_h01TKn@_i6oT;nA_i2oQ96oPD000=6oP05Aai6oTKnA_i77P03Ool00`00Oomoo`0COol002Qoo`03
001oogoo02Ioo`24001??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlN
Bae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7Dln
Bae?7T/MCci;7DlNBae??T/MCai;7DLNA_i77TKmAahfWCZn=Ydj_SZm>[hf_CZn>[dngSZm?]hj_SkN
>[dngSZn?]hn_CkN?[i2gSkM@]hngT;N?]e2oSkN@_hngD;n?]i2oT;M@_i2gT;n@]e6oT;N@_i2gDKn
@]i6oT;MA_i2oTKn@]i6oT;nA_i2gTKn@_i6oT;nA_i2oTKn2P0000i6oTLNA_i77P00Aai6oT/NA_i7
7TKnBai6oTLN0Woo00<007ooOol04goo000XOol00`00Oomoo`0WOol01D/NCai?7TlNBah00dlN00E;
7TlNCai?7T/N00=?7P05Bai?7TlNCai;7P03Cah01D/NCai?7TlNBah00dlN00E;7TlNCai?7T/N00=?
7P05Bai?7TlNCai;7P03Cah01D/NCai?7TlNBah00dlN00E;7TlNCai?7T/N00=?7P09Bai6oTKnA_i2
oTKn=[hj_SJN00Hj_P06?[hj_SZn?[hngSjn1SkN00I2gSkN?]hngT;N?]h2@]h02T;n@]i2gT;N@_i2
gT;n@]i2oT;N1T;n00M6oT;nA_i2oTKn@_i6oP09000?A_h00`00A_i6oP02A_h014LNA_i6oTKn0Woo
00<007ooOol04goo000XOol00`00Oomoo`0XOol0Kd/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;
7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;
7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlN@]i6oT;nA_i2gSZn=Ydj_SJM>[hj
_CZn=[dngSZm?]hj_CkN>[hngSZm@]hn_SkN?[e2gSkN@]hngD;N?]i2gSkM@_i2gT;n?]e2oT;N@_i2
gD;n@]i2oT;MA_i2gP0:000024Kn@_i6oT;NA_i2oTKn@_h3A_h01T;nAai6oTKn@_i77P=6oP0=Aai6
oTLNA_h004KnAai6oT/NA_i77TKnBah00Woo00<007ooOol04goo000WOol00`00Oomoo`0ZOol01D/N
Cai?7TlNBah00dlN00E;7TlNCai?7T/N00=?7P05Bai?7TlNCai;7P03Cah01D/NCai?7TlNBah00dlN
00E;7TlNCai?7T/N00=?7P05Bai?7TlNCai;7P03Cah01D/NCai?7TlNBah00dlN00E;7TlNCai?7T/N
00=?7PE2oP8f_PPj_P04?[hj_SkN?[h8?]h00d;N?]i2gP02@]h01CkN@]i2gT;n@]h02@0000=2oTKn
@_h00T;n00I6oT;nA_i2oTKn@_h3A_h00d;nA_i6oP0AA_h00`00A_i6oP04A_h01DLNA_ioogoo0000
5Goo000WOol00`00Oomoo`0[Ool0ET/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/M
Cai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/M
Cci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlN@]i6oT;N@_hfWCZn=Ydj_SZm>[hj_CZn>[dngSZm
?]hj_CkN>[hngSjm@]h2?]h00cjm@]hngP0900007SkM@_i2gT;n@]e2oT;NA_i2gDKn@]i6oT;MA_i2
gTKn@]i6oT;nA_i2gTKn@_i6oT;nA_i2oTKn@_i77P96oP0E@_i77TKnA_i2oTLNA_i77TKnAai6oP00
A_i;7TKnAai6oT/NA_i77TKn009oo`03001oogoo019oo`009goo00<007ooOol0:goo00=?7T/NCah0
0TlN00E;7TlNCai?7T/N00=?7P05Bai?7TlNCai;7P03Cah01D/NCai?7TlNBah00dlN00E;7TlNCai?
7T/N00=?7P05Bai?7TlNCai;7P03Cah01D/NCai?7TlNBah00dlN00E;7TlNCai?7T/N00=?7P0;Bai?
7TlNCai2gT;n@]i2oSJN>[hf_P08>[h00cjn0000000800000ckN@]hngP03@]h02CkN@]i2gT;n@]i2
oT;N@_i2gP03@_h014;N@_i2oTKn0d;n00I6oT;nA_i2oTKn@_hFA_h01@00A_i6oTKnAah00dKn00A7
7WooOol001Aoo`009goo00<007ooOol0;7oo04L004/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;
7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;
7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7D;n?]i2oSkN>[hfWCZn00T00007?]hj
_CkN>[hngSjm@]h00SkN02XngD;N?]i2oSkM@_hngT;n?]e2oT;N@_i2gD;n@]i2oT;MA_i2gTKn@]e6
oT;NA_i2gDKn@_i6oT;NA_i2oTKn@]i6oT;nA_i2oTKn@_i6oT;nAah2A_h04d;nAai6oTKn@_i77TKn
Aai6oTLN00177TKnBai6oTLNA_i;7TKn009oo`03001oogoo019oo`009goo00<007ooOol0;Goo00<0
04/NCah00TlN00E;7TlNCai?7T/N00=?7P05Bai?7TlNCai;7P03Cah01D/NCai?7TlNBah00dlN00E;
7TlNCai?7T/N00=?7P05Bai?7TlNCai;7P03Cah01D/NCai?7TlNBah00dlN00E;7TlNCai?7T/N009?
7PX000Hj_P06?]hj_SZn>[hngSjn1SkN00I2gSkN?]hngT;N?]h6@]h01T;n@]i2oT;N@_i2gPI2oP06
A_i2oTKn@_i6oT;n0dKn00=2oTKnA_h04TKn00<004KnA_h00dKn00=77TKnA_h00Woo00<007ooOol0
4Woo000WOol00`00Oomoo`0^Ool0<TlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7Dln
Bae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlN
Bad900005d/MCai;7Dln?]i2oSkN@_hfWCZn=Ydj_SZm>[hj_CZn>[dngSZm?]hj_SkN>[d00ckN02Tn
_D;N?]i2gSkM@]hngT;n?]e2oSkN@_hngD;n@]i2oT;M@_i2gT;n@]e6oT;NA_i2gDKn@]i6oT;MA_i2
oTKn@]i6oT;nA_i2gTKn@_i6oT;n00=6oP06@_i77TKnA_i2oTLN0dKn00e77TKnAah004/NA_i77TKn
Bai6oTLNA_i;7P02Ool00`00Oomoo`0AOol002Moo`03001oogoo02moo`03Cai;7TlN009?7P05Bai?
7TlNCai;7P03Cah01D/NCai?7TlNBah00dlN00E;7TlNCai?7T/N00=?7P05Bai?7TlNCai;7P03Cah0
0d/NCah0000900001D/NCai?7TlNBah00dlN00I;7TlNCai?7T/NCah4?]h00cJn>[hf_P04>[h01Cjn
>[hngSZn?[h00SkN00<n_SkN?]h013kN00=2gSkN?]h00T;N00@ngT;N@]i2oP=2gP06@_i2gT;n@]i2
oT;N0T;n00Y6oT;n@_i2oTKn@_i6oT;nA_i2oP=6oP03@_i6oTKn0156oP030016oTKn00A6oP05Aai6
oWooOol0000COol002Moo`03001oogoo031oo`0MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7Dln
Bae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7P0900006dlnBae?7T/MCci;7DlNBae??T/MCai;7Dln
Bae?7T/MCci;7DlNBae??T/MCai;7Dln>[hngP02>[h043JM>[hfWC[N>[dj_SZm?]hj_CkN>[dngSjn
?]hj_D;N0SkN02Xn_D;n?]i2gSkM@_hngT;n?]e2oT;N@_hngD;n@]i2oT;MA_i2gTKn@]e6oT;NA_i2
gDKn@]i6oT;NA_i2oTKn@]i6oT;nA_i2oTKn@_i6oT;nAah2A_h00d;nAai6oP02A_h03dLNA_i77TKn
Aai6oP00A_i;7TKnAai6oT/NA_i77P03000COol002Moo`03001oogoo031oo`03001?7T/N00=?7P05
Bai?7TlNCai;7P03Cah01D/NCai?7TlNBah02P0000=?7T/NCah00TlN00E;7TlNCai?7T/N00=?7P05
Bai?7TlNCai;7P03Cah01D/NCai?7TlNBah00dlN00E;7TlNCai?7T/N008jgP03?]hj_SZn00Lj_P04
?[hj_SkN>[h8?]h014;N?]i2gSkN0d;N00@ngT;N@]i2oP=2gP03@_i2gT;n0092oP04@]i2oT;nA_h3
@_h01TKn@_i6oT;nA_i2oQE6oP030016oTKn0096oP04Aai6oTKnA_h2Ool00`00Oomoo`0AOol002Mo
o`03001oogoo035oo`09Bae?7T/MCci;7DlNBae??T/M00T0001^Bae??T/MCai;7DlnBae?7T/MCci;
7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;
7DlnBae?7T/M>]hj_S[N=Ydj_SJM>[hj_CkN>[dngSZm?]hj_CkN>[dngSjn?]hn_D;N?]i2gSkM@_hn
gT;N?]e2oSkN@_hngD;n@]i2oSkMA_i2gT;n@]e6oT;NA_i2gDKn@]i6oT;MA_i2oTKn@]i6oT;nA_i2
oTKn@_i6oT;nA_i2oTKn@_i77P=6oP0AAai6oTKnA_i77TKnAai6oP00A_i77TKnBai6oTLNA_i;7P02
Ool00`00Oomoo`0AOol002Moo`03001oogoo031oo`X0009?7P05Bai?7TlNCai;7P03Cah01D/NCai?
7TlNBah00dlN00E;7TlNCai?7T/N00=?7P05Bai?7TlNCai;7P03Cah01D/NCai?7TlNBah00dlN00E;
7TlNCai?7T/N00=?7P04Bai?7TlNCah3>[h00c[N=[hj_P05>[h01SkN>[hn_SZn?]hn_PHngP04@]hn
gT;N?]h8@]h01T;n@]i2oT;N@_i2gP=2oP09@]i2oT;nA_i2oTKn@_i6oT;n00=6oP03@_i6oTKn0196
oP030016oTKn00=6oP05Aai6oWooOol0000COol002Ioo`03001oogoo02Qoo`T000=oo`1kBae?7T/M
Cci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/M
Cai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7SJm
>[hf_SZn=Ydj_SJM>[hj_CkN>[dngSZm?]hj_CkN>[dngSjn@]hn_D;N?]i2gSkM@_hngT;N?]e2oSkN
@_hngD;n@]i2oT;MA_i2gT;n@]e6oT;NA_i2gDKn@]i6oT;MA_i2oTKn@]i6oT;nA_i2oTKn@_i6oT;n
00=6oP0G@_i77TKnAai6oTLNA_i77TKnAai6oTLN001;7TKnAai6oT/NA_i77TKnOol0000COol002Io
o`03001oogoo01moo`T000eoo`9?7P05Bai?7TlNCai;7P03Cah01D/NCai?7TlNBah00dlN00E;7TlN
Cai?7T/N00=?7P05Bai?7TlNCai;7P03Cah01D/NCai?7TlNBah00dlN00E;7TlNCai?7T/N00=?7P05
Bai?7TlNCai;7P03Cah01d/NCai?7SZn=[hj_SJn00Pj_P04?]hj_Sjn>[h8?]h014;N?]i2gSkN14;N
00Y2oT;N@]i2gT;n@]i2oT;N@_i2gPA2oP08A_i2oTKn@_i6oT;nA_i2oP=6oP03@_i6oTKn0116oP05
0016oTKnA_i77P03A_h00dLNOol0000COol002Ioo`03001oogoo01Eoo`X001Ioo`1@001;7DlNBae?
?T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?
7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7CJn=Ydj
_SJM>[hfWCZn>[dj_SZm?]hj_SkN>[dngSjn?]hj_@8ngP0[@]hn_D;N?]i2gSkM@_hngT;n?]e2oT;N
@_hngD;n@]i2oT;MA_i2gTKn@]e6oT;NA_i2gDKn@]i6oT;NA_i2oTKn@_i6oT;nA_i2oTKn@_i6oT;n
Aah00TKn01E2oTLNA_i77TKnAai6oTLNA_i77TKn0016oT/NA_i77TKnBai6oWoo00004goo000VOol0
0`00Oomoo`0<Ool9000QOol3Cah01D/NCai?7TlNBah00dlN00E;7TlNCai?7T/N00=?7P05Bai?7TlN
Cai;7P03Cah01D/NCai?7TlNBah00dlN00E;7TlNCai?7T/N00=?7P05Bai?7TlNCai;7P03Cah03T/N
Cai?7TlNBai?7T/NCai;7TlNBahf_SJM=[h7>[h2?[h00ckN>[hngP07?]h014;N?]i2gSkN1T;N00I2
oT;N@]i2gT;n@]h3@_h02D;N@_i2oTKn@_i6oT;nA_i2oP03A_h00d;nA_i6oP0CA_h00`00A_i6oP02
A_h00dLNA_i6oP02Ool00`00Oomoo`0@Ool002Ioo`03001oogoo009oo`X002]oo`1mCci;7DlNBae?
?T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?
7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCahfWCZn=Ydj
_SJm>[hfWCkN>[dn_SZm?]hj_SkN>[dngSjn?]hj_D;N?]i2gSjm@_hngT;N?]e2oSkN@_hngD;n@]i2
oT;MA_i2gT;n@]e6oT;NA_i2gDKn@]i6oT;MA_i2oTKn@]i6oT;nA_i2oTKn@_i6oT;nAai2oTKn@_i7
7P03A_h04dLNA_i77TKnAai6oTLNA_h004KnAai6oT/NA_i77TKnBaioo`00019oo`009Woo1@00=Woo
0dlN00E;7TlNCai?7T/N00=?7P05Bai?7TlNCai;7P03Cah01D/NCai?7TlNBah00dlN00E;7TlNCai?
7T/N00=?7P05Bai?7TlNCai;7P03Cah01D/NCai?7TlNBah00dlN00E;7TlNCai?7T/N00@000Aoo`Pj
_P03?]hn_SkN00TngP03@]hngT;N00M2gP06@_i2gT;n@]i2oT;N0T;n00I6oT;NA_i2oTKn@_h3A_h0
0d;nA_i6oP0EA_h01000A_i6oTLN0dKn00A77TKnOol0019oo`009goo00<007ooOol0>7oo02Y??T/M
Cai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/M
Cci;7DlNBae??T/MCai;7DlnBad7000BOol0=SZm?]hj_Cjn>[dngSZn?]hn_CkN?[i2gSkM@]hngT;N
?]e2oSkN@]hngD;n?]i2oT;M@_i2gT;n@]e6oT;N@_i2gDKn@]i6oT;MA_i2gTKn@]e6oT;nA_i2gTKn
@_i6oT;nAai2oTKn@_i77P96oP0F@_i77TKnAai6oTLNA_i77TKnAai6oTLN001;7TKnAai6oT/NA_i7
7Woo000BOol002Qoo`03001oogoo03Qoo`=?7P05Bai?7TlNCai;7P03Cah01D/NCai?7TlNBah00dlN
00E;7TlNCai?7T/N00=?7P03Bai?7P0000P0021oo`04?]hj_SkN?[h8?]h00d;N?]i2gP05@]h01T;n
@]i2oT;N@_i2gP=2oP09@]i2oT;nA_i2oTKn@_i6oT;n00=6oP03@_i6oTKn01A6oP050016oTKnA_i7
7P03A_h00dLN001oo`0AOol002Uoo`03001oogoo03Moo`0EBae??T/MCai;7DlnBae?7T/MCci;7DlN
Bae??T/MCai;7DlnBae?7T/M00L0039oo`0/?]i2gSkM@]hngT;N?]e2oSkN@_hngD;n?]i2oT;M@_i2
gT;n@]e6oT;NA_i2gDKn@]i6oT;MA_i2gTKn@]i6oT;nA_i2oTKn@_i6oT;nAai2oTKn@_i77P96oP0D
@_i77TKnAai6oTLNA_i77TKnAah004LNA_i;7TKnAai6oT/NA_h0019oo`00:Woo00<007ooOol0=goo
00E;7TlNCai?7T/N00=?7PT004Uoo`03@]i2oT;N00=2oP04@]i2oT;nA_h3@_h01TKn@_i6oT;nA_i2
oQQ6oP030016oTLN00=6oP04Aai6oTKn000BOol002]oo`03001oogoo03Moo`H006Aoo`0<@_i6oT;N
A_i2oTKn@_i6oT;nA_i2oTLN0TKn01I2oTLNA_i77TKnAai6oTLNA_i77TKnAai6oP00A_i77TKnBai6
oT/NA_h0019oo`00;7oo00<007ooOol0=Woo00<007ooOol0PWoo00<007ooOol01Goo00<007ooOol0
47oo000]Ool00`00Oomoo`0eOol00`00Oomoo`22Ool00`00Oomoo`05Ool00`00Oomoo`0@Ool002io
o`03001oogoo03Aoo`03001oogoo08=oo`03001oogoo00Aoo`03001oogoo011oo`00;goo00<007oo
Ool0<goo00<007ooOol0Pgoo00<007ooOol017oo00<007ooOol047oo000`Ool00`00Oomoo`0bOol0
0`00Oomoo`23Ool00`00Oomoo`04Ool00`00Oomoo`0@Ool0035oo`03001oogoo035oo`03001oogoo
08=oo`03001oogoo00Aoo`03001oogoo011oo`00<Woo00<007ooOol0<7oo00<007ooOol0Q7oo00<0
07ooOol017oo00<007ooOol03goo000cOol00`00Oomoo`0_Ool00`00Oomoo`24Ool00`00Oomoo`04
Ool00`00Oomoo`0?Ool003Aoo`03001oogoo02eoo`03001oogoo08Eoo`03001oogoo00Aoo`03001o
ogoo00moo`00=Goo0P00;Goo00<007ooOol0QGoo00<007ooOol017oo00<007ooOol03goo000gOol0
0`00Oomoo`0ZOol00`00Oomoo`26Ool00`00Oomoo`03Ool00`00Oomoo`0?Ool003Qoo`03001oogoo
02Uoo`03001oogoo08Ioo`03001oogoo00=oo`03001oogoo00moo`00>Goo00<007ooOol0:7oo00<0
07ooOol0QWoo00<007ooOol00goo00<007ooOol03goo000jOol00`00Oomoo`0WOol00`00Oomoo`26
Ool00`00Oomoo`03Ool00`00Oomoo`0?Ool003]oo`03001oogoo02Ioo`03001oogoo08Moo`03001o
ogoo009oo`03001oogoo00moo`00?7oo00<007ooOol09Goo00<007ooOol0Qgoo00<007ooOol00Woo
00<007ooOol03goo000mOol00`00Oomoo`0TOol00`00Oomoo`27Ool00`00Oomoo`02Ool00`00Oomo
o`0?Ool003ioo`03001oogoo02=oo`03001oogoo08Qoo`05001oogooOol0000AOol003moo`03001o
ogoo029oo`03001oogoo08Qoo`05001oogooOol0000AOol0041oo`03001oogoo025oo`03001oogoo
08Qoo`05001oogooOol0000AOol0045oo`03001oogoo021oo`03001oogoo08Qoo`03001oogoo009o
o`03001oogoo00ioo`00@Woo00<007ooOol07goo00<007ooOol0RGoo00D007ooOomoo`00011oo`00
@goo00<007ooOol07Woo00<007ooOol0RGoo00D007ooOomoo`00011oo`00A7oo00<007ooOol07Goo
00<007ooOol0RGoo00D007ooOomoo`00011oo`00AGoo00<007ooOol077oo00<007ooOol0RGoo00D0
07ooOomoo`00011oo`00AWoo00<007ooOol06goo00<007ooOol0RWoo00@007ooOol0011oo`00Agoo
00<007ooOol06Goo00<007ooOol0Rgoo00@007ooOol0011oo`00B7oo00<007ooOol067oo00<007oo
Ool0Rgoo00@007ooOol0011oo`00BGoo00<007ooOol05goo00<007ooOol0S7oo00<007oo000047oo
001:Ool00`00Oomoo`0FOol00`00Oomoo`2<Ool00`00Ool0000@Ool004]oo`03001oogoo01Eoo`03
001oogoo08aoo`03001oo`00011oo`00C7oo00<007ooOol057oo00<007ooOol0S7oo00<007oo0000
47oo001=Ool00`00Oomoo`0COol00`00Oomoo`2=Ool2000@Ool004ioo`03001oogoo019oo`03001o
ogoo08eoo`80011oo`00Cgoo00<007ooOol04Goo00<007ooOol0SGoo00<007oo00003goo001@Ool0
0`00Oomoo`0@Ool00`00Oomoo`2=Ool00`00Ool0000?Ool0055oo`03001oogoo00moo`03001oogoo
08ioo`8000moo`00DWoo00<007ooOol03Woo00<007ooOol0SWoo0P003goo001COol2000>Ool00`00
Oomoo`2>Ool2000?Ool005Eoo`03001oogoo00]oo`03001oogoo08ioo`8000moo`00EWoo00<007oo
Ool02Woo00<007ooOol0Sgoo00<007ooOol03Goo001GOol00`00Oomoo`09Ool00`00Oomoo`29Ool7
000?Ool005Qoo`03001oogoo00Qoo`03001oogoo07]oo`h001Ioo`00FGoo00<007ooOol01goo00<0
07ooOol0KWoo3@0097oo001JOol00`00Oomoo`05Ool00`00Oomoo`1ROol=000aOol005]oo`03001o
ogoo00Aoo`03001oogoo05Aoo`h003ioo`00G7oo00<007ooOol00goo00<007ooOol0Agoo3@00C7oo
0014Ool3000FOol00`00Oomoo`02Ool00`00Oomoo`0jOol=001IOol004Eoo`03001oogoo01Ioo`05
001oogooOol0000^Ool>001VOol004Eoo`<001Moo`04001oogoo000QOol=001dOol004Eoo`04001o
ogoo000GOol00`00Ool0000DOol=0021Ool004Eoo`04001oogoo000HOol20006Ool>002>Ool004Ao
o`@001Yoo`L009aoo`00ogoo1Woo003oOol6Ool00?moo`Ioo`00ogoo1Woo003oOol6Ool00?moo`Io
o`00ogoo1Woo001lOol200000goo00000002Ool40003Ool20004Ool20004Ool20003Ool5001UOol0
07eoo`03001oo`0000Uoo`04001oogoo0008Ool01000Oomoo`0017oo00<007ooOol0IGoo001nOol0
0`00Oomoo`02Ool40002Ool01000Oomoo`0027oo00@007ooOol000Aoo`03001oogoo06Eoo`00O7oo
0P0000=oo`00000027oo00@007ooOol000Qoo`04001oogoo0004Ool00`00Oomoo`1UOol008Uoo`04
001oogoo0008Ool01000Oomoo`0017oo00<007ooOol0IGoo002:Ool2000:Ool20004Ool2001WOol0
0?moo`Ioo`00ogoo1Woo003oOol6Ool00?moo`Ioo`00\
\>"],
  ImageRangeCache->{{{0, 260.5}, {184.125, 0}} -> {-0.170371, 0.0461608, \
0.00439067, 0.00439067}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .70824 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1.10169 -0.148196 1.10169 [
[.5 .72074 -20 0 ]
[.5 .72074 20 15 ]
[.44797 -0.02478 -4.90556 -15 ]
[.44797 -0.02478 5.09444 0 ]
[.15892 .66839 -5.31917 0 ]
[.15892 .66839 4.68083 15 ]
[-0.06694 .27471 -10 -6.62571 ]
[-0.06694 .27471 0 8.37429 ]
[ 0 0 0 0 ]
[ 1 .70824 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .72074 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.437500 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(=) show
75.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.02) show
99.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math1Mono
%%DocumentNeededResources: + font Courier
%%DocumentNeededFonts: Math1Mono
%%DocumentNeededFont: + Courier
%%DocumentFonts: font Math1Mono
%%DocumentFonts: + font Courier
grestore
.25 Mabswid
.02946 .11175 m
.89362 0 L
s
gsave
.44797 -0.02478 -65.9056 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(u) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
0 .4272 m
.29069 .70824 L
s
gsave
.15892 .66839 -66.3192 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(p) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.02946 .11175 m
0 .4272 L
s
gsave
-0.06694 .27471 -71 -10.6257 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(q) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.02946 .11175 m
0 .4272 L
s
0 .4272 m
.29069 .70824 L
s
.29069 .70824 m
.30155 .45044 L
s
.30155 .45044 m
.02946 .11175 L
s
.89362 0 m
.98022 .38351 L
s
.98022 .38351 m
1 .65325 L
s
1 .65325 m
.91448 .33294 L
s
.91448 .33294 m
.89362 0 L
s
.02946 .11175 m
0 .4272 L
s
0 .4272 m
.91448 .33294 L
s
.91448 .33294 m
.89362 0 L
s
.89362 0 m
.02946 .11175 L
s
.30155 .45044 m
.98022 .38351 L
s
.98022 .38351 m
1 .65325 L
s
1 .65325 m
.29069 .70824 L
s
.29069 .70824 m
.30155 .45044 L
s
0 0 m
1 0 L
1 .70824 L
0 .70824 L
closepath
clip
newpath
.617 .786 .963 r
.29526 .44261 .30155 .45044 .32048 .44857 .31431 .44072 Mtetra
.31431 .44072 .32048 .44857 .33945 .44752 .33342 .43882 Mtetra
.456 .682 .962 r
.33342 .43882 .33945 .44752 .35824 .45383 .3524 .44255 Mtetra
.414 .595 .919 r
.3524 .44255 .35824 .45383 .37714 .46031 .37137 .44987 Mtetra
.417 .615 .932 r
.37137 .44987 .37714 .46031 .39617 .46624 .39049 .45637 Mtetra
.431 .637 .942 r
.39049 .45637 .39617 .46624 .41532 .47143 .40973 .46196 Mtetra
.449 .658 .95 r
.40973 .46196 .41532 .47143 .4346 .47587 .42911 .4667 Mtetra
.466 .675 .955 r
.42911 .4667 .4346 .47587 .45399 .47963 .44861 .47069 Mtetra
.481 .69 .959 r
.44861 .47069 .45399 .47963 .47348 .48279 .46821 .47402 Mtetra
.495 .703 .962 r
.46821 .47402 .47348 .48279 .49308 .48542 .48792 .47679 Mtetra
.507 .713 .964 r
.48792 .47679 .49308 .48542 .51277 .4876 .50773 .47908 Mtetra
.517 .722 .966 r
.50773 .47908 .51277 .4876 .53255 .48939 .52763 .48094 Mtetra
.526 .73 .967 r
.52763 .48094 .53255 .48939 .55242 .49083 .54762 .48245 Mtetra
.533 .736 .968 r
.54762 .48245 .55242 .49083 .57238 .49197 .5677 .48364 Mtetra
.54 .742 .969 r
.5677 .48364 .57238 .49197 .59241 .49284 .58786 .48456 Mtetra
.546 .746 .97 r
.58786 .48456 .59241 .49284 .61253 .49349 .60811 .48524 Mtetra
.551 .751 .97 r
.60811 .48524 .61253 .49349 .63273 .49393 .62843 .4857 Mtetra
.555 .754 .97 r
.62843 .4857 .63273 .49393 .653 .49418 .64883 .48598 Mtetra
.559 .757 .971 r
.64883 .48598 .653 .49418 .67335 .49428 .66931 .48609 Mtetra
.562 .76 .971 r
.66931 .48609 .67335 .49428 .69378 .49422 .68987 .48604 Mtetra
.565 .763 .971 r
.68987 .48604 .69378 .49422 .71429 .49404 .71051 .48587 Mtetra
.568 .765 .971 r
.71051 .48587 .71429 .49404 .73486 .49374 .73122 .48557 Mtetra
.57 .767 .971 r
.73122 .48557 .73486 .49374 .75552 .49333 .75201 .48516 Mtetra
.572 .769 .972 r
.75201 .48516 .75552 .49333 .77624 .49282 .77287 .48465 Mtetra
.574 .771 .972 r
.77287 .48465 .77624 .49282 .79704 .49223 .79381 .48405 Mtetra
.576 .772 .972 r
.79381 .48405 .79704 .49223 .81792 .49155 .81482 .48336 Mtetra
.578 .773 .972 r
.81482 .48336 .81792 .49155 .83887 .4908 .8359 .4826 Mtetra
.579 .775 .972 r
.8359 .4826 .83887 .4908 .85989 .48997 .85707 .48177 Mtetra
.58 .776 .972 r
.85707 .48177 .85989 .48997 .88099 .48908 .8783 .48087 Mtetra
.581 .777 .972 r
.8783 .48087 .88099 .48908 .90216 .48814 .89962 .47991 Mtetra
.582 .778 .972 r
.89962 .47991 .90216 .48814 .9234 .48713 .921 .47889 Mtetra
.583 .779 .972 r
.921 .47889 .9234 .48713 .94472 .48608 .94246 .47782 Mtetra
.584 .78 .973 r
.94246 .47782 .94472 .48608 .96611 .48498 .964 .47671 Mtetra
.585 .78 .973 r
.964 .47671 .96611 .48498 .98757 .48383 .98561 .47554 Mtetra
.617 .786 .963 r
.2889 .43469 .29526 .44261 .31431 .44072 .30806 .43277 Mtetra
.30806 .43277 .31431 .44072 .33342 .43882 .32729 .43085 Mtetra
.551 .755 .972 r
.32729 .43085 .33342 .43882 .3524 .44255 .3465 .43114 Mtetra
.386 .578 .916 r
.3465 .43114 .3524 .44255 .37137 .44987 .36554 .4393 Mtetra
.397 .603 .93 r
.36554 .4393 .37137 .44987 .39049 .45637 .38473 .44637 Mtetra
.417 .629 .941 r
.38473 .44637 .39049 .45637 .40973 .46196 .40408 .45237 Mtetra
.439 .652 .949 r
.40408 .45237 .40973 .46196 .42911 .4667 .42356 .45742 Mtetra
.458 .671 .955 r
.42356 .45742 .42911 .4667 .44861 .47069 .44316 .46163 Mtetra
.476 .687 .959 r
.44316 .46163 .44861 .47069 .46821 .47402 .46288 .46514 Mtetra
.491 .7 .962 r
.46288 .46514 .46821 .47402 .48792 .47679 .4827 .46804 Mtetra
.503 .711 .964 r
.4827 .46804 .48792 .47679 .50773 .47908 .50263 .47043 Mtetra
.514 .721 .966 r
.50263 .47043 .50773 .47908 .52763 .48094 .52265 .47239 Mtetra
.524 .728 .967 r
.52265 .47239 .52763 .48094 .54762 .48245 .54276 .47396 Mtetra
.532 .735 .968 r
.54276 .47396 .54762 .48245 .5677 .48364 .56296 .47521 Mtetra
.538 .741 .969 r
.56296 .47521 .5677 .48364 .58786 .48456 .58325 .47617 Mtetra
.544 .746 .97 r
.58325 .47617 .58786 .48456 .60811 .48524 .60362 .47688 Mtetra
.55 .75 .97 r
.60362 .47688 .60811 .48524 .62843 .4857 .62407 .47737 Mtetra
.554 .754 .97 r
.62407 .47737 .62843 .4857 .64883 .48598 .6446 .47766 Mtetra
.558 .757 .971 r
.6446 .47766 .64883 .48598 .66931 .48609 .66522 .47778 Mtetra
.561 .76 .971 r
.66522 .47778 .66931 .48609 .68987 .48604 .68591 .47775 Mtetra
.565 .762 .971 r
.68591 .47775 .68987 .48604 .71051 .48587 .70668 .47758 Mtetra
.567 .765 .971 r
.70668 .47758 .71051 .48587 .73122 .48557 .72752 .47729 Mtetra
.57 .767 .971 r
.72752 .47729 .73122 .48557 .75201 .48516 .74845 .47688 Mtetra
.572 .769 .972 r
.74845 .47688 .75201 .48516 .77287 .48465 .76945 .47636 Mtetra
.574 .77 .972 r
.76945 .47636 .77287 .48465 .79381 .48405 .79052 .47576 Mtetra
.576 .772 .972 r
.79052 .47576 .79381 .48405 .81482 .48336 .81167 .47507 Mtetra
.577 .773 .972 r
.81167 .47507 .81482 .48336 .8359 .4826 .8329 .47429 Mtetra
.579 .775 .972 r
.8329 .47429 .8359 .4826 .85707 .48177 .85421 .47345 Mtetra
.58 .776 .972 r
.85421 .47345 .85707 .48177 .8783 .48087 .87559 .47254 Mtetra
.581 .777 .972 r
.87559 .47254 .8783 .48087 .89962 .47991 .89704 .47157 Mtetra
.582 .778 .972 r
.89704 .47157 .89962 .47991 .921 .47889 .91857 .47054 Mtetra
.583 .779 .972 r
.91857 .47054 .921 .47889 .94246 .47782 .94018 .46945 Mtetra
.584 .779 .973 r
.94018 .46945 .94246 .47782 .964 .47671 .96187 .46832 Mtetra
.585 .78 .973 r
.96187 .46832 .964 .47671 .98561 .47554 .98363 .46714 Mtetra
.617 .786 .963 r
.28245 .42666 .2889 .43469 .30806 .43277 .30173 .42472 Mtetra
.30173 .42472 .30806 .43277 .32729 .43085 .32107 .42277 Mtetra
.32107 .42277 .32729 .43085 .3465 .43114 .34048 .42082 Mtetra
.356 .585 .93 r
.34048 .42082 .3465 .43114 .36554 .4393 .35963 .4286 Mtetra
.377 .59 .928 r
.35963 .4286 .36554 .4393 .38473 .44637 .37891 .43625 Mtetra
.403 .62 .94 r
.37891 .43625 .38473 .44637 .40408 .45237 .39835 .44267 Mtetra
.428 .645 .948 r
.39835 .44267 .40408 .45237 .42356 .45742 .41793 .44801 Mtetra
.451 .666 .955 r
.41793 .44801 .42356 .45742 .44316 .46163 .43764 .45245 Mtetra
.47 .683 .959 r
.43764 .45245 .44316 .46163 .46288 .46514 .45747 .45614 Mtetra
.486 .698 .962 r
.45747 .45614 .46288 .46514 .4827 .46804 .47741 .45918 Mtetra
.5 .709 .964 r
.47741 .45918 .4827 .46804 .50263 .47043 .49746 .46168 Mtetra
.512 .719 .966 r
.49746 .46168 .50263 .47043 .52265 .47239 .5176 .46372 Mtetra
.521 .727 .967 r
.5176 .46372 .52265 .47239 .54276 .47396 .53783 .46536 Mtetra
.53 .734 .968 r
.53783 .46536 .54276 .47396 .56296 .47521 .55816 .46666 Mtetra
.537 .74 .969 r
.55816 .46666 .56296 .47521 .58325 .47617 .57857 .46766 Mtetra
.543 .745 .97 r
.57857 .46766 .58325 .47617 .60362 .47688 .59907 .4684 Mtetra
.548 .749 .97 r
.59907 .4684 .60362 .47688 .62407 .47737 .61965 .46892 Mtetra
.553 .753 .97 r
.61965 .46892 .62407 .47737 .6446 .47766 .64032 .46923 Mtetra
.557 .757 .971 r
.64032 .46923 .6446 .47766 .66522 .47778 .66106 .46937 Mtetra
.561 .759 .971 r
.66106 .46937 .66522 .47778 .68591 .47775 .68189 .46935 Mtetra
.564 .762 .971 r
.68189 .46935 .68591 .47775 .70668 .47758 .70279 .46918 Mtetra
.567 .764 .971 r
.70279 .46918 .70668 .47758 .72752 .47729 .72378 .46889 Mtetra
.569 .767 .972 r
.72378 .46889 .72752 .47729 .74845 .47688 .74484 .46848 Mtetra
.571 .768 .972 r
.74484 .46848 .74845 .47688 .76945 .47636 .76598 .46796 Mtetra
.573 .77 .972 r
.76598 .46796 .76945 .47636 .79052 .47576 .78719 .46735 Mtetra
.575 .772 .972 r
.78719 .46735 .79052 .47576 .81167 .47507 .80849 .46665 Mtetra
.577 .773 .972 r
.80849 .46665 .81167 .47507 .8329 .47429 .82986 .46587 Mtetra
.578 .774 .972 r
.82986 .46587 .8329 .47429 .85421 .47345 .8513 .46502 Mtetra
.58 .776 .972 r
.8513 .46502 .85421 .47345 .87559 .47254 .87283 .4641 Mtetra
.581 .777 .972 r
.87283 .4641 .87559 .47254 .89704 .47157 .89443 .46311 Mtetra
.582 .778 .972 r
.89443 .46311 .89704 .47157 .91857 .47054 .91611 .46206 Mtetra
.583 .779 .972 r
.91611 .46206 .91857 .47054 .94018 .46945 .93787 .46096 Mtetra
.584 .779 .973 r
.93787 .46096 .94018 .46945 .96187 .46832 .9597 .45981 Mtetra
.585 .78 .973 r
.9597 .45981 .96187 .46832 .98363 .46714 .98161 .45862 Mtetra
.617 .786 .963 r
.27591 .41853 .28245 .42666 .30173 .42472 .29531 .41656 Mtetra
.29531 .41656 .30173 .42472 .32107 .42277 .31477 .41458 Mtetra
.31477 .41458 .32107 .42277 .34048 .42082 .3343 .4126 Mtetra
.368 .65 .965 r
.3343 .4126 .34048 .42082 .35963 .4286 .35365 .41777 Mtetra
.356 .577 .924 r
.35365 .41777 .35963 .4286 .37891 .43625 .37301 .426 Mtetra
.389 .611 .938 r
.37301 .426 .37891 .43625 .39835 .44267 .39254 .43283 Mtetra
.418 .639 .947 r
.39254 .43283 .39835 .44267 .41793 .44801 .41223 .43848 Mtetra
.443 .661 .954 r
.41223 .43848 .41793 .44801 .43764 .45245 .43205 .44316 Mtetra
.464 .68 .959 r
.43205 .44316 .43764 .45245 .45747 .45614 .45199 .44702 Mtetra
.482 .695 .962 r
.45199 .44702 .45747 .45614 .47741 .45918 .47205 .4502 Mtetra
.496 .707 .964 r
.47205 .4502 .47741 .45918 .49746 .46168 .49221 .4528 Mtetra
.509 .717 .966 r
.49221 .4528 .49746 .46168 .5176 .46372 .51248 .45493 Mtetra
.519 .726 .967 r
.51248 .45493 .5176 .46372 .53783 .46536 .53284 .45664 Mtetra
.528 .733 .968 r
.53284 .45664 .53783 .46536 .55816 .46666 .55329 .45799 Mtetra
.535 .739 .969 r
.55329 .45799 .55816 .46666 .57857 .46766 .57383 .45903 Mtetra
.542 .744 .97 r
.57383 .45903 .57857 .46766 .59907 .4684 .59446 .45981 Mtetra
.547 .749 .97 r
.59446 .45981 .59907 .4684 .61965 .46892 .61518 .46035 Mtetra
.552 .753 .97 r
.61518 .46035 .61965 .46892 .64032 .46923 .63597 .46069 Mtetra
.556 .756 .971 r
.63597 .46069 .64032 .46923 .66106 .46937 .65685 .46084 Mtetra
.56 .759 .971 r
.65685 .46084 .66106 .46937 .68189 .46935 .67782 .46083 Mtetra
.563 .762 .971 r
.67782 .46083 .68189 .46935 .70279 .46918 .69886 .46067 Mtetra
.566 .764 .971 r
.69886 .46067 .70279 .46918 .72378 .46889 .71998 .46037 Mtetra
.569 .766 .972 r
.71998 .46037 .72378 .46889 .74484 .46848 .74118 .45996 Mtetra
.571 .768 .972 r
.74118 .45996 .74484 .46848 .76598 .46796 .76246 .45944 Mtetra
.573 .77 .972 r
.76246 .45944 .76598 .46796 .78719 .46735 .78382 .45883 Mtetra
.575 .771 .972 r
.78382 .45883 .78719 .46735 .80849 .46665 .80525 .45812 Mtetra
.577 .773 .972 r
.80525 .45812 .80849 .46665 .82986 .46587 .82677 .45733 Mtetra
.578 .774 .972 r
.82677 .45733 .82986 .46587 .8513 .46502 .84836 .45647 Mtetra
.579 .775 .972 r
.84836 .45647 .8513 .46502 .87283 .4641 .87003 .45553 Mtetra
.581 .776 .972 r
.87003 .45553 .87283 .4641 .89443 .46311 .89178 .45453 Mtetra
.582 .777 .972 r
.89178 .45453 .89443 .46311 .91611 .46206 .91361 .45347 Mtetra
.583 .778 .972 r
.91361 .45347 .91611 .46206 .93787 .46096 .93552 .45236 Mtetra
.584 .779 .973 r
.93552 .45236 .93787 .46096 .9597 .45981 .9575 .45119 Mtetra
.585 .78 .973 r
.9575 .45119 .9597 .45981 .98161 .45862 .97957 .44997 Mtetra
.617 .786 .963 r
.26929 .41028 .27591 .41853 .29531 .41656 .28881 .40829 Mtetra
.28881 .40829 .29531 .41656 .31477 .41458 .30839 .40629 Mtetra
.30839 .40629 .31477 .41458 .3343 .4126 .32804 .40428 Mtetra
.475 .713 .974 r
.32804 .40428 .3343 .4126 .35365 .41777 .34759 .4068 Mtetra
.335 .563 .921 r
.34759 .4068 .35365 .41777 .37301 .426 .36704 .41562 Mtetra
.374 .601 .936 r
.36704 .41562 .37301 .426 .39254 .43283 .38667 .42287 Mtetra
.407 .632 .946 r
.38667 .42287 .39254 .43283 .41223 .43848 .40645 .42883 Mtetra
.435 .657 .953 r
.40645 .42883 .41223 .43848 .43205 .44316 .42638 .43374 Mtetra
.458 .676 .958 r
.42638 .43374 .43205 .44316 .45199 .44702 .44644 .43778 Mtetra
.477 .692 .962 r
.44644 .43778 .45199 .44702 .47205 .4502 .46662 .4411 Mtetra
.493 .705 .964 r
.46662 .4411 .47205 .4502 .49221 .4528 .4869 .44381 Mtetra
.506 .716 .966 r
.4869 .44381 .49221 .4528 .51248 .45493 .50729 .44602 Mtetra
.517 .724 .967 r
.50729 .44602 .51248 .45493 .53284 .45664 .52778 .4478 Mtetra
.526 .732 .968 r
.52778 .4478 .53284 .45664 .55329 .45799 .54836 .44921 Mtetra
.534 .738 .969 r
.54836 .44921 .55329 .45799 .57383 .45903 .56903 .45029 Mtetra
.54 .743 .97 r
.56903 .45029 .57383 .45903 .59446 .45981 .58979 .4511 Mtetra
.546 .748 .97 r
.58979 .4511 .59446 .45981 .61518 .46035 .61064 .45167 Mtetra
.551 .752 .97 r
.61064 .45167 .61518 .46035 .63597 .46069 .63157 .45202 Mtetra
.556 .756 .971 r
.63157 .45202 .63597 .46069 .65685 .46084 .65259 .45219 Mtetra
.559 .759 .971 r
.65259 .45219 .65685 .46084 .67782 .46083 .67368 .45219 Mtetra
.563 .761 .971 r
.67368 .45219 .67782 .46083 .69886 .46067 .69487 .45203 Mtetra
.566 .764 .971 r
.69487 .45203 .69886 .46067 .71998 .46037 .71613 .45174 Mtetra
.568 .766 .972 r
.71613 .45174 .71998 .46037 .74118 .45996 .73747 .45133 Mtetra
.571 .768 .972 r
.73747 .45133 .74118 .45996 .76246 .45944 .75889 .45081 Mtetra
.573 .77 .972 r
.75889 .45081 .76246 .45944 .78382 .45883 .78039 .45018 Mtetra
.575 .771 .972 r
.78039 .45018 .78382 .45883 .80525 .45812 .80198 .44947 Mtetra
.576 .773 .972 r
.80198 .44947 .80525 .45812 .82677 .45733 .82364 .44867 Mtetra
.578 .774 .972 r
.82364 .44867 .82677 .45733 .84836 .45647 .84538 .44779 Mtetra
.579 .775 .972 r
.84538 .44779 .84836 .45647 .87003 .45553 .8672 .44685 Mtetra
.581 .776 .972 r
.8672 .44685 .87003 .45553 .89178 .45453 .8891 .44583 Mtetra
.582 .777 .972 r
.8891 .44583 .89178 .45453 .91361 .45347 .91108 .44476 Mtetra
.583 .778 .972 r
.91108 .44476 .91361 .45347 .93552 .45236 .93314 .44362 Mtetra
.584 .779 .973 r
.93314 .44362 .93552 .45236 .9575 .45119 .95527 .44244 Mtetra
.585 .78 .973 r
.95527 .44244 .9575 .45119 .97957 .44997 .97749 .4412 Mtetra
.617 .786 .963 r
.26258 .40193 .26929 .41028 .28881 .40829 .28222 .39991 Mtetra
.28222 .39991 .28881 .40829 .30839 .40629 .30192 .39788 Mtetra
.30192 .39788 .30839 .40629 .32804 .40428 .32169 .39584 Mtetra
.564 .761 .97 r
.32169 .39584 .32804 .40428 .34759 .4068 .34145 .39569 Mtetra
.313 .548 .916 r
.34145 .39569 .34759 .4068 .36704 .41562 .36098 .4051 Mtetra
.358 .591 .933 r
.36098 .4051 .36704 .41562 .38667 .42287 .38071 .41278 Mtetra
.396 .625 .945 r
.38071 .41278 .38667 .42287 .40645 .42883 .4006 .41905 Mtetra
.427 .652 .953 r
.4006 .41905 .40645 .42883 .42638 .43374 .42064 .42419 Mtetra
.452 .673 .958 r
.42064 .42419 .42638 .43374 .44644 .43778 .44082 .42841 Mtetra
.473 .689 .962 r
.44082 .42841 .44644 .43778 .46662 .4411 .46111 .43187 Mtetra
.489 .703 .964 r
.46111 .43187 .46662 .4411 .4869 .44381 .48152 .4347 Mtetra
.503 .714 .966 r
.48152 .4347 .4869 .44381 .50729 .44602 .50203 .43699 Mtetra
.514 .723 .967 r
.50203 .43699 .50729 .44602 .52778 .4478 .52264 .43884 Mtetra
.524 .731 .968 r
.52264 .43884 .52778 .4478 .54836 .44921 .54336 .4403 Mtetra
.532 .737 .969 r
.54336 .4403 .54836 .44921 .56903 .45029 .56416 .44143 Mtetra
.539 .743 .97 r
.56416 .44143 .56903 .45029 .58979 .4511 .58505 .44228 Mtetra
.545 .747 .97 r
.58505 .44228 .58979 .4511 .61064 .45167 .60604 .44287 Mtetra
.55 .751 .971 r
.60604 .44287 .61064 .45167 .63157 .45202 .6271 .44324 Mtetra
.555 .755 .971 r
.6271 .44324 .63157 .45202 .65259 .45219 .64826 .44342 Mtetra
.559 .758 .971 r
.64826 .44342 .65259 .45219 .67368 .45219 .6695 .44342 Mtetra
.562 .761 .971 r
.6695 .44342 .67368 .45219 .69487 .45203 .69082 .44327 Mtetra
.565 .763 .971 r
.69082 .44327 .69487 .45203 .71613 .45174 .71222 .44299 Mtetra
.568 .766 .972 r
.71222 .44299 .71613 .45174 .73747 .45133 .73371 .44257 Mtetra
.57 .768 .972 r
.73371 .44257 .73747 .45133 .75889 .45081 .75527 .44205 Mtetra
.572 .769 .972 r
.75527 .44205 .75889 .45081 .78039 .45018 .77692 .44142 Mtetra
.574 .771 .972 r
.77692 .44142 .78039 .45018 .80198 .44947 .79865 .44069 Mtetra
.576 .773 .972 r
.79865 .44069 .80198 .44947 .82364 .44867 .82046 .43988 Mtetra
.578 .774 .972 r
.82046 .43988 .82364 .44867 .84538 .44779 .84235 .439 Mtetra
.579 .775 .972 r
.84235 .439 .84538 .44779 .8672 .44685 .86432 .43803 Mtetra
.58 .776 .972 r
.86432 .43803 .8672 .44685 .8891 .44583 .88637 .43701 Mtetra
.581 .777 .972 r
.88637 .43701 .8891 .44583 .91108 .44476 .90851 .43592 Mtetra
.583 .778 .972 r
.90851 .43592 .91108 .44476 .93314 .44362 .93072 .43477 Mtetra
.583 .779 .973 r
.93072 .43477 .93314 .44362 .95527 .44244 .95301 .43356 Mtetra
.584 .78 .973 r
.95301 .43356 .95527 .44244 .97749 .4412 .97539 .43231 Mtetra
.617 .786 .963 r
.25578 .39346 .26258 .40193 .28222 .39991 .27554 .39141 Mtetra
.27554 .39141 .28222 .39991 .30192 .39788 .29536 .38936 Mtetra
.29536 .38936 .30192 .39788 .32169 .39584 .31525 .38729 Mtetra
.31525 .38729 .32169 .39584 .34145 .39569 .33521 .38522 Mtetra
.287 .549 .923 r
.33521 .38522 .34145 .39569 .36098 .4051 .35486 .39445 Mtetra
.343 .581 .931 r
.35486 .39445 .36098 .4051 .38071 .41278 .37468 .40255 Mtetra
.385 .618 .944 r
.37468 .40255 .38071 .41278 .4006 .41905 .39467 .40914 Mtetra
.419 .647 .952 r
.39467 .40914 .4006 .41905 .42064 .42419 .41482 .41452 Mtetra
.446 .669 .958 r
.41482 .41452 .42064 .42419 .44082 .42841 .43511 .41892 Mtetra
.468 .687 .962 r
.43511 .41892 .44082 .42841 .46111 .43187 .45553 .42252 Mtetra
.486 .701 .964 r
.45553 .42252 .46111 .43187 .48152 .4347 .47606 .42546 Mtetra
.5 .712 .966 r
.47606 .42546 .48152 .4347 .50203 .43699 .4967 .42784 Mtetra
.512 .722 .967 r
.4967 .42784 .50203 .43699 .52264 .43884 .51744 .42976 Mtetra
.522 .73 .968 r
.51744 .42976 .52264 .43884 .54336 .4403 .53828 .43127 Mtetra
.531 .736 .969 r
.53828 .43127 .54336 .4403 .56416 .44143 .55922 .43245 Mtetra
.538 .742 .97 r
.55922 .43245 .56416 .44143 .58505 .44228 .58025 .43332 Mtetra
.544 .747 .97 r
.58025 .43332 .58505 .44228 .60604 .44287 .60137 .43394 Mtetra
.549 .751 .971 r
.60137 .43394 .60604 .44287 .6271 .44324 .62258 .43433 Mtetra
.554 .755 .971 r
.62258 .43433 .6271 .44324 .64826 .44342 .64387 .43453 Mtetra
.558 .758 .971 r
.64387 .43453 .64826 .44342 .6695 .44342 .66525 .43454 Mtetra
.561 .761 .971 r
.66525 .43454 .6695 .44342 .69082 .44327 .68671 .43439 Mtetra
.565 .763 .971 r
.68671 .43439 .69082 .44327 .71222 .44299 .70826 .43411 Mtetra
.567 .765 .972 r
.70826 .43411 .71222 .44299 .73371 .44257 .72989 .43369 Mtetra
.57 .767 .972 r
.72989 .43369 .73371 .44257 .75527 .44205 .75161 .43316 Mtetra
.572 .769 .972 r
.75161 .43316 .75527 .44205 .77692 .44142 .7734 .43253 Mtetra
.574 .771 .972 r
.7734 .43253 .77692 .44142 .79865 .44069 .79528 .43179 Mtetra
.576 .772 .972 r
.79528 .43179 .79865 .44069 .82046 .43988 .81724 .43097 Mtetra
.577 .774 .972 r
.81724 .43097 .82046 .43988 .84235 .439 .83928 .43007 Mtetra
.579 .775 .972 r
.83928 .43007 .84235 .439 .86432 .43803 .86141 .4291 Mtetra
.58 .776 .972 r
.86141 .4291 .86432 .43803 .88637 .43701 .88361 .42805 Mtetra
.581 .777 .972 r
.88361 .42805 .88637 .43701 .90851 .43592 .9059 .42695 Mtetra
.582 .778 .972 r
.9059 .42695 .90851 .43592 .93072 .43477 .92827 .42578 Mtetra
.583 .779 .973 r
.92827 .42578 .93072 .43477 .95301 .43356 .95072 .42456 Mtetra
.584 .78 .973 r
.95072 .42456 .95301 .43356 .97539 .43231 .97325 .42328 Mtetra
.617 .786 .963 r
.24888 .38488 .25578 .39346 .27554 .39141 .26877 .3828 Mtetra
.26877 .3828 .27554 .39141 .29536 .38936 .28872 .38072 Mtetra
.28872 .38072 .29536 .38936 .31525 .38729 .30873 .37863 Mtetra
.30873 .37863 .31525 .38729 .33521 .38522 .32882 .37653 Mtetra
.286 .596 .949 r
.32882 .37653 .33521 .38522 .35486 .39445 .34865 .38366 Mtetra
.327 .571 .928 r
.34865 .38366 .35486 .39445 .37468 .40255 .36856 .39219 Mtetra
.374 .611 .942 r
.36856 .39219 .37468 .40255 .39467 .40914 .38866 .3991 Mtetra
.411 .642 .951 r
.38866 .3991 .39467 .40914 .41482 .41452 .40893 .40472 Mtetra
.44 .665 .957 r
.40893 .40472 .41482 .41452 .43511 .41892 .42933 .4093 Mtetra
.463 .684 .961 r
.42933 .4093 .43511 .41892 .45553 .42252 .44987 .41304 Mtetra
.482 .699 .964 r
.44987 .41304 .45553 .42252 .47606 .42546 .47053 .41609 Mtetra
.497 .711 .966 r
.47053 .41609 .47606 .42546 .4967 .42784 .49129 .41856 Mtetra
.51 .72 .967 r
.49129 .41856 .4967 .42784 .51744 .42976 .51217 .42055 Mtetra
.52 .728 .968 r
.51217 .42055 .51744 .42976 .53828 .43127 .53314 .42212 Mtetra
.529 .735 .969 r
.53314 .42212 .53828 .43127 .55922 .43245 .55421 .42334 Mtetra
.537 .741 .97 r
.55421 .42334 .55922 .43245 .58025 .43332 .57538 .42425 Mtetra
.543 .746 .97 r
.57538 .42425 .58025 .43332 .60137 .43394 .59664 .42489 Mtetra
.548 .75 .971 r
.59664 .42489 .60137 .43394 .62258 .43433 .61798 .4253 Mtetra
.553 .754 .971 r
.61798 .4253 .62258 .43433 .64387 .43453 .63942 .42551 Mtetra
.557 .757 .971 r
.63942 .42551 .64387 .43453 .66525 .43454 .66094 .42553 Mtetra
.561 .76 .971 r
.66094 .42553 .66525 .43454 .68671 .43439 .68255 .42539 Mtetra
.564 .763 .971 r
.68255 .42539 .68671 .43439 .70826 .43411 .70424 .4251 Mtetra
.567 .765 .972 r
.70424 .4251 .70826 .43411 .72989 .43369 .72602 .42469 Mtetra
.569 .767 .972 r
.72602 .42469 .72989 .43369 .75161 .43316 .74788 .42415 Mtetra
.572 .769 .972 r
.74788 .42415 .75161 .43316 .7734 .43253 .76983 .42351 Mtetra
.574 .771 .972 r
.76983 .42351 .7734 .43253 .79528 .43179 .79186 .42276 Mtetra
.575 .772 .972 r
.79186 .42276 .79528 .43179 .81724 .43097 .81397 .42193 Mtetra
.577 .773 .972 r
.81397 .42193 .81724 .43097 .83928 .43007 .83617 .42102 Mtetra
.579 .775 .972 r
.83617 .42102 .83928 .43007 .86141 .4291 .85845 .42003 Mtetra
.58 .776 .972 r
.85845 .42003 .86141 .4291 .88361 .42805 .88081 .41897 Mtetra
.581 .777 .972 r
.88081 .41897 .88361 .42805 .9059 .42695 .90325 .41785 Mtetra
.582 .778 .972 r
.90325 .41785 .9059 .42695 .92827 .42578 .92578 .41666 Mtetra
.583 .779 .973 r
.92578 .41666 .92827 .42578 .95072 .42456 .94839 .41542 Mtetra
.584 .78 .973 r
.94839 .41542 .95072 .42456 .97325 .42328 .97109 .41413 Mtetra
.617 .786 .963 r
.24189 .37618 .24888 .38488 .26877 .3828 .2619 .37407 Mtetra
.2619 .37407 .26877 .3828 .28872 .38072 .28198 .37196 Mtetra
.28198 .37196 .28872 .38072 .30873 .37863 .30212 .36984 Mtetra
.30212 .36984 .30873 .37863 .32882 .37653 .32233 .36771 Mtetra
.379 .656 .966 r
.32233 .36771 .32882 .37653 .34865 .38366 .34235 .37273 Mtetra
.311 .56 .925 r
.34235 .37273 .34865 .38366 .36856 .39219 .36237 .3817 Mtetra
.363 .604 .94 r
.36237 .3817 .36856 .39219 .38866 .3991 .38257 .38892 Mtetra
.403 .637 .95 r
.38257 .38892 .38866 .3991 .40893 .40472 .40295 .39478 Mtetra
.434 .662 .957 r
.40295 .39478 .40893 .40472 .42933 .4093 .42348 .39955 Mtetra
.459 .681 .961 r
.42348 .39955 .42933 .4093 .44987 .41304 .44413 .40343 Mtetra
.478 .696 .964 r
.44413 .40343 .44987 .41304 .47053 .41609 .46492 .40659 Mtetra
.494 .709 .966 r
.46492 .40659 .47053 .41609 .49129 .41856 .48581 .40915 Mtetra
.508 .719 .967 r
.48581 .40915 .49129 .41856 .51217 .42055 .50682 .41121 Mtetra
.518 .727 .968 r
.50682 .41121 .51217 .42055 .53314 .42212 .52793 .41284 Mtetra
.527 .734 .969 r
.52793 .41284 .53314 .42212 .55421 .42334 .54914 .4141 Mtetra
.535 .74 .97 r
.54914 .4141 .55421 .42334 .57538 .42425 .57044 .41504 Mtetra
.542 .745 .97 r
.57044 .41504 .57538 .42425 .59664 .42489 .59184 .41571 Mtetra
.547 .75 .971 r
.59184 .41571 .59664 .42489 .61798 .4253 .61333 .41614 Mtetra
.552 .754 .971 r
.61333 .41614 .61798 .4253 .63942 .42551 .6349 .41636 Mtetra
.557 .757 .971 r
.6349 .41636 .63942 .42551 .66094 .42553 .65657 .41639 Mtetra
.56 .76 .971 r
.65657 .41639 .66094 .42553 .68255 .42539 .67833 .41625 Mtetra
.564 .762 .972 r
.67833 .41625 .68255 .42539 .70424 .4251 .70017 .41597 Mtetra
.566 .765 .972 r
.70017 .41597 .70424 .4251 .72602 .42469 .7221 .41555 Mtetra
.569 .767 .972 r
.7221 .41555 .72602 .42469 .74788 .42415 .74411 .41501 Mtetra
.571 .769 .972 r
.74411 .41501 .74788 .42415 .76983 .42351 .76621 .41436 Mtetra
.573 .77 .972 r
.76621 .41436 .76983 .42351 .79186 .42276 .78839 .41361 Mtetra
.575 .772 .972 r
.78839 .41361 .79186 .42276 .81397 .42193 .81066 .41276 Mtetra
.577 .773 .972 r
.81066 .41276 .81397 .42193 .83617 .42102 .83301 .41184 Mtetra
.578 .775 .972 r
.83301 .41184 .83617 .42102 .85845 .42003 .85544 .41083 Mtetra
.58 .776 .972 r
.85544 .41083 .85845 .42003 .88081 .41897 .87796 .40976 Mtetra
.581 .777 .972 r
.87796 .40976 .88081 .41897 .90325 .41785 .90057 .40861 Mtetra
.582 .778 .972 r
.90057 .40861 .90325 .41785 .92578 .41666 .92326 .40741 Mtetra
.583 .779 .973 r
.92326 .40741 .92578 .41666 .94839 .41542 .94603 .40615 Mtetra
.584 .78 .973 r
.94603 .40615 .94839 .41542 .97109 .41413 .96889 .40484 Mtetra
.617 .786 .963 r
.2348 .36736 .24189 .37618 .2619 .37407 .25494 .36522 Mtetra
.25494 .36522 .2619 .37407 .28198 .37196 .27515 .36308 Mtetra
.27515 .36308 .28198 .37196 .30212 .36984 .29542 .36093 Mtetra
.29542 .36093 .30212 .36984 .32233 .36771 .31576 .35877 Mtetra
.462 .705 .973 r
.31576 .35877 .32233 .36771 .34235 .37273 .33598 .36165 Mtetra
.295 .549 .921 r
.33598 .36165 .34235 .37273 .36237 .3817 .35609 .37106 Mtetra
.351 .596 .938 r
.35609 .37106 .36237 .3817 .38257 .38892 .3764 .37861 Mtetra
.395 .631 .949 r
.3764 .37861 .38257 .38892 .40295 .39478 .39689 .38471 Mtetra
.428 .658 .956 r
.39689 .38471 .40295 .39478 .42348 .39955 .41754 .38966 Mtetra
.454 .678 .961 r
.41754 .38966 .42348 .39955 .44413 .40343 .43832 .39369 Mtetra
.475 .694 .964 r
.43832 .39369 .44413 .40343 .46492 .40659 .45923 .39696 Mtetra
.492 .707 .966 r
.45923 .39696 .46492 .40659 .48581 .40915 .48026 .39961 Mtetra
.505 .718 .967 r
.48026 .39961 .48581 .40915 .50682 .41121 .50139 .40174 Mtetra
.516 .726 .968 r
.50139 .40174 .50682 .41121 .52793 .41284 .52264 .40342 Mtetra
.526 .733 .969 r
.52264 .40342 .52793 .41284 .54914 .4141 .54399 .40473 Mtetra
.534 .74 .97 r
.54399 .40473 .54914 .4141 .57044 .41504 .56543 .4057 Mtetra
.541 .745 .97 r
.56543 .4057 .57044 .41504 .59184 .41571 .58697 .4064 Mtetra
.546 .749 .971 r
.58697 .4064 .59184 .41571 .61333 .41614 .6086 .40685 Mtetra
.551 .753 .971 r
.6086 .40685 .61333 .41614 .6349 .41636 .63033 .40708 Mtetra
.556 .756 .971 r
.63033 .40708 .6349 .41636 .65657 .41639 .65214 .40712 Mtetra
.56 .759 .971 r
.65214 .40712 .65657 .41639 .67833 .41625 .67404 .40699 Mtetra
.563 .762 .972 r
.67404 .40699 .67833 .41625 .70017 .41597 .69603 .4067 Mtetra
.566 .764 .972 r
.69603 .4067 .70017 .41597 .7221 .41555 .71811 .40628 Mtetra
.569 .767 .972 r
.71811 .40628 .7221 .41555 .74411 .41501 .74028 .40573 Mtetra
.571 .768 .972 r
.74028 .40573 .74411 .41501 .76621 .41436 .76253 .40507 Mtetra
.573 .77 .972 r
.76253 .40507 .76621 .41436 .78839 .41361 .78487 .40431 Mtetra
.575 .772 .972 r
.78487 .40431 .78839 .41361 .81066 .41276 .80729 .40346 Mtetra
.577 .773 .972 r
.80729 .40346 .81066 .41276 .83301 .41184 .8298 .40252 Mtetra
.578 .774 .972 r
.8298 .40252 .83301 .41184 .85544 .41083 .8524 .4015 Mtetra
.579 .776 .972 r
.8524 .4015 .85544 .41083 .87796 .40976 .87508 .4004 Mtetra
.581 .777 .972 r
.87508 .4004 .87796 .40976 .90057 .40861 .89784 .39924 Mtetra
.582 .778 .972 r
.89784 .39924 .90057 .40861 .92326 .40741 .9207 .39802 Mtetra
.583 .779 .973 r
.9207 .39802 .92326 .40741 .94603 .40615 .94363 .39674 Mtetra
.584 .779 .973 r
.94363 .39674 .94603 .40615 .96889 .40484 .96666 .39541 Mtetra
.617 .786 .963 r
.22762 .35841 .2348 .36736 .25494 .36522 .24788 .35625 Mtetra
.24788 .35625 .25494 .36522 .27515 .36308 .26822 .35407 Mtetra
.26822 .35407 .27515 .36308 .29542 .36093 .28862 .35189 Mtetra
.28862 .35189 .29542 .36093 .31576 .35877 .30909 .34971 Mtetra
.535 .745 .973 r
.30909 .34971 .31576 .35877 .33598 .36165 .32952 .35043 Mtetra
.278 .538 .917 r
.32952 .35043 .33598 .36165 .35609 .37106 .34973 .36028 Mtetra
.34 .589 .936 r
.34973 .36028 .35609 .37106 .3764 .37861 .37015 .36815 Mtetra
.386 .626 .948 r
.37015 .36815 .3764 .37861 .39689 .38471 .39075 .37449 Mtetra
.422 .654 .956 r
.39075 .37449 .39689 .38471 .41754 .38966 .41151 .37964 Mtetra
.449 .675 .96 r
.41151 .37964 .41754 .38966 .43832 .39369 .43242 .38381 Mtetra
.471 .692 .964 r
.43242 .38381 .43832 .39369 .45923 .39696 .45346 .3872 Mtetra
.489 .705 .966 r
.45346 .3872 .45923 .39696 .48026 .39961 .47462 .38994 Mtetra
.503 .716 .967 r
.47462 .38994 .48026 .39961 .50139 .40174 .49589 .39214 Mtetra
.515 .725 .968 r
.49589 .39214 .50139 .40174 .52264 .40342 .51728 .39387 Mtetra
.524 .732 .969 r
.51728 .39387 .52264 .40342 .54399 .40473 .53876 .39522 Mtetra
.533 .739 .97 r
.53876 .39522 .54399 .40473 .56543 .4057 .56035 .39623 Mtetra
.54 .744 .97 r
.56035 .39623 .56543 .4057 .58697 .4064 .58203 .39695 Mtetra
.546 .749 .971 r
.58203 .39695 .58697 .4064 .6086 .40685 .60381 .39742 Mtetra
.551 .753 .971 r
.60381 .39742 .6086 .40685 .63033 .40708 .62568 .39766 Mtetra
.555 .756 .971 r
.62568 .39766 .63033 .40708 .65214 .40712 .64764 .39771 Mtetra
.559 .759 .971 r
.64764 .39771 .65214 .40712 .67404 .40699 .6697 .39758 Mtetra
.562 .762 .972 r
.6697 .39758 .67404 .40699 .69603 .4067 .69184 .3973 Mtetra
.565 .764 .972 r
.69184 .3973 .69603 .4067 .71811 .40628 .71407 .39687 Mtetra
.568 .766 .972 r
.71407 .39687 .71811 .40628 .74028 .40573 .73639 .39632 Mtetra
.571 .768 .972 r
.73639 .39632 .74028 .40573 .76253 .40507 .7588 .39565 Mtetra
.573 .77 .972 r
.7588 .39565 .76253 .40507 .78487 .40431 .78129 .39488 Mtetra
.575 .772 .972 r
.78129 .39488 .78487 .40431 .80729 .40346 .80388 .39401 Mtetra
.576 .773 .972 r
.80388 .39401 .80729 .40346 .8298 .40252 .82655 .39306 Mtetra
.578 .774 .972 r
.82655 .39306 .8298 .40252 .8524 .4015 .8493 .39202 Mtetra
.579 .775 .972 r
.8493 .39202 .8524 .4015 .87508 .4004 .87215 .39091 Mtetra
.58 .777 .972 r
.87215 .39091 .87508 .4004 .89784 .39924 .89508 .38974 Mtetra
.582 .778 .973 r
.89508 .38974 .89784 .39924 .9207 .39802 .9181 .38849 Mtetra
.583 .778 .973 r
.9181 .38849 .9207 .39802 .94363 .39674 .9412 .38719 Mtetra
.584 .779 .973 r
.9412 .38719 .94363 .39674 .96666 .39541 .9644 .38583 Mtetra
.617 .786 .963 r
.22033 .34934 .22762 .35841 .24788 .35625 .24073 .34715 Mtetra
.24073 .34715 .24788 .35625 .26822 .35407 .26119 .34494 Mtetra
.26119 .34494 .26822 .35407 .28862 .35189 .28173 .34273 Mtetra
.28173 .34273 .28862 .35189 .30909 .34971 .30233 .34051 Mtetra
.597 .777 .966 r
.30233 .34051 .30909 .34971 .32952 .35043 .32298 .33905 Mtetra
.261 .526 .913 r
.32298 .33905 .32952 .35043 .34973 .36028 .34328 .34935 Mtetra
.328 .581 .934 r
.34328 .34935 .34973 .36028 .37015 .36815 .3638 .35755 Mtetra
.378 .621 .947 r
.3638 .35755 .37015 .36815 .39075 .37449 .38452 .36414 Mtetra
.415 .65 .955 r
.38452 .36414 .39075 .37449 .41151 .37964 .40541 .36947 Mtetra
.445 .672 .96 r
.40541 .36947 .41151 .37964 .43242 .38381 .42644 .37379 Mtetra
.467 .69 .963 r
.42644 .37379 .43242 .38381 .45346 .3872 .44761 .3773 Mtetra
.486 .704 .966 r
.44761 .3773 .45346 .3872 .47462 .38994 .4689 .38013 Mtetra
.5 .715 .967 r
.4689 .38013 .47462 .38994 .49589 .39214 .49031 .38239 Mtetra
.513 .724 .968 r
.49031 .38239 .49589 .39214 .51728 .39387 .51184 .38419 Mtetra
.523 .732 .969 r
.51184 .38419 .51728 .39387 .53876 .39522 .53346 .38558 Mtetra
.531 .738 .97 r
.53346 .38558 .53876 .39522 .56035 .39623 .55519 .38662 Mtetra
.538 .743 .97 r
.55519 .38662 .56035 .39623 .58203 .39695 .57702 .38737 Mtetra
.545 .748 .971 r
.57702 .38737 .58203 .39695 .60381 .39742 .59895 .38786 Mtetra
.55 .752 .971 r
.59895 .38786 .60381 .39742 .62568 .39766 .62097 .38811 Mtetra
.554 .756 .971 r
.62097 .38811 .62568 .39766 .64764 .39771 .64308 .38817 Mtetra
.558 .759 .971 r
.64308 .38817 .64764 .39771 .6697 .39758 .66529 .38804 Mtetra
.562 .761 .972 r
.66529 .38804 .6697 .39758 .69184 .3973 .68758 .38776 Mtetra
.565 .764 .972 r
.68758 .38776 .69184 .3973 .71407 .39687 .70997 .38733 Mtetra
.568 .766 .972 r
.70997 .38733 .71407 .39687 .73639 .39632 .73245 .38677 Mtetra
.57 .768 .972 r
.73245 .38677 .73639 .39632 .7588 .39565 .75501 .38609 Mtetra
.572 .77 .972 r
.75501 .38609 .7588 .39565 .78129 .39488 .77767 .38531 Mtetra
.574 .771 .972 r
.77767 .38531 .78129 .39488 .80388 .39401 .80041 .38443 Mtetra
.576 .773 .972 r
.80041 .38443 .80388 .39401 .82655 .39306 .82324 .38346 Mtetra
.578 .774 .972 r
.82324 .38346 .82655 .39306 .8493 .39202 .84616 .38241 Mtetra
.579 .775 .972 r
.84616 .38241 .8493 .39202 .87215 .39091 .86917 .38128 Mtetra
.58 .776 .972 r
.86917 .38128 .87215 .39091 .89508 .38974 .89227 .38008 Mtetra
.581 .777 .973 r
.89227 .38008 .89508 .38974 .9181 .38849 .91546 .37882 Mtetra
.583 .778 .973 r
.91546 .37882 .9181 .38849 .9412 .38719 .93873 .3775 Mtetra
.583 .779 .973 r
.93873 .3775 .9412 .38719 .9644 .38583 .9621 .37612 Mtetra
.617 .786 .963 r
.21294 .34014 .22033 .34934 .24073 .34715 .23347 .33792 Mtetra
.23347 .33792 .24073 .34715 .26119 .34494 .25407 .33568 Mtetra
.25407 .33568 .26119 .34494 .28173 .34273 .27474 .33344 Mtetra
.27474 .33344 .28173 .34273 .30233 .34051 .29547 .33119 Mtetra
.29547 .33119 .30233 .34051 .32298 .33905 .31628 .32893 Mtetra
.236 .542 .926 r
.31628 .32893 .32298 .33905 .34328 .34935 .33674 .33827 Mtetra
.316 .573 .932 r
.33674 .33827 .34328 .34935 .3638 .35755 .35737 .3468 Mtetra
.369 .615 .946 r
.35737 .3468 .3638 .35755 .38452 .36414 .37821 .35364 Mtetra
.409 .646 .954 r
.37821 .35364 .38452 .36414 .40541 .36947 .39922 .35916 Mtetra
.44 .669 .96 r
.39922 .35916 .40541 .36947 .42644 .37379 .42038 .36363 Mtetra
.464 .688 .963 r
.42038 .36363 .42644 .37379 .44761 .3773 .44168 .36725 Mtetra
.483 .702 .966 r
.44168 .36725 .44761 .3773 .4689 .38013 .46311 .37017 Mtetra
.498 .713 .967 r
.46311 .37017 .4689 .38013 .49031 .38239 .48466 .37251 Mtetra
.511 .723 .968 r
.48466 .37251 .49031 .38239 .51184 .38419 .50632 .37436 Mtetra
.521 .731 .969 r
.50632 .37436 .51184 .38419 .53346 .38558 .52809 .3758 Mtetra
.53 .737 .97 r
.52809 .3758 .53346 .38558 .55519 .38662 .54996 .37688 Mtetra
.537 .743 .97 r
.54996 .37688 .55519 .38662 .57702 .38737 .57194 .37765 Mtetra
.544 .747 .971 r
.57194 .37765 .57702 .38737 .59895 .38786 .59401 .37815 Mtetra
.549 .752 .971 r
.59401 .37815 .59895 .38786 .62097 .38811 .61618 .37842 Mtetra
.554 .755 .971 r
.61618 .37842 .62097 .38811 .64308 .38817 .63845 .37848 Mtetra
.558 .758 .971 r
.63845 .37848 .64308 .38817 .66529 .38804 .66081 .37836 Mtetra
.561 .761 .972 r
.66081 .37836 .66529 .38804 .68758 .38776 .68326 .37808 Mtetra
.565 .764 .972 r
.68326 .37808 .68758 .38776 .70997 .38733 .70581 .37764 Mtetra
.567 .766 .972 r
.70581 .37764 .70997 .38733 .73245 .38677 .72844 .37708 Mtetra
.57 .768 .972 r
.72844 .37708 .73245 .38677 .75501 .38609 .75117 .37639 Mtetra
.572 .77 .972 r
.75117 .37639 .75501 .38609 .77767 .38531 .77399 .3756 Mtetra
.574 .771 .972 r
.77399 .3756 .77767 .38531 .80041 .38443 .7969 .3747 Mtetra
.576 .773 .972 r
.7969 .3747 .80041 .38443 .82324 .38346 .81989 .37372 Mtetra
.577 .774 .972 r
.81989 .37372 .82324 .38346 .84616 .38241 .84298 .37265 Mtetra
.579 .775 .972 r
.84298 .37265 .84616 .38241 .86917 .38128 .86616 .3715 Mtetra
.58 .776 .972 r
.86616 .3715 .86917 .38128 .89227 .38008 .88942 .37029 Mtetra
.581 .777 .973 r
.88942 .37029 .89227 .38008 .91546 .37882 .91278 .369 Mtetra
.582 .778 .973 r
.91278 .369 .91546 .37882 .93873 .3775 .93623 .36766 Mtetra
.583 .779 .973 r
.93623 .36766 .93873 .3775 .9621 .37612 .95976 .36625 Mtetra
.617 .786 .963 r
.20545 .33081 .21294 .34014 .23347 .33792 .22611 .32856 Mtetra
.22611 .32856 .23347 .33792 .25407 .33568 .24684 .32629 Mtetra
.24684 .32629 .25407 .33568 .27474 .33344 .26764 .32402 Mtetra
.26764 .32402 .27474 .33344 .29547 .33119 .28852 .32173 Mtetra
.28852 .32173 .29547 .33119 .31628 .32893 .30947 .31944 Mtetra
.276 .588 .946 r
.30947 .31944 .31628 .32893 .33674 .33827 .33011 .32704 Mtetra
.304 .565 .929 r
.33011 .32704 .33674 .33827 .35737 .3468 .35085 .3359 Mtetra
.36 .609 .944 r
.35085 .3359 .35737 .3468 .37821 .35364 .3718 .343 Mtetra
.403 .642 .954 r
.3718 .343 .37821 .35364 .39922 .35916 .39294 .34871 Mtetra
.435 .666 .959 r
.39294 .34871 .39922 .35916 .42038 .36363 .41423 .35333 Mtetra
.46 .685 .963 r
.41423 .35333 .42038 .36363 .44168 .36725 .43566 .35707 Mtetra
.48 .7 .966 r
.43566 .35707 .44168 .36725 .46311 .37017 .45723 .36008 Mtetra
.496 .712 .967 r
.45723 .36008 .46311 .37017 .48466 .37251 .47891 .36249 Mtetra
.509 .722 .968 r
.47891 .36249 .48466 .37251 .50632 .37436 .50072 .3644 Mtetra
.52 .73 .969 r
.50072 .3644 .50632 .37436 .52809 .3758 .52263 .36587 Mtetra
.529 .736 .97 r
.52263 .36587 .52809 .3758 .54996 .37688 .54466 .36699 Mtetra
.536 .742 .97 r
.54466 .36699 .54996 .37688 .57194 .37765 .56678 .36778 Mtetra
.543 .747 .971 r
.56678 .36778 .57194 .37765 .59401 .37815 .58901 .36831 Mtetra
.548 .751 .971 r
.58901 .36831 .59401 .37815 .61618 .37842 .61133 .36859 Mtetra
.553 .755 .971 r
.61133 .36859 .61618 .37842 .63845 .37848 .63375 .36866 Mtetra
.557 .758 .971 r
.63375 .36866 .63845 .37848 .66081 .37836 .65627 .36854 Mtetra
.561 .761 .972 r
.65627 .36854 .66081 .37836 .68326 .37808 .67888 .36825 Mtetra
.564 .763 .972 r
.67888 .36825 .68326 .37808 .70581 .37764 .70158 .36781 Mtetra
.567 .766 .972 r
.70158 .36781 .70581 .37764 .72844 .37708 .72438 .36724 Mtetra
.569 .768 .972 r
.72438 .36724 .72844 .37708 .75117 .37639 .74727 .36654 Mtetra
.572 .769 .972 r
.74727 .36654 .75117 .37639 .77399 .3756 .77025 .36574 Mtetra
.574 .771 .972 r
.77025 .36574 .77399 .3756 .7969 .3747 .79333 .36483 Mtetra
.575 .772 .972 r
.79333 .36483 .7969 .3747 .81989 .37372 .81649 .36383 Mtetra
.577 .774 .972 r
.81649 .36383 .81989 .37372 .84298 .37265 .83975 .36274 Mtetra
.579 .775 .972 r
.83975 .36274 .84298 .37265 .86616 .3715 .86309 .36158 Mtetra
.58 .776 .972 r
.86309 .36158 .86616 .3715 .88942 .37029 .88653 .36034 Mtetra
.581 .777 .973 r
.88653 .36034 .88942 .37029 .91278 .369 .91006 .35903 Mtetra
.582 .778 .973 r
.91006 .35903 .91278 .369 .93623 .36766 .93368 .35766 Mtetra
.583 .779 .973 r
.93368 .35766 .93623 .36766 .95976 .36625 .95739 .35624 Mtetra
.617 .786 .963 r
.19785 .32135 .20545 .33081 .22611 .32856 .21864 .31906 Mtetra
.21864 .31906 .22611 .32856 .24684 .32629 .23951 .31676 Mtetra
.23951 .31676 .24684 .32629 .26764 .32402 .26045 .31446 Mtetra
.26045 .31446 .26764 .32402 .28852 .32173 .28146 .31214 Mtetra
.28146 .31214 .28852 .32173 .30947 .31944 .30255 .30982 Mtetra
.352 .637 .961 r
.30255 .30982 .30947 .31944 .33011 .32704 .32339 .31565 Mtetra
.292 .557 .927 r
.32339 .31565 .33011 .32704 .35085 .3359 .34424 .32485 Mtetra
.352 .604 .943 r
.34424 .32485 .35085 .3359 .3718 .343 .36531 .3322 Mtetra
.396 .638 .953 r
.36531 .3322 .3718 .343 .39294 .34871 .38657 .33811 Mtetra
.43 .663 .959 r
.38657 .33811 .39294 .34871 .41423 .35333 .40799 .34288 Mtetra
.456 .683 .963 r
.40799 .34288 .41423 .35333 .43566 .35707 .42955 .34673 Mtetra
.477 .698 .965 r
.42955 .34673 .43566 .35707 .45723 .36008 .45126 .34984 Mtetra
.493 .71 .967 r
.45126 .34984 .45723 .36008 .47891 .36249 .47309 .35232 Mtetra
.507 .72 .968 r
.47309 .35232 .47891 .36249 .50072 .3644 .49504 .35428 Mtetra
.518 .729 .969 r
.49504 .35428 .50072 .3644 .52263 .36587 .5171 .3558 Mtetra
.527 .736 .97 r
.5171 .3558 .52263 .36587 .54466 .36699 .53927 .35695 Mtetra
.535 .741 .97 r
.53927 .35695 .54466 .36699 .56678 .36778 .56155 .35777 Mtetra
.542 .746 .971 r
.56155 .35777 .56678 .36778 .58901 .36831 .58393 .35831 Mtetra
.547 .751 .971 r
.58393 .35831 .58901 .36831 .61133 .36859 .60641 .35861 Mtetra
.552 .754 .971 r
.60641 .35861 .61133 .36859 .63375 .36866 .62898 .35868 Mtetra
.557 .758 .972 r
.62898 .35868 .63375 .36866 .65627 .36854 .65166 .35856 Mtetra
.56 .76 .972 r
.65166 .35856 .65627 .36854 .67888 .36825 .67443 .35827 Mtetra
.564 .763 .972 r
.67443 .35827 .67888 .36825 .70158 .36781 .6973 .35783 Mtetra
.566 .765 .972 r
.6973 .35783 .70158 .36781 .72438 .36724 .72026 .35725 Mtetra
.569 .767 .972 r
.72026 .35725 .72438 .36724 .74727 .36654 .74331 .35655 Mtetra
.571 .769 .972 r
.74331 .35655 .74727 .36654 .77025 .36574 .76646 .35573 Mtetra
.573 .771 .972 r
.76646 .35573 .77025 .36574 .79333 .36483 .7897 .3548 Mtetra
.575 .772 .972 r
.7897 .3548 .79333 .36483 .81649 .36383 .81303 .35379 Mtetra
.577 .774 .972 r
.81303 .35379 .81649 .36383 .83975 .36274 .83646 .35268 Mtetra
.578 .775 .972 r
.83646 .35268 .83975 .36274 .86309 .36158 .85998 .3515 Mtetra
.58 .776 .972 r
.85998 .3515 .86309 .36158 .88653 .36034 .88359 .35024 Mtetra
.581 .777 .973 r
.88359 .35024 .88653 .36034 .91006 .35903 .9073 .34891 Mtetra
.582 .778 .973 r
.9073 .34891 .91006 .35903 .93368 .35766 .9311 .34752 Mtetra
.583 .779 .973 r
.9311 .34752 .93368 .35766 .95739 .35624 .95499 .34607 Mtetra
.617 .786 .963 r
.19013 .31175 .19785 .32135 .21864 .31906 .21107 .30943 Mtetra
.21107 .30943 .21864 .31906 .23951 .31676 .23207 .3071 Mtetra
.23207 .3071 .23951 .31676 .26045 .31446 .25315 .30476 Mtetra
.25315 .30476 .26045 .31446 .28146 .31214 .27431 .30241 Mtetra
.27431 .30241 .28146 .31214 .30255 .30982 .29553 .30005 Mtetra
.421 .68 .97 r
.29553 .30005 .30255 .30982 .32339 .31565 .31657 .3041 Mtetra
.279 .548 .924 r
.31657 .3041 .32339 .31565 .34424 .32485 .33754 .31365 Mtetra
.343 .598 .941 r
.33754 .31365 .34424 .32485 .36531 .3322 .35872 .32125 Mtetra
.39 .634 .952 r
.35872 .32125 .36531 .3322 .38657 .33811 .3801 .32735 Mtetra
.425 .66 .958 r
.3801 .32735 .38657 .33811 .40799 .34288 .40166 .33227 Mtetra
.452 .681 .963 r
.40166 .33227 .40799 .34288 .42955 .34673 .42336 .33625 Mtetra
.474 .696 .965 r
.42336 .33625 .42955 .34673 .45126 .34984 .4452 .33944 Mtetra
.491 .709 .967 r
.4452 .33944 .45126 .34984 .47309 .35232 .46718 .342 Mtetra
.505 .719 .968 r
.46718 .342 .47309 .35232 .49504 .35428 .48927 .34402 Mtetra
.516 .728 .969 r
.48927 .34402 .49504 .35428 .5171 .3558 .51148 .34559 Mtetra
.526 .735 .97 r
.51148 .34559 .5171 .3558 .53927 .35695 .53381 .34677 Mtetra
.534 .741 .97 r
.53381 .34677 .53927 .35695 .56155 .35777 .55623 .34761 Mtetra
.541 .746 .971 r
.55623 .34761 .56155 .35777 .58393 .35831 .57877 .34817 Mtetra
.547 .75 .971 r
.57877 .34817 .58393 .35831 .60641 .35861 .60141 .34847 Mtetra
.552 .754 .971 r
.60141 .34847 .60641 .35861 .62898 .35868 .62414 .34856 Mtetra
.556 .757 .972 r
.62414 .34856 .62898 .35868 .65166 .35856 .64698 .34844 Mtetra
.56 .76 .972 r
.64698 .34844 .65166 .35856 .67443 .35827 .66991 .34815 Mtetra
.563 .763 .972 r
.66991 .34815 .67443 .35827 .6973 .35783 .69294 .3477 Mtetra
.566 .765 .972 r
.69294 .3477 .6973 .35783 .72026 .35725 .71607 .34711 Mtetra
.569 .767 .972 r
.71607 .34711 .72026 .35725 .74331 .35655 .73929 .3464 Mtetra
.571 .769 .972 r
.73929 .3464 .74331 .35655 .76646 .35573 .76261 .34556 Mtetra
.573 .771 .972 r
.76261 .34556 .76646 .35573 .7897 .3548 .78602 .34463 Mtetra
.575 .772 .972 r
.78602 .34463 .7897 .3548 .81303 .35379 .80953 .34359 Mtetra
.577 .773 .972 r
.80953 .34359 .81303 .35379 .83646 .35268 .83313 .34247 Mtetra
.578 .775 .972 r
.83313 .34247 .83646 .35268 .85998 .3515 .85682 .34126 Mtetra
.579 .776 .972 r
.85682 .34126 .85998 .3515 .88359 .35024 .88061 .33998 Mtetra
.581 .777 .973 r
.88061 .33998 .88359 .35024 .9073 .34891 .9045 .33863 Mtetra
.582 .778 .973 r
.9045 .33863 .9073 .34891 .9311 .34752 .92847 .33722 Mtetra
.583 .779 .973 r
.92847 .33722 .9311 .34752 .95499 .34607 .95255 .33574 Mtetra
.617 .786 .963 r
.18231 .30201 .19013 .31175 .21107 .30943 .20338 .29966 Mtetra
.20338 .29966 .21107 .30943 .23207 .3071 .22453 .29729 Mtetra
.22453 .29729 .23207 .3071 .25315 .30476 .24575 .29491 Mtetra
.24575 .29491 .25315 .30476 .27431 .30241 .26704 .29253 Mtetra
.26704 .29253 .27431 .30241 .29553 .30005 .28841 .29014 Mtetra
.484 .717 .973 r
.28841 .29014 .29553 .30005 .31657 .3041 .30966 .29239 Mtetra
.267 .54 .921 r
.30966 .29239 .31657 .3041 .33754 .31365 .33073 .30228 Mtetra
.334 .592 .94 r
.33073 .30228 .33754 .31365 .35872 .32125 .35204 .31014 Mtetra
.383 .629 .951 r
.35204 .31014 .35872 .32125 .3801 .32735 .37355 .31644 Mtetra
.42 .657 .958 r
.37355 .31644 .3801 .32735 .40166 .33227 .39523 .32151 Mtetra
.449 .678 .962 r
.39523 .32151 .40166 .33227 .42336 .33625 .41708 .32561 Mtetra
.471 .695 .965 r
.41708 .32561 .42336 .33625 .4452 .33944 .43906 .3289 Mtetra
.489 .708 .967 r
.43906 .3289 .4452 .33944 .46718 .342 .46118 .33153 Mtetra
.503 .718 .968 r
.46118 .33153 .46718 .342 .48927 .34402 .48342 .3336 Mtetra
.515 .727 .969 r
.48342 .3336 .48927 .34402 .51148 .34559 .50578 .33521 Mtetra
.525 .734 .97 r
.50578 .33521 .51148 .34559 .53381 .34677 .52826 .33643 Mtetra
.533 .74 .97 r
.52826 .33643 .53381 .34677 .55623 .34761 .55084 .3373 Mtetra
.54 .745 .971 r
.55084 .3373 .55623 .34761 .57877 .34817 .57353 .33787 Mtetra
.546 .75 .971 r
.57353 .33787 .57877 .34817 .60141 .34847 .59633 .33819 Mtetra
.551 .753 .971 r
.59633 .33819 .60141 .34847 .62414 .34856 .61923 .33828 Mtetra
.555 .757 .972 r
.61923 .33828 .62414 .34856 .64698 .34844 .64223 .33816 Mtetra
.559 .76 .972 r
.64223 .33816 .64698 .34844 .66991 .34815 .66533 .33787 Mtetra
.563 .762 .972 r
.66533 .33787 .66991 .34815 .69294 .3477 .68852 .33742 Mtetra
.566 .765 .972 r
.68852 .33742 .69294 .3477 .71607 .34711 .71182 .33682 Mtetra
.568 .767 .972 r
.71182 .33682 .71607 .34711 .73929 .3464 .73521 .33609 Mtetra
.571 .769 .972 r
.73521 .33609 .73929 .3464 .76261 .34556 .7587 .33524 Mtetra
.573 .77 .972 r
.7587 .33524 .76261 .34556 .78602 .34463 .78228 .33429 Mtetra
.575 .772 .972 r
.78228 .33429 .78602 .34463 .80953 .34359 .80597 .33324 Mtetra
.576 .773 .972 r
.80597 .33324 .80953 .34359 .83313 .34247 .82974 .33209 Mtetra
.578 .775 .972 r
.82974 .33209 .83313 .34247 .85682 .34126 .85361 .33087 Mtetra
.579 .776 .972 r
.85361 .33087 .85682 .34126 .88061 .33998 .87758 .32957 Mtetra
.581 .777 .973 r
.87758 .32957 .88061 .33998 .9045 .33863 .90165 .32819 Mtetra
.582 .778 .973 r
.90165 .32819 .9045 .33863 .92847 .33722 .92581 .32675 Mtetra
.583 .779 .973 r
.92581 .32675 .92847 .33722 .95255 .33574 .95006 .32525 Mtetra
.617 .786 .963 r
.17437 .29213 .18231 .30201 .20338 .29966 .19559 .28974 Mtetra
.19559 .28974 .20338 .29966 .22453 .29729 .21687 .28734 Mtetra
.21687 .28734 .22453 .29729 .24575 .29491 .23824 .28493 Mtetra
.23824 .28493 .24575 .29491 .26704 .29253 .25968 .28251 Mtetra
.25968 .28251 .26704 .29253 .28841 .29014 .28119 .28008 Mtetra
.54 .748 .972 r
.28119 .28008 .28841 .29014 .30966 .29239 .30266 .28052 Mtetra
.254 .531 .917 r
.30266 .28052 .30966 .29239 .33073 .30228 .32384 .29075 Mtetra
.325 .586 .938 r
.32384 .29075 .33073 .30228 .35204 .31014 .34526 .29887 Mtetra
.377 .625 .95 r
.34526 .29887 .35204 .31014 .37355 .31644 .3669 .30537 Mtetra
.415 .654 .957 r
.3669 .30537 .37355 .31644 .39523 .32151 .38872 .3106 Mtetra
.445 .676 .962 r
.38872 .3106 .39523 .32151 .41708 .32561 .4107 .31481 Mtetra
.468 .693 .965 r
.4107 .31481 .41708 .32561 .43906 .3289 .43283 .31819 Mtetra
.486 .706 .967 r
.43283 .31819 .43906 .3289 .46118 .33153 .45509 .3209 Mtetra
.501 .717 .968 r
.45509 .3209 .46118 .33153 .48342 .3336 .47748 .32303 Mtetra
.513 .726 .969 r
.47748 .32303 .48342 .3336 .50578 .33521 .5 .32469 Mtetra
.523 .733 .97 r
.5 .32469 .50578 .33521 .52826 .33643 .52263 .32593 Mtetra
.532 .739 .971 r
.52263 .32593 .52826 .33643 .55084 .3373 .54537 .32683 Mtetra
.539 .745 .971 r
.54537 .32683 .55084 .3373 .57353 .33787 .56822 .32742 Mtetra
.545 .749 .971 r
.56822 .32742 .57353 .33787 .59633 .33819 .59118 .32775 Mtetra
.55 .753 .971 r
.59118 .32775 .59633 .33819 .61923 .33828 .61424 .32784 Mtetra
.555 .756 .972 r
.61424 .32784 .61923 .33828 .64223 .33816 .63741 .32773 Mtetra
.559 .759 .972 r
.63741 .32773 .64223 .33816 .66533 .33787 .66067 .32743 Mtetra
.562 .762 .972 r
.66067 .32743 .66533 .33787 .68852 .33742 .68404 .32697 Mtetra
.565 .764 .972 r
.68404 .32697 .68852 .33742 .71182 .33682 .7075 .32637 Mtetra
.568 .767 .972 r
.7075 .32637 .71182 .33682 .73521 .33609 .73107 .32562 Mtetra
.57 .769 .972 r
.73107 .32562 .73521 .33609 .7587 .33524 .75473 .32476 Mtetra
.572 .77 .972 r
.75473 .32476 .7587 .33524 .78228 .33429 .77849 .32379 Mtetra
.574 .772 .972 r
.77849 .32379 .78228 .33429 .80597 .33324 .80235 .32272 Mtetra
.576 .773 .972 r
.80235 .32272 .80597 .33324 .82974 .33209 .8263 .32156 Mtetra
.578 .774 .972 r
.8263 .32156 .82974 .33209 .85361 .33087 .85036 .32031 Mtetra
.579 .776 .972 r
.85036 .32031 .85361 .33087 .87758 .32957 .87451 .31899 Mtetra
.58 .777 .973 r
.87451 .31899 .87758 .32957 .90165 .32819 .89875 .31759 Mtetra
.582 .778 .973 r
.89875 .31759 .90165 .32819 .92581 .32675 .9231 .31612 Mtetra
.583 .779 .973 r
.9231 .31612 .92581 .32675 .95006 .32525 .94754 .31459 Mtetra
.617 .786 .963 r
.16632 .28211 .17437 .29213 .19559 .28974 .18767 .27968 Mtetra
.18767 .27968 .19559 .28974 .21687 .28734 .2091 .27724 Mtetra
.2091 .27724 .21687 .28734 .23824 .28493 .23061 .2748 Mtetra
.23061 .2748 .23824 .28493 .25968 .28251 .2522 .27234 Mtetra
.2522 .27234 .25968 .28251 .28119 .28008 .27386 .26988 Mtetra
.59 .773 .967 r
.27386 .26988 .28119 .28008 .30266 .28052 .29555 .26848 Mtetra
.241 .522 .914 r
.29555 .26848 .30266 .28052 .32384 .29075 .31684 .27905 Mtetra
.316 .58 .936 r
.31684 .27905 .32384 .29075 .34526 .29887 .33839 .28744 Mtetra
.37 .621 .949 r
.33839 .28744 .34526 .29887 .3669 .30537 .36015 .29414 Mtetra
.41 .651 .957 r
.36015 .29414 .3669 .30537 .38872 .3106 .3821 .29952 Mtetra
.441 .673 .962 r
.3821 .29952 .38872 .3106 .4107 .31481 .40422 .30385 Mtetra
.465 .691 .965 r
.40422 .30385 .4107 .31481 .43283 .31819 .4265 .30733 Mtetra
.484 .705 .967 r
.4265 .30733 .43283 .31819 .45509 .3209 .44891 .31011 Mtetra
.499 .716 .968 r
.44891 .31011 .45509 .3209 .47748 .32303 .47145 .3123 Mtetra
.511 .725 .969 r
.47145 .3123 .47748 .32303 .5 .32469 .49412 .314 Mtetra
.522 .732 .97 r
.49412 .314 .5 .32469 .52263 .32593 .51691 .31528 Mtetra
.53 .739 .971 r
.51691 .31528 .52263 .32593 .54537 .32683 .53981 .3162 Mtetra
.538 .744 .971 r
.53981 .3162 .54537 .32683 .56822 .32742 .56283 .31681 Mtetra
.544 .749 .971 r
.56283 .31681 .56822 .32742 .59118 .32775 .58595 .31715 Mtetra
.549 .753 .971 r
.58595 .31715 .59118 .32775 .61424 .32784 .60917 .31724 Mtetra
.554 .756 .972 r
.60917 .31724 .61424 .32784 .63741 .32773 .63251 .31713 Mtetra
.558 .759 .972 r
.63251 .31713 .63741 .32773 .66067 .32743 .65594 .31683 Mtetra
.562 .762 .972 r
.65594 .31683 .66067 .32743 .68404 .32697 .67948 .31637 Mtetra
.565 .764 .972 r
.67948 .31637 .68404 .32697 .7075 .32637 .70312 .31575 Mtetra
.568 .766 .972 r
.70312 .31575 .7075 .32637 .73107 .32562 .72686 .315 Mtetra
.57 .768 .972 r
.72686 .315 .73107 .32562 .75473 .32476 .7507 .31412 Mtetra
.572 .77 .972 r
.7507 .31412 .75473 .32476 .77849 .32379 .77463 .31313 Mtetra
.574 .772 .972 r
.77463 .31313 .77849 .32379 .80235 .32272 .79867 .31204 Mtetra
.576 .773 .972 r
.79867 .31204 .80235 .32272 .8263 .32156 .82281 .31086 Mtetra
.577 .774 .972 r
.82281 .31086 .8263 .32156 .85036 .32031 .84705 .30959 Mtetra
.579 .775 .972 r
.84705 .30959 .85036 .32031 .87451 .31899 .87138 .30824 Mtetra
.58 .777 .973 r
.87138 .30824 .87451 .31899 .89875 .31759 .89582 .30681 Mtetra
.581 .778 .973 r
.89582 .30681 .89875 .31759 .9231 .31612 .92035 .30532 Mtetra
.582 .779 .973 r
.92035 .30532 .9231 .31612 .94754 .31459 .94498 .30376 Mtetra
.617 .786 .963 r
.15814 .27193 .16632 .28211 .18767 .27968 .17964 .26947 Mtetra
.17964 .26947 .18767 .27968 .2091 .27724 .20122 .26699 Mtetra
.20122 .26699 .2091 .27724 .23061 .2748 .22287 .26451 Mtetra
.22287 .26451 .23061 .2748 .2522 .27234 .24461 .26202 Mtetra
.24461 .26202 .2522 .27234 .27386 .26988 .26642 .25952 Mtetra
.26642 .25952 .27386 .26988 .29555 .26848 .2883 .25701 Mtetra
.226 .528 .919 r
.2883 .25701 .29555 .26848 .31684 .27905 .30974 .26719 Mtetra
.307 .574 .934 r
.30974 .26719 .31684 .27905 .33839 .28744 .33141 .27583 Mtetra
.363 .616 .948 r
.33141 .27583 .33839 .28744 .36015 .29414 .3533 .28274 Mtetra
.405 .648 .956 r
.3533 .28274 .36015 .29414 .3821 .29952 .37539 .28828 Mtetra
.437 .671 .961 r
.37539 .28828 .3821 .29952 .40422 .30385 .39765 .29273 Mtetra
.462 .689 .965 r
.39765 .29273 .40422 .30385 .4265 .30733 .42007 .2963 Mtetra
.481 .703 .967 r
.42007 .2963 .4265 .30733 .44891 .31011 .44264 .29915 Mtetra
.497 .715 .968 r
.44264 .29915 .44891 .31011 .47145 .3123 .46533 .3014 Mtetra
.51 .724 .969 r
.46533 .3014 .47145 .3123 .49412 .314 .48816 .30315 Mtetra
.52 .732 .97 r
.48816 .30315 .49412 .314 .51691 .31528 .51111 .30446 Mtetra
.529 .738 .971 r
.51111 .30446 .51691 .31528 .53981 .3162 .53417 .30541 Mtetra
.537 .743 .971 r
.53417 .30541 .53981 .3162 .56283 .31681 .55735 .30603 Mtetra
.543 .748 .971 r
.55735 .30603 .56283 .31681 .58595 .31715 .58063 .30638 Mtetra
.549 .752 .971 r
.58063 .30638 .58595 .31715 .60917 .31724 .60403 .30648 Mtetra
.553 .756 .972 r
.60403 .30648 .60917 .31724 .63251 .31713 .62753 .30637 Mtetra
.558 .759 .972 r
.62753 .30637 .63251 .31713 .65594 .31683 .65114 .30607 Mtetra
.561 .762 .972 r
.65114 .30607 .65594 .31683 .67948 .31637 .67485 .30559 Mtetra
.564 .764 .972 r
.67485 .30559 .67948 .31637 .70312 .31575 .69867 .30497 Mtetra
.567 .766 .972 r
.69867 .30497 .70312 .31575 .72686 .315 .72258 .3042 Mtetra
.57 .768 .972 r
.72258 .3042 .72686 .315 .7507 .31412 .7466 .30331 Mtetra
.572 .77 .972 r
.7466 .30331 .7507 .31412 .77463 .31313 .77072 .3023 Mtetra
.574 .771 .972 r
.77072 .3023 .77463 .31313 .79867 .31204 .79494 .30119 Mtetra
.576 .773 .972 r
.79494 .30119 .79867 .31204 .82281 .31086 .81926 .29999 Mtetra
.577 .774 .972 r
.81926 .29999 .82281 .31086 .84705 .30959 .84368 .29869 Mtetra
.579 .775 .973 r
.84368 .29869 .84705 .30959 .87138 .30824 .86821 .29732 Mtetra
.58 .776 .973 r
.86821 .29732 .87138 .30824 .89582 .30681 .89283 .29587 Mtetra
.581 .777 .973 r
.89283 .29587 .89582 .30681 .92035 .30532 .91755 .29435 Mtetra
.582 .778 .973 r
.91755 .29435 .92035 .30532 .94498 .30376 .94238 .29276 Mtetra
.617 .786 .963 r
.14985 .2616 .15814 .27193 .17964 .26947 .17149 .2591 Mtetra
.17149 .2591 .17964 .26947 .20122 .26699 .19322 .25659 Mtetra
.19322 .25659 .20122 .26699 .22287 .26451 .21502 .25407 Mtetra
.21502 .25407 .22287 .26451 .24461 .26202 .2369 .25154 Mtetra
.2369 .25154 .24461 .26202 .26642 .25952 .25886 .249 Mtetra
.25886 .249 .26642 .25952 .2883 .25701 .2809 .24646 Mtetra
.241 .562 .936 r
.2809 .24646 .2883 .25701 .30974 .26719 .30253 .25515 Mtetra
.297 .567 .932 r
.30253 .25515 .30974 .26719 .33141 .27583 .32433 .26406 Mtetra
.356 .612 .947 r
.32433 .26406 .33141 .27583 .3533 .28274 .34635 .27117 Mtetra
.4 .644 .956 r
.34635 .27117 .3533 .28274 .37539 .28828 .36858 .27686 Mtetra
.433 .669 .961 r
.36858 .27686 .37539 .28828 .39765 .29273 .39099 .28144 Mtetra
.459 .687 .965 r
.39099 .28144 .39765 .29273 .42007 .2963 .41355 .28511 Mtetra
.479 .702 .967 r
.41355 .28511 .42007 .2963 .44264 .29915 .43627 .28803 Mtetra
.495 .713 .968 r
.43627 .28803 .44264 .29915 .46533 .3014 .45912 .29034 Mtetra
.508 .723 .969 r
.45912 .29034 .46533 .3014 .48816 .30315 .4821 .29213 Mtetra
.519 .731 .97 r
.4821 .29213 .48816 .30315 .51111 .30446 .50521 .29348 Mtetra
.528 .737 .971 r
.50521 .29348 .51111 .30446 .53417 .30541 .52844 .29445 Mtetra
.536 .743 .971 r
.52844 .29445 .53417 .30541 .55735 .30603 .55178 .29509 Mtetra
.542 .748 .971 r
.55178 .29509 .55735 .30603 .58063 .30638 .57524 .29545 Mtetra
.548 .752 .971 r
.57524 .29545 .58063 .30638 .60403 .30648 .59881 .29555 Mtetra
.553 .755 .972 r
.59881 .29555 .60403 .30648 .62753 .30637 .62248 .29544 Mtetra
.557 .758 .972 r
.62248 .29544 .62753 .30637 .65114 .30607 .64626 .29513 Mtetra
.561 .761 .972 r
.64626 .29513 .65114 .30607 .67485 .30559 .67015 .29465 Mtetra
.564 .764 .972 r
.67015 .29465 .67485 .30559 .69867 .30497 .69414 .29401 Mtetra
.567 .766 .972 r
.69414 .29401 .69867 .30497 .72258 .3042 .71824 .29323 Mtetra
.569 .768 .972 r
.71824 .29323 .72258 .3042 .7466 .30331 .74244 .29232 Mtetra
.572 .77 .972 r
.74244 .29232 .7466 .30331 .77072 .3023 .76674 .2913 Mtetra
.574 .771 .972 r
.76674 .2913 .77072 .3023 .79494 .30119 .79115 .29017 Mtetra
.575 .773 .972 r
.79115 .29017 .79494 .30119 .81926 .29999 .81566 .28894 Mtetra
.577 .774 .972 r
.81566 .28894 .81926 .29999 .84368 .29869 .84027 .28762 Mtetra
.578 .775 .973 r
.84027 .28762 .84368 .29869 .86821 .29732 .86498 .28622 Mtetra
.58 .776 .973 r
.86498 .28622 .86821 .29732 .89283 .29587 .8898 .28475 Mtetra
.581 .777 .973 r
.8898 .28475 .89283 .29587 .91755 .29435 .91471 .2832 Mtetra
.582 .778 .973 r
.91471 .2832 .91755 .29435 .94238 .29276 .93974 .28158 Mtetra
.617 .786 .963 r
.14142 .25112 .14985 .2616 .17149 .2591 .16322 .24858 Mtetra
.16322 .24858 .17149 .2591 .19322 .25659 .18509 .24603 Mtetra
.18509 .24603 .19322 .25659 .21502 .25407 .20704 .24347 Mtetra
.20704 .24347 .21502 .25407 .2369 .25154 .22908 .2409 Mtetra
.22908 .2409 .2369 .25154 .25886 .249 .25119 .23833 Mtetra
.25119 .23833 .25886 .249 .2809 .24646 .27339 .23574 Mtetra
.305 .605 .952 r
.27339 .23574 .2809 .24646 .30253 .25515 .29522 .24293 Mtetra
.288 .561 .93 r
.29522 .24293 .30253 .25515 .32433 .26406 .31714 .25211 Mtetra
.349 .608 .946 r
.31714 .25211 .32433 .26406 .34635 .27117 .3393 .25942 Mtetra
.395 .641 .955 r
.3393 .25942 .34635 .27117 .36858 .27686 .36166 .26528 Mtetra
.429 .666 .961 r
.36166 .26528 .36858 .27686 .39099 .28144 .38421 .26998 Mtetra
.456 .685 .964 r
.38421 .26998 .39099 .28144 .41355 .28511 .40693 .27374 Mtetra
.476 .7 .967 r
.40693 .27374 .41355 .28511 .43627 .28803 .4298 .27674 Mtetra
.493 .712 .968 r
.4298 .27674 .43627 .28803 .45912 .29034 .45281 .27911 Mtetra
.507 .722 .969 r
.45281 .27911 .45912 .29034 .4821 .29213 .47596 .28094 Mtetra
.518 .73 .97 r
.47596 .28094 .4821 .29213 .50521 .29348 .49923 .28232 Mtetra
.527 .737 .971 r
.49923 .28232 .50521 .29348 .52844 .29445 .52262 .28331 Mtetra
.535 .742 .971 r
.52262 .28331 .52844 .29445 .55178 .29509 .54613 .28397 Mtetra
.542 .747 .971 r
.54613 .28397 .55178 .29509 .57524 .29545 .56976 .28434 Mtetra
.547 .751 .971 r
.56976 .28434 .57524 .29545 .59881 .29555 .5935 .28445 Mtetra
.552 .755 .972 r
.5935 .28445 .59881 .29555 .62248 .29544 .61735 .28434 Mtetra
.556 .758 .972 r
.61735 .28434 .62248 .29544 .64626 .29513 .64131 .28403 Mtetra
.56 .761 .972 r
.64131 .28403 .64626 .29513 .67015 .29465 .66537 .28353 Mtetra
.564 .763 .972 r
.66537 .28353 .67015 .29465 .69414 .29401 .68955 .28288 Mtetra
.566 .766 .972 r
.68955 .28288 .69414 .29401 .71824 .29323 .71383 .28209 Mtetra
.569 .768 .972 r
.71383 .28209 .71824 .29323 .74244 .29232 .73821 .28116 Mtetra
.571 .769 .972 r
.73821 .28116 .74244 .29232 .76674 .2913 .7627 .28012 Mtetra
.573 .771 .972 r
.7627 .28012 .76674 .2913 .79115 .29017 .78729 .27897 Mtetra
.575 .773 .972 r
.78729 .27897 .79115 .29017 .81566 .28894 .81199 .27772 Mtetra
.577 .774 .972 r
.81199 .27772 .81566 .28894 .84027 .28762 .83679 .27638 Mtetra
.578 .775 .973 r
.83679 .27638 .84027 .28762 .86498 .28622 .8617 .27495 Mtetra
.58 .776 .973 r
.8617 .27495 .86498 .28622 .8898 .28475 .88671 .27344 Mtetra
.581 .777 .973 r
.88671 .27344 .8898 .28475 .91471 .2832 .91183 .27187 Mtetra
.582 .778 .973 r
.91183 .27187 .91471 .2832 .93974 .28158 .93705 .27022 Mtetra
.617 .786 .963 r
.13287 .24047 .14142 .25112 .16322 .24858 .15482 .2379 Mtetra
.15482 .2379 .16322 .24858 .18509 .24603 .17684 .23531 Mtetra
.17684 .23531 .18509 .24603 .20704 .24347 .19895 .23271 Mtetra
.19895 .23271 .20704 .24347 .22908 .2409 .22114 .2301 Mtetra
.22114 .2301 .22908 .2409 .25119 .23833 .2434 .22749 Mtetra
.2434 .22749 .25119 .23833 .27339 .23574 .26575 .22486 Mtetra
.365 .644 .963 r
.26575 .22486 .27339 .23574 .29522 .24293 .2878 .23053 Mtetra
.278 .555 .928 r
.2878 .23053 .29522 .24293 .31714 .25211 .30984 .23998 Mtetra
.343 .603 .944 r
.30984 .23998 .31714 .25211 .3393 .25942 .33213 .2475 Mtetra
.39 .638 .954 r
.33213 .2475 .3393 .25942 .36166 .26528 .35464 .25352 Mtetra
.425 .664 .96 r
.35464 .25352 .36166 .26528 .38421 .26998 .37734 .25834 Mtetra
.452 .683 .964 r
.37734 .25834 .38421 .26998 .40693 .27374 .40021 .2622 Mtetra
.474 .699 .967 r
.40021 .2622 .40693 .27374 .4298 .27674 .42323 .26528 Mtetra
.491 .711 .968 r
.42323 .26528 .4298 .27674 .45281 .27911 .4464 .2677 Mtetra
.505 .721 .969 r
.4464 .2677 .45281 .27911 .47596 .28094 .46971 .26958 Mtetra
.516 .729 .97 r
.46971 .26958 .47596 .28094 .49923 .28232 .49315 .27099 Mtetra
.526 .736 .971 r
.49315 .27099 .49923 .28232 .52262 .28331 .51671 .27201 Mtetra
.534 .742 .971 r
.51671 .27201 .52262 .28331 .54613 .28397 .54039 .27268 Mtetra
.541 .747 .971 r
.54039 .27268 .54613 .28397 .56976 .28434 .56419 .27306 Mtetra
.547 .751 .972 r
.56419 .27306 .56976 .28434 .5935 .28445 .58811 .27317 Mtetra
.552 .755 .972 r
.58811 .27317 .5935 .28445 .61735 .28434 .61213 .27306 Mtetra
.556 .758 .972 r
.61213 .27306 .61735 .28434 .64131 .28403 .63627 .27274 Mtetra
.56 .761 .972 r
.63627 .27274 .64131 .28403 .66537 .28353 .66052 .27224 Mtetra
.563 .763 .972 r
.66052 .27224 .66537 .28353 .68955 .28288 .68488 .27158 Mtetra
.566 .765 .972 r
.68488 .27158 .68955 .28288 .71383 .28209 .70934 .27077 Mtetra
.569 .767 .972 r
.70934 .27077 .71383 .28209 .73821 .28116 .73391 .26982 Mtetra
.571 .769 .972 r
.73391 .26982 .73821 .28116 .7627 .28012 .75859 .26876 Mtetra
.573 .771 .972 r
.75859 .26876 .7627 .28012 .78729 .27897 .78338 .26759 Mtetra
.575 .772 .972 r
.78338 .26759 .78729 .27897 .81199 .27772 .80827 .26631 Mtetra
.577 .774 .972 r
.80827 .26631 .81199 .27772 .83679 .27638 .83327 .26494 Mtetra
.578 .775 .973 r
.83327 .26494 .83679 .27638 .8617 .27495 .85837 .26349 Mtetra
.579 .776 .973 r
.85837 .26349 .8617 .27495 .88671 .27344 .88358 .26196 Mtetra
.581 .777 .973 r
.88358 .26196 .88671 .27344 .91183 .27187 .90889 .26035 Mtetra
.582 .778 .973 r
.90889 .26035 .91183 .27187 .93705 .27022 .93432 .25867 Mtetra
.617 .786 .963 r
.12419 .22967 .13287 .24047 .15482 .2379 .14629 .22705 Mtetra
.14629 .22705 .15482 .2379 .17684 .23531 .16847 .22442 Mtetra
.16847 .22442 .17684 .23531 .19895 .23271 .19073 .22178 Mtetra
.19073 .22178 .19895 .23271 .22114 .2301 .21307 .21914 Mtetra
.21307 .21914 .22114 .2301 .2434 .22749 .2355 .21648 Mtetra
.2355 .21648 .2434 .22749 .26575 .22486 .25801 .21381 Mtetra
.421 .679 .969 r
.25801 .21381 .26575 .22486 .2878 .23053 .28027 .21794 Mtetra
.269 .548 .925 r
.28027 .21794 .2878 .23053 .30984 .23998 .30244 .22767 Mtetra
.336 .598 .943 r
.30244 .22767 .30984 .23998 .33213 .2475 .32486 .2354 Mtetra
.385 .635 .954 r
.32486 .2354 .33213 .2475 .35464 .25352 .34751 .24157 Mtetra
.421 .661 .96 r
.34751 .24157 .35464 .25352 .37734 .25834 .37036 .24652 Mtetra
.449 .681 .964 r
.37036 .24652 .37734 .25834 .40021 .2622 .39338 .25048 Mtetra
.471 .697 .966 r
.39338 .25048 .40021 .2622 .42323 .26528 .41656 .25363 Mtetra
.489 .71 .968 r
.41656 .25363 .42323 .26528 .4464 .2677 .43989 .25612 Mtetra
.503 .72 .969 r
.43989 .25612 .4464 .2677 .46971 .26958 .46337 .25804 Mtetra
.515 .728 .97 r
.46337 .25804 .46971 .26958 .49315 .27099 .48697 .25948 Mtetra
.525 .735 .971 r
.48697 .25948 .49315 .27099 .51671 .27201 .5107 .26052 Mtetra
.533 .741 .971 r
.5107 .26052 .51671 .27201 .54039 .27268 .53456 .26121 Mtetra
.54 .746 .971 r
.53456 .26121 .54039 .27268 .56419 .27306 .55853 .2616 Mtetra
.546 .75 .972 r
.55853 .2616 .56419 .27306 .58811 .27317 .58263 .26171 Mtetra
.551 .754 .972 r
.58263 .26171 .58811 .27317 .61213 .27306 .60684 .2616 Mtetra
.555 .757 .972 r
.60684 .2616 .61213 .27306 .63627 .27274 .63116 .26127 Mtetra
.559 .76 .972 r
.63116 .26127 .63627 .27274 .66052 .27224 .65559 .26076 Mtetra
.563 .763 .972 r
.65559 .26076 .66052 .27224 .68488 .27158 .68013 .26009 Mtetra
.566 .765 .972 r
.68013 .26009 .68488 .27158 .70934 .27077 .70479 .25926 Mtetra
.568 .767 .972 r
.70479 .25926 .70934 .27077 .73391 .26982 .72955 .2583 Mtetra
.571 .769 .972 r
.72955 .2583 .73391 .26982 .75859 .26876 .75442 .25721 Mtetra
.573 .771 .972 r
.75442 .25721 .75859 .26876 .78338 .26759 .7794 .25602 Mtetra
.575 .772 .972 r
.7794 .25602 .78338 .26759 .80827 .26631 .80448 .25472 Mtetra
.576 .774 .972 r
.80448 .25472 .80827 .26631 .83327 .26494 .82968 .25332 Mtetra
.578 .775 .973 r
.82968 .25332 .83327 .26494 .85837 .26349 .85498 .25184 Mtetra
.579 .776 .973 r
.85498 .25184 .85837 .26349 .88358 .26196 .88039 .25028 Mtetra
.581 .777 .973 r
.88039 .25028 .88358 .26196 .90889 .26035 .90591 .24864 Mtetra
.582 .778 .973 r
.90591 .24864 .90889 .26035 .93432 .25867 .93154 .24693 Mtetra
.617 .786 .963 r
.11538 .21869 .12419 .22967 .14629 .22705 .13763 .21604 Mtetra
.13763 .21604 .14629 .22705 .16847 .22442 .15996 .21337 Mtetra
.15996 .21337 .16847 .22442 .19073 .22178 .18238 .21069 Mtetra
.18238 .21069 .19073 .22178 .21307 .21914 .20488 .208 Mtetra
.20488 .208 .21307 .21914 .2355 .21648 .22747 .2053 Mtetra
.22747 .2053 .2355 .21648 .25801 .21381 .25014 .20259 Mtetra
.472 .709 .973 r
.25014 .20259 .25801 .21381 .28027 .21794 .27263 .20517 Mtetra
.259 .542 .923 r
.27263 .20517 .28027 .21794 .30244 .22767 .29492 .21517 Mtetra
.329 .594 .942 r
.29492 .21517 .30244 .22767 .32486 .2354 .31748 .22311 Mtetra
.379 .631 .953 r
.31748 .22311 .32486 .2354 .34751 .24157 .34027 .22945 Mtetra
.417 .659 .96 r
.34027 .22945 .34751 .24157 .37036 .24652 .36327 .23452 Mtetra
.446 .679 .964 r
.36327 .23452 .37036 .24652 .39338 .25048 .38645 .23858 Mtetra
.469 .696 .966 r
.38645 .23858 .39338 .25048 .41656 .25363 .40979 .2418 Mtetra
.487 .708 .968 r
.40979 .2418 .41656 .25363 .43989 .25612 .43328 .24434 Mtetra
.502 .719 .969 r
.43328 .24434 .43989 .25612 .46337 .25804 .45692 .24631 Mtetra
.514 .727 .97 r
.45692 .24631 .46337 .25804 .48697 .25948 .4807 .24779 Mtetra
.524 .735 .971 r
.4807 .24779 .48697 .25948 .5107 .26052 .5046 .24885 Mtetra
.532 .74 .971 r
.5046 .24885 .5107 .26052 .53456 .26121 .52863 .24956 Mtetra
.539 .746 .971 r
.52863 .24956 .53456 .26121 .55853 .2616 .55279 .24995 Mtetra
.545 .75 .972 r
.55279 .24995 .55853 .2616 .58263 .26171 .57706 .25007 Mtetra
.55 .754 .972 r
.57706 .25007 .58263 .26171 .60684 .2616 .60145 .24995 Mtetra
.555 .757 .972 r
.60145 .24995 .60684 .2616 .63116 .26127 .62596 .24962 Mtetra
.559 .76 .972 r
.62596 .24962 .63116 .26127 .65559 .26076 .65058 .2491 Mtetra
.562 .763 .972 r
.65058 .2491 .65559 .26076 .68013 .26009 .67531 .24841 Mtetra
.565 .765 .972 r
.67531 .24841 .68013 .26009 .70479 .25926 .70015 .24757 Mtetra
.568 .767 .972 r
.70015 .24757 .70479 .25926 .72955 .2583 .72511 .24658 Mtetra
.57 .769 .972 r
.72511 .24658 .72955 .2583 .75442 .25721 .75018 .24548 Mtetra
.573 .771 .972 r
.75018 .24548 .75442 .25721 .7794 .25602 .77535 .24426 Mtetra
.574 .772 .972 r
.77535 .24426 .7794 .25602 .80448 .25472 .80064 .24293 Mtetra
.576 .773 .972 r
.80064 .24293 .80448 .25472 .82968 .25332 .82603 .24151 Mtetra
.578 .775 .973 r
.82603 .24151 .82968 .25332 .85498 .25184 .85154 .24 Mtetra
.579 .776 .973 r
.85154 .24 .85498 .25184 .88039 .25028 .87715 .23841 Mtetra
.58 .777 .973 r
.87715 .23841 .88039 .25028 .90591 .24864 .90288 .23674 Mtetra
.582 .778 .973 r
.90288 .23674 .90591 .24864 .93154 .24693 .92872 .23499 Mtetra
.617 .786 .963 r
.10642 .20755 .11538 .21869 .13763 .21604 .12883 .20485 Mtetra
.12883 .20485 .13763 .21604 .15996 .21337 .15132 .20214 Mtetra
.15132 .20214 .15996 .21337 .18238 .21069 .1739 .19942 Mtetra
.1739 .19942 .18238 .21069 .20488 .208 .19656 .19669 Mtetra
.19656 .19669 .20488 .208 .22747 .2053 .21931 .19395 Mtetra
.21931 .19395 .22747 .2053 .25014 .20259 .24214 .1912 Mtetra
.52 .736 .973 r
.24214 .1912 .25014 .20259 .27263 .20517 .26487 .1922 Mtetra
.25 .535 .92 r
.26487 .1922 .27263 .20517 .29492 .21517 .28728 .20248 Mtetra
.322 .589 .94 r
.28728 .20248 .29492 .21517 .31748 .22311 .30998 .21063 Mtetra
.374 .628 .952 r
.30998 .21063 .31748 .22311 .34027 .22945 .33292 .21713 Mtetra
.413 .656 .959 r
.33292 .21713 .34027 .22945 .36327 .23452 .35607 .22233 Mtetra
.443 .678 .963 r
.35607 .22233 .36327 .23452 .38645 .23858 .3794 .22648 Mtetra
.466 .694 .966 r
.3794 .22648 .38645 .23858 .40979 .2418 .40291 .22979 Mtetra
.485 .707 .968 r
.40291 .22979 .40979 .2418 .43328 .24434 .42657 .23239 Mtetra
.5 .718 .969 r
.42657 .23239 .43328 .24434 .45692 .24631 .45037 .2344 Mtetra
.512 .727 .97 r
.45037 .2344 .45692 .24631 .4807 .24779 .47432 .23591 Mtetra
.522 .734 .971 r
.47432 .23591 .4807 .24779 .5046 .24885 .4984 .23699 Mtetra
.531 .74 .971 r
.4984 .23699 .5046 .24885 .52863 .24956 .52261 .23771 Mtetra
.538 .745 .971 r
.52261 .23771 .52863 .24956 .55279 .24995 .54695 .23811 Mtetra
.544 .75 .972 r
.54695 .23811 .55279 .24995 .57706 .25007 .5714 .23824 Mtetra
.55 .753 .972 r
.5714 .23824 .57706 .25007 .60145 .24995 .59598 .23811 Mtetra
.554 .757 .972 r
.59598 .23811 .60145 .24995 .62596 .24962 .62067 .23777 Mtetra
.558 .76 .972 r
.62067 .23777 .62596 .24962 .65058 .2491 .64548 .23724 Mtetra
.562 .762 .972 r
.64548 .23724 .65058 .2491 .67531 .24841 .67041 .23654 Mtetra
.565 .765 .972 r
.67041 .23654 .67531 .24841 .70015 .24757 .69545 .23568 Mtetra
.568 .767 .972 r
.69545 .23568 .70015 .24757 .72511 .24658 .7206 .23468 Mtetra
.57 .769 .972 r
.7206 .23468 .72511 .24658 .75018 .24548 .74586 .23355 Mtetra
.572 .77 .972 r
.74586 .23355 .75018 .24548 .77535 .24426 .77124 .2323 Mtetra
.574 .772 .972 r
.77124 .2323 .77535 .24426 .80064 .24293 .79673 .23095 Mtetra
.576 .773 .972 r
.79673 .23095 .80064 .24293 .82603 .24151 .82233 .2295 Mtetra
.578 .775 .973 r
.82233 .2295 .82603 .24151 .85154 .24 .84804 .22796 Mtetra
.579 .776 .973 r
.84804 .22796 .85154 .24 .87715 .23841 .87386 .22633 Mtetra
.58 .777 .973 r
.87386 .22633 .87715 .23841 .90288 .23674 .8998 .22463 Mtetra
.581 .778 .973 r
.8998 .22463 .90288 .23674 .92872 .23499 .92584 .22286 Mtetra
.617 .786 .963 r
.09733 .19623 .10642 .20755 .12883 .20485 .1199 .19349 Mtetra
.1199 .19349 .12883 .20485 .15132 .20214 .14255 .19074 Mtetra
.14255 .19074 .15132 .20214 .1739 .19942 .16529 .18797 Mtetra
.16529 .18797 .1739 .19942 .19656 .19669 .18811 .1852 Mtetra
.18811 .1852 .19656 .19669 .21931 .19395 .21102 .18242 Mtetra
.21102 .18242 .21931 .19395 .24214 .1912 .23402 .17962 Mtetra
.563 .759 .97 r
.23402 .17962 .24214 .1912 .26487 .1922 .25699 .17903 Mtetra
.24 .528 .918 r
.25699 .17903 .26487 .1922 .28728 .20248 .27953 .18959 Mtetra
.315 .584 .939 r
.27953 .18959 .28728 .20248 .30998 .21063 .30237 .19795 Mtetra
.369 .624 .951 r
.30237 .19795 .30998 .21063 .33292 .21713 .32545 .20462 Mtetra
.409 .654 .959 r
.32545 .20462 .33292 .21713 .35607 .22233 .34875 .20995 Mtetra
.44 .676 .963 r
.34875 .20995 .35607 .22233 .3794 .22648 .37225 .2142 Mtetra
.464 .693 .966 r
.37225 .2142 .3794 .22648 .40291 .22979 .39591 .21758 Mtetra
.483 .706 .968 r
.39591 .21758 .40291 .22979 .42657 .23239 .41974 .22024 Mtetra
.498 .717 .969 r
.41974 .22024 .42657 .23239 .45037 .2344 .44372 .22229 Mtetra
.511 .726 .97 r
.44372 .22229 .45037 .2344 .47432 .23591 .46784 .22383 Mtetra
.521 .733 .971 r
.46784 .22383 .47432 .23591 .4984 .23699 .4921 .22494 Mtetra
.53 .739 .971 r
.4921 .22494 .4984 .23699 .52261 .23771 .51649 .22568 Mtetra
.537 .745 .971 r
.51649 .22568 .52261 .23771 .54695 .23811 .54101 .22608 Mtetra
.544 .749 .972 r
.54101 .22608 .54695 .23811 .5714 .23824 .56565 .22621 Mtetra
.549 .753 .972 r
.56565 .22621 .5714 .23824 .59598 .23811 .59042 .22608 Mtetra
.554 .756 .972 r
.59042 .22608 .59598 .23811 .62067 .23777 .6153 .22573 Mtetra
.558 .759 .972 r
.6153 .22573 .62067 .23777 .64548 .23724 .6403 .22519 Mtetra
.561 .762 .972 r
.6403 .22519 .64548 .23724 .67041 .23654 .66542 .22447 Mtetra
.565 .764 .972 r
.66542 .22447 .67041 .23654 .69545 .23568 .69066 .22359 Mtetra
.567 .767 .972 r
.69066 .22359 .69545 .23568 .7206 .23468 .71601 .22257 Mtetra
.57 .768 .972 r
.71601 .22257 .7206 .23468 .74586 .23355 .74148 .22142 Mtetra
.572 .77 .972 r
.74148 .22142 .74586 .23355 .77124 .2323 .76706 .22015 Mtetra
.574 .772 .972 r
.76706 .22015 .77124 .2323 .79673 .23095 .79275 .21877 Mtetra
.576 .773 .972 r
.79275 .21877 .79673 .23095 .82233 .2295 .81856 .21729 Mtetra
.577 .774 .973 r
.81856 .21729 .82233 .2295 .84804 .22796 .84448 .21571 Mtetra
.579 .776 .973 r
.84448 .21571 .84804 .22796 .87386 .22633 .87051 .21406 Mtetra
.58 .777 .973 r
.87051 .21406 .87386 .22633 .8998 .22463 .89666 .21232 Mtetra
.581 .778 .973 r
.89666 .21232 .8998 .22463 .92584 .22286 .92292 .21051 Mtetra
.617 .786 .963 r
.0881 .18473 .09733 .19623 .1199 .19349 .11082 .18195 Mtetra
.11082 .18195 .1199 .19349 .14255 .19074 .13364 .17915 Mtetra
.13364 .17915 .14255 .19074 .16529 .18797 .15654 .17634 Mtetra
.15654 .17634 .16529 .18797 .18811 .1852 .17953 .17353 Mtetra
.17953 .17353 .18811 .1852 .21102 .18242 .2026 .1707 Mtetra
.2026 .1707 .21102 .18242 .23402 .17962 .22577 .16786 Mtetra
.602 .779 .965 r
.22577 .16786 .23402 .17962 .25699 .17903 .24899 .16566 Mtetra
.23 .521 .915 r
.24899 .16566 .25699 .17903 .27953 .18959 .27166 .1765 Mtetra
.307 .58 .937 r
.27166 .1765 .27953 .18959 .30237 .19795 .29463 .18508 Mtetra
.363 .621 .95 r
.29463 .18508 .30237 .19795 .32545 .20462 .31787 .19191 Mtetra
.405 .651 .958 r
.31787 .19191 .32545 .20462 .34875 .20995 .34132 .19736 Mtetra
.437 .674 .963 r
.34132 .19736 .34875 .20995 .37225 .2142 .36497 .20172 Mtetra
.461 .691 .966 r
.36497 .20172 .37225 .2142 .39591 .21758 .38881 .20517 Mtetra
.481 .705 .968 r
.38881 .20517 .39591 .21758 .41974 .22024 .41281 .20789 Mtetra
.497 .716 .969 r
.41281 .20789 .41974 .22024 .44372 .22229 .43696 .20999 Mtetra
.51 .725 .97 r
.43696 .20999 .44372 .22229 .46784 .22383 .46126 .21156 Mtetra
.52 .732 .971 r
.46126 .21156 .46784 .22383 .4921 .22494 .4857 .21269 Mtetra
.529 .739 .971 r
.4857 .21269 .4921 .22494 .51649 .22568 .51027 .21344 Mtetra
.537 .744 .971 r
.51027 .21344 .51649 .22568 .54101 .22608 .53498 .21385 Mtetra
.543 .749 .972 r
.53498 .21385 .54101 .22608 .56565 .22621 .55981 .21398 Mtetra
.548 .753 .972 r
.55981 .21398 .56565 .22621 .59042 .22608 .58476 .21385 Mtetra
.553 .756 .972 r
.58476 .21385 .59042 .22608 .6153 .22573 .60984 .21349 Mtetra
.557 .759 .972 r
.60984 .21349 .6153 .22573 .6403 .22519 .63504 .21294 Mtetra
.561 .762 .972 r
.63504 .21294 .6403 .22519 .66542 .22447 .66036 .2122 Mtetra
.564 .764 .972 r
.66036 .2122 .66542 .22447 .69066 .22359 .68579 .2113 Mtetra
.567 .766 .972 r
.68579 .2113 .69066 .22359 .71601 .22257 .71135 .21026 Mtetra
.569 .768 .972 r
.71135 .21026 .71601 .22257 .74148 .22142 .73702 .20908 Mtetra
.572 .77 .972 r
.73702 .20908 .74148 .22142 .76706 .22015 .7628 .20778 Mtetra
.574 .772 .972 r
.7628 .20778 .76706 .22015 .79275 .21877 .7887 .20637 Mtetra
.575 .773 .973 r
.7887 .20637 .79275 .21877 .81856 .21729 .81472 .20486 Mtetra
.577 .774 .973 r
.81472 .20486 .81856 .21729 .84448 .21571 .84086 .20326 Mtetra
.579 .775 .973 r
.84086 .20326 .84448 .21571 .87051 .21406 .86711 .20157 Mtetra
.58 .777 .973 r
.86711 .20157 .87051 .21406 .89666 .21232 .89347 .1998 Mtetra
.581 .778 .973 r
.89347 .1998 .89666 .21232 .92292 .21051 .91995 .19795 Mtetra
.617 .786 .963 r
.07871 .17305 .0881 .18473 .11082 .18195 .1016 .17022 Mtetra
.1016 .17022 .11082 .18195 .13364 .17915 .12458 .16738 Mtetra
.12458 .16738 .13364 .17915 .15654 .17634 .14765 .16453 Mtetra
.14765 .16453 .15654 .17634 .17953 .17353 .17081 .16167 Mtetra
.17081 .16167 .17953 .17353 .2026 .1707 .19405 .15879 Mtetra
.19405 .15879 .2026 .1707 .22577 .16786 .21739 .15591 Mtetra
.21739 .15591 .22577 .16786 .24899 .16566 .24081 .15301 Mtetra
.22 .533 .922 r
.24081 .15301 .24899 .16566 .27166 .1765 .26366 .1632 Mtetra
.3 .575 .936 r
.26366 .1632 .27166 .1765 .29463 .18508 .28678 .172 Mtetra
.358 .617 .95 r
.28678 .172 .29463 .18508 .31787 .19191 .31016 .179 Mtetra
.401 .648 .958 r
.31016 .179 .31787 .19191 .34132 .19736 .33377 .18458 Mtetra
.434 .672 .963 r
.33377 .18458 .34132 .19736 .36497 .20172 .35759 .18903 Mtetra
.459 .689 .966 r
.35759 .18903 .36497 .20172 .38881 .20517 .38159 .19257 Mtetra
.479 .704 .968 r
.38159 .19257 .38881 .20517 .41281 .20789 .40576 .19534 Mtetra
.495 .715 .969 r
.40576 .19534 .41281 .20789 .43696 .20999 .43009 .19748 Mtetra
.508 .724 .97 r
.43009 .19748 .43696 .20999 .46126 .21156 .45457 .19909 Mtetra
.519 .732 .971 r
.45457 .19909 .46126 .21156 .4857 .21269 .47919 .20024 Mtetra
.528 .738 .971 r
.47919 .20024 .4857 .21269 .51027 .21344 .50395 .201 Mtetra
.536 .744 .971 r
.50395 .201 .51027 .21344 .53498 .21385 .52884 .20142 Mtetra
.542 .748 .972 r
.52884 .20142 .53498 .21385 .55981 .21398 .55386 .20155 Mtetra
.548 .752 .972 r
.55386 .20155 .55981 .21398 .58476 .21385 .57901 .20141 Mtetra
.553 .756 .972 r
.57901 .20141 .58476 .21385 .60984 .21349 .60429 .20105 Mtetra
.557 .759 .972 r
.60429 .20105 .60984 .21349 .63504 .21294 .62969 .20048 Mtetra
.561 .762 .972 r
.62969 .20048 .63504 .21294 .66036 .2122 .6552 .19972 Mtetra
.564 .764 .972 r
.6552 .19972 .66036 .2122 .68579 .2113 .68084 .1988 Mtetra
.567 .766 .972 r
.68084 .1988 .68579 .2113 .71135 .21026 .7066 .19774 Mtetra
.569 .768 .972 r
.7066 .19774 .71135 .21026 .73702 .20908 .73248 .19653 Mtetra
.571 .77 .972 r
.73248 .19653 .73702 .20908 .7628 .20778 .75848 .19521 Mtetra
.573 .771 .972 r
.75848 .19521 .7628 .20778 .7887 .20637 .78459 .19377 Mtetra
.575 .773 .973 r
.78459 .19377 .7887 .20637 .81472 .20486 .81082 .19223 Mtetra
.577 .774 .973 r
.81082 .19223 .81472 .20486 .84086 .20326 .83717 .19059 Mtetra
.578 .775 .973 r
.83717 .19059 .84086 .20326 .86711 .20157 .86364 .18887 Mtetra
.58 .776 .973 r
.86364 .18887 .86711 .20157 .89347 .1998 .89023 .18706 Mtetra
.581 .777 .973 r
.89023 .18706 .89347 .1998 .91995 .19795 .91693 .18517 Mtetra
.617 .786 .963 r
.06918 .16119 .07871 .17305 .1016 .17022 .09223 .15831 Mtetra
.09223 .15831 .1016 .17022 .12458 .16738 .11538 .15542 Mtetra
.11538 .15542 .12458 .16738 .14765 .16453 .13862 .15252 Mtetra
.13862 .15252 .14765 .16453 .17081 .16167 .16194 .14961 Mtetra
.16194 .14961 .17081 .16167 .19405 .15879 .18536 .14669 Mtetra
.18536 .14669 .19405 .15879 .21739 .15591 .20887 .14376 Mtetra
.20887 .14376 .21739 .15591 .24081 .15301 .23247 .14082 Mtetra
.248 .565 .937 r
.23247 .14082 .24081 .15301 .26366 .1632 .25554 .1497 Mtetra
.293 .57 .934 r
.25554 .1497 .26366 .1632 .28678 .172 .27879 .15871 Mtetra
.353 .614 .949 r
.27879 .15871 .28678 .172 .31016 .179 .30233 .16588 Mtetra
.397 .646 .957 r
.30233 .16588 .31016 .179 .33377 .18458 .3261 .17159 Mtetra
.43 .67 .962 r
.3261 .17159 .33377 .18458 .35759 .18903 .35008 .17614 Mtetra
.456 .688 .966 r
.35008 .17614 .35759 .18903 .38159 .19257 .37425 .17975 Mtetra
.477 .702 .968 r
.37425 .17975 .38159 .19257 .40576 .19534 .39859 .18259 Mtetra
.493 .714 .969 r
.39859 .18259 .40576 .19534 .43009 .19748 .4231 .18477 Mtetra
.507 .723 .97 r
.4231 .18477 .43009 .19748 .45457 .19909 .44776 .18641 Mtetra
.518 .731 .971 r
.44776 .18641 .45457 .19909 .47919 .20024 .47257 .18758 Mtetra
.527 .738 .971 r
.47257 .18758 .47919 .20024 .50395 .201 .49752 .18836 Mtetra
.535 .743 .971 r
.49752 .18836 .50395 .201 .52884 .20142 .5226 .18878 Mtetra
.542 .748 .972 r
.5226 .18878 .52884 .20142 .55386 .20155 .54782 .18891 Mtetra
.547 .752 .972 r
.54782 .18891 .55386 .20155 .57901 .20141 .57317 .18877 Mtetra
.552 .755 .972 r
.57317 .18877 .57901 .20141 .60429 .20105 .59864 .18839 Mtetra
.556 .759 .972 r
.59864 .18839 .60429 .20105 .62969 .20048 .62424 .1878 Mtetra
.56 .761 .972 r
.62424 .1878 .62969 .20048 .6552 .19972 .64996 .18703 Mtetra
.563 .764 .972 r
.64996 .18703 .6552 .19972 .68084 .1988 .67581 .18609 Mtetra
.566 .766 .972 r
.67581 .18609 .68084 .1988 .7066 .19774 .70178 .185 Mtetra
.569 .768 .972 r
.70178 .185 .7066 .19774 .73248 .19653 .72787 .18377 Mtetra
.571 .77 .972 r
.72787 .18377 .73248 .19653 .75848 .19521 .75408 .18242 Mtetra
.573 .771 .972 r
.75408 .18242 .75848 .19521 .78459 .19377 .78041 .18095 Mtetra
.575 .773 .973 r
.78041 .18095 .78459 .19377 .81082 .19223 .80686 .17938 Mtetra
.577 .774 .973 r
.80686 .17938 .81082 .19223 .83717 .19059 .83343 .1777 Mtetra
.578 .775 .973 r
.83343 .1777 .83717 .19059 .86364 .18887 .86012 .17594 Mtetra
.58 .776 .973 r
.86012 .17594 .86364 .18887 .89023 .18706 .88693 .1741 Mtetra
.581 .777 .973 r
.88693 .1741 .89023 .18706 .91693 .18517 .91386 .17217 Mtetra
.617 .786 .963 r
.05949 .14913 .06918 .16119 .09223 .15831 .08271 .1462 Mtetra
.08271 .1462 .09223 .15831 .11538 .15542 .10603 .14327 Mtetra
.10603 .14327 .11538 .15542 .13862 .15252 .12944 .14032 Mtetra
.12944 .14032 .13862 .15252 .16194 .14961 .15293 .13737 Mtetra
.15293 .13737 .16194 .14961 .18536 .14669 .17653 .1344 Mtetra
.17653 .1344 .18536 .14669 .20887 .14376 .20021 .13142 Mtetra
.20021 .13142 .20887 .14376 .23247 .14082 .22398 .12842 Mtetra
.3 .601 .95 r
.22398 .12842 .23247 .14082 .25554 .1497 .24728 .13597 Mtetra
.286 .565 .933 r
.24728 .13597 .25554 .1497 .27879 .15871 .27068 .14521 Mtetra
.347 .61 .948 r
.27068 .14521 .27879 .15871 .30233 .16588 .29437 .15254 Mtetra
.393 .643 .957 r
.29437 .15254 .30233 .16588 .3261 .17159 .3183 .15839 Mtetra
.427 .668 .962 r
.3183 .15839 .3261 .17159 .35008 .17614 .34244 .16304 Mtetra
.454 .686 .965 r
.34244 .16304 .35008 .17614 .37425 .17975 .36679 .16673 Mtetra
.475 .701 .968 r
.36679 .16673 .37425 .17975 .39859 .18259 .39131 .16962 Mtetra
.492 .713 .969 r
.39131 .16962 .39859 .18259 .4231 .18477 .416 .17185 Mtetra
.505 .722 .97 r
.416 .17185 .4231 .18477 .44776 .18641 .44085 .17352 Mtetra
.517 .73 .971 r
.44085 .17352 .44776 .18641 .47257 .18758 .46584 .17471 Mtetra
.526 .737 .971 r
.46584 .17471 .47257 .18758 .49752 .18836 .49098 .1755 Mtetra
.534 .743 .971 r
.49098 .1755 .49752 .18836 .5226 .18878 .51626 .17593 Mtetra
.541 .747 .972 r
.51626 .17593 .5226 .18878 .54782 .18891 .54168 .17605 Mtetra
.547 .751 .972 r
.54168 .17605 .54782 .18891 .57317 .18877 .56722 .1759 Mtetra
.552 .755 .972 r
.56722 .1759 .57317 .18877 .59864 .18839 .5929 .17552 Mtetra
.556 .758 .972 r
.5929 .17552 .59864 .18839 .62424 .1878 .6187 .17492 Mtetra
.56 .761 .972 r
.6187 .17492 .62424 .1878 .64996 .18703 .64463 .17413 Mtetra
.563 .764 .972 r
.64463 .17413 .64996 .18703 .67581 .18609 .67069 .17316 Mtetra
.566 .766 .972 r
.67069 .17316 .67581 .18609 .70178 .185 .69687 .17205 Mtetra
.569 .768 .972 r
.69687 .17205 .70178 .185 .72787 .18377 .72317 .17079 Mtetra
.571 .769 .972 r
.72317 .17079 .72787 .18377 .75408 .18242 .7496 .16941 Mtetra
.573 .771 .972 r
.7496 .16941 .75408 .18242 .78041 .18095 .77615 .16791 Mtetra
.575 .773 .973 r
.77615 .16791 .78041 .18095 .80686 .17938 .80282 .1663 Mtetra
.577 .774 .973 r
.80282 .1663 .80686 .17938 .83343 .1777 .82961 .16459 Mtetra
.578 .775 .973 r
.82961 .16459 .83343 .1777 .86012 .17594 .85653 .16279 Mtetra
.579 .776 .973 r
.85653 .16279 .86012 .17594 .88693 .1741 .88357 .16091 Mtetra
.581 .777 .973 r
.88357 .16091 .88693 .1741 .91386 .17217 .91073 .15895 Mtetra
.617 .786 .963 r
.04964 .13687 .05949 .14913 .08271 .1462 .07304 .1339 Mtetra
.07304 .1339 .08271 .1462 .10603 .14327 .09653 .13092 Mtetra
.09653 .13092 .10603 .14327 .12944 .14032 .12011 .12792 Mtetra
.12011 .12792 .12944 .14032 .15293 .13737 .14378 .12492 Mtetra
.14378 .12492 .15293 .13737 .17653 .1344 .16755 .1219 Mtetra
.16755 .1219 .17653 .1344 .20021 .13142 .19141 .11887 Mtetra
.19141 .11887 .20021 .13142 .22398 .12842 .21536 .11582 Mtetra
.35 .634 .96 r
.21536 .11582 .22398 .12842 .24728 .13597 .2389 .12203 Mtetra
.278 .56 .931 r
.2389 .12203 .24728 .13597 .27068 .14521 .26244 .13148 Mtetra
.342 .607 .947 r
.26244 .13148 .27068 .14521 .29437 .15254 .28628 .13899 Mtetra
.389 .64 .956 r
.28628 .13899 .29437 .15254 .3183 .15839 .31037 .14497 Mtetra
.424 .665 .962 r
.31037 .14497 .3183 .15839 .34244 .16304 .33468 .14972 Mtetra
.451 .685 .965 r
.33468 .14972 .34244 .16304 .36679 .16673 .3592 .15349 Mtetra
.473 .7 .967 r
.3592 .15349 .36679 .16673 .39131 .16962 .3839 .15644 Mtetra
.49 .712 .969 r
.3839 .15644 .39131 .16962 .416 .17185 .40878 .15871 Mtetra
.504 .722 .97 r
.40878 .15871 .416 .17185 .44085 .17352 .43381 .16041 Mtetra
.516 .73 .971 r
.43381 .16041 .44085 .17352 .46584 .17471 .459 .16162 Mtetra
.525 .736 .971 r
.459 .16162 .46584 .17471 .49098 .1755 .48433 .16242 Mtetra
.533 .742 .971 r
.48433 .16242 .49098 .1755 .51626 .17593 .50981 .16285 Mtetra
.54 .747 .972 r
.50981 .16285 .51626 .17593 .54168 .17605 .53542 .16298 Mtetra
.546 .751 .972 r
.53542 .16298 .54168 .17605 .56722 .1759 .56117 .16282 Mtetra
.551 .755 .972 r
.56117 .16282 .56722 .1759 .5929 .17552 .58706 .16242 Mtetra
.555 .758 .972 r
.58706 .16242 .5929 .17552 .6187 .17492 .61307 .1618 Mtetra
.559 .761 .972 r
.61307 .1618 .6187 .17492 .64463 .17413 .63921 .16099 Mtetra
.563 .763 .972 r
.63921 .16099 .64463 .17413 .67069 .17316 .66548 .16001 Mtetra
.566 .766 .972 r
.66548 .16001 .67069 .17316 .69687 .17205 .69188 .15887 Mtetra
.568 .768 .972 r
.69188 .15887 .69687 .17205 .72317 .17079 .7184 .15758 Mtetra
.571 .769 .972 r
.7184 .15758 .72317 .17079 .7496 .16941 .74504 .15617 Mtetra
.573 .771 .972 r
.74504 .15617 .7496 .16941 .77615 .16791 .77182 .15463 Mtetra
.575 .772 .973 r
.77182 .15463 .77615 .16791 .80282 .1663 .79871 .15299 Mtetra
.576 .774 .973 r
.79871 .15299 .80282 .1663 .82961 .16459 .82573 .15125 Mtetra
.578 .775 .973 r
.82573 .15125 .82961 .16459 .85653 .16279 .85288 .14941 Mtetra
.579 .776 .973 r
.85288 .14941 .85653 .16279 .88357 .16091 .88015 .14749 Mtetra
.58 .777 .973 r
.88015 .14749 .88357 .16091 .91073 .15895 .90754 .14548 Mtetra
.617 .786 .963 r
.03963 .12441 .04964 .13687 .07304 .1339 .0632 .12139 Mtetra
.0632 .12139 .07304 .1339 .09653 .13092 .08686 .11836 Mtetra
.08686 .11836 .09653 .13092 .12011 .12792 .11062 .11531 Mtetra
.11062 .11531 .12011 .12792 .14378 .12492 .13447 .11226 Mtetra
.13447 .11226 .14378 .12492 .16755 .1219 .15842 .10919 Mtetra
.15842 .10919 .16755 .1219 .19141 .11887 .18246 .10611 Mtetra
.18246 .10611 .19141 .11887 .21536 .11582 .2066 .10302 Mtetra
.398 .664 .966 r
.2066 .10302 .21536 .11582 .2389 .12203 .23037 .10786 Mtetra
.271 .555 .929 r
.23037 .10786 .2389 .12203 .26244 .13148 .25406 .11754 Mtetra
.336 .603 .946 r
.25406 .11754 .26244 .13148 .28628 .13899 .27805 .12521 Mtetra
.384 .638 .955 r
.27805 .12521 .28628 .13899 .31037 .14497 .30231 .13132 Mtetra
.421 .663 .961 r
.30231 .13132 .31037 .14497 .33468 .14972 .3268 .13618 Mtetra
.449 .683 .965 r
.3268 .13618 .33468 .14972 .3592 .15349 .35149 .14002 Mtetra
.471 .698 .967 r
.35149 .14002 .3592 .15349 .3839 .15644 .37637 .14303 Mtetra
.488 .711 .969 r
.37637 .14303 .3839 .15644 .40878 .15871 .40143 .14534 Mtetra
.503 .721 .97 r
.40143 .14534 .40878 .15871 .43381 .16041 .42666 .14708 Mtetra
.514 .729 .971 r
.42666 .14708 .43381 .16041 .459 .16162 .45204 .14831 Mtetra
.524 .736 .971 r
.45204 .14831 .459 .16162 .48433 .16242 .47757 .14912 Mtetra
.532 .741 .971 r
.47757 .14912 .48433 .16242 .50981 .16285 .50325 .14956 Mtetra
.539 .746 .972 r
.50325 .14956 .50981 .16285 .53542 .16298 .52907 .14967 Mtetra
.545 .751 .972 r
.52907 .14967 .53542 .16298 .56117 .16282 .55502 .14951 Mtetra
.55 .754 .972 r
.55502 .14951 .56117 .16282 .58706 .16242 .58111 .1491 Mtetra
.555 .758 .972 r
.58111 .1491 .58706 .16242 .61307 .1618 .60734 .14846 Mtetra
.559 .761 .972 r
.60734 .14846 .61307 .1618 .63921 .16099 .63369 .14763 Mtetra
.562 .763 .972 r
.63369 .14763 .63921 .16099 .66548 .16001 .66018 .14662 Mtetra
.565 .765 .972 r
.66018 .14662 .66548 .16001 .69188 .15887 .68679 .14545 Mtetra
.568 .767 .972 r
.68679 .14545 .69188 .15887 .7184 .15758 .71354 .14414 Mtetra
.57 .769 .972 r
.71354 .14414 .7184 .15758 .74504 .15617 .74041 .14269 Mtetra
.572 .771 .972 r
.74041 .14269 .74504 .15617 .77182 .15463 .76741 .14112 Mtetra
.574 .772 .973 r
.76741 .14112 .77182 .15463 .79871 .15299 .79453 .13944 Mtetra
.576 .774 .973 r
.79453 .13944 .79871 .15299 .82573 .15125 .82178 .13766 Mtetra
.578 .775 .973 r
.82178 .13766 .82573 .15125 .85288 .14941 .84916 .13579 Mtetra
.579 .776 .973 r
.84916 .13579 .85288 .14941 .88015 .14749 .87667 .13382 Mtetra
.58 .777 .973 r
.87667 .13382 .88015 .14749 .90754 .14548 .9043 .13178 Mtetra
.617 .786 .963 r
.02946 .11175 .03963 .12441 .0632 .12139 .0532 .10868 Mtetra
.0532 .10868 .0632 .12139 .08686 .11836 .07704 .10559 Mtetra
.07704 .10559 .08686 .11836 .11062 .11531 .10098 .1025 Mtetra
.10098 .1025 .11062 .11531 .13447 .11226 .12501 .09939 Mtetra
.12501 .09939 .13447 .11226 .15842 .10919 .14914 .09627 Mtetra
.14914 .09627 .15842 .10919 .18246 .10611 .17336 .09314 Mtetra
.17336 .09314 .18246 .10611 .2066 .10302 .19768 .08999 Mtetra
.442 .691 .971 r
.19768 .08999 .2066 .10302 .23037 .10786 .22171 .09346 Mtetra
.264 .55 .927 r
.22171 .09346 .23037 .10786 .25406 .11754 .24554 .10336 Mtetra
.331 .599 .945 r
.24554 .10336 .25406 .11754 .27805 .12521 .26969 .11121 Mtetra
.38 .635 .955 r
.26969 .11121 .27805 .12521 .30231 .13132 .29411 .11745 Mtetra
.418 .661 .961 r
.29411 .11745 .30231 .13132 .3268 .13618 .31877 .12241 Mtetra
.446 .681 .965 r
.31877 .12241 .3268 .13618 .35149 .14002 .34365 .12633 Mtetra
.469 .697 .967 r
.34365 .12633 .35149 .14002 .37637 .14303 .36871 .1294 Mtetra
.487 .71 .969 r
.36871 .1294 .37637 .14303 .40143 .14534 .39396 .13175 Mtetra
.501 .72 .97 r
.39396 .13175 .40143 .14534 .42666 .14708 .41938 .13351 Mtetra
.513 .728 .971 r
.41938 .13351 .42666 .14708 .45204 .14831 .44496 .13477 Mtetra
.523 .735 .971 r
.44496 .13477 .45204 .14831 .47757 .14912 .47069 .13558 Mtetra
.532 .741 .971 r
.47069 .13558 .47757 .14912 .50325 .14956 .49657 .13603 Mtetra
.539 .746 .972 r
.49657 .13603 .50325 .14956 .52907 .14967 .5226 .13614 Mtetra
.545 .75 .972 r
.5226 .13614 .52907 .14967 .55502 .14951 .54876 .13597 Mtetra
.55 .754 .972 r
.54876 .13597 .55502 .14951 .58111 .1491 .57507 .13554 Mtetra
.554 .757 .972 r
.57507 .13554 .58111 .1491 .60734 .14846 .6015 .13489 Mtetra
.558 .76 .972 r
.6015 .13489 .60734 .14846 .63369 .14763 .62808 .13404 Mtetra
.562 .763 .972 r
.62808 .13404 .63369 .14763 .66018 .14662 .65478 .133 Mtetra
.565 .765 .972 r
.65478 .133 .66018 .14662 .68679 .14545 .68162 .1318 Mtetra
.568 .767 .972 r
.68162 .1318 .68679 .14545 .71354 .14414 .70859 .13046 Mtetra
.57 .769 .972 r
.70859 .13046 .71354 .14414 .74041 .14269 .73569 .12898 Mtetra
.572 .771 .973 r
.73569 .12898 .74041 .14269 .76741 .14112 .76292 .12737 Mtetra
.574 .772 .973 r
.76292 .12737 .76741 .14112 .79453 .13944 .79028 .12566 Mtetra
.576 .774 .973 r
.79028 .12566 .79453 .13944 .82178 .13766 .81776 .12384 Mtetra
.577 .775 .973 r
.81776 .12384 .82178 .13766 .84916 .13579 .84538 .12192 Mtetra
.579 .776 .973 r
.84538 .12192 .84916 .13579 .87667 .13382 .87312 .11991 Mtetra
.58 .777 .973 r
.87312 .11991 .87667 .13382 .9043 .13178 .901 .11782 Mtetra
0 g
.89362 0 m
.98022 .38351 L
s
.98022 .38351 m
1 .65325 L
s
1 .65325 m
.91448 .33294 L
s
.91448 .33294 m
.89362 0 L
s
.02946 .11175 m
0 .4272 L
s
0 .4272 m
.91448 .33294 L
s
.91448 .33294 m
.89362 0 L
s
.89362 0 m
.02946 .11175 L
s
.02946 .11175 m
.89362 0 L
s
gsave
.44797 -0.02478 -65.9056 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(u) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
0 .4272 m
.29069 .70824 L
s
gsave
.15892 .66839 -66.3192 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(p) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{261.563, 185.063},
  ImageMargins->{{30.25, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.095767,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000450000^A000`40O003h00Oogoo1Woo003oOol6
Ool00?moo`Ioo`00ogoo1Woo003oOol6Ool00?moo`Ioo`00PWoo1000Ogoo0021Ool01000Oomoo`00
P7oo0021Ool01000Oomoo`00P7oo0020Ool200000goo00000020Ool00?moo`Ioo`00ogoo1Woo003o
Ool6Ool00?moo`Ioo`00ogoo1Woo003oOol6Ool00?moo`Ioo`00ogoo1Woo003oOol6Ool00?moo`Io
o`00ogoo1Woo003LOol4000UOol00=Aoo`P000=oo`03001oogoo02=oo`00c7oo20002goo00<007oo
Ool08goo0034Ool8000COol2000TOol00;aoo`P001]oo`8002Aoo`00]Goo1`008goo0P0097oo002]
Ool8000ZOol2000TOol00:Eoo`P0039oo`03001oo`0002=oo`00WGoo2000>Woo00<007oo00008goo
002FOol70013Ool2000SOol008ioo`P004Yoo`8002=oo`00QWoo2000DWoo00<007oo00008Woo001n
Ool8001JOol00`00Ool0000ROol007Ioo`P0069oo`03001oo`00029oo`00Kgoo1`00JWoo00<007oo
00008Woo001WOol8001aOol00`00Ool0000ROol005moo`P007Uoo`04001oogoo000QOol005Moo`P0
085oo`04001oogoo000QOol0051oo`L008Uoo`04001oogoo000QOol004Qoo`P00004>[hf_SJn=[j<
Ool01000Oomoo`008Goo0010Ool800001D/NCai?7TlNBah00dlN1CJn00<N?GooOol0R7oo00D007oo
Oomoo`00021oo`00>7oo200001=?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlN=[hj_P02
=[h011hL8SdN728mQgoo00D007ooOomoo`00021oo`00<7oo20000TlN00E;7TlNCai?7T/N00=?7P05
Bai?7TlNCai;7P03Cah01D/NCai?7TlNBah00dlN00T^WS:N<YhbWQhL7SdN7B8m9Ud0QGoo00D007oo
Oomoo`00021oo`00;7oo100002i??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/M
Cci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlN;Ydb_RjN<YhN728m7Q`ZGBIM:WhVGH9oo`05001o
ogooOol0000POol002aoo`05001?7TlNCai;7P03Cah01D/NCai?7TlNBah00dlN00E;7TlNCai?7T/N
00=?7P05Bai?7TlNCai;7P03Cah01D/NCai?7TlNBah00dlN00DZOC:N<YhR?Ahl008R?@08:UdVGBYM
9Ud^ORim;Wh^OGeoo`05001oogooOol0000POol002aoo`0l001oo`00Bae?7T/MCci;7DlNBae??T/M
Cai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBadZWRYm
;YhZOB8m7Q`R?AhL:WhVGBYn9Ud^WRim<Yh^OCJN<Ydf_S:MKGoo00a6oT/OA_i;7TKnBam6oT/NA_i;
7dKn0004Ool00`00Oomoo`0MOol002aoo`04001oo`00Ool2Cah01D/NCai?7TlNBah00dlN00E;7TlN
Cai?7T/N00=?7P05Bai?7TlNCai;7P03Cah01D/NCai?7TlNBah00dlN00I;7TlNCahZORYm:Wh28Sd0
0ahl8SdZG@04:Ud01BjN;Wd^OS:N=Yh00c:N13JnGGoo0dLN00E;7TLNAai77T/N00=77P0=Bai77T/N
Aai;7TLNBai77T/NAai;7TLN00000goo00<007ooOol07Goo000/Ool0C000Oomoo`00Cci;7DlNBae?
?T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?
7T/MCchRGBIN:Wd^WR8l8SdN728m9UdZORIM:Wh^OC:N;WdbWS:M=YhbWCJn=Yhj_SJM>[hfWS[N>[dj
gSZn>]hj_SkN>[hngSZn@Goo02U6oTLNA_i;7TKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dKnBai6oT/O
A_i;7TKnBam6oT/NA_i;7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;7`0000=oo`03001oogoo01eoo`00
;7oo00D007ooOomoo`0000=?7P05Bai?7TlNCai;7P03Cah01D/NCai?7TlNBah00dlN00E;7TlNCai?
7T/N00=?7P05Bai?7TlNCai;7P03Cah01D/NCahRGBIN8Ud0128m0RYM00TZOBYM:Ud^OBjN;Wd^OS:N
=Yh00S:N1CJn1SZn00<ngS[N?]h01ckN00U2gSkN?]hngT;n?]i2oT;N@_h05Goo0dKn00=2oTKnA_h0
24Kn00E77TKnA_i6oTLN00=6oP0>Aai6oTLNA_i77TKnAai6oTLNA_i77TKnAai6oP=77P05A_i77TLN
Aai6oP02Aah01D/NAai77TLNBah00dLN00m;7TLNAai77T/NAai;7TLNBai77T/NAai;7TLN00000goo
00<007ooOol07Goo000[Ool00`00Oomoo`03Ool0A`00Cci;7DlNBae??T/MCai;7DlnBae?7T/MCci;
7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/M9WhRGBIN8UdV?B8l8SdN
72Yn:UdZORIM<Yh^OC:N;Wdf_S:M=YhbWCJn=Yhj_SJM>[hfWS[N>[djgSZn?]hj_SkN>[h01SkN06A2
oSkN@_hngT;n?]i2oSkN@_hngT;n@]i2oT;N@_i2gTKn@]i2oT;NA_i2oTKn@]i6oT;nA_i2oTLN@_i6
oT;nAai2oTKn@_i77T;nAai2oTLN@_i77T;nAai6oTLN@_i77TKnAai6oTLNA_i77TKnBai6oTLNA_i;
7TKnAai6oT/NA_i;7TKnBam6oT/NA_i;7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dKnBai6oT/OA_i;
7TKnBam6oT/NA_i;7dKnBah000Aoo`03001oogoo01aoo`00:goo00<007ooOol017oo00D004lNCai?
7T/N00=?7P05Bai?7TlNCai;7P03Cah01D/NCai?7TlNBah00dlN00E;7TlNCai?7T/N00=?7P05Bai?
7TlNCai;7P047Sd38Sd3:Ud01RYm:Ud^ORim<Yh^O@8bWP03=YhbWS:N00@f_PDj_P04?]hjgSkN>]h8
?]h02T;N?]hngT;N@_hngT;n@]i2oT;N2T;n00Y6oT;n@_i2oTKn@_i6oT;nA_i2oP=6oP03@_i6oTKn
00A6oP05Aai6oTKnA_i77P03A_h03TLNA_i6oTKnAai6oTLNA_i77TKnAai6oTLNA_h3Aah01DKnAai7
7TLNA_h00dLN00A6oTLNAai;7P=77P0ABai77TLNAai;7TLNBai77T/NAai;7TLNBai77T/NAah00004
Ool00`00Oomoo`0LOol002]oo`03001oogoo00Eoo`0U001??T/MCai;7DlnBae?7T/MCci;7DlNBae?
?T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBad00ahm01DJ?2IM8S`R
?BYM:WhZGBYn;WdbWRim<Yh^OCJn<Ydf_S:M>[hf_SZn=Yd00SZn00PjgSZm>]hj_SkN>[hngSZn1SkN
06=2oSkN@_hngT;n?]i2oSkN@_i2gT;n@]i2oT;N@_i2gTKn@]i2oT;NA_i2oTKn@_i6oT;nA_i2oTLN
@_i6oT;nAai2oTLN@_i77TKnAai2oTLNA_i77T;nAai6oTLNA_i77TKnAai6oTLNA_i77TKnBai6oTLN
A_i;7TKnAai6oT/NA_i;7TKnBai6oT/NA_i;7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dKnBai6oT/O
A_i;7TKnBam6oT/NA_i;7`00Bah00goo00<007ooOol077oo000[Ool00`00Oomoo`05Ool00`00Bai?
7P02Cah01D/NCai?7TlNBah00dlN00E;7TlNCai?7T/N00=?7P05Bai?7TlNCai;7P03Cah01D/NCai?
7TlNBah00dlN00A;7QXM7SdN?@<R?@089SdZGBYm:UdZOBim<Yh^O@8bWP04=YhbWSJN<Yh2=[h01CZn
=[hj_SZn>]h00SZn00DjgSkN>]hngS[N00PngP06@]hngT;n@]i2oT;N0d;n00=2gT;n@_h024;n00Q6
oT;n@_i2oTKn@_i6oT;n34Kn00E77TKnA_i6oTLN00=6oP0>Aai6oTLNA_i77TKnAai6oTLNA_i77TKn
Aai6oP=77P05A_i77TLNBai6oP02Aah01D/NAai77TLNBah00dLN011;7TLNAai77T/NAai;7TLNBai7
7T/NAai;7TLN00177P=oo`03001oogoo01aoo`00:goo00<007ooOol01Woo04H004/MCci;7DlNBae?
?T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?
7QXL6QdJ71XM8S`VGB8m9SdZGBYn:UdbWRim<Yh^OC:N<Ydf_S:M=[hfWCZn=[hj_SJM?]hj_S[N>[dn
gSZn?]hj_P@ngP0F@]hngT;n?]i2oSkN@_hngT;n?]i2oSkN@_i2gT;n@]i2oT;N@_i2gTKn@]h2@_h0
CDKn@_i6oT;nAai2oTKn@_i77T;nAai2oTLN@_i77T;nAai6oTLN@_i77TKnAai2oTLNA_i77TKnAai6
oTLNA_i;7TKnAai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBam6oT/NA_i;7dKnBai6
oT/OA_i;7TKnBam6oT/NA_i;7dKnBai6oT/OA_i;7P00Bal017oo00<007ooOol06goo000[Ool00`00
Oomoo`07Ool00`00Bai?7P02Cah01D/NCai?7TlNBah00dlN00E;7TlNCai?7T/N00=?7P05Bai?7TlN
Cai;7P03Cah01D/NCai?7TlNBah00dlN00@J71XM6Q`J7@<R?@0::WdZGBYm:WdbWRim<Yh^OCJn<Yh2
=Yh2=[h00cZn=[hj_P03>[h00c[N>[hngP02?]h00c[N?]hngP04?]h014;N?]i2gSkN0T;N00A2oT;N
@_i2gP=2oP03@]i2oT;n00A2oP06A_i2oT;n@_i6oT;n0dKn00=2oTKnA_h034Kn01I77TKnA_i6oTLN
A_i77TKnAai6oTLNA_i77TKnAai6oTLNA_i77TKnAai6oP=77P05A_i77TLNBai6oP02Aah01D/NAai7
7TLNBah00dLN00i;7TLNBai77T/NAai;7TLNBai77T/NAah004LN17oo00<007ooOol06goo000[Ool0
0`00Oomoo`08Ool0A`00Bae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;
7DlNBae??T/MCai;7DlnBae?7T[mCai;7QhM6O`J7AXL9UdR?2IM8Sd^ORYM;Wh^OC:N;WdbWRim=[hb
WCJn<Ydj_SJM>[hf_SZn>[dngSZn>]hj_SkN>[hngSZn@]h00ckN0112gSkN@_hngT;n?]i2oSkN@_hn
gT;n@]i2oT;N@_i2gP92oP1AA_i2gTKn@_i6oT;nA_i2oTKn@_i77T;nA_i2oTLN@_i77T;nAai2oTLN
@_i77TKnAai6oTLNA_i77TKnAai6oTLNA_i77TKnAai6oT/NA_i77TKnBai6oT/NA_i;7TKnBai6oT/N
A_i;7TKnBam6oT/NA_i;7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dKnBai6oT/OA_i;7TKnBal004/N
00Aoo`03001oogoo01]oo`00:goo00<007ooOol02Goo00<004/NCah00TlN00E;7TlNCai?7T/N00=?
7P05Bai?7TlNCai;7P03Cah01D/NCai?7TlNBah00dlN00=;7TlNBah014/N014J71Wl6Q`J72IM8SdV
?BYm;WhZGBYm<YdbWRim<YhfWSJn00<fWP05>[hf_SZn=[hjgP03>[h2>]h3?]h00c[N?]hngP04?]h0
2T;N?]i2gSkN@_i2gT;n@]i2oT;N0d;n00=2gT;n@_h014;n00I6oT;n@_i2oTKn@_h3A_h00d;nA_i6
oP0<A_h04TLNA_i77TKnAai6oTLNA_i77TKnAai6oTLNA_i77TKnAai6oP=77P05A_i77TLNAai6oP02
Aah01D/NA_i77TLNBah00dLN011;7TLNAai77T/NAai;7TLNBai77T/NAai;7TLN00177PAoo`03001o
ogoo01]oo`00:goo00<007ooOol02Goo03L004lNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/M
Cai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBai?7T[mCahIo1hM6O`N7B8m9UdR?2IM:Ud^ORYM
<Yh^OC:N;WdbWS:M=[hbW@02=[h033Zn=[dj_SJn>]hj_CkN>[hjgSZn?]hj_P8ngP1V@]hngSkN?]i2
oSkN@_hngT;n?]i2oSkN@_hngT;n@]i2oT;N@_i2gTKn@_i6oT;NA_i2oTKn@_i6oT;nA_i2oTLN@_i6
oT;nAai2oTLN@_i77TKnAai2oTLNA_i77TKnAai6oTLNA_i77TKnAai6oTLNA_i77TKnBai6oTLNA_i;
7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dKnBai6oT/OA_i;
7TKnBam6oT/N001;7dKn0goo00<007ooOol06goo000[Ool00`00Oomoo`0:Ool00`00Cai;7P03Cah0
1D/NCai?7TlNBah00dlN00E;7TlNCai?7T/N00=?7P05Bai?7TlNCai;7P03Cah00d/NCai6oP03A_h0
1ahL6Q`Io1XL9SdVGBHm008ZO@03;WhZGC:N008bWP04<WdfWSJN=[h2=Yh01SJn>[hf_SZn=[hjgP<j
_PXngP04@]hngT;N?]h2@]h014;n@]i2oT;N2T;n00Q6oT;nA_i2oTKn@_i6oT;n3TKn01977TKnA_i6
oTLNA_i77TKnAai6oTLNA_i77TKnAai6oTLNA_h3Aah01DKnAai77TLNA_h00TLN00E;7TKnAai77T/N
00=77P05Bai77TLNAai;7P03Aah02d/NAai;7TLNBai77T/NAah004LNBah017oo00<007ooOol06Woo
000[Ool00`00Oomoo`0;Ool0>`00Cai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;
7DlNBae??T/MCai;7DlnBae?7T/MAai6oTLNA_i77QXL7QdIo2IM8SdVGB8l;WhZGBin:UdbWRim<Yh^
OCJn=Ydf_S:M>[hf_SZn=[d00SZn00PngSZm?]hj_SkN>[hngSZn0SkN06A2oSkN?]hngT;n?]i2oSkN
@_hngT;n?]i2oSkN@_i2gT;n@]i6oT;NA_i2oTKn@]i6oT;nA_i2oTKn@_i6oT;nAai2oTLN@_i77T;n
Aai2oTLNA_i77T;nAai6oTLNA_i77TKnAai6oTLNA_i77TKnBai6oTLNA_i;7TKnBai6oT/NA_i;7TKn
Bai6oT/NA_i;7TKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;7`00
Bai6oPAoo`03001oogoo01Yoo`00:Woo00<007ooOol03Goo0TlN00E;7TlNCai?7T/N00=?7P05Bai?
7TlNCai;7P03Cah01D/NCai?7TlNBah00dlN00e;7TlNCai?7T/N@_i2gT;n?]i2oQhL7QdJ70039Ud0
1BHm;WdZOBin:Wd00c:N00DbWCJn=Yhf_SJN00<j_P06=[hj_SZn>]hj_S[N2ckN00Q2gSkN@_hngT;n
@]i2oT;N34;n00A6oT;nA_i2oP=6oP03@_i6oTKn00a6oP0>Aai6oTKnA_i77TKnAai6oTLNA_i77TKn
Aai6oP=77P05A_i77TLNAai6oP03Aah01DKnAai77T/NA_h00TLN00E;7TLNAai77T/N00=77P0=Bai7
7TLNAai;7TLNBai77T/NAah004LNBah017oo00<007ooOol06Woo000ZOol00`00Oomoo`0>Ool0ZD/M
Cai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/M
@_lngT;n?]hN7AhL7QdJ72IM9SdVGBYM;WhZGBin;WdbWS9m<YhbWCJn=Ydf_S:M>[hf_SZn=[dngSZn
?]hj_CkN>]hngSZn?]hjgT;N?]i2oSkN@_hngT;n?]i2oSkN@_hngT;n?]i2oT;N@_i2gT;n@]i6oT;N
A_i2oTKn@_i6oT;nA_i2oTLN@_i6oT;nAai2oTLN@_i77T;nAai2oTLNA_i77T;nAai6oTLNA_i77TKn
Aai6oT/NA_i77TKnBai6oTLNA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7dKnBai6oT/OA_i;7TKn
Bam6oT/NA_i;7dKnBai6oT/OA_i;7TKnBam77T/N001;7dLN00Aoo`03001oogoo01Yoo`00:Woo00<0
07ooOol03Woo00@004lNCai;7P=?7P05Bai?7TlNCai;7P03Cah01D/NCai?7TlNBah00dlN00E;7TlN
Cai?7T/N00=?7P05BahjgS[N>]hj_P027Q`00ahM9UdVG@029Ud3;Wd00bin<YdbWP02<Yh013JN=[hf
WSJn1CZn00@jgSZn>]hj_PXngP0:@_hngT;N?]i2oT;N@_i2gT;n@]h:@_h01TKn@_i6oT;nA_i2oP=6
oP03@_i6oTKn00A6oP05Aai6oTKnA_i77P03A_h03TLNA_i6oTKnAai6oTLNA_i77TKnAai6oTLNA_h3
Aah01DKnAai77TLNA_h00TLN00I;7TKnAai77T/NA_h2Aah054/NAai77TLNBai77T/NAai;7TLNBai7
7T/NAai;7TLN00177T/NAah4Ool00`00Oomoo`0IOol002Yoo`03001oogoo00moo`14001;7DlNBae?
?T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCahj_S[O>[hj
gQhL8SdN71hM9SdZGBHm;WhZGBin:Wd^OS9m<YhbWCJn<Ydf_SJM=[hf_CZn=[hj_SZm?]hj_SkN>[dn
gS[N?]hj_P8ngP1S@]hngT;n?]i2oSkN@_hngT;n?]i2oT;N@_hngTKn@]i2oT;NA_i2oTKn@]i6oT;n
A_i2oTKn@_i6oT;nAai2oTKn@_i77T;nAai2oTLN@_i77T;nAai6oTLNA_i77TKnAai6oT/NA_i77TKn
Bai6oTLNA_i;7TKnAai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dKn
Bai6oT/OA_i;7TKnBam6oT/NA_i;7dLN0016oT/O00Aoo`03001oogoo01Uoo`00:Woo00<007ooOol0
47oo0dlN00E;7TlNCai?7T/N00=?7P05Bai?7TlNCai;7P03Cah01D/NCai?7TlNBah00dlN00E;7TlN
Cai?7SZn00<jgP037Q`N7AhL00@VG@06;Wh^OBim;WdbWS:M0S:N00@f_SJN=[hf_PHj_P04>]hj_SkN
>[h9?]h00d;N@_hngP02@]h014;n@]i2oT;N34;n00I6oT;nA_i2oTKn@_h:A_h01DLNA_i6oTKnAah0
0dKn00i77TKnAai6oTLNA_i77TKnAai6oTLNA_i77TKn0dLN00E6oTLNAai77TKn00977P05Bai6oTLN
Aai;7P03Aah04T/NAai;7TLNBai77T/NAai;7TLNBai77T/NAai;7P00Bai77PAoo`03001oogoo01Uo
o`00:Woo00<007ooOol04Goo041??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/M
Cci;7DlNBae??T/MCai;7DlnBae?7S:N=[hbWR8m7Q`R?AhL:UdV?BYM;Wd^ORYm;Wh^OC:N<WdbWSJM
=[hfWCJn=Ydj_SJm>]hf_SkN>[dngSZn?]hj_P<ngP1U>[i2oSkN@]hngT;n?]i2oSkN@_hngT;n?]i2
oT;N@_i2gTKn@]i2oT;NA_i2oTKn@]i6oT;nA_i2oTKn@_i6oT;nAai2oTKn@_i77T;nAai2oTLNA_i7
7T;nAai6oTLNA_i77TKnAai6oT/NA_i77TKnBai6oTLNA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;
7TKnBai6oT/NA_i;7TKnBam6oT/NA_i;7dKnBai6oT/OA_i;7TKnBam6oT/NA_h004LNBai6oP03Ool0
0`00Oomoo`0IOol002Yoo`03001oogoo019oo`=?7P05Bai?7TlNCai;7P03Cah01D/NCai?7TlNBah0
0dlN00E;7TlNCai?7T/N00=?7P05Bai?7TlN=[hbWP02<[h02B8m7Q`N7BIM:UdVGBYM;Wd^OP02;Wd2
<Yh01C:M<Yhf_SJn=Yh00SJn13Zn00@ngSZn>]hj_PXngP92gP03@_hngT;N0092oP03@]i2oT;n00Q2
oP06A_i2oTKn@_i6oT;n0dKn00=2oTKnA_h024Kn00E77TKnA_i6oTLN00=6oP0:Aai6oTLNA_i77TKn
Aai6oTLNA_h3Aah01DKnAai77TLNA_h00dLN00E6oTLNAai;7TKn00977P0EBai77TLNAai;7TLNBai7
7T/NAai;7TLNBai77T/NAai;7P00Bai77T/N00=oo`03001oogoo01Uoo`00:Woo00<007ooOol04goo
03A??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7Dln
Bad^WRYm;YhZOB8m7Q`R?BIM:UdVGBYN;Wd^ORim<YhbWC:N<WdfWSJM=[hfW@<j_P09=[djgSZn?]hj
_CkN>[hngSZn00@ngP1R@_hngT;N?]i2oSkN@_hngT;n@]i2oSkN@_i2gT;n@]i6oT;NA_i2gTKn@_i6
oT;nA_i2oTKn@_i6oT;nA_i2oTLN@_i77T;nAai2oTLN@_i77TKnAai2oTLNA_i77TKnAai6oTLNA_i;
7TKnAai6oT/NA_i77TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7dKnBai6oT/OA_i;
7TKnBam6oT/NA_i;7dKnBai6oT/OAah004KnBam77PAoo`03001oogoo01Qoo`00:Woo00<007ooOol0
4goo00D004lNCai?7T/N00=?7P05Bai?7TlNCai;7P03Cah01D/NCai?7TlNBah00dlN00E;7TlNCai?
7T/N009?7P03;YhZORjN008R?@037Q`R?BYM00<ZG@04;Wd^ORim;Wd2<Yh01S:M=[hf_SJn=Yhf_PDj
_P04?]hj_SkN>[h:?]h2@]h00d;n?]i2oP02@_h00d;N@_i2oP04@_h02TKn@_i2oT;nA_i2oTKn@_i6
oT;n0dKn00=2oTKnA_h024Kn00E77TKnA_i6oTLN00=6oP0:Aai6oTLNA_i77TKnAai6oTLNA_h3Aah0
1DKnAai77TLNA_h00TLN00I;7TKnAai77T/NA_h2Aah04d/NAai77TLNBai77T/NAai;7TLNBai77T/N
Aai;7P00Bai77T/N00Aoo`03001oogoo01Qoo`00:Woo00<007ooOol057oo03H004lnBae?7T/MCci;
7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7BIn:Wd^WR8L8SdN
72Yn9UdZGBIM<Yh^OC:N;WdfWS:M=YhbWCZn=Ydj_SJM>]h2>[h02CJm>]hj_SkN>[dngSZn?]hj_P02
?]h0HT;n?]i2oSkN@_hngT;n?]i2oSkN@_i2gT;n?]i6oT;N@_i2gTKn@_i6oT;NA_i2oTKn@_i6oT;n
A_i2oTLN@_i6oT;nAai2oTLN@_i77T;nAai2oTLNA_i77TKnAai6oTLNA_i;7TKnAai6oT/NA_i77TKn
Bai6oTLNA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dKn
Bai6oT/OA_i;7TKn00177T/NA_h4Ool00`00Oomoo`0HOol002Yoo`03001oogoo01Eoo`05001?7TlN
Cai;7P03Cah01D/NCai?7TlNBah00dlN00E;7TlNCai?7T/N00=?7P09Bai?7TlNCai;7TlN9UdVGRIM
00<R?@038S`ZGBYM008ZG@04;Wh^OBin;Wd3<Yh01CJN=[hf_SJn=Yh013Zn00@ngSZn?]hj_PHngP06
@]hngSkN?]i2oSkN0T;N00=2oT;N@_h00T;n00=2gT;n@_h014;n00Y6oT;n@_i2oTKn@_i6oT;nA_i2
oP=6oP03@_i6oTKn00A6oP05Aai6oTKnA_i77P03A_h03TLNA_i77TKnAai6oTLNA_i77TKnAai6oTLN
A_h3Aah01DKnAai77TLNA_h00TLN00E;7TKnAai77T/N00=77P0BBai77T/NAai;7TLNBai77T/NAai;
7TLNBah004/NAai;7TLN0goo00<007ooOol067oo000YOol00`00Oomoo`0GOol0?@00Cci;7DlNBae?
?T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??QXm9WhRGBHm8Q`R
?BIM:WhZGBYm;WdbWRim<YhbWCJn<YdfWSJM>[hfWCZn=YdjgSZn>]hj_CkN>[hngSZm00HngP1Q@_hn
gT;n?]i2oSkN@_hngT;n?]i2oT;N@_hngTKn@]i2oT;NA_i2oTKn@]i6oT;nA_i2oTKn@_i6oT;nAai2
oTKn@_i77T;nAai2oTLNA_i77T;nAai6oTLNA_i77TKnAai6oT/NA_i77TKnBai6oTLNA_i;7TKnBai6
oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBam6oT/NA_i;7dKnBai6oT/OA_i;7TKnBam6
oP00A_i;7dLNBah017oo00<007ooOol05goo000YOol00`00Oomoo`0HOol01D/NCai?7TlNBah00dlN
00E;7TlNCai?7T/N00=?7P05Bai?7TlNCai;7P03Cah01D/NCai?7TlNBah00ahm00@J?B8m8SdR?@@Z
G@05;Wd^ORim<YhbW@02<Yh00cJN=[hf_P02=[h5>[h013kN>]hngSZn1SkN00Y2gSkN?]hngT;n@]i2
oT;N@_i2gPY2oP08A_i2oT;n@_i6oT;nA_i2oPa6oP05Aai6oTKnA_i77P03A_h02TLNA_i77TKnAai6
oTLNA_i77TKn0dLN00E6oTLNAai77TKn00=77P05A_i77TLNBai6oP02Aah054/NAai77TLNBai77T/N
Aai;7TLNBai77T/NAai;7P00Bai77T/NAah4Ool00`00Oomoo`0GOol001Aoo`<0019oo`03001oogoo
01Qoo`0n001;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7Dln
Bae?7T/M7SdJ?Ahm8S`VGB8l8SdZGBin:UdbWRim<Yh^OC:N<Ydf_S:M>[hfWCZn=Ydj_SZm>]hj_S[N
>[dngSZn?]hj_@@ngP1Q@_hngT;n?]i2oSkN@_hngT;n?]i2oT;N@_i2gT;n@]i6oT;N@_i2gTKn@_i6
oT;NA_i2oTKn@_i77T;nA_i2oTLN@_i6oT;nAai6oTLN@_i77TKnAai2oTLNA_i77TKnAai6oTLNA_i;
7TKnAai6oT/NA_i77TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/OA_i;
7TKnBam6oT/NA_i;7dKnBai6oP00Aai;7TKnBal017oo00<007ooOol05goo000EOol00`00Oomoo`0A
Ool00`00Oomoo`0IOol00dlNBai?7P02Cah01D/NCai?7TlNBah00dlN00E;7TlNCai?7T/N00=?7P05
Bai?7TlNCai;7P03Cah024/N6Q`N?Ahm8SdV?B8m:Wd3:Ud02C:N;WdbWS9m=YhbWCJN<Yhj_P03=[h6
>[h:?]h01T;N?]i2oT;N@_i2gP=2oP03@]i2oT;n00Q2oP06A_i2oTKn@_i6oT;n3TKn00E77TKnA_i6
oTLN00=6oP0:Aai6oTLNA_i77TKnAai6oTLNA_h3Aah01DKnAai77T/NA_h00TLN00E;7TLNAai77T/N
00=77P0CBai77TLNAai;7TLNBai77T/NAai;7TLNBah004/NAai;7TLNBah00goo00<007ooOol05goo
000COol3000COol00`00Oomoo`0JOol0?4lNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;
7DlnBae?7T/MCci;7DlNBae??T/MCahIo1hM6Q`V?B8l9UdR?2in:Ud^ORim<Yh^OC:N;Wdf_S:M=[hb
WCZn=Ydj_SJM>]hj_CkN>[hngSZm?]hj_PHngP1P@_hngT;n?]i2oSkN@_hngT;n@]i2oT;N@_i2gTKn
@]i6oT;NA_i2gTKn@_i6oT;NAai2oTKn@_i77T;nA_i2oTLN@_i77T;nAai6oTLNA_i77TKnAai6oTLN
A_i77TKnAai6oTLNA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/N
A_i;7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dKn0016oT/OAai;7TKn17oo00<007ooOol05Woo000B
Ool01000Oomoo`004goo00<007ooOol06goo00=?7T/NCah00TlN00E;7TlNCai?7T/N00=?7P05Bai?
7TlNCai;7P03Cah01D/NCai?7TlNB_h00d/N00hIo1XL6Q`V?B8m9SdZGBim:UdZOC9m<Yh^OC:N0SJN
00DbWSJN=[hj_SJn00Hj_P03?]hjgSkN00LngP08@]hngT;N@]i2oT;N@_i2gP=2oP03@]i2oT;n00A2
oP06A_i2oT;n@_i6oT;n0dKn00=2oTKnA_h024Kn00E77TKnA_i6oTLN00=6oP0>Aai6oTLNA_i77TKn
Aai6oTLNA_i77TKnAai6oP=77P05A_i77TLNBai6oP02Aah01D/NAai77TLNBah00dLN015;7TLNBai7
7T/NAai;7TLNBai77T/N001;7TLNBai77T/N00Aoo`03001oogoo01Ioo`004Woo00@007ooOol001=o
o`03001oogoo01aoo`0bCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae?
?T/MBai6oD/NB_hN71Wl7QdIo2IM8S`VGBYM;WhZGBin;WdbWRim<YhbWCJn<Ydf_SJm>[hfW@8j_P08
>]hj_CkN>[hngSZm?]hj_P8ngP0@@]hngT;n?]i2oSkN@_hngT;n?]i2oSkN@_i2gT;n@]h2@_h0DDKn
@]i6oT;nA_i2oTKn@_i6oT;nAai2oTKn@_i77T;nAai2oTLNA_i77T;nAai6oTLNA_i77TKnAai6oTLN
A_i77TKnBai6oTLNA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/N
A_i;7dKnBai6oT/OA_i;7TKnBam6oT/NA_h004LNBai6oT/OAai;7P03Ool00`00Oomoo`0FOol001=o
o`@0019oo`03001oogoo01eoo`03Cai;7TlN009?7P05Bai?7TlNCai;7P03Cah01D/NCai?7TlNBah0
0dlN00=;7TlNCah014;n00DN71Wl7Q`V?BIM008V?@0?:Wd^OBYM<YhbOC:N<WdbWSJN=[hfWSZn=[hj
_SJn008j_P03>]hj_SZn00TngP04@]hngT;N?]h2@]h014;n@]i2oT;N0d;n00=2gT;n@_h014;n00I6
oT;nA_i2oTKn@_h>A_h01DLNA_i6oTKnAah00dKn00Y77TKnAai6oTLNA_i77TKnAai6oP=77P05A_i7
7TLNBai6oP02Aah01D/NA_i77TLNBah00dLN01A;7TLNAai77T/NAai;7TLNBai77T/NAai;7P00Bai7
7T/NAai;7TLN0goo00<007ooOol05Woo000YOol00`00Oomoo`0MOol0>`00Cai;7DlnBae?7T/MCci;
7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T;nA_i2gTKn@_hN7AWl7QdV?BIM9S`^ORYM;WhZ
GC:N<WdbWRim=[hbWCJn<Ydj_SJn>[hfWCkN>[hngSZm?]hj_SkN>[d013kN0652gSkN@_hngT;n?]i2
oSkN@_hngT;n@]i2oT;N@_i2gTKn@_i6oT;NA_i2oTKn@_i6oT;nA_i2oTLN@_i77T;nAai2oTLN@_i7
7TKnAai2oTLNA_i77TKnAai6oTLNA_i77TKnAai6oT/NA_i77TKnBai6oT/NA_i;7TKnBai6oT/NA_i;
7TKnBai6oT/NA_i;7TKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dKnBai6oT/OA_h004KnBam77T/NA_i;
7`03Ool00`00Oomoo`0FOol002Uoo`03001oogoo01ioo`9?7P05Bai?7TlNCai;7P03Cah01D/NCai?
7TlNBah00dlN00I;7TlNCai?7T/NCah4@_h37Q`012IM9SdVGBHm12im00@bWS:M<YhbO@8fWP03=[hf
WSZn008j_P04=[hj_SZn>]h2>[h9?]h02T;N?]i2gSkN@_i2gT;n@]i2oT;N24;n00A6oT;nA_i2oP=6
oP03@_i6oTKn00a6oP0BAai6oTKnA_i77TKnAai6oTLNA_i77TKnAai6oTLNA_i77TKn0dLN00E6oTLN
Aai;7TKn00977P05Bai77TLNAai;7P03Aah04T/NAai77TLNBai77T/NAai;7TLNBai77P00Aai;7TLN
Bai77PAoo`03001oogoo01Eoo`00:7oo00<007ooOol087oo09m;7DlNBae??T/MCai;7DlnBae?7T/M
Cci;7DlNBae??T/MCai;7DlnBae?7T/MCchjgSkN>[hngahL7QdMo2YM9SdZGBHm;WhZGBin<WdbWS9m
<YhbWCJn=Ydf_S:M>[hf_SZn>[dngSZn?]hj_CkN>[hngSZm@_hngT;N?]i2oSkN@_hngT;n?]i2oSkN
@_i2gT;n@]i6oT;NA_i2gTKn@_i6oT;nA_i2oTKn@_i77T;nA_i2oTLN@_i77T;nAai2oTLN@_i77TKn
Aai6oTLNA_i77TKnBai6oTLNA_i;7TKnAai6oT/NA_i77TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKn
Bai6oT/NA_i;7TKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dKnBai6oT/O001;7TKnBam77T/NA_h00goo
00<007ooOol05Goo000XOol00`00Oomoo`0QOol2Cah01D/NCai?7TlNBah00dlN00E;7TlNCai?7T/N
00=?7P05Bai?7TlNCai;7P02>]h01SkN>]hjgQhL8QdN708VG@03:Ud^OBim008^O@08<YdbWS:M<Yhf
WSJn=Yhf_PLj_PXngP04@]hngT;n?]h2@]h014;n@]i2oT;N2T;n00A6oT;nA_i2oP=6oP03@_i6oTKn
00a6oP0>Aai6oTLNA_i77TKnAai6oTLNA_i77TKnAai6oP=77P05A_i77TLNAai6oP02Aah01D/NA_i7
7TLNBah00dLN01E;7TLNBai77T/NAai;7TLNBai77T/NAai;7TLN00177T/NAai;7TLNBah00goo00<0
07ooOol05Goo000XOol00`00Oomoo`0ROol0;d/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7Dln
Bae?7T/MCci;7DlNBadf_S:N=[hbWR8m8Q`R?AhL:UdV?BYM;Ud^ORim<YhbOC:N<Wdf_SJM=[hfWCZn
=[d00cZn00Dj_CkN>[hngSZm00<ngP1S>[e2oSkN@]hngT;n?]i2oSkN@_i2gT;n?]i2oT;N@_i2gTKn
@]i6oT;NA_i2oTKn@_i6oT;nA_i2oTLN@_i6oT;nAai2oTLN@_i77TKnAai2oTLNA_i77TKnAai6oTLN
A_i;7TKnAai6oT/NA_i77TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/N
A_i;7TKnBam6oT/NA_i;7dKnBai6oT/OA_i;7P00Bam77T/NA_i;7dLN00=oo`03001oogoo01Eoo`00
:7oo00<007ooOol08Woo00@004lNCai;7P=?7P05Bai?7TlNCai;7P03Cah01D/NCai?7TlNBah00dlN
00U;7S:n<[hf_S:n8SdR728m9Ud00RYM00`^ORim;Wd^OC:N<YdbWS:M=[hfWSJn=Yh6>[h00c[N>[hn
gP09?]h2@]h01T;n?]i2oT;N@_i2gPI2oP0:A_i2oT;n@_i6oT;nA_i2oTKn@_h3A_h00d;nA_i6oP04
A_h01DLNA_i6oTKnAah00dKn00Y77TKnAai6oTLNA_i77TKnAai6oP=77P05A_i77TLNAai6oP02Aah0
1D/NA_i77TLNBah00dLN01M;7TLNBai77T/NAai;7TLNBai77T/NAai;7TLNBai77P00Aai;7TLNBai7
7T/N00Aoo`03001oogoo01Aoo`00:7oo00<007ooOol08goo02`004/MCai;7DlnBae?7T/MCci;7DlN
Bae??T/MCai;7DlnBae?7T/MCci;7DlNBad^WRYm;YhN728m8Q`R?BIM:UdVGC9n;WdbWRim=YhbOCJN
<Ydf_SJM0cZn00Tf_CZn>[hngSZm?]hj_SkN>[d013kN0612oSkN@]hngT;n?]i2oSkN@_i2gT;n?]i6
oT;N@_i2gTKn@_i6oT;NA_i2oTKn@_i6oT;nA_i2oTLN@_i6oT;nAai2oTLN@_i77TKnAai2oTLNA_i7
7TKnAai6oTLNA_i;7TKnAai6oT/NA_i77TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;
7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7dKnBai6oT/O001;7TKnBam77T/NA_h4Ool00`00Oomoo`0D
Ool002Qoo`03001oogoo02Aoo`=?7P05Bai?7TlNCai;7P03Cah01D/NCai?7TlNBah00dlN00A;7TlN
Cai?7P<ZOP04:YhR?28m8Q`4:Ud01bin;Wd^OBim=YhbWC:N008f_P03=Yhf_SZn00@j_P03?]hj_SkN
00TngP06@_hngT;N@]i2oT;N0d;n00=2gT;n@_h014;n00Y6oT;n@_i2oTKn@_i6oT;nA_i2oPY6oP05
Aai6oTKnA_i77P03A_h02TLNA_i77TKnAai6oTLNA_i77TKn0dLN00E6oTLNAai77TKn00977P05Bai6
oTLNAai;7P03Aah04T/NAai;7TLNBai77T/NAai;7TLNBai77T/NAah004LNBai77P=;7P05Aaioogoo
Ool0000FOol002Qoo`03001oogoo02Eoo`0/Cci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae?
?T/MCai;7DlnBae?7Qhm8UhN?B9N8Q`V?B8L:UdVGBYm:UdbWRim<YhbWCJN<YdfWSJM>[hfW@<j_P05
=[djgSZn?]hj_@03?]h0I3jm?]hngT;N?]i2oSkN@_hngT;n?]i2oSkN@_i2gT;n@]i6oT;N@_i2gTKn
@_i6oT;NA_i2oTKn@_i6oT;nA_i2oTLN@_i77T;nAai2oTLN@_i77TKnAai2oTLNA_i77TKnAai6oTLN
A_i;7TKnAai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/N
A_i;7TKnBam6oT/NA_i;7dLNBah004/OAai;7TKnBam77T/N0goo00<007ooOol057oo000XOol00`00
Oomoo`0VOol3Cah01D/NCai?7TlNBah00dlN00E;7TlNCai?7T/N00=?7P04Bai?7TlNCah48Ud00b8l
8SdR?@03:Ud01bim<Wh^OBim<YhfWS:M00<f_P03=Yhf_SZn008j_P04?]hj_SkN>[h6?]h01T;N?]hn
gSkN@_hngP92gP03@_i2gT;n00U2oP06A_i2oT;n@_i6oT;n3TKn01977TKnA_i6oTLNA_i77TKnAai6
oTLNA_i77TKnAai6oTLNA_h3Aah01DKnAai77TLNA_h00TLN00E;7TKnAai77T/N00=77P08Bai77T/N
Aai;7TLNBai77PD00005Aai;7T/NBai77P02Bah3Ool00`00Oomoo`0DOol002Qoo`03001oogoo02Io
o`0^001??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlN6Q`N?AXL9SdR
?2Hm:Ud^OBYM;Wh^OC:N;WdfWS:M=YhbWCZn=Ydj_SJM>]h2>[h01CZm?]hj_SkN>[d00ckN04`n_D;n
?]i2oSkN@_hngT;n?]i2oSkN@_i2gT;n@]i2oT;NA_i2gT;n@]i6oT;nA_i2gTKn@_i6oT;nAai2oTKn
@_i77TKnAai2oTLNA_i77T;nAai6oTLNA_i77TKnAai6oT/NA_i77TKnBai6oTLNA_i;7TKnBai6oT/N
A_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7PX0000<A_i;7TKnBal004/NA_i;7dLNBai6oT/O17oo
00<007ooOol04goo000XOol00`00Oomoo`0WOol01D/NCai?7TlNBah00dlN00E;7TlNCai?7T/N00=?
7P05Bai?7TlNCai;7P02Cah00ahM6Q`N7@029Sd01B8l9SdZGBim:Ud00S9m00<bWRim=Yh00SJN00Df
WCJn=[hj_SJn00@j_P<ngP03>[hngSkN00@ngP05@]hngSkN@]i2oP03@]h00d;n@]i2oP05@_h01TKn
@_i2oT;nA_i2oPi6oP05Aai6oTKnA_i77P03A_h02TLNA_i77TKnAai6oTLNA_i77TKn0dLN00I6oTLN
Aai;7TKnAah900004T/NAai;7TLNBai77T/NAai;7TLNBai77T/NAai;7P00Bai77P=;7P03Aai;7Woo
009oo`03001oogoo01=oo`00:7oo00<007ooOol0:7oo03I;7DlnBae?7T/MCci;7DlNBae??T/MCai;
7DlnBae?7T/MCci;7D/NB_e;7T[n8Q`J71hm9S`VGBHl;WhZGBim:UdbWRim<YhbWCJn<YdfWSJM>[hf
WCZn>[dngSZn>]hj_CkN>[hngSZm@]h3?]h0=T;n?]i2oSkN@_hngT;n?]i2oT;N@_i2gT;n@]i6oT;N
A_i2gTKn@]i6oT;nA_i2oTKn@_i6oT;nAai2oTKn@_i77TKnAai2oTLNA_i77TKnAai6oTLNA_i77TKn
Aai6oT/NA_i77TKnBai6oPX0000PBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6
oT/OA_i;7TKn00177T/NA_i;7dLNBai6oP=oo`03001oogoo01=oo`009goo00<007ooOol0:Woo00E;
7TlNCai?7T/N00=?7P05Bai?7TlNCai;7P03Cah00d/NCai;7P03Bah37Q`49Sd022im:Ud^OC9m<Yhb
OC:N=Yd3=Yh00cJn>[hf_P06>[h8?]h024;N?]i2gSkN@_i2gT;n@]h3@_h00d;N@_i2oP04@_h01TKn
@_i2oT;nA_i2oPi6oP06Aai6oTKnA_i77TKn2@0000=6oTLNA_h00dLN00E6oTLNAai;7TKn00977P05
Bai6oTLNAai;7P03Aah04T/NAai;7TLNBai77T/NAai;7TLNBai77T/N001;7TLNBai77P=;7P=oo`03
001oogoo01=oo`009goo00<007ooOol0:goo01I;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?
7T/MCci2gT;n@]i2o`8R700N7O`ZGBHm:UdV?2in:Ud^ORim<YhbOC:N<Ydf_SJM>[hfWCZn=YdngSZm
?]hj_SkN>[dngSZn?]hngD;N0ckN0292oSkN@_hngT;n?]i2oSkN@_i2gT;n@]i6oT;NA_i2gTKn@_i6
oT;NA_i2oTKn@_i77T;nA_i2oTLN@_i6oT;nAai6oPT0000cA_i77TKnAai6oT/NA_i;7TKnBai6oT/N
A_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7dKnBai6oT/O
Aah004KnBam77T/NA_i;7dLN00Aoo`03001oogoo019oo`009goo00<007ooOol0:goo00=?7T/NCah0
0TlN00E;7TlNCai?7T/N00=?7P06Bai?7TlNCai;7TlN14;n0b8L00<VGBHm:Ud012im00DbOC:N<Ydf
WSJM008fWP05>[hf_SZn>[hjgP03>[h00ckN?[hngP07?]h024;N?]i2gT;N@_i2gT;n@]h8@_h014Kn
@_i6oT;n0dKn2P001DKn00E77TKnA_i6oTLN00=6oP0:Aai6oTLNA_i77TKnAai6oTLNA_h3Aah01DKn
Aai77T/NA_h00TLN00E;7TLNAai77T/N00=77P0>Bai77T/NAai;7TLNBai77T/NAai;7TLN00177P=;
7P03Aai;7T/N00=oo`03001oogoo019oo`009goo00<007ooOol0;7oo04L004/MCci;7DlNBae??T/M
Cai;7DlnBae?7T/MCci;7DlNBae??SJn>]hf_RHm8Q`R7AhL:UdV?BYM;Ud^ORiM<YhbOC:N<Wdf_SJM
=[hf_CZn=Ydj_SJm?]hj_CkN>[hngSZm?]hj_T;N?]e2gSkN@_hngT;n?]i2oSkN@_hngT;n@]i2oT;N
@_i2gTKn00T00017A_i2oTLN@_i77T;nAai2oTLN@_i77TKnAai6oTLNA_i77TKnAai6oTLNA_i;7TKn
Aai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKn
Bai6oT/NA_i;7dKnBai6oT/O001;7TKnBam77T/NA_i;7`03Ool00`00Oomoo`0BOol002Moo`03001o
ogoo02eoo`03001;7TlN009?7P05Bai?7TlNCai;7P03Cah034/NCai?7TlNBahjgSZn>]hj_R8l8Q`V
?@<ZG@@^O@07<YhbWC:N=Yhf_SJM=Yh01CZn00<ngSZn>[h02CkN00A2gSkN@]i2gPX000A2oP04A_i2
oTKn@_h3A_h00d;nA_i6oP08A_h04TLNA_i6oTKnAai6oTLNA_i77TKnAai6oTLNA_i77TKnAai6oP=7
7P05A_i77TLNBai6oP02Aah06T/NAai77TLNBai77T/NAai;7TLNBai77T/NAai;7TLNBai77T/NAai;
7TLN00177T/NAah3Bah01DLNOomoogoo000057oo000WOol00`00Oomoo`0^Ool04dlNBae??T/MCai;
7DlnBae?7T/MCci;7DlNBae??T/MCai;7C:N008^WP048Q`V?B8L9Sd2:Ud03bXm<Wh^OC9n<WdfWS9m
=YhfWCJn=Ydj_SJm>[hf_@02>[h01SkN>[dngSjn?]hj_@T0001J?]i2oSkN@_i2gT;n@]i6oT;NA_i2
gTKn@_i6oT;nA_i2oTKn@_i77T;nA_i2oTLN@_i77T;nAai6oTLN@_i77TKnAai6oTLNA_i77TKnBai6
oTLNA_i;7TKnAai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6
oT/NA_i;7TKnBai6oT/NA_i;7dKnBah004/OAai;7TKnBam77T/N17oo00<007ooOol04Goo000WOol0
0`00Oomoo`0_Ool00dlNBai?7P02Cah01D/NCai?7TlNBah00dlN00I;7TlNCai?7T/N8Ud2;Yh00bHl
9SdV?003:Ud4;Wd023:M=YhbWCJn=Yhf_SJM>[h:0006?]h00d;N@_hngP02@]h014;n@]i2oT;N14;n
00Y6oT;n@_i2oTKn@_i6oT;nA_i2oPi6oP0>Aai6oTKnA_i77TKnAai6oTLNA_i77TKnAai6oP=77P05
A_i77TLNAai6oP02Aah01D/NA_i77TLNBah00dLN019;7TLNBai77T/NAai;7TLNBai77T/NAai;7TLN
Bai77T/N0003Bah014LNBai;7T/N0goo00<007ooOol04Goo000WOol00`00Oomoo`0`Ool07DlNBae?
?T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7BIN8UdV?B8L9SdV?2im:Ud^GBim<Wh02@0000Pj
_SZm>[hf_CkN>[hngSZm0ckN06<j_D;n?]i2gSkM@_hngT;n?]i2oT;N@_hngT;n@]i2oT;NA_i2gTKn
@]i6oT;nA_i2oTKn@_i6oT;nAai2oTKn@_i77T;nAai2oTLNA_i77T;nAai6oTLNA_i77TKnAai6oT/N
A_i77TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/N
A_i;7TKnBai6oT/OA_i;7TKnBam77P00A_i;7dLNBai6oT/OAah010004goo000WOol00`00Oomoo`0`
Ool00`00Cai;7P03Cah01D/NCai?7TlNBah00dlN00E;7TlNCai?7T/N00X0000:<Wd^OCJN=YdfWS:M
=[hfWSJn=Yd4>[h00ckN>[hngP07?]h01T;N?]i2gT;N@_hngP92gP03@_i2gT;n00E2oP0:A_i2oT;n
@_i6oT;nA_i2oTKn@_h>A_h03TLNA_i77TKnAai6oTLNA_i77TKnAai6oTLNA_h3Aah01DKnAai77TLN
A_h00TLN00E;7TKnAai77T/N00=77P0BBai77T/NAai;7TLNBai77T/NAai;7TLNBai77T/N001;7TLN
0d/N00=77T/NOol00Woo00<007ooOol04Goo000WOol00`00Oomoo`0aOol02D/MCai;7DlnBae?7T/M
Cci;7@0900001B8L9SdR72YM9S`00RYM01H^OBYM<YhbOC:N;WdfWS:M=YhbWCZn=Ydj_SZm>]hj_CZn
>[dngSZn?]hn_@<ngP1Q?]e2oSkN@]hngT;n?]i2oSkN@_i2gT;n?]i6oT;N@_i2gTKn@_i6oT;NA_i2
oTKn@_i6oT;nA_i2oTLN@_i77T;nAai2oTLN@_i77TKnAai6oTLNA_i77TKnBai6oTLNA_i;7TKnAai6
oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6
oT/NA_i;7dLNBai6oP00Aai;7TKnBam77T/NA_h00goo00<007ooOol04Goo000WOol00`00Oomoo`0`
Ool:0002Cah014/NCai?7TlN0dKn00XV?2HL8SdR72YM9S`V?BiM;Wd^G@8bO@04<YhbOCJN=Yd2=Yh0
0cZn=[hj_P03>[h013kN>[hngSjn23kN14;N00=2oT;N@_h00T;n00=2gT;n@_h014;n00I6oT;nA_i2
oTKn@_h3A_h00d;nA_i6oP08A_h03TLNA_i6oTKnAai6oTLNA_i77TKnAai6oTLNA_h3Aah01DKnAai7
7T/NA_h00TLN00E;7TKnAai77T/N00=77P0CBai77T/NAai;7TLNBai77T/NAai;7TLNBai77T/NAai;
7TLN00000T/N00E77T/NBai;7TLN009oo`03001oogoo015oo`009Woo00<007ooOol0:7oo2@000goo
099;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DLNA_i77TKn9SdV72Hm:S`ZGBHl;Wh^GBim:UdfWS9m
<YhbWCJn=YdfWSJM>[hfWCZn>[dngSZm?]hj_CkN>[hngSjm@]hngT;N?]e2oSkN@_hngT;n?]i2oT;N
@_i2gT;n@]i6oT;NA_i2gTKn@_i6oT;NA_i2oTKn@_i6oT;nA_i2oTLNA_i77T;nAai6oTLN@_i77TKn
Aai6oTLNA_i77TKnBai6oTLNA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKn
Bai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai77T/NA_i;7TLNBah004/OAai;7TKnBam77T/N0Woo00<0
07ooOol04Goo000VOol00`00Oomoo`0OOol9000=Ool2Cah01D/NCai?7TlNBah00dlN00=;7TlNCah0
0c[N00@V72Hl9Q`V?08ZG@0=:Sd^OBim;WdbOC:M<WdbWSJM=YhfWCZn=[h01CZn00Dn_SkN>[hngSjn
00@ngP05@]hngT;N?]i2oP03@]h00d;n@]i2oP09@_h00dKn@_i6oP02A_h00d;nA_i6oP08A_h01DLN
A_i6oTKnAah00dKn00Y77TKnAai6oTLNA_i77TKnAai6oP=77P05A_i77TLNBai6oP02Aah01D/NA_i7
7TLNBah00dLN00i;7TLNBai77T/NAai;7TLNBai77T/NAai;7TLN0T/N00<004LNBah00T/N00=77T/N
Bah00Woo00<007ooOol04Goo000VOol00`00Oomoo`0EOol:000FOol05P00Bae?7T/MCci;7DlNBae?
?T/MCai;7Dln>[hjgSZn?]lV?2Xm9S`^GBYL0RiM07TbORiM<WdbOCJN<Wdf_SJM=[hfWCZn=Ydj_SZm
?]hj_CkN>[hngSZm?]hj_T;N?]e2gSkN@]hngD;n?]i2oSkN@_hngT;n@]i2oT;NA_i2gTKn@]i6oT;N
A_i2oTKn@_i6oT;nA_i2oTLN@_i6oT;nAai6oTLN@_i77TKnAai6oTLNA_i77TKnAai6oTLNA_i;7TKn
Bai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKn
Bai6oT/NA_i;7TLNBai6oT/OAah004KnBam77T/NA_i;7`02Ool00`00Oomoo`0AOol002Ioo`03001o
ogoo00aoo`T0025oo`=?7P05Bai?7TlNCai;7P03Cah00d/NCah^WP02;Yh2:S`01RXm;Ud^GBYM;Ud^
O@8bO@07=YhbOC:M<Ydf_SJM=Yh01CZn00<n_SZn>[h00SkN00<n_SkN?]h013kN00E2gSkN@]i2gT;n
00=2gP03@_i2gT;n00M2oP04A_i2oTKn@_h>A_h01DLNA_i6oTKnAah00dKn00Y77TKnAai6oTLNA_i7
7TKnAai6oP=77P05A_i77TLNBai6oP02Aah01D/NA_i77TLNBah00dLN019;7TLNBai77T/NAai;7TLN
Bai77T/NAai;7TLNBah004/NAah3Bah01DLNOomoogoo00004Woo000VOol00`00Oomoo`02Ool:000[
Ool0;4lnBae?7T/MCci;7DlNBae??T/MCai;7Dln:Wh^WRYm;UdV?2Xm:U`^OBiM<Wd^GC9n;WdfWS9m
=YhfWCZn=Ydj_SZm>[hfWCZn>[dngSZm?]hn_SkN>[d2?]h0HD;N?]e2gSkN@_hngD;n?]i2oSkN@_i2
gT;n@]i2oT;NA_i2gTKn@]i6oT;NA_i2oTKn@_i77T;nA_i2oTLN@_i6oT;nAai6oTLNA_i77TKnAai6
oTLNA_i77TKnBai6oTLNA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6
oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TLNBai6oP00Aai;7TKnBam77T/N00=oo`03001o
ogoo011oo`009Woo1@00=Woo0dlN00E;7TlNCai?7T/N00=?7P04Bai?7RYM;Ud2:Sd00bXl;Ud^G@02
;Ud3<Wd01cJM=YhbWCJM=Yhj_SJM00Hj_P03?]hj_Sjn00LngP=2gP05?]i2gT;N@_i2gP03@_h014;N
@_i2oTKn0d;n00I6oT;nA_i2oTKn@_h>A_h03TLNA_i6oTKnAai6oTLNA_i77TKnAai6oTLNA_h3Aah0
1DKnAai77T/NA_h00TLN01I;7TKnAai77T/NAai;7TLNBai77T/NAai;7TLNBai77T/NAai;7TLNBai7
7P=;7P05001;7T/NBai77P03Bah2Ool00`00Oomoo`0@Ool002Moo`03001oogoo03Qoo`0DCci;7DlN
Bae??T/MCai;7DlnBae?7T/M;UdZ?2iM:S`^GBXl<Wd^G@8bO@1h<WhbOC:N=YdfWS:M>[hfWCZn=Ydn
_SZm>[hj_CkN>[dngSZm?]hn_SkN>[e2gSkN@]hngD;n?]i2oSkM@_i2gT;n?]i6oT;N@_i2gTKn@]i6
oT;NA_i2oTKn@]i6oT;nA_i2oTLN@_i6oT;nAai2oTLN@_i77TKnAai6oTLNA_i77TKnBai6oTLNA_i;
7TKnAai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;
7TKnBai6oT/NA_i;7TLNBai6oT/NAai;7P00Bam77T/NA_i;7dLN0Woo00<007ooOol047oo000XOol0
0`00Oomoo`0hOol3Cah01D/NCai?7TlNBah00dKn00=2oRhl;S`00RiL0RiM00DbOBiM;WdbOCJM008b
O@03=YdfWSJM00<j_P03=Ydj_SZn008j_P8n_P03?]hj_SkN00DngP03@]hngT;N0092gP05?]i2oT;N
@_i2gP03@_h014;N@_i2oTKn0d;n00=6oT;nA_h00TKn00=2oTKnA_h024Kn00E77TKnA_i6oTLN00=6
oP0:Aai6oTLNA_i77TKnAai6oTLNA_h3Aah01DKnAai77T/NA_h00TLN019;7TLNAai77T/NAai;7TLN
Bai77T/NAai;7TLNBai77T/NAah3Bah01DLNBai;7P00Aah00d/N00E77T/NOomoo`00019oo`00:Goo
00<007ooOol0=goo01E;7DlnBae?7T/MCci;7DlNBadj_SJM>[h^?39M;S`bOBiL;Ud^G39m;Ud00S9m
07HfWS9m=YhfWCJN=Ydj_SJM>[hfWCkN>[dn_SZm?]hj_CkN?[dngSjn?]hngD;n?]i2gSkM@_hngT;n
?]i2oT;N@_i2gTKn@]i2oT;NA_i2oTKn@]i6oT;nA_i2oTLN@_i6oT;nAai2oTLN@_i77TKnAai2oTLN
A_i77TKnAai6oTLNA_i;7TKnAai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/N
A_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NAai;7TKnBal004/NA_i;7dLNBai6oP9o
o`03001oogoo011oo`00:Woo00<007ooOol0=goo00E;7TlNCai?7T/N00=?7P05Bahj_SJn>[hbG002
;S`00c9M;UdbG@04<Wd2=Yd01C9m=YhfWCJN=Yd01cZn00<n_SkN?[h013kN00E2gSkN?]hngT;n00=2
gP04@_i2gT;n@]h8@_h01TKn@_i6oT;nA_i2oPi6oP0BAai6oTKnA_i77TKnAai6oTLNA_i77TKnAai6
oTLNA_i77TKn0dLN00E6oTLNAai;7TKn00977P0BBai77T/NAai;7TLNBai77T/NAai;7TLNBai77T/N
Aai;7TLN0d/N00E77P00Bai;7TLN00=;7P03Aaioo`00019oo`00:goo00<007ooOol0=goo1P001Goo
00HbGC9L=Ud^G39m;U`2<Wd0NcIm<WdfWS9m=YhbOCZn=Ydj_SJM>[hfWCZn>[dngSZm?]hj_CkN>[dn
gSjm@]hngT;N?]e2oSkN@_hngD;n?]i2oT;N@_i2gT;n@]i6oT;NA_i2gTKn@_i6oT;nA_i2oTKn@_i7
7T;nA_i2oTLNA_i77T;nAai6oTLN@_i77TKnAai6oT/NA_i77TKnBai6oTLNA_i;7TKnBai6oT/NA_i;
7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai77T/NA_i;
7TLNBai6oP00Aai;7TKnBam77T/NOol0000BOol002aoo`03001oogoo03Ioo`03001oogoo00Yoo`8b
G08bO@03<UdbOC9m008bO@@fW@04=YhfWCZN>[d2>[h023jn>[hj_SZn?]hn_SkN?[h4?]h01D;N?]i2
gT;N@_h00d;N00A2oT;N@_i2gPA2oP06A_i2oT;n@_i6oT;n4TKn00Y77TKnAai6oTLNA_i77TKnAai6
oP=77P05A_i77TLNBai6oP02Aah01D/NA_i77TLNBah00dLN00i;7TLNBai77T/NAai;7TLNBai77T/N
Aai;7TLN0d/N00E77T/NBai;7P0000=;7P05Aai;7T/NOol0000BOol002eoo`03001oogoo03Eoo`03
001oogoo00aoo`0H=WdbG3Im<U`fWS9m=YdfOCJN=WdfWSJM>[hfWCZn>Ydj_SZM?]hj_CkN>[dngSZm
0SkN06E2gSjm@]hngT;N?]e2oT;N@_hngD;n@]i2oT;N@_i2gTKn@]i6oT;nA_i2gTKn@_i6oT;nA_i2
oTKn@_i77T;nAai2oTLNA_i77TKnAai6oTLNA_i77TKnAai6oT/NA_i77TKnBai6oT/NA_i;7TKnBai6
oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai7
7T/NA_i;7dLN0016oT/OAai;7TKnBam77P00019oo`00;Woo00<007ooOol0=7oo00<007ooOol047oo
0cIm13JM00Hj_SJM>YhjWCZn>[d2>[h00cjn>[hn_P02?]h013jn?]hngT;N0SkN0T;N00@ngT;N@]i2
oP92gP92oP03@]i2oT;n00A2oP03A_i2oTKn0096oP03@_i6oTKn00Q6oP05Aai6oTKnA_i77P03A_h0
2TLNA_i77TKnAai6oTLNA_i77TKn0dLN00E6oTLNAai;7TKn00977P05Bai6oTLNAai;7P03Aah03T/N
Aai;7TLNBai77T/NAai;7TLNBai77T/NAah3Bah01DLNBai;7P00Aah00d/N00=77T/N00004Woo000_
Ool00`00Oomoo`0cOol00`00Oomoo`0DOol0McZN=YdjWSJM>[hfWCZn>[dj_SZM?[hj_CkN>[dngSjm
?]hn_D;N?]i2gSkM@_hngT;n?]e2oT;N@_hngD;n@]i2oT;NA_i2gTKn@]i6oT;nA_i2gTKn@_i6oT;n
A_i2oTKn@_i77TKnAai2oTLNA_i77TKnAai6oTLNA_i;7TKnAai6oT/NA_i77TKnBai6oT/NA_i;7TKn
Bai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NAai;7TKn
Bai77T/NA_i;7`00Bai6oT/OAai;7TKn00004Woo000`Ool00`00Oomoo`0bOol00`00Oomoo`0HOol0
0cZM>[hjW@02>[h01Sjn>[dn_Sjn?]hj_PHngP03@]hngT;N00E2gP03@_i2gT;n0092oP09@]i2oT;n
A_i2oTKn@_i6oT;n00=6oP03@_i6oTKn00Q6oP05Aai6oTKnA_i77P03A_h02TLNA_i77TKnAai6oTLN
A_i77TKn0dLN00E6oTLNAai;7TKn00977P0FBai77T/NAai;7TLNBai77T/NAai;7TLNBai77T/NAai;
7TLNBai77T/NAah3Bah01DLN001;7T/NAah00d/N00<007ooOol047oo000aOol00`00Oomoo`0aOol0
0`00Oomoo`0LOol0Kcjn>[dn_SZm?]hj_CkN>[e2gSjm?]hngD;N?]i2gSkM@_hngT;n?]e2oT;N@_i2
gDKn@]i2oT;NA_i2gTKn@]i6oT;nA_i2gTLN@_i6oT;nAai2oTKn@_i77TKnAai2oTLNA_i77TKnAai6
oTLNA_i;7TKnAai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6
oT/NA_i;7TKnBai6oT/NA_i;7TLNBai6oT/NAai;7TKnBai77T/N001;7dLNBai6oT/OAah0000BOol0
039oo`03001oogoo031oo`03001oogoo02Aoo`DngP03@]hngT;N00E2gP04@_i2gT;n@]h6@_h01TKn
@_i6oT;nA_i2oPi6oP0>Aai6oTKnA_i77TKnAai6oTLNA_i77TKnAai6oP=77P05A_i77TLNBai6oP02
Aah05T/NA_i77TLNBai77T/NAai;7TLNBai77T/NAai;7TLNBai77T/NAai;7TLN0d/N00E77T/NBai;
7P0000=;7P04Aai;7Woo000AOol003=oo`03001oogoo02moo`03001oogoo02aoo`0K@_hngD;n?]i2
oT;M@_i2gT;n@]i6oT;NA_i2gTKn@]i6oT;nA_i2oTKn@_i77T;nA_i2oTLN0096oP0[@_i77TKnAai2
oTLNA_i77TKnBai6oTLNA_i;7TKnAai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6
oT/NA_i;7TKnBai6oT/NA_h047oo00<007ooOol017oo00<007ooOol03goo000dOol00`00Oomoo`0]
Ool00`00Oomoo`0nOol00dKn@_i6oP0AA_h02TLNA_i6oTKnAai6oTLNA_i77TKn:Goo00<007ooOol0
17oo00<007ooOol03goo000eOol2000]Ool00`00Oomoo`25Ool00`00Oomoo`04Ool00`00Oomoo`0?
Ool003Moo`03001oogoo02Yoo`03001oogoo08Ioo`03001oogoo00=oo`03001oogoo00moo`00>7oo
00<007ooOol0:Goo00<007ooOol0QWoo00<007ooOol00goo00<007ooOol03goo000iOol00`00Oomo
o`0XOol00`00Oomoo`26Ool00`00Oomoo`03Ool00`00Oomoo`0?Ool003Yoo`03001oogoo02Moo`03
001oogoo08Ioo`03001oogoo00=oo`03001oogoo00moo`00>goo00<007ooOol09Woo00<007ooOol0
Qgoo00<007ooOol00Woo00<007ooOol03goo000lOol00`00Oomoo`0UOol00`00Oomoo`27Ool00`00
Oomoo`02Ool00`00Oomoo`0?Ool003eoo`03001oogoo02Aoo`03001oogoo08Moo`03001oogoo009o
o`03001oogoo00moo`00?Woo00<007ooOol08goo00<007ooOol0R7oo00D007ooOomoo`00015oo`00
?goo00<007ooOol08Woo00<007ooOol0R7oo00D007ooOomoo`00015oo`00@7oo00<007ooOol08Goo
00<007ooOol0R7oo00D007ooOomoo`00015oo`00@Goo00<007ooOol087oo00<007ooOol0R7oo00<0
07ooOol00Woo00<007ooOol03Woo0012Ool00`00Oomoo`0OOol00`00Oomoo`29Ool01@00Oomoogoo
000047oo0013Ool00`00Oomoo`0NOol00`00Oomoo`29Ool01@00Oomoogoo000047oo0014Ool00`00
Oomoo`0MOol00`00Oomoo`29Ool01@00Oomoogoo000047oo0015Ool00`00Oomoo`0LOol00`00Oomo
o`29Ool01@00Oomoogoo000047oo0016Ool00`00Oomoo`0KOol00`00Oomoo`2:Ool01000Oomoo`00
47oo0017Ool00`00Oomoo`0IOol00`00Oomoo`2;Ool01000Oomoo`0047oo0018Ool00`00Oomoo`0H
Ool00`00Oomoo`2;Ool01000Oomoo`0047oo0019Ool00`00Oomoo`0GOol00`00Oomoo`2<Ool00`00
Ool0000@Ool004Yoo`03001oogoo01Ioo`03001oogoo08aoo`03001oo`00011oo`00Bgoo00<007oo
Ool05Goo00<007ooOol0S7oo00<007oo000047oo001<Ool00`00Oomoo`0DOol00`00Oomoo`2<Ool0
0`00Ool0000@Ool004eoo`03001oogoo01=oo`03001oogoo08eoo`80011oo`00CWoo00<007ooOol0
4Woo00<007ooOol0SGoo0P0047oo001?Ool00`00Oomoo`0AOol00`00Oomoo`2=Ool00`00Ool0000?
Ool0051oo`03001oogoo011oo`03001oogoo08eoo`03001oo`0000moo`00DGoo00<007ooOol03goo
00<007ooOol0SWoo0P003goo001BOol00`00Oomoo`0>Ool00`00Oomoo`2>Ool2000?Ool005=oo`80
00ioo`03001oogoo08ioo`8000moo`00EGoo00<007ooOol02goo00<007ooOol0SWoo0P003goo001F
Ool00`00Oomoo`0:Ool00`00Oomoo`2?Ool00`00Oomoo`0=Ool005Moo`03001oogoo00Uoo`03001o
ogoo08Uoo`L000moo`00F7oo00<007ooOol027oo00<007ooOol0Ngoo3P005Woo001IOol00`00Oomo
o`07Ool00`00Oomoo`1^Ool=000TOol005Yoo`03001oogoo00Eoo`03001oogoo069oo`d0035oo`00
Fgoo00<007ooOol017oo00<007ooOol0E7oo3P00?Woo001LOol00`00Oomoo`03Ool00`00Oomoo`17
Ool=001<Ool004Aoo`<001Ioo`03001oogoo009oo`03001oogoo03Yoo`d005Uoo`00AGoo00<007oo
Ool05Woo00D007ooOomoo`0002ioo`h006Ioo`00AGoo0`005goo00@007ooOol0025oo`d007Aoo`00
AGoo00@007ooOol001Moo`03001oo`0001Aoo`d0085oo`00AGoo00@007ooOol001Qoo`8000Ioo`h0
08ioo`00A7oo10006Woo1`00W7oo003oOol6Ool00?moo`Ioo`00ogoo1Woo003oOol6Ool00?moo`Io
o`00ogoo1Woo003oOol6Ool007aoo`800003Ool00000009oo`@000=oo`8000Aoo`8000Aoo`8000=o
o`@006Ioo`00OGoo00<007oo00002Goo00@007ooOol000Qoo`04001oogoo0002Ool00`00Oomoo`1W
Ool007ioo`03001oogoo009oo`@0009oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol0
IWoo001lOol200000goo00000008Ool01000Oomoo`0027oo00@007ooOol000Aoo`03001oogoo06Eo
o`00RGoo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`00IWoo002:Ool2000:Ool20004
Ool2001WOol00?moo`Ioo`00ogoo1Woo003oOol6Ool00?moo`Ioo`00\
\>"],
  ImageRangeCache->{{{0, 260.563}, {184.063, 0}} -> {-0.170749, 0.0461341, \
0.00439245, 0.00439245}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .70824 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1.10169 -0.148196 1.10169 [
[.5 .72074 -20 0 ]
[.5 .72074 20 15 ]
[.44797 -0.02478 -4.90556 -15 ]
[.44797 -0.02478 5.09444 0 ]
[.15892 .66839 -5.31917 0 ]
[.15892 .66839 4.68083 15 ]
[-0.06694 .27471 -10 -6.62571 ]
[-0.06694 .27471 0 8.37429 ]
[ 0 0 0 0 ]
[ 1 .70824 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .72074 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.437500 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(=) show
75.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.03) show
99.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math1Mono
%%DocumentNeededResources: + font Courier
%%DocumentNeededFonts: Math1Mono
%%DocumentNeededFont: + Courier
%%DocumentFonts: font Math1Mono
%%DocumentFonts: + font Courier
grestore
.25 Mabswid
.02946 .11175 m
.89362 0 L
s
gsave
.44797 -0.02478 -65.9056 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(u) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
0 .4272 m
.29069 .70824 L
s
gsave
.15892 .66839 -66.3192 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(p) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.02946 .11175 m
0 .4272 L
s
gsave
-0.06694 .27471 -71 -10.6257 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(q) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.02946 .11175 m
0 .4272 L
s
0 .4272 m
.29069 .70824 L
s
.29069 .70824 m
.30155 .45044 L
s
.30155 .45044 m
.02946 .11175 L
s
.89362 0 m
.98022 .38351 L
s
.98022 .38351 m
1 .65325 L
s
1 .65325 m
.91448 .33294 L
s
.91448 .33294 m
.89362 0 L
s
.02946 .11175 m
0 .4272 L
s
0 .4272 m
.91448 .33294 L
s
.91448 .33294 m
.89362 0 L
s
.89362 0 m
.02946 .11175 L
s
.30155 .45044 m
.98022 .38351 L
s
.98022 .38351 m
1 .65325 L
s
1 .65325 m
.29069 .70824 L
s
.29069 .70824 m
.30155 .45044 L
s
0 0 m
1 0 L
1 .70824 L
0 .70824 L
closepath
clip
newpath
.832 .74 .763 r
.2912 .5366 .29714 .55519 .31746 .52625 .31147 .51178 Mtetra
.741 .731 .842 r
.31147 .51178 .31746 .52625 .33701 .51579 .33104 .50348 Mtetra
.663 .722 .893 r
.33104 .50348 .33701 .51579 .35634 .51216 .35044 .50113 Mtetra
.61 .717 .921 r
.35044 .50113 .35634 .51216 .37565 .51129 .36982 .50107 Mtetra
.58 .717 .937 r
.36982 .50107 .37565 .51129 .39499 .51154 .38925 .50188 Mtetra
.564 .721 .947 r
.38925 .50188 .39499 .51154 .41439 .51221 .40876 .50294 Mtetra
.557 .727 .953 r
.40876 .50294 .41439 .51221 .43387 .51297 .42835 .50399 Mtetra
.555 .732 .958 r
.42835 .50399 .43387 .51297 .45343 .51367 .44802 .5049 Mtetra
.556 .738 .961 r
.44802 .5049 .45343 .51367 .47307 .51425 .46778 .50564 Mtetra
.557 .744 .964 r
.46778 .50564 .47307 .51425 .49279 .51467 .48761 .50618 Mtetra
.56 .748 .965 r
.48761 .50618 .49279 .51467 .5126 .51493 .50753 .50655 Mtetra
.562 .753 .967 r
.50753 .50655 .5126 .51493 .53247 .51504 .52753 .50673 Mtetra
.565 .756 .968 r
.52753 .50673 .53247 .51504 .55243 .515 .54761 .50675 Mtetra
.567 .76 .969 r
.54761 .50675 .55243 .515 .57246 .51483 .56777 .50663 Mtetra
.57 .763 .969 r
.56777 .50663 .57246 .51483 .59257 .51453 .588 .50637 Mtetra
.572 .765 .97 r
.588 .50637 .59257 .51453 .61275 .51412 .6083 .50598 Mtetra
.574 .768 .97 r
.6083 .50598 .61275 .51412 .633 .5136 .62869 .50549 Mtetra
.576 .77 .971 r
.62869 .50549 .633 .5136 .65333 .51299 .64914 .50489 Mtetra
.577 .772 .971 r
.64914 .50489 .65333 .51299 .67372 .51229 .66967 .5042 Mtetra
.579 .773 .972 r
.66967 .5042 .67372 .51229 .6942 .51152 .69028 .50343 Mtetra
.58 .775 .972 r
.69028 .50343 .6942 .51152 .71474 .51066 .71095 .50258 Mtetra
.581 .776 .972 r
.71095 .50258 .71474 .51066 .73536 .50975 .73171 .50166 Mtetra
.582 .778 .972 r
.73171 .50166 .73536 .50975 .75605 .50877 .75253 .50068 Mtetra
.584 .779 .972 r
.75253 .50068 .75605 .50877 .77681 .50773 .77343 .49964 Mtetra
.584 .78 .973 r
.77343 .49964 .77681 .50773 .79764 .50664 .7944 .49854 Mtetra
.585 .781 .973 r
.7944 .49854 .79764 .50664 .81854 .5055 .81544 .49739 Mtetra
.586 .782 .973 r
.81544 .49739 .81854 .5055 .83952 .50431 .83656 .49619 Mtetra
.587 .782 .973 r
.83656 .49619 .83952 .50431 .86057 .50309 .85775 .49495 Mtetra
.587 .783 .973 r
.85775 .49495 .86057 .50309 .88169 .50182 .87901 .49367 Mtetra
.588 .784 .973 r
.87901 .49367 .88169 .50182 .90289 .50051 .90035 .49236 Mtetra
.589 .784 .973 r
.90035 .49236 .90289 .50051 .92415 .49917 .92176 .491 Mtetra
.589 .785 .973 r
.92176 .491 .92415 .49917 .94549 .4978 .94324 .48961 Mtetra
.59 .786 .973 r
.94324 .48961 .94549 .4978 .96691 .4964 .9648 .48819 Mtetra
.59 .786 .974 r
.9648 .48819 .96691 .4964 .98839 .49497 .98643 .48674 Mtetra
.813 .731 .774 r
.28521 .51783 .2912 .5366 .31147 .51178 .30541 .49716 Mtetra
.717 .719 .851 r
.30541 .49716 .31147 .51178 .33104 .50348 .32501 .49103 Mtetra
.64 .71 .898 r
.32501 .49103 .33104 .50348 .35044 .50113 .34446 .48996 Mtetra
.591 .707 .923 r
.34446 .48996 .35044 .50113 .36982 .50107 .36392 .49073 Mtetra
.565 .709 .938 r
.36392 .49073 .36982 .50107 .38925 .50188 .38345 .49209 Mtetra
.553 .715 .948 r
.38345 .49209 .38925 .50188 .40876 .50294 .40306 .49355 Mtetra
.549 .722 .954 r
.40306 .49355 .40876 .50294 .42835 .50399 .42275 .49488 Mtetra
.549 .729 .958 r
.42275 .49488 .42835 .50399 .44802 .5049 .44254 .49601 Mtetra
.551 .735 .961 r
.44254 .49601 .44802 .5049 .46778 .50564 .46241 .49691 Mtetra
.553 .741 .964 r
.46241 .49691 .46778 .50564 .48761 .50618 .48236 .49759 Mtetra
.556 .747 .966 r
.48236 .49759 .48761 .50618 .50753 .50655 .5024 .49805 Mtetra
.56 .751 .967 r
.5024 .49805 .50753 .50655 .52753 .50673 .52253 .49831 Mtetra
.563 .755 .968 r
.52253 .49831 .52753 .50673 .54761 .50675 .54273 .49839 Mtetra
.566 .759 .969 r
.54273 .49839 .54761 .50675 .56777 .50663 .56301 .49831 Mtetra
.568 .762 .97 r
.56301 .49831 .56777 .50663 .588 .50637 .58337 .49809 Mtetra
.571 .765 .97 r
.58337 .49809 .588 .50637 .6083 .50598 .6038 .49773 Mtetra
.573 .767 .971 r
.6038 .49773 .6083 .50598 .62869 .50549 .62432 .49726 Mtetra
.575 .769 .971 r
.62432 .49726 .62869 .50549 .64914 .50489 .6449 .49668 Mtetra
.576 .771 .971 r
.6449 .49668 .64914 .50489 .66967 .5042 .66557 .496 Mtetra
.578 .773 .972 r
.66557 .496 .66967 .5042 .69028 .50343 .6863 .49523 Mtetra
.58 .775 .972 r
.6863 .49523 .69028 .50343 .71095 .50258 .70712 .49439 Mtetra
.581 .776 .972 r
.70712 .49439 .71095 .50258 .73171 .50166 .728 .49347 Mtetra
.582 .777 .972 r
.728 .49347 .73171 .50166 .75253 .50068 .74896 .49248 Mtetra
.583 .779 .972 r
.74896 .49248 .75253 .50068 .77343 .49964 .77 .49143 Mtetra
.584 .78 .973 r
.77 .49143 .77343 .49964 .7944 .49854 .79111 .49033 Mtetra
.585 .781 .973 r
.79111 .49033 .7944 .49854 .81544 .49739 .81229 .48917 Mtetra
.586 .781 .973 r
.81229 .48917 .81544 .49739 .83656 .49619 .83355 .48796 Mtetra
.587 .782 .973 r
.83355 .48796 .83656 .49619 .85775 .49495 .85488 .48671 Mtetra
.587 .783 .973 r
.85488 .48671 .85775 .49495 .87901 .49367 .87629 .48542 Mtetra
.588 .784 .973 r
.87629 .48542 .87901 .49367 .90035 .49236 .89777 .48408 Mtetra
.89777 .48408 .90035 .49236 .92176 .491 .91933 .48271 Mtetra
.589 .785 .973 r
.91933 .48271 .92176 .491 .94324 .48961 .94096 .48131 Mtetra
.94096 .48131 .94324 .48961 .9648 .48819 .96267 .47987 Mtetra
.59 .786 .974 r
.96267 .47987 .9648 .48819 .98643 .48674 .98445 .4784 Mtetra
.79 .719 .786 r
.27916 .49888 .28521 .51783 .30541 .49716 .29929 .48237 Mtetra
.69 .705 .859 r
.29929 .48237 .30541 .49716 .32501 .49103 .3189 .47843 Mtetra
.615 .696 .902 r
.3189 .47843 .32501 .49103 .34446 .48996 .33841 .47866 Mtetra
.571 .696 .926 r
.33841 .47866 .34446 .48996 .36392 .49073 .35795 .48026 Mtetra
.55 .701 .94 r
.35795 .48026 .36392 .49073 .38345 .49209 .37757 .48219 Mtetra
.542 .709 .948 r
.37757 .48219 .38345 .49209 .40306 .49355 .39728 .48404 Mtetra
.54 .717 .954 r
.39728 .48404 .40306 .49355 .42275 .49488 .41708 .48566 Mtetra
.542 .725 .959 r
.41708 .48566 .42275 .49488 .44254 .49601 .43698 .48701 Mtetra
.545 .733 .962 r
.43698 .48701 .44254 .49601 .46241 .49691 .45697 .48808 Mtetra
.549 .739 .964 r
.45697 .48808 .46241 .49691 .48236 .49759 .47704 .48888 Mtetra
.553 .745 .966 r
.47704 .48888 .48236 .49759 .5024 .49805 .49721 .48943 Mtetra
.557 .75 .967 r
.49721 .48943 .5024 .49805 .52253 .49831 .51745 .48977 Mtetra
.561 .754 .968 r
.51745 .48977 .52253 .49831 .54273 .49839 .53778 .48992 Mtetra
.564 .758 .969 r
.53778 .48992 .54273 .49839 .56301 .49831 .55819 .48988 Mtetra
.567 .761 .97 r
.55819 .48988 .56301 .49831 .58337 .49809 .57868 .4897 Mtetra
.569 .764 .97 r
.57868 .4897 .58337 .49809 .6038 .49773 .59924 .48937 Mtetra
.572 .767 .971 r
.59924 .48937 .6038 .49773 .62432 .49726 .61989 .48892 Mtetra
.574 .769 .971 r
.61989 .48892 .62432 .49726 .6449 .49668 .64061 .48835 Mtetra
.576 .771 .971 r
.64061 .48835 .6449 .49668 .66557 .496 .6614 .48768 Mtetra
.577 .773 .972 r
.6614 .48768 .66557 .496 .6863 .49523 .68228 .48692 Mtetra
.579 .774 .972 r
.68228 .48692 .6863 .49523 .70712 .49439 .70323 .48608 Mtetra
.58 .776 .972 r
.70323 .48608 .70712 .49439 .728 .49347 .72425 .48516 Mtetra
.582 .777 .972 r
.72425 .48516 .728 .49347 .74896 .49248 .74535 .48417 Mtetra
.583 .778 .972 r
.74535 .48417 .74896 .49248 .77 .49143 .76653 .48311 Mtetra
.584 .779 .973 r
.76653 .48311 .77 .49143 .79111 .49033 .78778 .482 Mtetra
.585 .78 .973 r
.78778 .482 .79111 .49033 .81229 .48917 .8091 .48083 Mtetra
.586 .781 .973 r
.8091 .48083 .81229 .48917 .83355 .48796 .8305 .47962 Mtetra
.586 .782 .973 r
.8305 .47962 .83355 .48796 .85488 .48671 .85198 .47835 Mtetra
.587 .783 .973 r
.85198 .47835 .85488 .48671 .87629 .48542 .87353 .47704 Mtetra
.588 .784 .973 r
.87353 .47704 .87629 .48542 .89777 .48408 .89516 .47569 Mtetra
.89516 .47569 .89777 .48408 .91933 .48271 .91686 .47431 Mtetra
.589 .785 .973 r
.91686 .47431 .91933 .48271 .94096 .48131 .93864 .47289 Mtetra
.93864 .47289 .94096 .48131 .96267 .47987 .9605 .47143 Mtetra
.59 .786 .974 r
.9605 .47143 .96267 .47987 .98445 .4784 .98243 .46994 Mtetra
.762 .705 .798 r
.27305 .47974 .27916 .49888 .29929 .48237 .2931 .46742 Mtetra
.659 .689 .867 r
.2931 .46742 .29929 .48237 .3189 .47843 .31272 .46568 Mtetra
.588 .681 .906 r
.31272 .46568 .3189 .47843 .33841 .47866 .33229 .46721 Mtetra
.55 .684 .927 r
.33229 .46721 .33841 .47866 .35795 .48026 .35191 .46965 Mtetra
.534 .692 .94 r
.35191 .46965 .35795 .48026 .37757 .48219 .37162 .47215 Mtetra
.53 .702 .949 r
.37162 .47215 .37757 .48219 .39728 .48404 .39143 .47441 Mtetra
.532 .712 .955 r
.39143 .47441 .39728 .48404 .41708 .48566 .41134 .47632 Mtetra
.535 .722 .959 r
.41134 .47632 .41708 .48566 .43698 .48701 .43135 .47789 Mtetra
.54 .73 .962 r
.43135 .47789 .43698 .48701 .45697 .48808 .45146 .47912 Mtetra
.545 .737 .964 r
.45146 .47912 .45697 .48808 .47704 .48888 .47165 .48005 Mtetra
.55 .743 .966 r
.47165 .48005 .47704 .48888 .49721 .48943 .49194 .48071 Mtetra
.554 .748 .967 r
.49194 .48071 .49721 .48943 .51745 .48977 .51231 .48112 Mtetra
.558 .753 .968 r
.51231 .48112 .51745 .48977 .53778 .48992 .53276 .48133 Mtetra
.562 .757 .969 r
.53276 .48133 .53778 .48992 .55819 .48988 .5533 .48134 Mtetra
.565 .76 .97 r
.5533 .48134 .55819 .48988 .57868 .4897 .57392 .48119 Mtetra
.568 .763 .97 r
.57392 .48119 .57868 .4897 .59924 .48937 .59462 .48089 Mtetra
.571 .766 .971 r
.59462 .48089 .59924 .48937 .61989 .48892 .61539 .48046 Mtetra
.573 .768 .971 r
.61539 .48046 .61989 .48892 .64061 .48835 .63625 .47991 Mtetra
.575 .77 .971 r
.63625 .47991 .64061 .48835 .6614 .48768 .65718 .47925 Mtetra
.577 .772 .972 r
.65718 .47925 .6614 .48768 .68228 .48692 .67819 .4785 Mtetra
.578 .774 .972 r
.67819 .4785 .68228 .48692 .70323 .48608 .69928 .47765 Mtetra
.58 .775 .972 r
.69928 .47765 .70323 .48608 .72425 .48516 .72044 .47673 Mtetra
.581 .777 .972 r
.72044 .47673 .72425 .48516 .74535 .48417 .74169 .47574 Mtetra
.582 .778 .972 r
.74169 .47574 .74535 .48417 .76653 .48311 .763 .47468 Mtetra
.583 .779 .973 r
.763 .47468 .76653 .48311 .78778 .482 .7844 .47356 Mtetra
.584 .78 .973 r
.7844 .47356 .78778 .482 .8091 .48083 .80587 .47238 Mtetra
.585 .781 .973 r
.80587 .47238 .8091 .48083 .8305 .47962 .82741 .47115 Mtetra
.586 .782 .973 r
.82741 .47115 .8305 .47962 .85198 .47835 .84903 .46987 Mtetra
.587 .783 .973 r
.84903 .46987 .85198 .47835 .87353 .47704 .87073 .46855 Mtetra
.87073 .46855 .87353 .47704 .89516 .47569 .89251 .46719 Mtetra
.588 .784 .973 r
.89251 .46719 .89516 .47569 .91686 .47431 .91436 .46578 Mtetra
.589 .785 .973 r
.91436 .46578 .91686 .47431 .93864 .47289 .9363 .46434 Mtetra
.9363 .46434 .93864 .47289 .9605 .47143 .9583 .46287 Mtetra
.59 .786 .974 r
.9583 .46287 .9605 .47143 .98243 .46994 .98039 .46136 Mtetra
.729 .686 .809 r
.26689 .46043 .27305 .47974 .2931 .46742 .28685 .45231 Mtetra
.623 .669 .873 r
.28685 .45231 .2931 .46742 .31272 .46568 .30647 .45278 Mtetra
.558 .665 .908 r
.30647 .45278 .31272 .46568 .33229 .46721 .32609 .45563 Mtetra
.528 .671 .928 r
.32609 .45563 .33229 .46721 .35191 .46965 .34579 .45891 Mtetra
.518 .683 .941 r
.34579 .45891 .35191 .46965 .37162 .47215 .36559 .46198 Mtetra
.518 .695 .949 r
.36559 .46198 .37162 .47215 .39143 .47441 .3855 .46464 Mtetra
.523 .707 .955 r
.3855 .46464 .39143 .47441 .41134 .47632 .40552 .46686 Mtetra
.529 .718 .959 r
.40552 .46686 .41134 .47632 .43135 .47789 .42565 .46864 Mtetra
.535 .727 .962 r
.42565 .46864 .43135 .47789 .45146 .47912 .44587 .47004 Mtetra
.541 .735 .965 r
.44587 .47004 .45146 .47912 .47165 .48005 .46619 .4711 Mtetra
.547 .741 .966 r
.46619 .4711 .47165 .48005 .49194 .48071 .4866 .47186 Mtetra
.552 .747 .967 r
.4866 .47186 .49194 .48071 .51231 .48112 .5071 .47235 Mtetra
.556 .752 .968 r
.5071 .47235 .51231 .48112 .53276 .48133 .52768 .47262 Mtetra
.56 .756 .969 r
.52768 .47262 .53276 .48133 .5533 .48134 .54835 .47268 Mtetra
.564 .759 .97 r
.54835 .47268 .5533 .48134 .57392 .48119 .5691 .47257 Mtetra
.567 .763 .97 r
.5691 .47257 .57392 .48119 .59462 .48089 .58993 .4723 Mtetra
.57 .765 .971 r
.58993 .4723 .59462 .48089 .61539 .48046 .61084 .47189 Mtetra
.572 .768 .971 r
.61084 .47189 .61539 .48046 .63625 .47991 .63183 .47135 Mtetra
.574 .77 .971 r
.63183 .47135 .63625 .47991 .65718 .47925 .6529 .4707 Mtetra
.576 .772 .972 r
.6529 .4707 .65718 .47925 .67819 .4785 .67405 .46995 Mtetra
.578 .774 .972 r
.67405 .46995 .67819 .4785 .69928 .47765 .69528 .46911 Mtetra
.579 .775 .972 r
.69528 .46911 .69928 .47765 .72044 .47673 .71659 .46819 Mtetra
.581 .776 .972 r
.71659 .46819 .72044 .47673 .74169 .47574 .73797 .46719 Mtetra
.582 .778 .973 r
.73797 .46719 .74169 .47574 .763 .47468 .75943 .46613 Mtetra
.583 .779 .973 r
.75943 .46613 .763 .47468 .7844 .47356 .78097 .465 Mtetra
.584 .78 .973 r
.78097 .465 .7844 .47356 .80587 .47238 .80258 .46381 Mtetra
.585 .781 .973 r
.80258 .46381 .80587 .47238 .82741 .47115 .82428 .46257 Mtetra
.586 .782 .973 r
.82428 .46257 .82741 .47115 .84903 .46987 .84605 .46128 Mtetra
.587 .783 .973 r
.84605 .46128 .84903 .46987 .87073 .46855 .8679 .45994 Mtetra
.8679 .45994 .87073 .46855 .89251 .46719 .88983 .45856 Mtetra
.588 .784 .973 r
.88983 .45856 .89251 .46719 .91436 .46578 .91183 .45714 Mtetra
.588 .785 .973 r
.91183 .45714 .91436 .46578 .9363 .46434 .93391 .45568 Mtetra
.589 .785 .973 r
.93391 .45568 .9363 .46434 .9583 .46287 .95608 .45418 Mtetra
.589 .786 .974 r
.95608 .45418 .9583 .46287 .98039 .46136 .97832 .45266 Mtetra
.688 .663 .82 r
.26066 .44092 .26689 .46043 .28685 .45231 .28052 .43702 Mtetra
.583 .646 .878 r
.28052 .43702 .28685 .45231 .30647 .45278 .30015 .43973 Mtetra
.526 .646 .91 r
.30015 .43973 .30647 .45278 .32609 .45563 .31981 .4439 Mtetra
.504 .658 .929 r
.31981 .4439 .32609 .45563 .34579 .45891 .33958 .44804 Mtetra
.501 .673 .941 r
.33958 .44804 .34579 .45891 .36559 .46198 .35948 .45169 Mtetra
.506 .688 .95 r
.35948 .45169 .36559 .46198 .3855 .46464 .3795 .45476 Mtetra
.514 .702 .955 r
.3795 .45476 .3855 .46464 .40552 .46686 .39963 .45727 Mtetra
.522 .714 .96 r
.39963 .45727 .40552 .46686 .42565 .46864 .41987 .45928 Mtetra
.53 .724 .963 r
.41987 .45928 .42565 .46864 .44587 .47004 .44021 .46084 Mtetra
.537 .732 .965 r
.44021 .46084 .44587 .47004 .46619 .4711 .46065 .46203 Mtetra
.544 .739 .966 r
.46065 .46203 .46619 .4711 .4866 .47186 .48119 .46289 Mtetra
.549 .745 .968 r
.48119 .46289 .4866 .47186 .5071 .47235 .50181 .46347 Mtetra
.554 .75 .969 r
.50181 .46347 .5071 .47235 .52768 .47262 .52253 .46379 Mtetra
.558 .755 .969 r
.52253 .46379 .52768 .47262 .54835 .47268 .54333 .46391 Mtetra
.562 .759 .97 r
.54333 .46391 .54835 .47268 .5691 .47257 .56421 .46383 Mtetra
.566 .762 .97 r
.56421 .46383 .5691 .47257 .58993 .4723 .58518 .46359 Mtetra
.568 .765 .971 r
.58518 .46359 .58993 .4723 .61084 .47189 .60622 .46319 Mtetra
.571 .767 .971 r
.60622 .46319 .61084 .47189 .63183 .47135 .62735 .46267 Mtetra
.573 .769 .972 r
.62735 .46267 .63183 .47135 .6529 .4707 .64856 .46203 Mtetra
.575 .771 .972 r
.64856 .46203 .6529 .4707 .67405 .46995 .66985 .46129 Mtetra
.577 .773 .972 r
.66985 .46129 .67405 .46995 .69528 .46911 .69122 .46045 Mtetra
.579 .775 .972 r
.69122 .46045 .69528 .46911 .71659 .46819 .71267 .45953 Mtetra
.58 .776 .972 r
.71267 .45953 .71659 .46819 .73797 .46719 .7342 .45853 Mtetra
.581 .777 .973 r
.7342 .45853 .73797 .46719 .75943 .46613 .75581 .45745 Mtetra
.583 .779 .973 r
.75581 .45745 .75943 .46613 .78097 .465 .77749 .45631 Mtetra
.584 .78 .973 r
.77749 .45631 .78097 .465 .80258 .46381 .79926 .45512 Mtetra
.585 .781 .973 r
.79926 .45512 .80258 .46381 .82428 .46257 .8211 .45386 Mtetra
.585 .782 .973 r
.8211 .45386 .82428 .46257 .84605 .46128 .84302 .45256 Mtetra
.586 .782 .973 r
.84302 .45256 .84605 .46128 .8679 .45994 .86502 .4512 Mtetra
.587 .783 .973 r
.86502 .4512 .8679 .45994 .88983 .45856 .8871 .44981 Mtetra
.588 .784 .973 r
.8871 .44981 .88983 .45856 .91183 .45714 .90926 .44837 Mtetra
.90926 .44837 .91183 .45714 .93391 .45568 .9315 .44689 Mtetra
.589 .785 .973 r
.9315 .44689 .93391 .45568 .95608 .45418 .95382 .44538 Mtetra
.589 .786 .974 r
.95382 .44538 .95608 .45418 .97832 .45266 .97622 .44383 Mtetra
.639 .634 .829 r
.25438 .42123 .26066 .44092 .28052 .43702 .27412 .42157 Mtetra
.537 .619 .881 r
.27412 .42157 .28052 .43702 .30015 .43973 .29374 .42652 Mtetra
.491 .626 .91 r
.29374 .42652 .30015 .43973 .31981 .4439 .31346 .43203 Mtetra
.48 .643 .929 r
.31346 .43203 .31981 .4439 .33958 .44804 .3333 .43702 Mtetra
.484 .663 .941 r
.3333 .43702 .33958 .44804 .35948 .45169 .35329 .44125 Mtetra
.493 .681 .95 r
.35329 .44125 .35948 .45169 .3795 .45476 .37341 .44474 Mtetra
.504 .697 .956 r
.37341 .44474 .3795 .45476 .39963 .45727 .39365 .44755 Mtetra
.515 .71 .96 r
.39365 .44755 .39963 .45727 .41987 .45928 .41401 .44978 Mtetra
.524 .721 .963 r
.41401 .44978 .41987 .45928 .44021 .46084 .43447 .45152 Mtetra
.533 .73 .965 r
.43447 .45152 .44021 .46084 .46065 .46203 .45504 .45284 Mtetra
.54 .738 .967 r
.45504 .45284 .46065 .46203 .48119 .46289 .4757 .4538 Mtetra
.547 .744 .968 r
.4757 .4538 .48119 .46289 .50181 .46347 .49645 .45446 Mtetra
.552 .749 .969 r
.49645 .45446 .50181 .46347 .52253 .46379 .5173 .45485 Mtetra
.557 .754 .969 r
.5173 .45485 .52253 .46379 .54333 .46391 .53823 .45501 Mtetra
.561 .758 .97 r
.53823 .45501 .54333 .46391 .56421 .46383 .55925 .45497 Mtetra
.564 .761 .971 r
.55925 .45497 .56421 .46383 .58518 .46359 .58036 .45475 Mtetra
.567 .764 .971 r
.58036 .45475 .58518 .46359 .60622 .46319 .60154 .45438 Mtetra
.57 .767 .971 r
.60154 .45438 .60622 .46319 .62735 .46267 .62281 .45387 Mtetra
.573 .769 .972 r
.62281 .45387 .62735 .46267 .64856 .46203 .64416 .45324 Mtetra
.575 .771 .972 r
.64416 .45324 .64856 .46203 .66985 .46129 .6656 .45251 Mtetra
.577 .773 .972 r
.6656 .45251 .66985 .46129 .69122 .46045 .68711 .45167 Mtetra
.578 .774 .972 r
.68711 .45167 .69122 .46045 .71267 .45953 .7087 .45074 Mtetra
.58 .776 .972 r
.7087 .45074 .71267 .45953 .7342 .45853 .73038 .44973 Mtetra
.581 .777 .973 r
.73038 .44973 .7342 .45853 .75581 .45745 .75213 .44865 Mtetra
.582 .778 .973 r
.75213 .44865 .75581 .45745 .77749 .45631 .77397 .44751 Mtetra
.583 .779 .973 r
.77397 .44751 .77749 .45631 .79926 .45512 .79588 .4463 Mtetra
.584 .78 .973 r
.79588 .4463 .79926 .45512 .8211 .45386 .81787 .44503 Mtetra
.585 .781 .973 r
.81787 .44503 .8211 .45386 .84302 .45256 .83995 .44371 Mtetra
.586 .782 .973 r
.83995 .44371 .84302 .45256 .86502 .4512 .8621 .44234 Mtetra
.587 .783 .973 r
.8621 .44234 .86502 .4512 .8871 .44981 .88434 .44093 Mtetra
.587 .784 .973 r
.88434 .44093 .8871 .44981 .90926 .44837 .90665 .43947 Mtetra
.588 .784 .973 r
.90665 .43947 .90926 .44837 .9315 .44689 .92905 .43797 Mtetra
.589 .785 .973 r
.92905 .43797 .9315 .44689 .95382 .44538 .95153 .43644 Mtetra
.589 .785 .974 r
.95153 .43644 .95382 .44538 .97622 .44383 .97408 .43487 Mtetra
.578 .596 .835 r
.24803 .40134 .25438 .42123 .27412 .42157 .26765 .40594 Mtetra
.485 .587 .881 r
.26765 .40594 .27412 .42157 .29374 .42652 .28726 .41315 Mtetra
.454 .603 .909 r
.28726 .41315 .29374 .42652 .31346 .43203 .30702 .42001 Mtetra
.454 .628 .928 r
.30702 .42001 .31346 .43203 .3333 .43702 .32694 .42586 Mtetra
.466 .652 .941 r
.32694 .42586 .3333 .43702 .35329 .44125 .34702 .43068 Mtetra
.48 .674 .949 r
.34702 .43068 .35329 .44125 .37341 .44474 .36724 .43458 Mtetra
.495 .691 .956 r
.36724 .43458 .37341 .44474 .39365 .44755 .3876 .4377 Mtetra
.508 .706 .96 r
.3876 .4377 .39365 .44755 .41401 .44978 .40807 .44016 Mtetra
.519 .718 .963 r
.40807 .44016 .41401 .44978 .43447 .45152 .42866 .44207 Mtetra
.529 .728 .965 r
.42866 .44207 .43447 .45152 .45504 .45284 .44935 .44352 Mtetra
.537 .736 .967 r
.44935 .44352 .45504 .45284 .4757 .4538 .47014 .44459 Mtetra
.544 .742 .968 r
.47014 .44459 .4757 .4538 .49645 .45446 .49102 .44532 Mtetra
.55 .748 .969 r
.49102 .44532 .49645 .45446 .5173 .45485 .512 .44577 Mtetra
.555 .753 .97 r
.512 .44577 .5173 .45485 .53823 .45501 .53307 .44598 Mtetra
.559 .757 .97 r
.53307 .44598 .53823 .45501 .55925 .45497 .55423 .44598 Mtetra
.563 .76 .971 r
.55423 .44598 .55925 .45497 .58036 .45475 .57547 .44579 Mtetra
.566 .764 .971 r
.57547 .44579 .58036 .45475 .60154 .45438 .5968 .44544 Mtetra
.569 .766 .971 r
.5968 .44544 .60154 .45438 .62281 .45387 .61821 .44495 Mtetra
.572 .769 .972 r
.61821 .44495 .62281 .45387 .64416 .45324 .6397 .44433 Mtetra
.574 .771 .972 r
.6397 .44433 .64416 .45324 .6656 .45251 .66128 .44359 Mtetra
.576 .772 .972 r
.66128 .44359 .6656 .45251 .68711 .45167 .68294 .44276 Mtetra
.578 .774 .972 r
.68294 .44276 .68711 .45167 .7087 .45074 .70468 .44183 Mtetra
.579 .776 .972 r
.70468 .44183 .7087 .45074 .73038 .44973 .7265 .44082 Mtetra
.581 .777 .973 r
.7265 .44082 .73038 .44973 .75213 .44865 .7484 .43973 Mtetra
.582 .778 .973 r
.7484 .43973 .75213 .44865 .77397 .44751 .77039 .43857 Mtetra
.583 .779 .973 r
.77039 .43857 .77397 .44751 .79588 .4463 .79245 .43735 Mtetra
.584 .78 .973 r
.79245 .43735 .79588 .4463 .81787 .44503 .8146 .43607 Mtetra
.585 .781 .973 r
.8146 .43607 .81787 .44503 .83995 .44371 .83683 .43474 Mtetra
.586 .782 .973 r
.83683 .43474 .83995 .44371 .8621 .44234 .85914 .43335 Mtetra
.587 .783 .973 r
.85914 .43335 .8621 .44234 .88434 .44093 .88153 .43192 Mtetra
.587 .784 .973 r
.88153 .43192 .88434 .44093 .90665 .43947 .90401 .43044 Mtetra
.588 .784 .973 r
.90401 .43044 .90665 .43947 .92905 .43797 .92656 .42893 Mtetra
.588 .785 .973 r
.92656 .42893 .92905 .43797 .95153 .43644 .9492 .42737 Mtetra
.589 .785 .974 r
.9492 .42737 .95153 .43644 .97408 .43487 .97192 .42578 Mtetra
.504 .549 .836 r
.24162 .38126 .24803 .40134 .26765 .40594 .26111 .39013 Mtetra
.427 .55 .877 r
.26111 .39013 .26765 .40594 .28726 .41315 .28071 .39962 Mtetra
.414 .578 .906 r
.28071 .39962 .28726 .41315 .30702 .42001 .3005 .40783 Mtetra
.427 .611 .926 r
.3005 .40783 .30702 .42001 .32694 .42586 .3205 .41456 Mtetra
.447 .641 .94 r
.3205 .41456 .32694 .42586 .34702 .43068 .34067 .41997 Mtetra
.467 .666 .949 r
.34067 .41997 .34702 .43068 .36724 .43458 .361 .42429 Mtetra
.485 .686 .955 r
.361 .42429 .36724 .43458 .3876 .4377 .38146 .42771 Mtetra
.501 .702 .96 r
.38146 .42771 .3876 .4377 .40807 .44016 .40205 .4304 Mtetra
.514 .715 .963 r
.40205 .4304 .40807 .44016 .42866 .44207 .42276 .43249 Mtetra
.524 .725 .965 r
.42276 .43249 .42866 .44207 .44935 .44352 .44358 .43407 Mtetra
.534 .734 .967 r
.44358 .43407 .44935 .44352 .47014 .44459 .4645 .43524 Mtetra
.541 .741 .968 r
.4645 .43524 .47014 .44459 .49102 .44532 .48552 .43606 Mtetra
.548 .747 .969 r
.48552 .43606 .49102 .44532 .512 .44577 .50663 .43657 Mtetra
.553 .752 .97 r
.50663 .43657 .512 .44577 .53307 .44598 .52783 .43683 Mtetra
.558 .756 .97 r
.52783 .43683 .53307 .44598 .55423 .44598 .54913 .43686 Mtetra
.562 .76 .971 r
.54913 .43686 .55423 .44598 .57547 .44579 .57051 .4367 Mtetra
.565 .763 .971 r
.57051 .4367 .57547 .44579 .5968 .44544 .59198 .43637 Mtetra
.568 .766 .971 r
.59198 .43637 .5968 .44544 .61821 .44495 .61354 .4359 Mtetra
.571 .768 .972 r
.61354 .4359 .61821 .44495 .6397 .44433 .63517 .43529 Mtetra
.573 .77 .972 r
.63517 .43529 .6397 .44433 .66128 .44359 .6569 .43456 Mtetra
.575 .772 .972 r
.6569 .43456 .66128 .44359 .68294 .44276 .6787 .43372 Mtetra
.577 .774 .972 r
.6787 .43372 .68294 .44276 .70468 .44183 .70059 .43279 Mtetra
.579 .775 .972 r
.70059 .43279 .70468 .44183 .7265 .44082 .72257 .43177 Mtetra
.58 .777 .973 r
.72257 .43177 .7265 .44082 .7484 .43973 .74462 .43068 Mtetra
.582 .778 .973 r
.74462 .43068 .7484 .43973 .77039 .43857 .76676 .42951 Mtetra
.583 .779 .973 r
.76676 .42951 .77039 .43857 .79245 .43735 .78898 .42827 Mtetra
.584 .78 .973 r
.78898 .42827 .79245 .43735 .8146 .43607 .81128 .42698 Mtetra
.585 .781 .973 r
.81128 .42698 .8146 .43607 .83683 .43474 .83367 .42563 Mtetra
.586 .782 .973 r
.83367 .42563 .83683 .43474 .85914 .43335 .85614 .42423 Mtetra
.586 .783 .973 r
.85614 .42423 .85914 .43335 .88153 .43192 .87869 .42278 Mtetra
.587 .783 .973 r
.87869 .42278 .88153 .43192 .90401 .43044 .90132 .42128 Mtetra
.588 .784 .973 r
.90132 .42128 .90401 .43044 .92656 .42893 .92404 .41975 Mtetra
.588 .785 .973 r
.92404 .41975 .92656 .42893 .9492 .42737 .94684 .41817 Mtetra
.589 .785 .974 r
.94684 .41817 .9492 .42737 .97192 .42578 .96972 .41656 Mtetra
.458 .601 .906 r
.2348 .36736 .24162 .38126 .26111 .39013 .25449 .37414 Mtetra
.363 .508 .869 r
.25449 .37414 .26111 .39013 .28071 .39962 .27407 .38592 Mtetra
.371 .55 .9 r
.27407 .38592 .28071 .39962 .3005 .40783 .2939 .3955 Mtetra
.398 .593 .923 r
.2939 .3955 .3005 .40783 .3205 .41456 .31397 .40311 Mtetra
.427 .629 .938 r
.31397 .40311 .3205 .41456 .34067 .41997 .33423 .40912 Mtetra
.454 .658 .948 r
.33423 .40912 .34067 .41997 .361 .42429 .35466 .41386 Mtetra
.475 .68 .955 r
.35466 .41386 .361 .42429 .38146 .42771 .37524 .41759 Mtetra
.493 .698 .96 r
.37524 .41759 .38146 .42771 .40205 .4304 .39595 .42051 Mtetra
.508 .712 .963 r
.39595 .42051 .40205 .4304 .42276 .43249 .41678 .42277 Mtetra
.52 .723 .965 r
.41678 .42277 .42276 .43249 .44358 .43407 .43773 .42449 Mtetra
.53 .732 .967 r
.43773 .42449 .44358 .43407 .4645 .43524 .45878 .42577 Mtetra
.538 .739 .968 r
.45878 .42577 .4645 .43524 .48552 .43606 .47993 .42666 Mtetra
.545 .745 .969 r
.47993 .42666 .48552 .43606 .50663 .43657 .50118 .42724 Mtetra
.551 .751 .97 r
.50118 .42724 .50663 .43657 .52783 .43683 .52252 .42755 Mtetra
.556 .755 .97 r
.52252 .42755 .52783 .43683 .54913 .43686 .54396 .42762 Mtetra
.56 .759 .971 r
.54396 .42762 .54913 .43686 .57051 .4367 .56548 .42749 Mtetra
.564 .762 .971 r
.56548 .42749 .57051 .4367 .59198 .43637 .5871 .42718 Mtetra
.567 .765 .971 r
.5871 .42718 .59198 .43637 .61354 .4359 .6088 .42671 Mtetra
.57 .768 .972 r
.6088 .42671 .61354 .4359 .63517 .43529 .63058 .42611 Mtetra
.573 .77 .972 r
.63058 .42611 .63517 .43529 .6569 .43456 .65245 .42539 Mtetra
.575 .772 .972 r
.65245 .42539 .6569 .43456 .6787 .43372 .67441 .42455 Mtetra
.577 .774 .972 r
.67441 .42455 .6787 .43372 .70059 .43279 .69645 .42362 Mtetra
.578 .775 .973 r
.69645 .42362 .70059 .43279 .72257 .43177 .71858 .42259 Mtetra
.58 .776 .973 r
.71858 .42259 .72257 .43177 .74462 .43068 .74079 .42149 Mtetra
.581 .778 .973 r
.74079 .42149 .74462 .43068 .76676 .42951 .76308 .42031 Mtetra
.582 .779 .973 r
.76308 .42031 .76676 .42951 .78898 .42827 .78545 .41906 Mtetra
.583 .78 .973 r
.78545 .41906 .78898 .42827 .81128 .42698 .80792 .41776 Mtetra
.584 .781 .973 r
.80792 .41776 .81128 .42698 .83367 .42563 .83046 .41639 Mtetra
.585 .782 .973 r
.83046 .41639 .83367 .42563 .85614 .42423 .85309 .41497 Mtetra
.586 .783 .973 r
.85309 .41497 .85614 .42423 .87869 .42278 .8758 .4135 Mtetra
.587 .783 .973 r
.8758 .4135 .87869 .42278 .90132 .42128 .8986 .41199 Mtetra
.588 .784 .973 r
.8986 .41199 .90132 .42128 .92404 .41975 .92148 .41043 Mtetra
.588 .785 .973 r
.92148 .41043 .92404 .41975 .94684 .41817 .94444 .40883 Mtetra
.589 .785 .974 r
.94444 .40883 .94684 .41817 .96972 .41656 .96749 .40719 Mtetra
.569 .764 .97 r
.22762 .35841 .2348 .36736 .25449 .37414 .24779 .35797 Mtetra
.292 .459 .855 r
.24779 .35797 .25449 .37414 .27407 .38592 .26735 .37206 Mtetra
.325 .52 .892 r
.26735 .37206 .27407 .38592 .2939 .3955 .28722 .38301 Mtetra
.368 .574 .919 r
.28722 .38301 .2939 .3955 .31397 .40311 .30736 .39151 Mtetra
.407 .617 .936 r
.30736 .39151 .31397 .40311 .33423 .40912 .32771 .39812 Mtetra
.44 .649 .947 r
.32771 .39812 .33423 .40912 .35466 .41386 .34824 .40329 Mtetra
.466 .674 .955 r
.34824 .40329 .35466 .41386 .37524 .41759 .36893 .40734 Mtetra
.486 .693 .96 r
.36893 .40734 .37524 .41759 .39595 .42051 .38976 .41049 Mtetra
.503 .708 .963 r
.38976 .41049 .39595 .42051 .41678 .42277 .41072 .41292 Mtetra
.516 .72 .965 r
.41072 .41292 .41678 .42277 .43773 .42449 .4318 .41478 Mtetra
.527 .73 .967 r
.4318 .41478 .43773 .42449 .45878 .42577 .45298 .41616 Mtetra
.536 .738 .968 r
.45298 .41616 .45878 .42577 .47993 .42666 .47427 .41713 Mtetra
.543 .744 .969 r
.47427 .41713 .47993 .42666 .50118 .42724 .49565 .41778 Mtetra
.549 .75 .97 r
.49565 .41778 .50118 .42724 .52252 .42755 .51714 .41813 Mtetra
.555 .754 .97 r
.51714 .41813 .52252 .42755 .54396 .42762 .53871 .41824 Mtetra
.559 .758 .971 r
.53871 .41824 .54396 .42762 .56548 .42749 .56038 .41814 Mtetra
.563 .762 .971 r
.56038 .41814 .56548 .42749 .5871 .42718 .58214 .41785 Mtetra
.566 .765 .972 r
.58214 .41785 .5871 .42718 .6088 .42671 .60399 .4174 Mtetra
.569 .767 .972 r
.60399 .4174 .6088 .42671 .63058 .42611 .62592 .41681 Mtetra
.572 .769 .972 r
.62592 .41681 .63058 .42611 .65245 .42539 .64795 .41608 Mtetra
.574 .771 .972 r
.64795 .41608 .65245 .42539 .67441 .42455 .67005 .41525 Mtetra
.576 .773 .972 r
.67005 .41525 .67441 .42455 .69645 .42362 .69225 .41431 Mtetra
.578 .775 .973 r
.69225 .41431 .69645 .42362 .71858 .42259 .71453 .41328 Mtetra
.579 .776 .973 r
.71453 .41328 .71858 .42259 .74079 .42149 .73689 .41217 Mtetra
.581 .778 .973 r
.73689 .41217 .74079 .42149 .76308 .42031 .75934 .41098 Mtetra
.582 .779 .973 r
.75934 .41098 .76308 .42031 .78545 .41906 .78188 .40972 Mtetra
.583 .78 .973 r
.78188 .40972 .78545 .41906 .80792 .41776 .8045 .40839 Mtetra
.584 .781 .973 r
.8045 .40839 .80792 .41776 .83046 .41639 .8272 .40701 Mtetra
.585 .782 .973 r
.8272 .40701 .83046 .41639 .85309 .41497 .84999 .40557 Mtetra
.586 .782 .973 r
.84999 .40557 .85309 .41497 .8758 .4135 .87287 .40409 Mtetra
.587 .783 .973 r
.87287 .40409 .8758 .4135 .8986 .41199 .89583 .40255 Mtetra
.587 .784 .973 r
.89583 .40255 .8986 .41199 .92148 .41043 .91888 .40097 Mtetra
.588 .784 .974 r
.91888 .40097 .92148 .41043 .94444 .40883 .94201 .39935 Mtetra
.589 .785 .974 r
.94201 .39935 .94444 .40883 .96749 .40719 .96523 .39769 Mtetra
.617 .786 .963 r
.22033 .34934 .22762 .35841 .24779 .35797 .24073 .34715 Mtetra
.188 .493 .903 r
.24073 .34715 .24779 .35797 .26735 .37206 .26054 .35802 Mtetra
.277 .487 .882 r
.26054 .35802 .26735 .37206 .28722 .38301 .28045 .37036 Mtetra
.337 .554 .914 r
.28045 .37036 .28722 .38301 .30736 .39151 .30065 .37975 Mtetra
.387 .604 .934 r
.30065 .37975 .30736 .39151 .32771 .39812 .3211 .38698 Mtetra
.426 .641 .946 r
.3211 .38698 .32771 .39812 .34824 .40329 .34173 .39258 Mtetra
.455 .668 .954 r
.34173 .39258 .34824 .40329 .36893 .40734 .36254 .39693 Mtetra
.479 .689 .96 r
.36254 .39693 .36893 .40734 .38976 .41049 .38349 .40032 Mtetra
.497 .705 .963 r
.38349 .40032 .38976 .41049 .41072 .41292 .40457 .40294 Mtetra
.512 .718 .965 r
.40457 .40294 .41072 .41292 .4318 .41478 .42578 .40493 Mtetra
.523 .728 .967 r
.42578 .40493 .4318 .41478 .45298 .41616 .4471 .40641 Mtetra
.533 .736 .968 r
.4471 .40641 .45298 .41616 .47427 .41713 .46852 .40747 Mtetra
.541 .743 .969 r
.46852 .40747 .47427 .41713 .49565 .41778 .49005 .40818 Mtetra
.548 .749 .97 r
.49005 .40818 .49565 .41778 .51714 .41813 .51167 .40858 Mtetra
.553 .753 .971 r
.51167 .40858 .51714 .41813 .53871 .41824 .53339 .40873 Mtetra
.558 .757 .971 r
.53339 .40873 .53871 .41824 .56038 .41814 .55521 .40865 Mtetra
.562 .761 .971 r
.55521 .40865 .56038 .41814 .58214 .41785 .57712 .40839 Mtetra
.565 .764 .972 r
.57712 .40839 .58214 .41785 .60399 .4174 .59911 .40795 Mtetra
.569 .767 .972 r
.59911 .40795 .60399 .4174 .62592 .41681 .6212 .40736 Mtetra
.571 .769 .972 r
.6212 .40736 .62592 .41681 .64795 .41608 .64337 .40665 Mtetra
.574 .771 .972 r
.64337 .40665 .64795 .41608 .67005 .41525 .66563 .40581 Mtetra
.576 .773 .972 r
.66563 .40581 .67005 .41525 .69225 .41431 .68798 .40487 Mtetra
.577 .775 .973 r
.68798 .40487 .69225 .41431 .71453 .41328 .71042 .40383 Mtetra
.579 .776 .973 r
.71042 .40383 .71453 .41328 .73689 .41217 .73294 .40271 Mtetra
.58 .777 .973 r
.73294 .40271 .73689 .41217 .75934 .41098 .75555 .40151 Mtetra
.582 .778 .973 r
.75555 .40151 .75934 .41098 .78188 .40972 .77825 .40023 Mtetra
.583 .78 .973 r
.77825 .40023 .78188 .40972 .8045 .40839 .80103 .39889 Mtetra
.584 .781 .973 r
.80103 .39889 .8045 .40839 .8272 .40701 .8239 .39749 Mtetra
.585 .781 .973 r
.8239 .39749 .8272 .40701 .84999 .40557 .84685 .39604 Mtetra
.586 .782 .973 r
.84685 .39604 .84999 .40557 .87287 .40409 .86989 .39453 Mtetra
.586 .783 .973 r
.86989 .39453 .87287 .40409 .89583 .40255 .89302 .39297 Mtetra
.587 .784 .973 r
.89302 .39297 .89583 .40255 .91888 .40097 .91624 .39137 Mtetra
.588 .784 .974 r
.91624 .39137 .91888 .40097 .94201 .39935 .93954 .38973 Mtetra
.588 .785 .974 r
.93954 .38973 .94201 .39935 .96523 .39769 .96294 .38805 Mtetra
.617 .786 .963 r
.21294 .34014 .22033 .34934 .24073 .34715 .23347 .33792 Mtetra
.333 .631 .961 r
.23347 .33792 .24073 .34715 .26054 .35802 .25365 .34381 Mtetra
.226 .452 .869 r
.25365 .34381 .26054 .35802 .28045 .37036 .27359 .35755 Mtetra
.305 .532 .908 r
.27359 .35755 .28045 .37036 .30065 .37975 .29386 .36784 Mtetra
.366 .59 .931 r
.29386 .36784 .30065 .37975 .3211 .38698 .31439 .37568 Mtetra
.411 .632 .945 r
.31439 .37568 .3211 .38698 .34173 .39258 .33514 .38171 Mtetra
.445 .662 .954 r
.33514 .38171 .34173 .39258 .36254 .39693 .35606 .38639 Mtetra
.471 .684 .959 r
.35606 .38639 .36254 .39693 .38349 .40032 .37713 .39001 Mtetra
.491 .702 .963 r
.37713 .39001 .38349 .40032 .40457 .40294 .39834 .39281 Mtetra
.507 .715 .965 r
.39834 .39281 .40457 .40294 .42578 .40493 .41968 .39494 Mtetra
.52 .726 .967 r
.41968 .39494 .42578 .40493 .4471 .40641 .44113 .39652 Mtetra
.53 .735 .968 r
.44113 .39652 .4471 .40641 .46852 .40747 .46269 .39767 Mtetra
.539 .742 .969 r
.46269 .39767 .46852 .40747 .49005 .40818 .48436 .39844 Mtetra
.546 .748 .97 r
.48436 .39844 .49005 .40818 .51167 .40858 .50613 .39889 Mtetra
.552 .753 .971 r
.50613 .39889 .51167 .40858 .53339 .40873 .528 .39908 Mtetra
.557 .757 .971 r
.528 .39908 .53339 .40873 .55521 .40865 .54996 .39903 Mtetra
.561 .76 .971 r
.54996 .39903 .55521 .40865 .57712 .40839 .57201 .39878 Mtetra
.565 .763 .972 r
.57201 .39878 .57712 .40839 .59911 .40795 .59416 .39836 Mtetra
.568 .766 .972 r
.59416 .39836 .59911 .40795 .6212 .40736 .6164 .39778 Mtetra
.57 .769 .972 r
.6164 .39778 .6212 .40736 .64337 .40665 .63873 .39707 Mtetra
.573 .771 .972 r
.63873 .39707 .64337 .40665 .66563 .40581 .66115 .39623 Mtetra
.575 .773 .972 r
.66115 .39623 .66563 .40581 .68798 .40487 .68365 .39529 Mtetra
.577 .774 .973 r
.68365 .39529 .68798 .40487 .71042 .40383 .70625 .39424 Mtetra
.579 .776 .973 r
.70625 .39424 .71042 .40383 .73294 .40271 .72893 .39311 Mtetra
.58 .777 .973 r
.72893 .39311 .73294 .40271 .75555 .40151 .7517 .39189 Mtetra
.581 .778 .973 r
.7517 .39189 .75555 .40151 .77825 .40023 .77456 .39061 Mtetra
.583 .779 .973 r
.77456 .39061 .77825 .40023 .80103 .39889 .79751 .38925 Mtetra
.584 .78 .973 r
.79751 .38925 .80103 .39889 .8239 .39749 .82054 .38783 Mtetra
.585 .781 .973 r
.82054 .38783 .8239 .39749 .84685 .39604 .84366 .38636 Mtetra
.585 .782 .973 r
.84366 .38636 .84685 .39604 .86989 .39453 .86688 .38483 Mtetra
.586 .783 .973 r
.86688 .38483 .86989 .39453 .89302 .39297 .89017 .38325 Mtetra
.587 .784 .973 r
.89017 .38325 .89302 .39297 .91624 .39137 .91356 .38163 Mtetra
.588 .784 .974 r
.91356 .38163 .91624 .39137 .93954 .38973 .93704 .37996 Mtetra
.588 .785 .974 r
.93704 .37996 .93954 .38973 .96294 .38805 .9606 .37825 Mtetra
.617 .786 .963 r
.20545 .33081 .21294 .34014 .23347 .33792 .22611 .32856 Mtetra
.527 .743 .974 r
.22611 .32856 .23347 .33792 .25365 .34381 .24668 .32942 Mtetra
.173 .415 .853 r
.24668 .32942 .25365 .34381 .27359 .35755 .26664 .34457 Mtetra
.272 .51 .9 r
.26664 .34457 .27359 .35755 .29386 .36784 .28698 .35577 Mtetra
.344 .576 .927 r
.28698 .35577 .29386 .36784 .31439 .37568 .3076 .36423 Mtetra
.396 .622 .943 r
.3076 .36423 .31439 .37568 .33514 .38171 .32845 .3707 Mtetra
.435 .655 .953 r
.32845 .3707 .33514 .38171 .35606 .38639 .34948 .37569 Mtetra
.463 .68 .959 r
.34948 .37569 .35606 .38639 .37713 .39001 .37068 .37956 Mtetra
.486 .698 .963 r
.37068 .37956 .37713 .39001 .39834 .39281 .39202 .38253 Mtetra
.503 .713 .965 r
.39202 .38253 .39834 .39281 .41968 .39494 .41349 .3848 Mtetra
.516 .724 .967 r
.41349 .3848 .41968 .39494 .44113 .39652 .43508 .3865 Mtetra
.527 .733 .969 r
.43508 .3865 .44113 .39652 .46269 .39767 .45678 .38772 Mtetra
.536 .74 .969 r
.45678 .38772 .46269 .39767 .48436 .39844 .47859 .38856 Mtetra
.544 .747 .97 r
.47859 .38856 .48436 .39844 .50613 .39889 .50051 .38906 Mtetra
.55 .752 .971 r
.50051 .38906 .50613 .39889 .528 .39908 .52252 .38928 Mtetra
.555 .756 .971 r
.52252 .38928 .528 .39908 .54996 .39903 .54463 .38926 Mtetra
.56 .76 .971 r
.54463 .38926 .54996 .39903 .57201 .39878 .56684 .38904 Mtetra
.564 .763 .972 r
.56684 .38904 .57201 .39878 .59416 .39836 .58914 .38863 Mtetra
.567 .766 .972 r
.58914 .38863 .59416 .39836 .6164 .39778 .61153 .38806 Mtetra
.57 .768 .972 r
.61153 .38806 .6164 .39778 .63873 .39707 .63402 .38735 Mtetra
.572 .77 .972 r
.63402 .38735 .63873 .39707 .66115 .39623 .65659 .38651 Mtetra
.574 .772 .972 r
.65659 .38651 .66115 .39623 .68365 .39529 .67926 .38556 Mtetra
.576 .774 .973 r
.67926 .38556 .68365 .39529 .70625 .39424 .70202 .38451 Mtetra
.578 .775 .973 r
.70202 .38451 .70625 .39424 .72893 .39311 .72486 .38336 Mtetra
.58 .777 .973 r
.72486 .38336 .72893 .39311 .7517 .39189 .7478 .38214 Mtetra
.581 .778 .973 r
.7478 .38214 .7517 .39189 .77456 .39061 .77082 .38083 Mtetra
.582 .779 .973 r
.77082 .38083 .77456 .39061 .79751 .38925 .79393 .37946 Mtetra
.583 .78 .973 r
.79393 .37946 .79751 .38925 .82054 .38783 .81714 .37803 Mtetra
.584 .781 .973 r
.81714 .37803 .82054 .38783 .84366 .38636 .84043 .37653 Mtetra
.585 .782 .973 r
.84043 .37653 .84366 .38636 .86688 .38483 .86381 .37498 Mtetra
.586 .783 .973 r
.86381 .37498 .86688 .38483 .89017 .38325 .88728 .37338 Mtetra
.587 .783 .973 r
.88728 .37338 .89017 .38325 .91356 .38163 .91084 .37173 Mtetra
.587 .784 .974 r
.91084 .37173 .91356 .38163 .93704 .37996 .93449 .37004 Mtetra
.588 .785 .974 r
.93449 .37004 .93704 .37996 .9606 .37825 .95824 .36831 Mtetra
.617 .786 .963 r
.19785 .32135 .20545 .33081 .22611 .32856 .21864 .31906 Mtetra
.21864 .31906 .22611 .32856 .24668 .32942 .23951 .31676 Mtetra
.101 .4 .854 r
.23951 .31676 .24668 .32942 .26664 .34457 .2596 .33141 Mtetra
.237 .486 .891 r
.2596 .33141 .26664 .34457 .28698 .35577 .28 .34353 Mtetra
.321 .561 .923 r
.28 .34353 .28698 .35577 .3076 .36423 .30071 .35262 Mtetra
.381 .613 .941 r
.30071 .35262 .3076 .36423 .32845 .3707 .32166 .35953 Mtetra
.424 .649 .952 r
.32166 .35953 .32845 .3707 .34948 .37569 .34281 .36485 Mtetra
.456 .675 .959 r
.34281 .36485 .34948 .37569 .37068 .37956 .36413 .36895 Mtetra
.48 .695 .963 r
.36413 .36895 .37068 .37956 .39202 .38253 .3856 .37211 Mtetra
.498 .71 .965 r
.3856 .37211 .39202 .38253 .41349 .3848 .40721 .37452 Mtetra
.513 .722 .967 r
.40721 .37452 .41349 .3848 .43508 .3865 .42894 .37632 Mtetra
.525 .731 .969 r
.42894 .37632 .43508 .3865 .45678 .38772 .45078 .37763 Mtetra
.534 .739 .97 r
.45078 .37763 .45678 .38772 .47859 .38856 .47274 .37853 Mtetra
.542 .745 .97 r
.47274 .37853 .47859 .38856 .50051 .38906 .4948 .37908 Mtetra
.549 .751 .971 r
.4948 .37908 .50051 .38906 .52252 .38928 .51696 .37935 Mtetra
.554 .755 .971 r
.51696 .37935 .52252 .38928 .54463 .38926 .53923 .37935 Mtetra
.559 .759 .972 r
.53923 .37935 .54463 .38926 .56684 .38904 .56159 .37915 Mtetra
.563 .762 .972 r
.56159 .37915 .56684 .38904 .58914 .38863 .58404 .37875 Mtetra
.566 .765 .972 r
.58404 .37875 .58914 .38863 .61153 .38806 .60659 .37819 Mtetra
.569 .768 .972 r
.60659 .37819 .61153 .38806 .63402 .38735 .62924 .37748 Mtetra
.572 .77 .972 r
.62924 .37748 .63402 .38735 .65659 .38651 .65197 .37664 Mtetra
.574 .772 .973 r
.65197 .37664 .65659 .38651 .67926 .38556 .6748 .37569 Mtetra
.576 .774 .973 r
.6748 .37569 .67926 .38556 .70202 .38451 .69772 .37463 Mtetra
.578 .775 .973 r
.69772 .37463 .70202 .38451 .72486 .38336 .72073 .37347 Mtetra
.579 .777 .973 r
.72073 .37347 .72486 .38336 .7478 .38214 .74383 .37223 Mtetra
.581 .778 .973 r
.74383 .37223 .7478 .38214 .77082 .38083 .76702 .37091 Mtetra
.582 .779 .973 r
.76702 .37091 .77082 .38083 .79393 .37946 .7903 .36952 Mtetra
.583 .78 .973 r
.7903 .36952 .79393 .37946 .81714 .37803 .81368 .36807 Mtetra
.584 .781 .973 r
.81368 .36807 .81714 .37803 .84043 .37653 .83714 .36655 Mtetra
.585 .782 .973 r
.83714 .36655 .84043 .37653 .86381 .37498 .8607 .36498 Mtetra
.586 .783 .973 r
.8607 .36498 .86381 .37498 .88728 .37338 .88434 .36336 Mtetra
.587 .783 .973 r
.88434 .36336 .88728 .37338 .91084 .37173 .90808 .36169 Mtetra
.587 .784 .974 r
.90808 .36169 .91084 .37173 .93449 .37004 .93191 .35997 Mtetra
.588 .785 .974 r
.93191 .35997 .93449 .37004 .95824 .36831 .95583 .35821 Mtetra
.617 .786 .963 r
.19013 .31175 .19785 .32135 .21864 .31906 .21107 .30943 Mtetra
.21107 .30943 .21864 .31906 .23951 .31676 .23207 .3071 Mtetra
.093 .466 .89 r
.23207 .3071 .23951 .31676 .2596 .33141 .25247 .31809 Mtetra
.202 .461 .881 r
.25247 .31809 .2596 .33141 .28 .34353 .27293 .33113 Mtetra
.298 .546 .918 r
.27293 .33113 .28 .34353 .30071 .35262 .29373 .34084 Mtetra
.366 .603 .939 r
.29373 .34084 .30071 .35262 .32166 .35953 .31479 .34821 Mtetra
.413 .642 .951 r
.31479 .34821 .32166 .35953 .34281 .36485 .33605 .35385 Mtetra
.448 .671 .958 r
.33605 .35385 .34281 .36485 .36413 .36895 .3575 .35819 Mtetra
.474 .691 .962 r
.3575 .35819 .36413 .36895 .3856 .37211 .3791 .36154 Mtetra
.494 .707 .965 r
.3791 .36154 .3856 .37211 .40721 .37452 .40084 .36409 Mtetra
.509 .72 .967 r
.40084 .36409 .40721 .37452 .42894 .37632 .42271 .366 Mtetra
.522 .73 .969 r
.42271 .366 .42894 .37632 .45078 .37763 .4447 .36739 Mtetra
.532 .738 .97 r
.4447 .36739 .45078 .37763 .47274 .37853 .4668 .36836 Mtetra
.54 .744 .97 r
.4668 .36836 .47274 .37853 .4948 .37908 .48901 .36896 Mtetra
.547 .75 .971 r
.48901 .36896 .4948 .37908 .51696 .37935 .51132 .36926 Mtetra
.553 .755 .971 r
.51132 .36926 .51696 .37935 .53923 .37935 .53374 .3693 Mtetra
.558 .758 .972 r
.53374 .3693 .53923 .37935 .56159 .37915 .55625 .36911 Mtetra
.562 .762 .972 r
.55625 .36911 .56159 .37915 .58404 .37875 .57887 .36873 Mtetra
.565 .765 .972 r
.57887 .36873 .58404 .37875 .60659 .37819 .60158 .36817 Mtetra
.568 .767 .972 r
.60158 .36817 .60659 .37819 .62924 .37748 .62438 .36746 Mtetra
.571 .77 .972 r
.62438 .36746 .62924 .37748 .65197 .37664 .64728 .36662 Mtetra
.573 .772 .973 r
.64728 .36662 .65197 .37664 .6748 .37569 .67027 .36566 Mtetra
.575 .773 .973 r
.67027 .36566 .6748 .37569 .69772 .37463 .69336 .36459 Mtetra
.577 .775 .973 r
.69336 .36459 .69772 .37463 .72073 .37347 .71653 .36343 Mtetra
.579 .776 .973 r
.71653 .36343 .72073 .37347 .74383 .37223 .7398 .36217 Mtetra
.58 .778 .973 r
.7398 .36217 .74383 .37223 .76702 .37091 .76317 .36084 Mtetra
.582 .779 .973 r
.76317 .36084 .76702 .37091 .7903 .36952 .78662 .35943 Mtetra
.583 .78 .973 r
.78662 .35943 .7903 .36952 .81368 .36807 .81017 .35796 Mtetra
.584 .781 .973 r
.81017 .35796 .81368 .36807 .83714 .36655 .83381 .35642 Mtetra
.585 .782 .973 r
.83381 .35642 .83714 .36655 .8607 .36498 .85754 .35483 Mtetra
.586 .782 .973 r
.85754 .35483 .8607 .36498 .88434 .36336 .88136 .35318 Mtetra
.586 .783 .973 r
.88136 .35318 .88434 .36336 .90808 .36169 .90528 .35149 Mtetra
.587 .784 .974 r
.90528 .35149 .90808 .36169 .93191 .35997 .92929 .34974 Mtetra
.588 .785 .974 r
.92929 .34974 .93191 .35997 .95583 .35821 .95339 .34796 Mtetra
.617 .786 .963 r
.18231 .30201 .19013 .31175 .21107 .30943 .20338 .29966 Mtetra
.20338 .29966 .21107 .30943 .23207 .3071 .22453 .29729 Mtetra
.277 .594 .949 r
.22453 .29729 .23207 .3071 .25247 .31809 .24524 .30458 Mtetra
.165 .435 .869 r
.24524 .30458 .25247 .31809 .27293 .33113 .26576 .31856 Mtetra
.275 .53 .913 r
.26576 .31856 .27293 .33113 .29373 .34084 .28665 .32891 Mtetra
.35 .593 .937 r
.28665 .32891 .29373 .34084 .31479 .34821 .30781 .33672 Mtetra
.402 .635 .95 r
.30781 .33672 .31479 .34821 .33605 .35385 .32919 .34269 Mtetra
.44 .666 .957 r
.32919 .34269 .33605 .35385 .3575 .35819 .35076 .34728 Mtetra
.468 .688 .962 r
.35076 .34728 .3575 .35819 .3791 .36154 .3725 .35081 Mtetra
.489 .705 .965 r
.3725 .35081 .3791 .36154 .40084 .36409 .39437 .3535 Mtetra
.506 .718 .967 r
.39437 .3535 .40084 .36409 .42271 .366 .41638 .35552 Mtetra
.519 .728 .969 r
.41638 .35552 .42271 .366 .4447 .36739 .43852 .357 Mtetra
.53 .736 .97 r
.43852 .357 .4447 .36739 .4668 .36836 .46077 .35803 Mtetra
.538 .743 .97 r
.46077 .35803 .4668 .36836 .48901 .36896 .48313 .35869 Mtetra
.546 .749 .971 r
.48313 .35869 .48901 .36896 .51132 .36926 .5056 .35902 Mtetra
.551 .754 .971 r
.5056 .35902 .51132 .36926 .53374 .3693 .52817 .35909 Mtetra
.557 .758 .972 r
.52817 .35909 .53374 .3693 .55625 .36911 .55084 .35892 Mtetra
.561 .761 .972 r
.55084 .35892 .55625 .36911 .57887 .36873 .57362 .35855 Mtetra
.565 .764 .972 r
.57362 .35855 .57887 .36873 .60158 .36817 .59649 .358 Mtetra
.568 .767 .972 r
.59649 .358 .60158 .36817 .62438 .36746 .61945 .35729 Mtetra
.57 .769 .972 r
.61945 .35729 .62438 .36746 .64728 .36662 .64252 .35645 Mtetra
.573 .771 .973 r
.64252 .35645 .64728 .36662 .67027 .36566 .66567 .35548 Mtetra
.575 .773 .973 r
.66567 .35548 .67027 .36566 .69336 .36459 .68893 .35441 Mtetra
.577 .775 .973 r
.68893 .35441 .69336 .36459 .71653 .36343 .71227 .35323 Mtetra
.579 .776 .973 r
.71227 .35323 .71653 .36343 .7398 .36217 .73572 .35196 Mtetra
.58 .777 .973 r
.73572 .35196 .7398 .36217 .76317 .36084 .75925 .35061 Mtetra
.581 .779 .973 r
.75925 .35061 .76317 .36084 .78662 .35943 .78288 .34919 Mtetra
.583 .78 .973 r
.78288 .34919 .78662 .35943 .81017 .35796 .8066 .34769 Mtetra
.584 .781 .973 r
.8066 .34769 .81017 .35796 .83381 .35642 .83042 .34613 Mtetra
.585 .782 .973 r
.83042 .34613 .83381 .35642 .85754 .35483 .85433 .34452 Mtetra
.85433 .34452 .85754 .35483 .88136 .35318 .87833 .34285 Mtetra
.586 .783 .973 r
.87833 .34285 .88136 .35318 .90528 .35149 .90243 .34112 Mtetra
.587 .784 .974 r
.90243 .34112 .90528 .35149 .92929 .34974 .92662 .33935 Mtetra
.588 .784 .974 r
.92662 .33935 .92929 .34974 .95339 .34796 .95091 .33754 Mtetra
.617 .786 .963 r
.17437 .29213 .18231 .30201 .20338 .29966 .19559 .28974 Mtetra
.19559 .28974 .20338 .29966 .22453 .29729 .21687 .28734 Mtetra
.433 .69 .973 r
.21687 .28734 .22453 .29729 .24524 .30458 .23791 .2909 Mtetra
.128 .408 .857 r
.23791 .2909 .24524 .30458 .26576 .31856 .2585 .30581 Mtetra
.251 .514 .907 r
.2585 .30581 .26576 .31856 .28665 .32891 .27947 .3168 Mtetra
.334 .582 .934 r
.27947 .3168 .28665 .32891 .30781 .33672 .30073 .32507 Mtetra
.391 .628 .948 r
.30073 .32507 .30781 .33672 .32919 .34269 .32224 .33137 Mtetra
.432 .661 .957 r
.32224 .33137 .32919 .34269 .35076 .34728 .34393 .33621 Mtetra
.462 .684 .962 r
.34393 .33621 .35076 .34728 .3725 .35081 .3658 .33992 Mtetra
.485 .702 .965 r
.3658 .33992 .3725 .35081 .39437 .3535 .38782 .34276 Mtetra
.502 .716 .967 r
.38782 .34276 .39437 .3535 .41638 .35552 .40997 .34489 Mtetra
.516 .727 .969 r
.40997 .34489 .41638 .35552 .43852 .357 .43225 .34646 Mtetra
.527 .735 .97 r
.43225 .34646 .43852 .357 .46077 .35803 .45465 .34755 Mtetra
.536 .742 .97 r
.45465 .34755 .46077 .35803 .48313 .35869 .47716 .34826 Mtetra
.544 .748 .971 r
.47716 .34826 .48313 .35869 .5056 .35902 .49979 .34863 Mtetra
.55 .753 .971 r
.49979 .34863 .5056 .35902 .52817 .35909 .52252 .34872 Mtetra
.555 .757 .972 r
.52252 .34872 .52817 .35909 .55084 .35892 .54535 .34857 Mtetra
.56 .761 .972 r
.54535 .34857 .55084 .35892 .57362 .35855 .56828 .34822 Mtetra
.564 .764 .972 r
.56828 .34822 .57362 .35855 .59649 .358 .59132 .34767 Mtetra
.567 .767 .972 r
.59132 .34767 .59649 .358 .61945 .35729 .61445 .34697 Mtetra
.57 .769 .972 r
.61445 .34697 .61945 .35729 .64252 .35645 .63768 .34612 Mtetra
.572 .771 .973 r
.63768 .34612 .64252 .35645 .66567 .35548 .66101 .34515 Mtetra
.575 .773 .973 r
.66101 .34515 .66567 .35548 .68893 .35441 .68443 .34406 Mtetra
.576 .774 .973 r
.68443 .34406 .68893 .35441 .71227 .35323 .70795 .34287 Mtetra
.578 .776 .973 r
.70795 .34287 .71227 .35323 .73572 .35196 .73156 .34159 Mtetra
.58 .777 .973 r
.73156 .34159 .73572 .35196 .75925 .35061 .75527 .34022 Mtetra
.581 .778 .973 r
.75527 .34022 .75925 .35061 .78288 .34919 .77908 .33878 Mtetra
.582 .779 .973 r
.77908 .33878 .78288 .34919 .8066 .34769 .80298 .33726 Mtetra
.583 .78 .973 r
.80298 .33726 .8066 .34769 .83042 .34613 .82697 .33568 Mtetra
.584 .781 .973 r
.82697 .33568 .83042 .34613 .85433 .34452 .85107 .33404 Mtetra
.585 .782 .973 r
.85107 .33404 .85433 .34452 .87833 .34285 .87525 .33235 Mtetra
.586 .783 .973 r
.87525 .33235 .87833 .34285 .90243 .34112 .89954 .3306 Mtetra
.587 .784 .974 r
.89954 .3306 .90243 .34112 .92662 .33935 .92392 .3288 Mtetra
.92392 .3288 .92662 .33935 .95091 .33754 .94839 .32696 Mtetra
.617 .786 .963 r
.16632 .28211 .17437 .29213 .19559 .28974 .18767 .27968 Mtetra
.18767 .27968 .19559 .28974 .21687 .28734 .2091 .27724 Mtetra
.557 .758 .971 r
.2091 .27724 .21687 .28734 .23791 .2909 .23049 .27702 Mtetra
.09 .381 .842 r
.23049 .27702 .23791 .2909 .2585 .30581 .25113 .29289 Mtetra
.226 .497 .9 r
.25113 .29289 .2585 .30581 .27947 .3168 .27219 .30453 Mtetra
.317 .571 .931 r
.27219 .30453 .27947 .3168 .30073 .32507 .29356 .31325 Mtetra
.38 .621 .947 r
.29356 .31325 .30073 .32507 .32224 .33137 .31518 .31989 Mtetra
.424 .656 .956 r
.31518 .31989 .32224 .33137 .34393 .33621 .337 .32498 Mtetra
.456 .681 .962 r
.337 .32498 .34393 .33621 .3658 .33992 .359 .32888 Mtetra
.48 .699 .965 r
.359 .32888 .3658 .33992 .38782 .34276 .38116 .33186 Mtetra
.499 .714 .967 r
.38116 .33186 .38782 .34276 .40997 .34489 .40346 .3341 Mtetra
.513 .725 .969 r
.40346 .3341 .40997 .34489 .43225 .34646 .42589 .33575 Mtetra
.525 .734 .97 r
.42589 .33575 .43225 .34646 .45465 .34755 .44844 .33692 Mtetra
.535 .741 .97 r
.44844 .33692 .45465 .34755 .47716 .34826 .47111 .33767 Mtetra
.542 .747 .971 r
.47111 .33767 .47716 .34826 .49979 .34863 .49389 .33808 Mtetra
.549 .752 .971 r
.49389 .33808 .49979 .34863 .52252 .34872 .51678 .3382 Mtetra
.554 .757 .972 r
.51678 .3382 .52252 .34872 .54535 .34857 .53977 .33807 Mtetra
.559 .76 .972 r
.53977 .33807 .54535 .34857 .56828 .34822 .56287 .33772 Mtetra
.563 .763 .972 r
.56287 .33772 .56828 .34822 .59132 .34767 .58607 .33719 Mtetra
.566 .766 .972 r
.58607 .33719 .59132 .34767 .61445 .34697 .60937 .33649 Mtetra
.569 .768 .973 r
.60937 .33649 .61445 .34697 .63768 .34612 .63277 .33564 Mtetra
.572 .771 .973 r
.63277 .33564 .63768 .34612 .66101 .34515 .65627 .33466 Mtetra
.574 .772 .973 r
.65627 .33466 .66101 .34515 .68443 .34406 .67986 .33356 Mtetra
.576 .774 .973 r
.67986 .33356 .68443 .34406 .70795 .34287 .70356 .33236 Mtetra
.578 .776 .973 r
.70356 .33236 .70795 .34287 .73156 .34159 .72735 .33106 Mtetra
.579 .777 .973 r
.72735 .33106 .73156 .34159 .75527 .34022 .75123 .32967 Mtetra
.581 .778 .973 r
.75123 .32967 .75527 .34022 .77908 .33878 .77522 .32821 Mtetra
.582 .779 .973 r
.77522 .32821 .77908 .33878 .80298 .33726 .7993 .32667 Mtetra
.583 .78 .973 r
.7993 .32667 .80298 .33726 .82697 .33568 .82348 .32507 Mtetra
.584 .781 .973 r
.82348 .32507 .82697 .33568 .85107 .33404 .84775 .3234 Mtetra
.585 .782 .973 r
.84775 .3234 .85107 .33404 .87525 .33235 .87213 .32168 Mtetra
.586 .783 .973 r
.87213 .32168 .87525 .33235 .89954 .3306 .8966 .3199 Mtetra
.587 .784 .974 r
.8966 .3199 .89954 .3306 .92392 .3288 .92117 .31808 Mtetra
.92117 .31808 .92392 .3288 .94839 .32696 .94583 .3162 Mtetra
.617 .786 .963 r
.15814 .27193 .16632 .28211 .18767 .27968 .17964 .26947 Mtetra
.17964 .26947 .18767 .27968 .2091 .27724 .20122 .26699 Mtetra
.20122 .26699 .2091 .27724 .23049 .27702 .22287 .26451 Mtetra
.036 .371 .839 r
.22287 .26451 .23049 .27702 .25113 .29289 .24366 .27979 Mtetra
.201 .479 .893 r
.24366 .27979 .25113 .29289 .27219 .30453 .2648 .29208 Mtetra
.301 .56 .927 r
.2648 .29208 .27219 .30453 .29356 .31325 .28628 .30126 Mtetra
.368 .614 .945 r
.28628 .30126 .29356 .31325 .31518 .31989 .30801 .30824 Mtetra
.416 .651 .955 r
.30801 .30824 .31518 .31989 .337 .32498 .32997 .31357 Mtetra
.45 .677 .961 r
.32997 .31357 .337 .32498 .359 .32888 .3521 .31767 Mtetra
.476 .697 .965 r
.3521 .31767 .359 .32888 .38116 .33186 .3744 .32079 Mtetra
.495 .712 .967 r
.3744 .32079 .38116 .33186 .40346 .3341 .39685 .32315 Mtetra
.511 .723 .969 r
.39685 .32315 .40346 .3341 .42589 .33575 .41943 .32489 Mtetra
.523 .732 .97 r
.41943 .32489 .42589 .33575 .44844 .33692 .44213 .32612 Mtetra
.533 .74 .971 r
.44213 .32612 .44844 .33692 .47111 .33767 .46496 .32692 Mtetra
.541 .746 .971 r
.46496 .32692 .47111 .33767 .49389 .33808 .4879 .32737 Mtetra
.548 .751 .971 r
.4879 .32737 .49389 .33808 .51678 .3382 .51095 .32752 Mtetra
.553 .756 .972 r
.51095 .32752 .51678 .3382 .53977 .33807 .53411 .32741 Mtetra
.558 .76 .972 r
.53411 .32741 .53977 .33807 .56287 .33772 .55737 .32707 Mtetra
.562 .763 .972 r
.55737 .32707 .56287 .33772 .58607 .33719 .58074 .32654 Mtetra
.566 .766 .972 r
.58074 .32654 .58607 .33719 .60937 .33649 .60421 .32584 Mtetra
.569 .768 .973 r
.60421 .32584 .60937 .33649 .63277 .33564 .62778 .32499 Mtetra
.571 .77 .973 r
.62778 .32499 .63277 .33564 .65627 .33466 .65145 .324 Mtetra
.574 .772 .973 r
.65145 .324 .65627 .33466 .67986 .33356 .67522 .32289 Mtetra
.576 .774 .973 r
.67522 .32289 .67986 .33356 .70356 .33236 .69909 .32167 Mtetra
.577 .775 .973 r
.69909 .32167 .70356 .33236 .72735 .33106 .72306 .32036 Mtetra
.579 .777 .973 r
.72306 .32036 .72735 .33106 .75123 .32967 .74713 .31895 Mtetra
.58 .778 .973 r
.74713 .31895 .75123 .32967 .77522 .32821 .7713 .31747 Mtetra
.582 .779 .973 r
.7713 .31747 .77522 .32821 .7993 .32667 .79556 .31591 Mtetra
.583 .78 .973 r
.79556 .31591 .7993 .32667 .82348 .32507 .81993 .31428 Mtetra
.584 .781 .973 r
.81993 .31428 .82348 .32507 .84775 .3234 .84439 .31259 Mtetra
.585 .782 .973 r
.84439 .31259 .84775 .3234 .87213 .32168 .86895 .31084 Mtetra
.586 .783 .974 r
.86895 .31084 .87213 .32168 .8966 .3199 .89361 .30904 Mtetra
.89361 .30904 .8966 .3199 .92117 .31808 .91837 .30718 Mtetra
.587 .784 .974 r
.91837 .30718 .92117 .31808 .94583 .3162 .94323 .30528 Mtetra
.617 .786 .963 r
.14985 .2616 .15814 .27193 .17964 .26947 .17149 .2591 Mtetra
.17149 .2591 .17964 .26947 .20122 .26699 .19322 .25659 Mtetra
.19322 .25659 .20122 .26699 .22287 .26451 .21502 .25407 Mtetra
.042 .425 .867 r
.21502 .25407 .22287 .26451 .24366 .27979 .23608 .2665 Mtetra
.176 .461 .885 r
.23608 .2665 .24366 .27979 .2648 .29208 .25731 .27944 Mtetra
.284 .549 .923 r
.25731 .27944 .2648 .29208 .28628 .30126 .27889 .2891 Mtetra
.356 .606 .943 r
.27889 .2891 .28628 .30126 .30801 .30824 .30074 .29641 Mtetra
.407 .645 .954 r
.30074 .29641 .30801 .30824 .32997 .31357 .32283 .302 Mtetra
.444 .673 .961 r
.32283 .302 .32997 .31357 .3521 .31767 .3451 .30629 Mtetra
.471 .694 .965 r
.3451 .30629 .3521 .31767 .3744 .32079 .36754 .30956 Mtetra
.492 .709 .967 r
.36754 .30956 .3744 .32079 .39685 .32315 .39014 .31203 Mtetra
.508 .722 .969 r
.39014 .31203 .39685 .32315 .41943 .32489 .41287 .31386 Mtetra
.521 .731 .97 r
.41287 .31386 .41943 .32489 .44213 .32612 .43573 .31515 Mtetra
.531 .739 .971 r
.43573 .31515 .44213 .32612 .46496 .32692 .45871 .31601 Mtetra
.539 .745 .971 r
.45871 .31601 .46496 .32692 .4879 .32737 .48181 .31649 Mtetra
.546 .751 .972 r
.48181 .31649 .4879 .32737 .51095 .32752 .50503 .31667 Mtetra
.552 .755 .972 r
.50503 .31667 .51095 .32752 .53411 .32741 .52835 .31658 Mtetra
.557 .759 .972 r
.52835 .31658 .53411 .32741 .55737 .32707 .55179 .31625 Mtetra
.561 .762 .972 r
.55179 .31625 .55737 .32707 .58074 .32654 .57532 .31573 Mtetra
.565 .765 .972 r
.57532 .31573 .58074 .32654 .60421 .32584 .59897 .31502 Mtetra
.568 .768 .973 r
.59897 .31502 .60421 .32584 .62778 .32499 .62271 .31417 Mtetra
.571 .77 .973 r
.62271 .31417 .62778 .32499 .65145 .324 .64656 .31317 Mtetra
.573 .772 .973 r
.64656 .31317 .65145 .324 .67522 .32289 .67051 .31205 Mtetra
.575 .774 .973 r
.67051 .31205 .67522 .32289 .69909 .32167 .69456 .31082 Mtetra
.577 .775 .973 r
.69456 .31082 .69909 .32167 .72306 .32036 .71871 .30949 Mtetra
.579 .777 .973 r
.71871 .30949 .72306 .32036 .74713 .31895 .74296 .30807 Mtetra
.58 .778 .973 r
.74296 .30807 .74713 .31895 .7713 .31747 .76731 .30656 Mtetra
.581 .779 .973 r
.76731 .30656 .7713 .31747 .79556 .31591 .79177 .30498 Mtetra
.583 .78 .973 r
.79177 .30498 .79556 .31591 .81993 .31428 .81632 .30332 Mtetra
.584 .781 .973 r
.81632 .30332 .81993 .31428 .84439 .31259 .84097 .30161 Mtetra
.585 .782 .973 r
.84097 .30161 .84439 .31259 .86895 .31084 .86572 .29983 Mtetra
.586 .783 .974 r
.86572 .29983 .86895 .31084 .89361 .30904 .89058 .298 Mtetra
.89058 .298 .89361 .30904 .91837 .30718 .91553 .29611 Mtetra
.587 .784 .974 r
.91553 .29611 .91837 .30718 .94323 .30528 .94059 .29418 Mtetra
.617 .786 .963 r
.14142 .25112 .14985 .2616 .17149 .2591 .16322 .24858 Mtetra
.16322 .24858 .17149 .2591 .19322 .25659 .18509 .24603 Mtetra
.18509 .24603 .19322 .25659 .21502 .25407 .20704 .24347 Mtetra
.184 .529 .922 r
.20704 .24347 .21502 .25407 .23608 .2665 .2284 .25302 Mtetra
.15 .442 .876 r
.2284 .25302 .23608 .2665 .25731 .27944 .24971 .26663 Mtetra
.266 .537 .919 r
.24971 .26663 .25731 .27944 .27889 .2891 .27139 .27676 Mtetra
.345 .598 .941 r
.27139 .27676 .27889 .2891 .30074 .29641 .29337 .28441 Mtetra
.399 .64 .953 r
.29337 .28441 .30074 .29641 .32283 .302 .31558 .29026 Mtetra
.438 .669 .96 r
.31558 .29026 .32283 .302 .3451 .30629 .33799 .29474 Mtetra
.466 .691 .964 r
.33799 .29474 .3451 .30629 .36754 .30956 .36058 .29816 Mtetra
.488 .707 .967 r
.36058 .29816 .36754 .30956 .39014 .31203 .38332 .30074 Mtetra
.505 .72 .969 r
.38332 .30074 .39014 .31203 .41287 .31386 .40621 .30265 Mtetra
.518 .73 .97 r
.40621 .30265 .41287 .31386 .43573 .31515 .42923 .30402 Mtetra
.529 .738 .971 r
.42923 .30402 .43573 .31515 .45871 .31601 .45237 .30492 Mtetra
.538 .744 .971 r
.45237 .30492 .45871 .31601 .48181 .31649 .47564 .30545 Mtetra
.545 .75 .972 r
.47564 .30545 .48181 .31649 .50503 .31667 .49902 .30565 Mtetra
.551 .755 .972 r
.49902 .30565 .50503 .31667 .52835 .31658 .52251 .30557 Mtetra
.556 .759 .972 r
.52251 .30557 .52835 .31658 .55179 .31625 .54611 .30526 Mtetra
.56 .762 .972 r
.54611 .30526 .55179 .31625 .57532 .31573 .56983 .30474 Mtetra
.564 .765 .972 r
.56983 .30474 .57532 .31573 .59897 .31502 .59364 .30404 Mtetra
.567 .767 .973 r
.59364 .30404 .59897 .31502 .62271 .31417 .61757 .30318 Mtetra
.57 .77 .973 r
.61757 .30318 .62271 .31417 .64656 .31317 .64159 .30217 Mtetra
.573 .772 .973 r
.64159 .30217 .64656 .31317 .67051 .31205 .66572 .30104 Mtetra
.575 .773 .973 r
.66572 .30104 .67051 .31205 .69456 .31082 .68995 .29979 Mtetra
.577 .775 .973 r
.68995 .29979 .69456 .31082 .71871 .30949 .71429 .29844 Mtetra
.578 .776 .973 r
.71429 .29844 .71871 .30949 .74296 .30807 .73873 .297 Mtetra
.58 .778 .973 r
.73873 .297 .74296 .30807 .76731 .30656 .76327 .29547 Mtetra
.581 .779 .973 r
.76327 .29547 .76731 .30656 .79177 .30498 .78791 .29387 Mtetra
.582 .78 .973 r
.78791 .29387 .79177 .30498 .81632 .30332 .81265 .29219 Mtetra
.584 .781 .973 r
.81265 .29219 .81632 .30332 .84097 .30161 .83749 .29044 Mtetra
.584 .782 .973 r
.83749 .29044 .84097 .30161 .86572 .29983 .86244 .28864 Mtetra
.585 .782 .974 r
.86244 .28864 .86572 .29983 .89058 .298 .88749 .28678 Mtetra
.586 .783 .974 r
.88749 .28678 .89058 .298 .91553 .29611 .91265 .28486 Mtetra
.587 .784 .974 r
.91265 .28486 .91553 .29611 .94059 .29418 .9379 .28289 Mtetra
.617 .786 .963 r
.13287 .24047 .14142 .25112 .16322 .24858 .15482 .2379 Mtetra
.15482 .2379 .16322 .24858 .18509 .24603 .17684 .23531 Mtetra
.17684 .23531 .18509 .24603 .20704 .24347 .19895 .23271 Mtetra
.315 .617 .956 r
.19895 .23271 .20704 .24347 .2284 .25302 .2206 .23935 Mtetra
.124 .423 .867 r
.2206 .23935 .2284 .25302 .24971 .26663 .24199 .25363 Mtetra
.249 .525 .915 r
.24199 .25363 .24971 .26663 .27139 .27676 .26378 .26423 Mtetra
.333 .591 .939 r
.26378 .26423 .27139 .27676 .29337 .28441 .28588 .27223 Mtetra
.39 .635 .952 r
.28588 .27223 .29337 .28441 .31558 .29026 .30822 .27834 Mtetra
.431 .666 .96 r
.30822 .27834 .31558 .29026 .33799 .29474 .33078 .28301 Mtetra
.461 .688 .964 r
.33078 .28301 .33799 .29474 .36058 .29816 .35351 .28658 Mtetra
.484 .705 .967 r
.35351 .28658 .36058 .29816 .38332 .30074 .3764 .28928 Mtetra
.502 .718 .969 r
.3764 .28928 .38332 .30074 .40621 .30265 .39944 .29128 Mtetra
.516 .728 .97 r
.39944 .29128 .40621 .30265 .42923 .30402 .42262 .29271 Mtetra
.527 .737 .971 r
.42262 .29271 .42923 .30402 .45237 .30492 .44593 .29366 Mtetra
.536 .744 .971 r
.44593 .29366 .45237 .30492 .47564 .30545 .46936 .29423 Mtetra
.544 .749 .972 r
.46936 .29423 .47564 .30545 .49902 .30565 .49291 .29446 Mtetra
.55 .754 .972 r
.49291 .29446 .49902 .30565 .52251 .30557 .51658 .2944 Mtetra
.555 .758 .972 r
.51658 .2944 .52251 .30557 .54611 .30526 .54035 .2941 Mtetra
.56 .761 .972 r
.54035 .2941 .54611 .30526 .56983 .30474 .56424 .29358 Mtetra
.563 .764 .973 r
.56424 .29358 .56983 .30474 .59364 .30404 .58823 .29288 Mtetra
.567 .767 .973 r
.58823 .29288 .59364 .30404 .61757 .30318 .61234 .29201 Mtetra
.57 .769 .973 r
.61234 .29201 .61757 .30318 .64159 .30217 .63654 .291 Mtetra
.572 .771 .973 r
.63654 .291 .64159 .30217 .66572 .30104 .66086 .28985 Mtetra
.574 .773 .973 r
.66086 .28985 .66572 .30104 .68995 .29979 .68527 .28859 Mtetra
.576 .775 .973 r
.68527 .28859 .68995 .29979 .71429 .29844 .7098 .28722 Mtetra
.578 .776 .973 r
.7098 .28722 .71429 .29844 .73873 .297 .73442 .28576 Mtetra
.58 .777 .973 r
.73442 .28576 .73873 .297 .76327 .29547 .75915 .28421 Mtetra
.581 .779 .973 r
.75915 .28421 .76327 .29547 .78791 .29387 .78399 .28258 Mtetra
.582 .78 .973 r
.78399 .28258 .78791 .29387 .81265 .29219 .80892 .28087 Mtetra
.583 .781 .973 r
.80892 .28087 .81265 .29219 .83749 .29044 .83396 .2791 Mtetra
.584 .782 .973 r
.83396 .2791 .83749 .29044 .86244 .28864 .85911 .27726 Mtetra
.585 .782 .974 r
.85911 .27726 .86244 .28864 .88749 .28678 .88436 .27537 Mtetra
.586 .783 .974 r
.88436 .27537 .88749 .28678 .91265 .28486 .90971 .27342 Mtetra
.587 .784 .974 r
.90971 .27342 .91265 .28486 .9379 .28289 .93517 .27142 Mtetra
.617 .786 .963 r
.12419 .22967 .13287 .24047 .15482 .2379 .14629 .22705 Mtetra
.14629 .22705 .15482 .2379 .17684 .23531 .16847 .22442 Mtetra
.16847 .22442 .17684 .23531 .19895 .23271 .19073 .22178 Mtetra
.43 .687 .972 r
.19073 .22178 .19895 .23271 .2206 .23935 .21269 .22548 Mtetra
.097 .404 .857 r
.21269 .22548 .2206 .23935 .24199 .25363 .23417 .24044 Mtetra
.231 .513 .91 r
.23417 .24044 .24199 .25363 .26378 .26423 .25606 .25152 Mtetra
.32 .583 .937 r
.25606 .25152 .26378 .26423 .28588 .27223 .27828 .25987 Mtetra
.382 .629 .951 r
.27828 .25987 .28588 .27223 .30822 .27834 .30076 .26624 Mtetra
.425 .662 .959 r
.30076 .26624 .30822 .27834 .33078 .28301 .32345 .27111 Mtetra
.457 .685 .964 r
.32345 .27111 .33078 .28301 .35351 .28658 .34633 .27483 Mtetra
.481 .703 .967 r
.34633 .27483 .35351 .28658 .3764 .28928 .36938 .27764 Mtetra
.499 .716 .969 r
.36938 .27764 .3764 .28928 .39944 .29128 .39258 .27973 Mtetra
.514 .727 .97 r
.39258 .27973 .39944 .29128 .42262 .29271 .41592 .28122 Mtetra
.525 .736 .971 r
.41592 .28122 .42262 .29271 .44593 .29366 .43939 .28223 Mtetra
.535 .743 .971 r
.43939 .28223 .44593 .29366 .46936 .29423 .46299 .28283 Mtetra
.542 .748 .972 r
.46299 .28283 .46936 .29423 .49291 .29446 .48671 .28308 Mtetra
.549 .753 .972 r
.48671 .28308 .49291 .29446 .51658 .2944 .51055 .28305 Mtetra
.554 .757 .972 r
.51055 .28305 .51658 .2944 .54035 .2941 .5345 .28275 Mtetra
.559 .761 .972 r
.5345 .28275 .54035 .2941 .56424 .29358 .55856 .28224 Mtetra
.563 .764 .973 r
.55856 .28224 .56424 .29358 .58823 .29288 .58274 .28154 Mtetra
.566 .767 .973 r
.58274 .28154 .58823 .29288 .61234 .29201 .60702 .28066 Mtetra
.569 .769 .973 r
.60702 .28066 .61234 .29201 .63654 .291 .63141 .27964 Mtetra
.572 .771 .973 r
.63141 .27964 .63654 .291 .66086 .28985 .65591 .27848 Mtetra
.574 .773 .973 r
.65591 .27848 .66086 .28985 .68527 .28859 .68052 .2772 Mtetra
.576 .774 .973 r
.68052 .2772 .68527 .28859 .7098 .28722 .70523 .27582 Mtetra
.578 .776 .973 r
.70523 .27582 .7098 .28722 .73442 .28576 .73005 .27433 Mtetra
.579 .777 .973 r
.73005 .27433 .73442 .28576 .75915 .28421 .75497 .27276 Mtetra
.581 .778 .973 r
.75497 .27276 .75915 .28421 .78399 .28258 .78 .2711 Mtetra
.582 .78 .973 r
.78 .2711 .78399 .28258 .80892 .28087 .80513 .26937 Mtetra
.583 .781 .973 r
.80513 .26937 .80892 .28087 .83396 .2791 .83037 .26757 Mtetra
.584 .781 .973 r
.83037 .26757 .83396 .2791 .85911 .27726 .85572 .2657 Mtetra
.585 .782 .974 r
.85572 .2657 .85911 .27726 .88436 .27537 .88117 .26378 Mtetra
.586 .783 .974 r
.88117 .26378 .88436 .27537 .90971 .27342 .90673 .2618 Mtetra
.587 .784 .974 r
.90673 .2618 .90971 .27342 .93517 .27142 .93239 .25976 Mtetra
.617 .786 .963 r
.11538 .21869 .12419 .22967 .14629 .22705 .13763 .21604 Mtetra
.13763 .21604 .14629 .22705 .16847 .22442 .15996 .21337 Mtetra
.15996 .21337 .16847 .22442 .19073 .22178 .18238 .21069 Mtetra
.526 .741 .973 r
.18238 .21069 .19073 .22178 .21269 .22548 .20467 .21141 Mtetra
.071 .384 .846 r
.20467 .21141 .21269 .22548 .23417 .24044 .22623 .22705 Mtetra
.213 .5 .905 r
.22623 .22705 .23417 .24044 .25606 .25152 .24823 .23861 Mtetra
.308 .574 .934 r
.24823 .23861 .25606 .25152 .27828 .25987 .27056 .24732 Mtetra
.373 .624 .95 r
.27056 .24732 .27828 .25987 .30076 .26624 .29317 .25395 Mtetra
.419 .658 .959 r
.29317 .25395 .30076 .26624 .32345 .27111 .31601 .25901 Mtetra
.452 .682 .964 r
.31601 .25901 .32345 .27111 .34633 .27483 .33904 .26289 Mtetra
.477 .701 .967 r
.33904 .26289 .34633 .27483 .36938 .27764 .36224 .26581 Mtetra
.496 .715 .969 r
.36224 .26581 .36938 .27764 .39258 .27973 .3856 .26799 Mtetra
.511 .726 .97 r
.3856 .26799 .39258 .27973 .41592 .28122 .4091 .26955 Mtetra
.523 .734 .971 r
.4091 .26955 .41592 .28122 .43939 .28223 .43274 .27061 Mtetra
.533 .742 .971 r
.43274 .27061 .43939 .28223 .46299 .28283 .45651 .27125 Mtetra
.541 .748 .972 r
.45651 .27125 .46299 .28283 .48671 .28308 .48041 .27153 Mtetra
.548 .753 .972 r
.48041 .27153 .48671 .28308 .51055 .28305 .50442 .27151 Mtetra
.553 .757 .972 r
.50442 .27151 .51055 .28305 .5345 .28275 .52855 .27123 Mtetra
.558 .76 .972 r
.52855 .27123 .5345 .28275 .55856 .28224 .55279 .27072 Mtetra
.562 .764 .973 r
.55279 .27072 .55856 .28224 .58274 .28154 .57715 .27001 Mtetra
.566 .766 .973 r
.57715 .27001 .58274 .28154 .60702 .28066 .60162 .26913 Mtetra
.569 .769 .973 r
.60162 .26913 .60702 .28066 .63141 .27964 .6262 .2681 Mtetra
.571 .771 .973 r
.6262 .2681 .63141 .27964 .65591 .27848 .65089 .26693 Mtetra
.574 .773 .973 r
.65089 .26693 .65591 .27848 .68052 .2772 .67568 .26563 Mtetra
.576 .774 .973 r
.67568 .26563 .68052 .2772 .70523 .27582 .70059 .26422 Mtetra
.577 .776 .973 r
.70059 .26422 .70523 .27582 .73005 .27433 .7256 .26272 Mtetra
.579 .777 .973 r
.7256 .26272 .73005 .27433 .75497 .27276 .75072 .26112 Mtetra
.58 .778 .973 r
.75072 .26112 .75497 .27276 .78 .2711 .77595 .25943 Mtetra
.582 .779 .973 r
.77595 .25943 .78 .2711 .80513 .26937 .80128 .25767 Mtetra
.583 .78 .973 r
.80128 .25767 .80513 .26937 .83037 .26757 .82672 .25584 Mtetra
.584 .781 .973 r
.82672 .25584 .83037 .26757 .85572 .2657 .85227 .25395 Mtetra
.585 .782 .974 r
.85227 .25395 .85572 .2657 .88117 .26378 .87793 .25199 Mtetra
.586 .783 .974 r
.87793 .25199 .88117 .26378 .90673 .2618 .9037 .24997 Mtetra
.586 .784 .974 r
.9037 .24997 .90673 .2618 .93239 .25976 .92957 .24791 Mtetra
.617 .786 .963 r
.10642 .20755 .11538 .21869 .13763 .21604 .12883 .20485 Mtetra
.12883 .20485 .13763 .21604 .15996 .21337 .15132 .20214 Mtetra
.15132 .20214 .15996 .21337 .18238 .21069 .1739 .19942 Mtetra
.606 .781 .965 r
.1739 .19942 .18238 .21069 .20467 .21141 .19653 .19714 Mtetra
.044 .364 .834 r
.19653 .19714 .20467 .21141 .22623 .22705 .21817 .21346 Mtetra
.195 .487 .899 r
.21817 .21346 .22623 .22705 .24823 .23861 .24027 .22551 Mtetra
.296 .566 .932 r
.24027 .22551 .24823 .23861 .27056 .24732 .26273 .23457 Mtetra
.364 .618 .949 r
.26273 .23457 .27056 .24732 .29317 .25395 .28547 .24147 Mtetra
.412 .654 .958 r
.28547 .24147 .29317 .25395 .31601 .25901 .30845 .24674 Mtetra
.447 .679 .963 r
.30845 .24674 .31601 .25901 .33904 .26289 .33163 .25076 Mtetra
.473 .698 .967 r
.33163 .25076 .33904 .26289 .36224 .26581 .35499 .2538 Mtetra
.493 .713 .969 r
.35499 .2538 .36224 .26581 .3856 .26799 .37851 .25607 Mtetra
.509 .724 .97 r
.37851 .25607 .3856 .26799 .4091 .26955 .40218 .2577 Mtetra
.521 .733 .971 r
.40218 .2577 .4091 .26955 .43274 .27061 .42599 .25881 Mtetra
.531 .741 .971 r
.42599 .25881 .43274 .27061 .45651 .27125 .44993 .25948 Mtetra
.54 .747 .972 r
.44993 .25948 .45651 .27125 .48041 .27153 .474 .25979 Mtetra
.547 .752 .972 r
.474 .25979 .48041 .27153 .50442 .27151 .49819 .25979 Mtetra
.552 .756 .972 r
.49819 .25979 .50442 .27151 .52855 .27123 .5225 .25952 Mtetra
.557 .76 .972 r
.5225 .25952 .52855 .27123 .55279 .27072 .54693 .25901 Mtetra
.561 .763 .973 r
.54693 .25901 .55279 .27072 .57715 .27001 .57148 .2583 Mtetra
.565 .766 .973 r
.57148 .2583 .57715 .27001 .60162 .26913 .59613 .25741 Mtetra
.568 .768 .973 r
.59613 .25741 .60162 .26913 .6262 .2681 .6209 .25637 Mtetra
.571 .77 .973 r
.6209 .25637 .6262 .2681 .65089 .26693 .64578 .25518 Mtetra
.573 .772 .973 r
.64578 .25518 .65089 .26693 .67568 .26563 .67077 .25387 Mtetra
.575 .774 .973 r
.67077 .25387 .67568 .26563 .70059 .26422 .69587 .25244 Mtetra
.577 .776 .973 r
.69587 .25244 .70059 .26422 .7256 .26272 .72108 .25091 Mtetra
.579 .777 .973 r
.72108 .25091 .7256 .26272 .75072 .26112 .7464 .24928 Mtetra
.58 .778 .973 r
.7464 .24928 .75072 .26112 .77595 .25943 .77183 .24757 Mtetra
.581 .779 .973 r
.77183 .24757 .77595 .25943 .80128 .25767 .79737 .24578 Mtetra
.583 .78 .973 r
.79737 .24578 .80128 .25767 .82672 .25584 .82301 .24392 Mtetra
.584 .781 .973 r
.82301 .24392 .82672 .25584 .85227 .25395 .84877 .24199 Mtetra
.585 .782 .974 r
.84877 .24199 .85227 .25395 .87793 .25199 .87464 .24 Mtetra
.586 .783 .974 r
.87464 .24 .87793 .25199 .9037 .24997 .90061 .23795 Mtetra
.90061 .23795 .9037 .24997 .92957 .24791 .9267 .23585 Mtetra
.617 .786 .963 r
.09733 .19623 .10642 .20755 .12883 .20485 .1199 .19349 Mtetra
.1199 .19349 .12883 .20485 .15132 .20214 .14255 .19074 Mtetra
.14255 .19074 .15132 .20214 .1739 .19942 .16529 .18797 Mtetra
.16529 .18797 .1739 .19942 .19653 .19714 .18811 .1852 Mtetra
0 .377 .84 r
.18811 .1852 .19653 .19714 .21817 .21346 .20999 .19967 Mtetra
.177 .474 .893 r
.20999 .19967 .21817 .21346 .24027 .22551 .23219 .21221 Mtetra
.283 .557 .929 r
.23219 .21221 .24027 .22551 .26273 .23457 .25478 .22163 Mtetra
.355 .612 .947 r
.25478 .22163 .26273 .23457 .28547 .24147 .27765 .22879 Mtetra
.406 .65 .957 r
.27765 .22879 .28547 .24147 .30845 .24674 .30078 .23426 Mtetra
.442 .676 .963 r
.30078 .23426 .30845 .24674 .33163 .25076 .32411 .23844 Mtetra
.469 .696 .966 r
.32411 .23844 .33163 .25076 .35499 .2538 .34763 .2416 Mtetra
.49 .711 .969 r
.34763 .2416 .35499 .2538 .37851 .25607 .37131 .24396 Mtetra
.506 .723 .97 r
.37131 .24396 .37851 .25607 .40218 .2577 .39515 .24566 Mtetra
.519 .732 .971 r
.39515 .24566 .40218 .2577 .42599 .25881 .41913 .24682 Mtetra
.53 .74 .971 r
.41913 .24682 .42599 .25881 .44993 .25948 .44325 .24753 Mtetra
.538 .746 .972 r
.44325 .24753 .44993 .25948 .474 .25979 .46749 .24786 Mtetra
.545 .751 .972 r
.46749 .24786 .474 .25979 .49819 .25979 .49187 .24787 Mtetra
.551 .756 .972 r
.49187 .24787 .49819 .25979 .5225 .25952 .51636 .24761 Mtetra
.556 .759 .973 r
.51636 .24761 .5225 .25952 .54693 .25901 .54097 .24711 Mtetra
.561 .763 .973 r
.54097 .24711 .54693 .25901 .57148 .2583 .56571 .2464 Mtetra
.564 .766 .973 r
.56571 .2464 .57148 .2583 .59613 .25741 .59055 .2455 Mtetra
.568 .768 .973 r
.59055 .2455 .59613 .25741 .6209 .25637 .61551 .24444 Mtetra
.57 .77 .973 r
.61551 .24444 .6209 .25637 .64578 .25518 .64059 .24324 Mtetra
.573 .772 .973 r
.64059 .24324 .64578 .25518 .67077 .25387 .66577 .24191 Mtetra
.575 .774 .973 r
.66577 .24191 .67077 .25387 .69587 .25244 .69107 .24046 Mtetra
.577 .775 .973 r
.69107 .24046 .69587 .25244 .72108 .25091 .71648 .2389 Mtetra
.578 .777 .973 r
.71648 .2389 .72108 .25091 .7464 .24928 .74201 .23725 Mtetra
.58 .778 .973 r
.74201 .23725 .7464 .24928 .77183 .24757 .76764 .23551 Mtetra
.581 .779 .973 r
.76764 .23551 .77183 .24757 .79737 .24578 .79338 .23369 Mtetra
.582 .78 .973 r
.79338 .23369 .79737 .24578 .82301 .24392 .81924 .2318 Mtetra
.583 .781 .974 r
.81924 .2318 .82301 .24392 .84877 .24199 .84521 .22984 Mtetra
.584 .782 .974 r
.84521 .22984 .84877 .24199 .87464 .24 .87129 .22781 Mtetra
.585 .783 .974 r
.87129 .22781 .87464 .24 .90061 .23795 .89748 .22572 Mtetra
.586 .783 .974 r
.89748 .22572 .90061 .23795 .9267 .23585 .92378 .22358 Mtetra
.617 .786 .963 r
.0881 .18473 .09733 .19623 .1199 .19349 .11082 .18195 Mtetra
.11082 .18195 .1199 .19349 .14255 .19074 .13364 .17915 Mtetra
.13364 .17915 .14255 .19074 .16529 .18797 .15654 .17634 Mtetra
.15654 .17634 .16529 .18797 .18811 .1852 .17953 .17353 Mtetra
.081 .452 .883 r
.17953 .17353 .18811 .1852 .20999 .19967 .20168 .18567 Mtetra
.158 .461 .887 r
.20168 .18567 .20999 .19967 .23219 .21221 .22399 .19871 Mtetra
.27 .549 .926 r
.22399 .19871 .23219 .21221 .25478 .22163 .2467 .20849 Mtetra
.346 .606 .946 r
.2467 .20849 .25478 .22163 .27765 .22879 .26971 .21592 Mtetra
.399 .645 .956 r
.26971 .21592 .27765 .22879 .30078 .23426 .29298 .22159 Mtetra
.437 .673 .963 r
.29298 .22159 .30078 .23426 .32411 .23844 .31647 .22592 Mtetra
.466 .694 .966 r
.31647 .22592 .32411 .23844 .34763 .2416 .34014 .2292 Mtetra
.487 .709 .968 r
.34014 .2292 .34763 .2416 .37131 .24396 .36399 .23165 Mtetra
.504 .721 .97 r
.36399 .23165 .37131 .24396 .39515 .24566 .388 .23342 Mtetra
.517 .731 .971 r
.388 .23342 .39515 .24566 .41913 .24682 .41216 .23463 Mtetra
.528 .739 .971 r
.41216 .23463 .41913 .24682 .44325 .24753 .43645 .23538 Mtetra
.537 .745 .972 r
.43645 .23538 .44325 .24753 .46749 .24786 .46088 .23574 Mtetra
.544 .751 .972 r
.46088 .23574 .46749 .24786 .49187 .24787 .48543 .23577 Mtetra
.55 .755 .972 r
.48543 .23577 .49187 .24787 .51636 .24761 .51011 .23551 Mtetra
.556 .759 .973 r
.51011 .23551 .51636 .24761 .54097 .24711 .53492 .23501 Mtetra
.56 .762 .973 r
.53492 .23501 .54097 .24711 .56571 .2464 .55984 .23429 Mtetra
.564 .765 .973 r
.55984 .23429 .56571 .2464 .59055 .2455 .58488 .23339 Mtetra
.567 .768 .973 r
.58488 .23339 .59055 .2455 .61551 .24444 .61004 .23232 Mtetra
.57 .77 .973 r
.61004 .23232 .61551 .24444 .64059 .24324 .63531 .2311 Mtetra
.572 .772 .973 r
.63531 .2311 .64059 .24324 .66577 .24191 .6607 .22974 Mtetra
.574 .774 .973 r
.6607 .22974 .66577 .24191 .69107 .24046 .6862 .22827 Mtetra
.576 .775 .973 r
.6862 .22827 .69107 .24046 .71648 .2389 .71181 .22669 Mtetra
.578 .777 .973 r
.71181 .22669 .71648 .2389 .74201 .23725 .73754 .22501 Mtetra
.58 .778 .973 r
.73754 .22501 .74201 .23725 .76764 .23551 .76338 .22325 Mtetra
.581 .779 .973 r
.76338 .22325 .76764 .23551 .79338 .23369 .78933 .22139 Mtetra
.582 .78 .973 r
.78933 .22139 .79338 .23369 .81924 .2318 .8154 .21947 Mtetra
.583 .781 .974 r
.8154 .21947 .81924 .2318 .84521 .22984 .84158 .21747 Mtetra
.584 .782 .974 r
.84158 .21747 .84521 .22984 .87129 .22781 .86788 .21541 Mtetra
.585 .783 .974 r
.86788 .21541 .87129 .22781 .89748 .22572 .89429 .21329 Mtetra
.586 .783 .974 r
.89429 .21329 .89748 .22572 .92378 .22358 .92081 .21111 Mtetra
.617 .786 .963 r
.07871 .17305 .0881 .18473 .11082 .18195 .1016 .17022 Mtetra
.1016 .17022 .11082 .18195 .13364 .17915 .12458 .16738 Mtetra
.12458 .16738 .13364 .17915 .15654 .17634 .14765 .16453 Mtetra
.14765 .16453 .15654 .17634 .17953 .17353 .17081 .16167 Mtetra
.189 .53 .923 r
.17081 .16167 .17953 .17353 .20168 .18567 .19325 .17146 Mtetra
.139 .447 .88 r
.19325 .17146 .20168 .18567 .22399 .19871 .21566 .185 Mtetra
.257 .54 .922 r
.21566 .185 .22399 .19871 .2467 .20849 .23849 .19514 Mtetra
.337 .6 .944 r
.23849 .19514 .2467 .20849 .26971 .21592 .26164 .20284 Mtetra
.392 .641 .956 r
.26164 .20284 .26971 .21592 .29298 .22159 .28506 .20872 Mtetra
.432 .67 .962 r
.28506 .20872 .29298 .22159 .31647 .22592 .3087 .21321 Mtetra
.462 .691 .966 r
.3087 .21321 .31647 .22592 .34014 .2292 .33254 .21661 Mtetra
.484 .708 .968 r
.33254 .21661 .34014 .2292 .36399 .23165 .35656 .21914 Mtetra
.502 .72 .97 r
.35656 .21914 .36399 .23165 .388 .23342 .38074 .22098 Mtetra
.515 .73 .971 r
.38074 .22098 .388 .23342 .41216 .23463 .40507 .22224 Mtetra
.527 .738 .971 r
.40507 .22224 .41216 .23463 .43645 .23538 .42954 .22303 Mtetra
.536 .744 .972 r
.42954 .22303 .43645 .23538 .46088 .23574 .45415 .22341 Mtetra
.543 .75 .972 r
.45415 .22341 .46088 .23574 .48543 .23577 .4789 .22345 Mtetra
.549 .755 .972 r
.4789 .22345 .48543 .23577 .51011 .23551 .50377 .22321 Mtetra
.555 .758 .973 r
.50377 .22321 .51011 .23551 .53492 .23501 .52876 .22271 Mtetra
.559 .762 .973 r
.52876 .22271 .53492 .23501 .55984 .23429 .55388 .22199 Mtetra
.563 .765 .973 r
.55388 .22199 .55984 .23429 .58488 .23339 .57911 .22107 Mtetra
.566 .767 .973 r
.57911 .22107 .58488 .23339 .61004 .23232 .60447 .21999 Mtetra
.569 .77 .973 r
.60447 .21999 .61004 .23232 .63531 .2311 .62994 .21875 Mtetra
.572 .772 .973 r
.62994 .21875 .63531 .2311 .6607 .22974 .65553 .21738 Mtetra
.574 .773 .973 r
.65553 .21738 .6607 .22974 .6862 .22827 .68124 .21588 Mtetra
.576 .775 .973 r
.68124 .21588 .6862 .22827 .71181 .22669 .70706 .21427 Mtetra
.578 .776 .973 r
.70706 .21427 .71181 .22669 .73754 .22501 .73299 .21257 Mtetra
.579 .778 .973 r
.73299 .21257 .73754 .22501 .76338 .22325 .75905 .21077 Mtetra
.581 .779 .973 r
.75905 .21077 .76338 .22325 .78933 .22139 .78521 .20889 Mtetra
.582 .78 .973 r
.78521 .20889 .78933 .22139 .8154 .21947 .8115 .20693 Mtetra
.583 .781 .974 r
.8115 .20693 .8154 .21947 .84158 .21747 .8379 .20489 Mtetra
.584 .782 .974 r
.8379 .20489 .84158 .21747 .86788 .21541 .86441 .2028 Mtetra
.585 .782 .974 r
.86441 .2028 .86788 .21541 .89429 .21329 .89104 .20064 Mtetra
.586 .783 .974 r
.89104 .20064 .89429 .21329 .92081 .21111 .91779 .19842 Mtetra
.617 .786 .963 r
.06918 .16119 .07871 .17305 .1016 .17022 .09223 .15831 Mtetra
.09223 .15831 .1016 .17022 .12458 .16738 .11538 .15542 Mtetra
.11538 .15542 .12458 .16738 .14765 .16453 .13862 .15252 Mtetra
.13862 .15252 .14765 .16453 .17081 .16167 .16194 .14961 Mtetra
.291 .6 .95 r
.16194 .14961 .17081 .16167 .19325 .17146 .18469 .15702 Mtetra
.12 .433 .873 r
.18469 .15702 .19325 .17146 .21566 .185 .2072 .17107 Mtetra
.244 .531 .919 r
.2072 .17107 .21566 .185 .23849 .19514 .23015 .18158 Mtetra
.328 .594 .942 r
.23015 .18158 .23849 .19514 .26164 .20284 .25344 .18956 Mtetra
.386 .637 .955 r
.25344 .18956 .26164 .20284 .28506 .20872 .27701 .19564 Mtetra
.427 .667 .962 r
.27701 .19564 .28506 .20872 .3087 .21321 .30081 .20028 Mtetra
.458 .689 .966 r
.30081 .20028 .3087 .21321 .33254 .21661 .32481 .2038 Mtetra
.481 .706 .968 r
.32481 .2038 .33254 .21661 .35656 .21914 .349 .20643 Mtetra
.499 .719 .97 r
.349 .20643 .35656 .21914 .38074 .22098 .37335 .20833 Mtetra
.514 .729 .971 r
.37335 .20833 .38074 .22098 .40507 .22224 .39786 .20965 Mtetra
.525 .737 .971 r
.39786 .20965 .40507 .22224 .42954 .22303 .42252 .21047 Mtetra
.534 .744 .972 r
.42252 .21047 .42954 .22303 .45415 .22341 .44732 .21088 Mtetra
.542 .749 .972 r
.44732 .21088 .45415 .22341 .4789 .22345 .47225 .21094 Mtetra
.548 .754 .972 r
.47225 .21094 .4789 .22345 .50377 .22321 .49731 .2107 Mtetra
.554 .758 .973 r
.49731 .2107 .50377 .22321 .52876 .22271 .5225 .2102 Mtetra
.559 .761 .973 r
.5225 .2102 .52876 .22271 .55388 .22199 .54781 .20947 Mtetra
.562 .764 .973 r
.54781 .20947 .55388 .22199 .57911 .22107 .57325 .20855 Mtetra
.566 .767 .973 r
.57325 .20855 .57911 .22107 .60447 .21999 .5988 .20745 Mtetra
.569 .769 .973 r
.5988 .20745 .60447 .21999 .62994 .21875 .62448 .20619 Mtetra
.571 .771 .973 r
.62448 .20619 .62994 .21875 .65553 .21738 .65028 .2048 Mtetra
.574 .773 .973 r
.65028 .2048 .65553 .21738 .68124 .21588 .67619 .20328 Mtetra
.576 .775 .973 r
.67619 .20328 .68124 .21588 .70706 .21427 .70222 .20164 Mtetra
.577 .776 .973 r
.70222 .20164 .70706 .21427 .73299 .21257 .72837 .19991 Mtetra
.579 .777 .973 r
.72837 .19991 .73299 .21257 .75905 .21077 .75464 .19808 Mtetra
.58 .779 .973 r
.75464 .19808 .75905 .21077 .78521 .20889 .78102 .19616 Mtetra
.582 .78 .973 r
.78102 .19616 .78521 .20889 .8115 .20693 .80753 .19417 Mtetra
.583 .781 .974 r
.80753 .19417 .8115 .20693 .8379 .20489 .83415 .1921 Mtetra
.584 .782 .974 r
.83415 .1921 .8379 .20489 .86441 .2028 .86088 .18996 Mtetra
.585 .782 .974 r
.86088 .18996 .86441 .2028 .89104 .20064 .88774 .18776 Mtetra
.586 .783 .974 r
.88774 .18776 .89104 .20064 .91779 .19842 .91471 .1855 Mtetra
.617 .786 .963 r
.05949 .14913 .06918 .16119 .09223 .15831 .08271 .1462 Mtetra
.08271 .1462 .09223 .15831 .11538 .15542 .10603 .14327 Mtetra
.10603 .14327 .11538 .15542 .13862 .15252 .12944 .14032 Mtetra
.12944 .14032 .13862 .15252 .16194 .14961 .15293 .13737 Mtetra
.384 .659 .967 r
.15293 .13737 .16194 .14961 .18469 .15702 .17599 .14237 Mtetra
.101 .419 .866 r
.17599 .14237 .18469 .15702 .2072 .17107 .19861 .15692 Mtetra
.231 .522 .915 r
.19861 .15692 .2072 .17107 .23015 .18158 .22169 .16781 Mtetra
.318 .588 .94 r
.22169 .16781 .23015 .18158 .25344 .18956 .24511 .17606 Mtetra
.379 .633 .954 r
.24511 .17606 .25344 .18956 .27701 .19564 .26883 .18235 Mtetra
.422 .664 .961 r
.26883 .18235 .27701 .19564 .30081 .20028 .29279 .18715 Mtetra
.454 .687 .966 r
.29279 .18715 .30081 .20028 .32481 .2038 .31696 .19079 Mtetra
.478 .704 .968 r
.31696 .19079 .32481 .2038 .349 .20643 .34132 .1935 Mtetra
.497 .717 .97 r
.34132 .1935 .349 .20643 .37335 .20833 .36585 .19548 Mtetra
.512 .728 .971 r
.36585 .19548 .37335 .20833 .39786 .20965 .39054 .19684 Mtetra
.523 .736 .971 r
.39054 .19684 .39786 .20965 .42252 .21047 .41538 .1977 Mtetra
.533 .743 .972 r
.41538 .1977 .42252 .21047 .44732 .21088 .44037 .19814 Mtetra
.541 .749 .972 r
.44037 .19814 .44732 .21088 .47225 .21094 .46549 .19821 Mtetra
.548 .753 .972 r
.46549 .19821 .47225 .21094 .49731 .2107 .49074 .19798 Mtetra
.553 .758 .973 r
.49074 .19798 .49731 .2107 .5225 .2102 .51613 .19748 Mtetra
.558 .761 .973 r
.51613 .19748 .5225 .2102 .54781 .20947 .54164 .19674 Mtetra
.562 .764 .973 r
.54164 .19674 .54781 .20947 .57325 .20855 .56728 .19581 Mtetra
.565 .767 .973 r
.56728 .19581 .57325 .20855 .5988 .20745 .59304 .19469 Mtetra
.568 .769 .973 r
.59304 .19469 .5988 .20745 .62448 .20619 .61893 .19342 Mtetra
.571 .771 .973 r
.61893 .19342 .62448 .20619 .65028 .2048 .64493 .192 Mtetra
.573 .773 .973 r
.64493 .192 .65028 .2048 .67619 .20328 .67106 .19046 Mtetra
.575 .774 .973 r
.67106 .19046 .67619 .20328 .70222 .20164 .6973 .1888 Mtetra
.577 .776 .973 r
.6973 .1888 .70222 .20164 .72837 .19991 .72367 .18703 Mtetra
.579 .777 .973 r
.72367 .18703 .72837 .19991 .75464 .19808 .75015 .18517 Mtetra
.58 .778 .973 r
.75015 .18517 .75464 .19808 .78102 .19616 .77676 .18322 Mtetra
.582 .78 .973 r
.77676 .18322 .78102 .19616 .80753 .19417 .80348 .18118 Mtetra
.583 .78 .974 r
.80348 .18118 .80753 .19417 .83415 .1921 .83033 .17908 Mtetra
.584 .781 .974 r
.83033 .17908 .83415 .1921 .86088 .18996 .85729 .1769 Mtetra
.585 .782 .974 r
.85729 .1769 .86088 .18996 .88774 .18776 .88438 .17466 Mtetra
.586 .783 .974 r
.88438 .17466 .88774 .18776 .91471 .1855 .91158 .17236 Mtetra
.617 .786 .963 r
.04964 .13687 .05949 .14913 .08271 .1462 .07304 .1339 Mtetra
.07304 .1339 .08271 .1462 .10603 .14327 .09653 .13092 Mtetra
.09653 .13092 .10603 .14327 .12944 .14032 .12011 .12792 Mtetra
.12011 .12792 .12944 .14032 .15293 .13737 .14378 .12492 Mtetra
.467 .708 .973 r
.14378 .12492 .15293 .13737 .17599 .14237 .16716 .12748 Mtetra
.082 .405 .858 r
.16716 .12748 .17599 .14237 .19861 .15692 .18988 .14255 Mtetra
.218 .512 .911 r
.18988 .14255 .19861 .15692 .22169 .16781 .21308 .15381 Mtetra
.309 .582 .938 r
.21308 .15381 .22169 .16781 .24511 .17606 .23665 .16234 Mtetra
.372 .628 .953 r
.23665 .16234 .24511 .17606 .26883 .18235 .26052 .16884 Mtetra
.417 .661 .961 r
.26052 .16884 .26883 .18235 .29279 .18715 .28463 .1738 Mtetra
.45 .684 .965 r
.28463 .1738 .29279 .18715 .31696 .19079 .30897 .17756 Mtetra
.475 .702 .968 r
.30897 .17756 .31696 .19079 .34132 .1935 .33351 .18037 Mtetra
.494 .716 .97 r
.33351 .18037 .34132 .1935 .36585 .19548 .35822 .18241 Mtetra
.51 .726 .971 r
.35822 .18241 .36585 .19548 .39054 .19684 .38309 .18382 Mtetra
.522 .735 .972 r
.38309 .18382 .39054 .19684 .41538 .1977 .40812 .18472 Mtetra
.532 .742 .972 r
.40812 .18472 .41538 .1977 .44037 .19814 .4333 .18518 Mtetra
.54 .748 .972 r
.4333 .18518 .44037 .19814 .46549 .19821 .45861 .18527 Mtetra
.547 .753 .973 r
.45861 .18527 .46549 .19821 .49074 .19798 .48407 .18504 Mtetra
.552 .757 .973 r
.48407 .18504 .49074 .19798 .51613 .19748 .50965 .18454 Mtetra
.557 .761 .973 r
.50965 .18454 .51613 .19748 .54164 .19674 .53537 .1838 Mtetra
.561 .764 .973 r
.53537 .1838 .54164 .19674 .56728 .19581 .56121 .18285 Mtetra
.565 .766 .973 r
.56121 .18285 .56728 .19581 .59304 .19469 .58718 .18172 Mtetra
.568 .769 .973 r
.58718 .18172 .59304 .19469 .61893 .19342 .61328 .18042 Mtetra
.571 .771 .973 r
.61328 .18042 .61893 .19342 .64493 .192 .63949 .17898 Mtetra
.573 .773 .973 r
.63949 .17898 .64493 .192 .67106 .19046 .66583 .17741 Mtetra
.575 .774 .973 r
.66583 .17741 .67106 .19046 .6973 .1888 .6923 .17572 Mtetra
.577 .776 .973 r
.6923 .17572 .6973 .1888 .72367 .18703 .71888 .17392 Mtetra
.579 .777 .973 r
.71888 .17392 .72367 .18703 .75015 .18517 .74559 .17203 Mtetra
.58 .778 .973 r
.74559 .17203 .75015 .18517 .77676 .18322 .77242 .17004 Mtetra
.581 .779 .974 r
.77242 .17004 .77676 .18322 .80348 .18118 .79937 .16797 Mtetra
.582 .78 .974 r
.79937 .16797 .80348 .18118 .83033 .17908 .82645 .16583 Mtetra
.584 .781 .974 r
.82645 .16583 .83033 .17908 .85729 .1769 .85364 .16361 Mtetra
.585 .782 .974 r
.85364 .16361 .85729 .1769 .88438 .17466 .88096 .16133 Mtetra
.585 .783 .974 r
.88096 .16133 .88438 .17466 .91158 .17236 .9084 .15898 Mtetra
.617 .786 .963 r
.03963 .12441 .04964 .13687 .07304 .1339 .0632 .12139 Mtetra
.0632 .12139 .07304 .1339 .09653 .13092 .08686 .11836 Mtetra
.08686 .11836 .09653 .13092 .12011 .12792 .11062 .11531 Mtetra
.11062 .11531 .12011 .12792 .14378 .12492 .13447 .11226 Mtetra
.538 .747 .972 r
.13447 .11226 .14378 .12492 .16716 .12748 .15819 .11236 Mtetra
.063 .39 .85 r
.15819 .11236 .16716 .12748 .18988 .14255 .18102 .12795 Mtetra
.204 .503 .907 r
.18102 .12795 .18988 .14255 .21308 .15381 .20434 .13959 Mtetra
.3 .575 .936 r
.20434 .13959 .21308 .15381 .23665 .16234 .22804 .14839 Mtetra
.365 .624 .952 r
.22804 .14839 .23665 .16234 .26052 .16884 .25206 .1551 Mtetra
.412 .658 .96 r
.25206 .1551 .26052 .16884 .28463 .1738 .27635 .16022 Mtetra
.446 .682 .965 r
.27635 .16022 .28463 .1738 .30897 .17756 .30085 .16411 Mtetra
.472 .7 .968 r
.30085 .16411 .30897 .17756 .33351 .18037 .32556 .16701 Mtetra
.492 .714 .97 r
.32556 .16701 .33351 .18037 .35822 .18241 .35046 .16912 Mtetra
.508 .725 .971 r
.35046 .16912 .35822 .18241 .38309 .18382 .37552 .17058 Mtetra
.52 .734 .972 r
.37552 .17058 .38309 .18382 .40812 .18472 .40074 .17151 Mtetra
.53 .741 .972 r
.40074 .17151 .40812 .18472 .4333 .18518 .42611 .172 Mtetra
.539 .747 .972 r
.42611 .172 .4333 .18518 .45861 .18527 .45162 .1721 Mtetra
.546 .752 .973 r
.45162 .1721 .45861 .18527 .48407 .18504 .47727 .17188 Mtetra
.551 .757 .973 r
.47727 .17188 .48407 .18504 .50965 .18454 .50306 .17137 Mtetra
.556 .76 .973 r
.50306 .17137 .50965 .18454 .53537 .1838 .52898 .17063 Mtetra
.561 .763 .973 r
.52898 .17063 .53537 .1838 .56121 .18285 .55504 .16967 Mtetra
.564 .766 .973 r
.55504 .16967 .56121 .18285 .58718 .18172 .58122 .16852 Mtetra
.567 .768 .973 r
.58122 .16852 .58718 .18172 .61328 .18042 .60753 .1672 Mtetra
.57 .771 .973 r
.60753 .1672 .61328 .18042 .63949 .17898 .63396 .16574 Mtetra
.573 .772 .973 r
.63396 .16574 .63949 .17898 .66583 .17741 .66052 .16414 Mtetra
.575 .774 .973 r
.66052 .16414 .66583 .17741 .6923 .17572 .6872 .16242 Mtetra
.577 .776 .973 r
.6872 .16242 .6923 .17572 .71888 .17392 .71401 .16059 Mtetra
.578 .777 .973 r
.71401 .16059 .71888 .17392 .74559 .17203 .74095 .15866 Mtetra
.58 .778 .973 r
.74095 .15866 .74559 .17203 .77242 .17004 .768 .15663 Mtetra
.581 .779 .974 r
.768 .15663 .77242 .17004 .79937 .16797 .79519 .15452 Mtetra
.582 .78 .974 r
.79519 .15452 .79937 .16797 .82645 .16583 .82249 .15234 Mtetra
.583 .781 .974 r
.82249 .15234 .82645 .16583 .85364 .16361 .84992 .15008 Mtetra
.584 .782 .974 r
.84992 .15008 .85364 .16361 .88096 .16133 .87748 .14775 Mtetra
.585 .783 .974 r
.87748 .14775 .88096 .16133 .9084 .15898 .90516 .14537 Mtetra
.617 .786 .963 r
.02946 .11175 .03963 .12441 .0632 .12139 .0532 .10868 Mtetra
.0532 .10868 .0632 .12139 .08686 .11836 .07704 .10559 Mtetra
.07704 .10559 .08686 .11836 .11062 .11531 .10098 .1025 Mtetra
.10098 .1025 .11062 .11531 .13447 .11226 .12501 .09939 Mtetra
.6 .778 .966 r
.12501 .09939 .13447 .11226 .15819 .11236 .14908 .097 Mtetra
.043 .376 .842 r
.14908 .097 .15819 .11236 .18102 .12795 .172 .11311 Mtetra
.191 .493 .903 r
.172 .11311 .18102 .12795 .20434 .13959 .19545 .12513 Mtetra
.29 .569 .934 r
.19545 .12513 .20434 .13959 .22804 .14839 .2193 .13422 Mtetra
.358 .619 .951 r
.2193 .13422 .22804 .14839 .25206 .1551 .24347 .14114 Mtetra
.407 .654 .96 r
.24347 .14114 .25206 .1551 .27635 .16022 .26792 .14642 Mtetra
.442 .68 .965 r
.26792 .14642 .27635 .16022 .30085 .16411 .2926 .15043 Mtetra
.469 .698 .968 r
.2926 .15043 .30085 .16411 .32556 .16701 .31749 .15342 Mtetra
.49 .713 .97 r
.31749 .15342 .32556 .16701 .35046 .16912 .34256 .1556 Mtetra
.506 .724 .971 r
.34256 .1556 .35046 .16912 .37552 .17058 .36781 .15712 Mtetra
.519 .733 .972 r
.36781 .15712 .37552 .17058 .40074 .17151 .39322 .15808 Mtetra
.529 .74 .972 r
.39322 .15808 .40074 .17151 .42611 .172 .41879 .15859 Mtetra
.538 .747 .972 r
.41879 .15859 .42611 .172 .45162 .1721 .44451 .1587 Mtetra
.545 .752 .973 r
.44451 .1587 .45162 .1721 .47727 .17188 .47036 .15849 Mtetra
.551 .756 .973 r
.47036 .15849 .47727 .17188 .50306 .17137 .49636 .15798 Mtetra
.556 .76 .973 r
.49636 .15798 .50306 .17137 .52898 .17063 .52249 .15723 Mtetra
.56 .763 .973 r
.52249 .15723 .52898 .17063 .55504 .16967 .54875 .15625 Mtetra
.564 .766 .973 r
.54875 .15625 .55504 .16967 .58122 .16852 .57515 .15509 Mtetra
.567 .768 .973 r
.57515 .15509 .58122 .16852 .60753 .1672 .60168 .15375 Mtetra
.57 .77 .973 r
.60168 .15375 .60753 .1672 .63396 .16574 .62833 .15226 Mtetra
.572 .772 .973 r
.62833 .15226 .63396 .16574 .66052 .16414 .65511 .15063 Mtetra
.574 .774 .973 r
.65511 .15063 .66052 .16414 .6872 .16242 .68202 .14888 Mtetra
.576 .775 .973 r
.68202 .14888 .6872 .16242 .71401 .16059 .70906 .14701 Mtetra
.578 .777 .973 r
.70906 .14701 .71401 .16059 .74095 .15866 .73622 .14504 Mtetra
.58 .778 .973 r
.73622 .14504 .74095 .15866 .768 .15663 .76351 .14298 Mtetra
.581 .779 .974 r
.76351 .14298 .768 .15663 .79519 .15452 .79092 .14083 Mtetra
.582 .78 .974 r
.79092 .14083 .79519 .15452 .82249 .15234 .81847 .13861 Mtetra
.583 .781 .974 r
.81847 .13861 .82249 .15234 .84992 .15008 .84614 .13631 Mtetra
.584 .782 .974 r
.84614 .13631 .84992 .15008 .87748 .14775 .87393 .13394 Mtetra
.585 .783 .974 r
.87393 .13394 .87748 .14775 .90516 .14537 .90186 .1315 Mtetra
0 g
.89362 0 m
.98022 .38351 L
s
.98022 .38351 m
1 .65325 L
s
1 .65325 m
.91448 .33294 L
s
.91448 .33294 m
.89362 0 L
s
.02946 .11175 m
0 .4272 L
s
0 .4272 m
.91448 .33294 L
s
.91448 .33294 m
.89362 0 L
s
.89362 0 m
.02946 .11175 L
s
.02946 .11175 m
.89362 0 L
s
gsave
.44797 -0.02478 -65.9056 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(u) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
0 .4272 m
.29069 .70824 L
s
gsave
.15892 .66839 -66.3192 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(p) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{261.563, 185.125},
  ImageMargins->{{30.3125, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.095767,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000450000^A000`40O003h00Oogoo1Woo003oOol6
Ool00?moo`Ioo`00ogoo1Woo003oOol6Ool00?moo`Ioo`00PWoo1000Ogoo0021Ool01000Oomoo`00
P7oo0021Ool01000Oomoo`00P7oo0020Ool200000goo00000020Ool00?moo`Ioo`00ogoo1Woo003o
Ool6Ool00?moo`Ioo`00ogoo1Woo003oOol6Ool00?moo`Ioo`00ogoo1Woo003oOol6Ool00?moo`Io
o`00g7oo10009Goo003DOol80003Ool00`00Oomoo`0SOol00<eoo`L000]oo`03001oogoo02=oo`00
aGoo20004Woo0P0097oo002nOol7000JOol2000TOol00;Ioo`P0025oo`8002Aoo`00[goo1`00:Goo
0P0097oo002XOol7000`Ool00`00Ool0000SOol00:1oo`P003Moo`03001oo`0002=oo`00VGoo1`00
@7oo0P008goo002AOol80017Ool2000SOol008Yoo`L004moo`8002=oo`00PWoo2000EWoo00<007oo
00008Woo001kOol7001NOol00`00Ool0000ROol007=oo`P006Eoo`03001oo`00029oo`00K7oo1`00
KGoo00<007oo00008Woo001TOol8001dOol01000Oomoo`008Goo001MOol7001lOol01000Oomoo`00
8Goo001FOol70023Ool01000Oomoo`008Goo001>Ool8002:Ool01000Oomoo`008Goo0017Ool7002B
Ool01@00Oomoogoo000087oo000oOol8002IOol01@00Oomoogoo000087oo000hOol7000014/MCai:
oDlN0T/N00=:oGooOol0V7oo00D007ooOomoo`00021oo`00<7oo20000TlN00E;7TlNCai?7T/N009?
7PE;7P85NYQoo`05001oogooOol0000POol002aoo`@0000ECci;7DlNBae??T/MCai;7DlnBae?7T/M
Cci;7DlNBae??T/MBai:oDlN009;7P031GT5NPEj09Ioo`05001oogooOol0000POol002aoo`05001?
7TlNCai;7P03Cah01D/NCai?7TlNBah00dlN00E;7TlNCai?7T/N009?7PE2oP<5NP035Oaoogoo099o
o`03001oogoo009oo`03001oogoo01eoo`00;7oo01d007oo001;7DlNBae??T/MCai;7DlnBae?7T/M
Cci;7DlNBae??T/MCai;7DlnBae2oT;NA_i2oPFJ0085NP045M`Eo1GK5ObBOol01@00Oomoogoo0000
7goo000/Ool01000Ool007oo0TlN00E;7TlNCai?7T/N00=?7P05Bai?7TlNCai;7P03Cah01D/NCai?
7S[N>[h00S[N00<5VPEj1GX011Gl00<R?GooOol0SWoo00D007ooOomoo`0001moo`00;7oo024007oo
Ool004lnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??SZn>]hf_S[O>[h5VPEj
1I/00QGl00DEfbIM8SdV?B8l08eoo`05001oogooOol0000OOol002aoo`05001oogooOol00003Cah0
1D/NCai?7TlNBah00dlN00E;7TlNCai?7T/N00=?7P0=Bai?7S[N>]hj_S[N1IX9V`Ej6O`Eo1Wl5O`0
0b8m0RYmOgoo0d/N00E77T/NBai;7TLN00=;7P03Aah007oo00=oo`03001oogoo01aoo`00:goo00<0
07ooOol00goo02P004lnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??RjN<Yh^
WC:N1IX9V`Ej6O`Eo1Wl8S`VGB8m9SdZGBin:Ud^OW5oo`0HBam77T/NA_i;7dLNBai6oT/OAai;7TLN
Bam77T/NAai;7dLNBai77T/OAai;7P0017oo00<007ooOol077oo000[Ool00`00Oomoo`04Ool01@00
Cai?7TlNBah00dlN00E;7TlNCai?7T/N00=?7P06Bai?7TlNCai;7TlN12jN00X5VPVK6O`Io1Gl6O`R
?BHm8Sd^OP<ZO@03<YhbWC:N008bWU]oo`0FBai77TLNAai;7TLNBai77T/NAai;7TLNBai77T/NAai;
7TLNBai77T/NAah3Bah01DLNBai;7T/NAah00d/N00E77T/NBai;7TLN009;7P03001oogoo009oo`03
001oogoo01aoo`00:goo00<007ooOol01Goo030004lnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?
7T/MCci;7DlNBae??R9M<Yh^W@fk2IX9VaGl6QdIo2IM8S`VGB8m;WhZGBin:UdbWS9m<YhbWCJn=Ydj
_SJN=[i;Ool0=4/NA_i;7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dKnBai6oT/OAai;7TKnBam77T/N
A_i;7dLNBai6oT/OAai;7TKnBam77T/NA_i;7dLNBai77T/OAai;7TLNBam77T/NAai;7`0017oo00<0
07ooOol077oo000[Ool00`00Oomoo`05Ool00`00Bai?7P02Cah01D/NCai?7TlNBah00dlN00E;7TlN
Cai?7T/N00=?7P05BahRGB9M8UhRG@022I/02aXL6O`Io1Wl9UdR?BHm;Wd^ORYm;Wd00S:N00<bWC:N
<Yh01CJn1CZn0ckN00<jgWooOol0;Woo00Q77TKnAai6oTLNA_i77TKn0dLN00E6oTLNAai77TKn00Y7
7P05Bai77TLNAai;7P03Aah04T/NAai;7TLNBai77T/NAai;7TLNBai77T/NAai;7TLNBai77P=;7P05
Aai;7T/NBai77P03Bah01TLNBai;7T/NAah000Aoo`03001oogoo01aoo`00:goo00<007ooOol01Woo
02X004/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7BIn8UdVGPVJ3K/9VQhM
5O`J7BHm9UdR?BIM:Wd^ORYM;WhbWC:N<Yd2=Yh03cJn=Ydj_SJN=[hj_C[N>[hjgSZn?]hj_SkN>[i2
oP03?]h03D;n?]i2oSkN@_hngT;n?]i2oT;N@_i2gTKn0092oP1Q@]i6oT;nA_i2oTKo@_i6oT;nAam2
oTKn@_i77d;nAai2oTLOA_i77T;nAam6oTLNA_i77dKnAai6oT/OA_i77TKnBam6oTLNA_i;7dKnAai6
oT/OA_i;7TKnBam6oT/NA_i;7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dKnBai6oT/OAai;7TKnBam7
7T/NA_i;7dLNBai6oT/OAai;7TKnBam77T/NA_i;7dLNBai77T/OAai;7TLNBam77T/N00001Goo00<0
07ooOol06goo000[Ool00`00Oomoo`07Ool00`00Bai?7P02Cah01D/NCai?7TlNBah00dlN00E;7TlN
Cai?7T/N00=?7P04BahF7B9M8Uh23K/02QXL7Q`Io1XL9SdVGBHm9Ud^OBin0Rim0S:N00<bWC:N=[h0
13Jn00@jgSZn>[hj_P8jgP<ngP03>]hngSkN008ngP08@]hngT;n?]i2gSkN@_i2gPY2oP06A_i2oT;n
@_i6oT;n2TKn00i77TKnA_i6oTLNA_i77TKnAai6oTLNA_i77TKn0dLN00E6oTLNAai77TKn00=77P04
A_i77TLNBah3Aah01D/NAai77TLNBah00dLN01I;7TLNAai77T/NAai;7TLNBai77T/NAai;7TLNBai7
7T/NAai;7TLNBai77P=;7P05Aai;7T/NBai77P03Bah01DLNBai;7P00Aah017oo00<007ooOol06goo
000[Ool00`00Oomoo`08Ool0>000Bae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?
7QGl5QdF70fk2IX=^aWl7QdIo1hM9SdVGB8m;Wh^OBin:Wd^OS:M=YhbWCJn=Yhj_SJM>[hfWS[N>[dj
gSZn?]hj_SkN>[h2?]h04D;n?]i2gSkN@_hngT;n?]i2oT;N@_hngT;n@]i2oT;NA_h00T;n0612gTKo
@_i6oT;nA_m2oTKn@_i77d;nAai2oTLO@_i77T;nAam6oTLN@_i77dKnAai6oTLOA_i77TKnBam6oTLN
A_i;7dKnAai6oT/OA_i;7TKnBam6oT/NA_i;7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dKnBai6oT/O
Aai;7TKnBam77T/NA_i;7dLNBai6oT/OAai;7TKnBam77T/NA_i;7dLNBai6oT/OAai;7TLNBam77T/N
Aai;7`00Bah4Ool00`00Oomoo`0KOol002]oo`03001oogoo00Uoo`03001;7TlN009?7P05Bai?7TlN
Cai;7P03Cah01D/NCai?7TlNBah00dlN00<F71HM5Q`00`fk0QhL00<Io2IM9Ud00RIM0Rim00<^ORim
<Yh013:N00Hf_SZn=[hf_SZn>]h3>[h00ckN>]hngP07?]h2@]h00d;n?]i2gP02@_h00d;N@_i2oP08
@_h00dKn@_i6oP02A_h00d;nA_i6oP08A_h03TLNA_i6oTKnAai6oTLNA_i77TKnAai6oTLNA_h3Aah0
1DKnAai77TLNA_h01TLN00E;7TLNAai77T/N00=77P0FBai77T/NAai;7TLNBai77T/NAai;7TLNBai7
7T/NAai;7TLNBai77T/NAah3Bah01DLNBai;7T/NAah00d/N00=77T/NBah00T/N00<004/NOol00goo
00<007ooOol06goo000[Ool00`00Oomoo`09Ool0;`00Cai;7DlnBae?7T/MCci;7DlNBae??T/MCai;
7DlnBae?7T/MCci;7@WL1K/F7@fk4M/9VQhM6Q`N7AWl:UdV?BIM9SdbWRim;Yh^OCJn<YdfWS:M>[hf
_SZn=Yd00SZn01HjgSZm?]hj_SkN>[hngSZn@]hngT;n?]i2gSkN@_hngT;n?]i2oT;N@_hngP=2oP03
@]i6oT;n0092oP1MA_m2oTKn@_i77d;nA_i2oTLO@_i77T;nAam2oTLN@_i77dKnAai2oTLOA_i77TKn
Aam6oTLNA_i;7dKnAai6oT/OA_i;7TKnBam6oT/NA_i;7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dKn
Bai6oT/OA_i;7TKnBam77T/NA_i;7dLNBai6oT/OAai;7TKnBam77T/NA_i;7dLNBai6oT/OAai;7TLN
Bam77T/NAai;7dLNBah004/O00Eoo`03001oogoo01Yoo`00:goo00<007ooOol02Woo00<004lNBah0
0dlN00E;7TlNCai?7T/N00=?7P05Bai?7TlNCai;7P02Cah01PWK1K/9^`fk4K/=^`8N70037QdN72IM
008VG@09;Wd^ORim;Wh^OCJN<YhfWS:N008f_P05>[hf_SZn>[hjgP02>[h;?]h014;n@]i2oSkN0d;n
00=2gT;n@_h014;n00I6oT;n@_i2oTKn@_h3A_h00d;nA_i6oP04A_h04TLNA_i6oTKnAai6oTLNA_i7
7TKnAai6oTLNA_i77TKnAai6oP=77P05A_i77TLNAai6oP02Aah01D/NAai77TLNBah00dLN019;7TLN
Aai77T/NAai;7TLNBai77T/NAai;7TLNBai77T/NAah3Bah01DLNBai;7T/NAah00d/N00E77T/NBai;
7TLN00I;7P03001;7Woo00Aoo`03001oogoo01Yoo`00:goo00<007ooOol02goo03L004lNBae??T/M
Cai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBad9g0Fk2M`=^a7K3K/R?AXL7QdVGBYN9UdZGBim
<Yh^OBjN<Ydf_S:M=YhbWCZn=[hj_SJM?]hj_S[N>[dngS[N?]hj_P02?]h03T;N?]i2oSkN@]hngT;n
?]i2oSkN@_i2gT;n@]h2@_h0HDKn@]i6oT;nA_i2oTKo@_i6oT;nAam2oTKn@_i77d;nAai2oTLO@_i7
7T;nAam6oTLNA_i77dKnAai6oTLOA_i77TKnBam6oT/NA_i;7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;
7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dKnBai6oT/OAai;7TKnBam77T/NA_i;7dLNBai6oT/OAai;
7TKnBam77T/NA_i;7dLNBai77T/OAai;7TLNBal004/N00Eoo`03001oogoo01Yoo`00:Woo00<007oo
Ool03Goo0TlN00E;7TlNCai?7T/N00=?7P05Bai?7TlNCai;7P03Cah01D/NCai?7P5j1K/00Q7K00DA
^ahL7QdN71hM00<VG@0<:Ud^OBin;Wd^WS:N=YhbWSJN=[hj_SJn0SZn00@jgSZn>]hj_PXngP06@_hn
gT;n@]i2oT;N0d;n00=2gT;n@_h014;n00I6oT;nA_i2oTKn@_h3A_h00d;nA_i6oP04A_h03TLNA_i6
oTKnAai6oTLNA_i77TKnAai6oTLNA_h3Aah01DKnAai77TLNA_h00dLN00A6oTLNAai;7P=77P0FBai7
7TLNAai;7TLNBai77T/NAai;7TLNBai77T/NAai;7TLNBai77T/NAah3Bah01DLNBai;7T/NAah00d/N
00E77T/NBai;7TLN00A;7P03001;7T/N00Aoo`03001oogoo01Yoo`00:Woo00<007ooOol03Woo03=;
7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae?7T/NCai:oDlNBah1NP5i4M`A^a7L7Q`R?AhL:UdV
GBYn9UdbWRim<Yh^OCJn<Ydf_S:M=[hfWCZn=[hj_SZm?]hj_SkN>[d00ckN07<j_SkN?]i2oSkN@_hn
gT;n?]i2oSkN@_i2gT;n@]i2oT;NA_i2oTKn@]i6oT;nA_i2oTKn@_i77T;nAam2oTLN@_i77d;nAai2
oTLOA_i77T;nAam6oTLNA_i77dKnAai6oT/OA_i77TKnBam6oT/NA_i;7dKnBai6oT/OA_i;7TKnBam6
oT/NA_i;7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dLNBai6oT/OAai;7TKnBam77T/NA_i;7dLNBai6
oT/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;7P00Bam77P04Ool00`00Oomoo`0JOol002Yoo`03
001oogoo00ioo`04001?7TlNBah3Cah01D/NCai?7TlNBah00dlN0d/N00a?7T/NBah5NP5j4M/Eg17K
4M`N71hM7Q`4:Ud01S:N;Wd^ORim=YhbWP8fWP09>[hf_SZn>[hjgSZn>]hj_S[N00LngP08@]hngSkN
@]i2oSkN@_i2gPa2oP06A_i2oTKn@_i6oT;n2TKn00i77TKnA_i6oTLNA_i77TKnAai6oTLNA_i77TKn
0dLN00E6oTLNAai77TKn00I77P05Bai77TLNAai;7P03Aah04T/NAai;7TLNBai77T/NAai;7TLNBai7
7T/NAai;7TLNBai77P=;7P05Aai;7T/NBai77P03Bah01DLNBai;7T/NAah00T/N00@004/NBai;7PAo
o`03001oogoo01Uoo`00:Woo00<007ooOol03goo03@004/MCai;7DlnBae?7T/MCci;7DlNBae??T/M
Cai;7DlNBai?7T[mCah5F@5j4M/Eo17K8SdN728m9UdZGBIM:Wh^OC:N;WdbWS:M=[hbWCJn<Ydj_SJm
>[hf_SkN>[dngSZn?]hjgP<ngP1b>]i2oSkN@_hngT;n?]i2oSkN@_hngT;n@]i2oT;N@_i2gTKn@_i6
oT;NA_i2oTKn@_i6oT;nAai2oTLO@_i77T;nAam2oTLN@_i77dKnAai2oTLOA_i77TKnAam6oTLNA_i;
7dKnAai6oT/OA_i;7TKnBam6oT/NA_i;7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dKnBai6oT/OA_i;
7TKnBam77T/NA_i;7dLNBai6oT/OAai;7TKnBam77T/NA_i;7dLNBai77T/OAai;7TLNBam77T/NAai;
7dLN00177T/O17oo00<007ooOol06Goo000ZOol00`00Oomoo`0@Ool3Cah01D/NCai?7TlNBah00dlN
00E;7TlNCai?7T/N00=2oP0<@]h5NPEj5M`AfaGL5M/R?AhL8SdZGBYm0RYM00H^OC:N;WdbWSJN=[h2
=Yh2>[h01cJn>[hj_SkN>[hjgSZn00PngP06@]hngSkN@]i2oT;N34;n00A6oT;nA_i2oP=6oP03@_i6
oTKn00Q6oP0>Aai6oTKnA_i77TKnAai6oTLNA_i77TKnAai6oP=77P05A_i77TLNAai6oP02Aah01D/N
Aai77TLNBah00dLN01I;7TLNAai77T/NAai;7TLNBai77T/NAai;7TLNBai77T/NAai;7TLNBai77P=;
7P05Aai;7T/NBai77P03Bah00dLNBai;7P03Bah00`00Bai;7P04Ool00`00Oomoo`0IOol002Yoo`03
001oogoo015oo`0XCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae2ockN@_hngPVJ1GXEo17K
5O`R728m8Q`R?BYM:WhZGBYn;WdbWRim<YhbWCJn<Yd2=[h02SZn=[dj_SJn?]hj_CkN>[hngS[N13kN
06m2oSkN@_hngT;n?]i2oSkN@_i2gT;n@]i2oT;NA_i2gTKn@_i6oT;nAai2oTKn@_i77d;nAai2oTLO
A_i77T;nAam6oTLN@_i77dKnAai2oTLOA_i77TKnAam6oTLNA_i;7dKnAai6oT/OA_i;7TKnBam6oT/N
A_i;7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dLNBai6oT/OAai;7TKnBam77T/NA_i;7dLNBai6oT/O
Aai;7TKnBam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/NAah004LNBah017oo00<007ooOol06Goo
000ZOol00`00Oomoo`0BOol3Cah01D/NCai?7TlNBah00dlN00A;7TlNCai?7P@f_P<5NP035O`Eg1Gl
008R?@0>8S`R?BYM:WdZGC:N<YdbWS9m<YhfWSJn=Yhf_P@j_P03>]hngSZn008jgPPngP06@]hngT;n
@]i2oT;N2T;n00I6oT;nA_i2oTKn@_h3A_h014;nA_i6oTLN0dKn00Y77TKnA_i6oTLNA_i77TKnAai6
oP=77P05A_i77TLNAai6oP03Aah01DKnAai77TLNA_h00TLN00E;7TLNAai77T/N00=77P0BBai77T/N
Aai;7TLNBai77T/NAai;7TLNBai77T/NAai;7TLN0d/N00E77T/NBai;7TLN00=;7P05Aai;7T/NBai7
7P03Bah00`00Bai;7P05Ool00`00Oomoo`0HOol002Yoo`03001oogoo01=oo`0YCci;7DlNBae??T/M
Cai;7DlnBae?7T/MCci;7DlN<Yhf_S:n=[h5NPVJ1GXEo1GK6O`R?28m8Q`^ORYM;WhZGC:N;WdbWRim
=[hfWCJn<YdjgP02>[h01cJm>]hj_SkN>[dngSZn00@ngP1`@_hngT;n?]i2oSkN@_hngT;n?]i6oT;N
@_i2gTKn@_i6oT;NA_i2oTKn@_i77T;nA_i2oTLO@_i77T;nAam6oTLN@_i77dKnAai6oTLOA_i77TKn
Aam6oTLNA_i;7dKnAai6oT/OA_i;7TKnBam6oT/NA_i;7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dKn
Bai6oT/OAai;7TKnBam77T/NA_i;7dLNBai6oT/OAai;7TKnBam77T/NA_i;7dLNBai77T/OAai;7TLN
Bam77T/NAai;7dLN00177T/OAah4Ool00`00Oomoo`0HOol002Yoo`03001oogoo01=oo`05001?7TlN
Cai;7P03Cah01D/NCai?7TlNBah00TlN13Jn00<9V`VJ1GX00QWl014Eg28m8SdV?B8m:WdZGBYm:Udb
WS:M<YhbWCJn=Yhf_SJN00Dj_P03>]hngSZn00HngP04@]hngSkN?]h2@]h014;n@]i2oT;N1T;n00Q6
oT;n@_i2oTKn@_i6oT;n24Kn00E77TKnA_i6oTLN00=6oP06Aai6oTLNA_i77TKn0dLN00E6oTLNAai7
7TKn00Y77P05Bai77TLNAai;7P03Aah04T/NAai;7TLNBai77T/NAai;7TLNBai77T/NAai;7TLNBai7
7P=;7P05Aai;7T/NBai77P03Bah01dLNBai;7T/NAai;7P0000=;7PAoo`03001oogoo01Qoo`00:Woo
00<007ooOol057oo02X004lnBae?7T/MCci;7DlNBae??T/MCai;7DlnBadVORIM9WhVG@VK2GX9VaGl
6O`EfbHm8S`V?BYM;WhZGBin;WdbWS9m<YhfWCZn=Ydf_SJm>]h2>[h01CJm?]hj_SkN>[d013kN0712
gSkN@_hngT;n?]i2oSkN@_i2gT;n@]i6oT;N@_i2gTKn@_i6oT;nA_i2oTKn@_i77T;nAai2oTLO@_i7
7T;nAam6oTLN@_i77dKnAai6oTLOA_i77TKnBam6oTLNA_i;7dKnAai6oT/OA_i;7TKnBam6oT/NA_i;
7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dKnBai6oT/OAai;7TKnBam77T/NA_i;7dLNBai6oT/OAai;
7TKnBam77T/NA_i;7dLNBai77T/OAai;7TLNBam77T/NAah004LNBai77PAoo`03001oogoo01Qoo`00
:Woo00<007ooOol05Goo00D004lNCai?7T/N00=?7P05Bai?7TlNCai;7P02Cah01RIn9UdVORIm2I/9
VP@Io0049SdR?BHm:Wd3;Wd01C:M<YhbWC:N=Yh00cJn1CZn0ckN00<jgSkN?]h013kN00I2oSkN@]hn
gT;n@]h:@_h024Kn@_i2oT;nA_i2oTKn@_h8A_h01DLNA_i6oTKnAah00dKn00I77TKnAai6oTLNA_h3
Aah01DKnAai77TLNA_h00TLN00E;7TLNAai77T/N00=77P05Bai77TLNAai;7P03Aah03T/NAai;7TLN
Bai77T/NAai;7TLNBai77T/NAah3Bah01DLNBai;7T/NAah00d/N00=77T/NBah01D/N00<004/NBah0
0T/N0goo00<007ooOol067oo000YOol00`00Oomoo`0GOol0<P00Cci;7DlNBae??T/MCai;7DlnBae?
7T/MCci;7AHM9UdVOPfJ3K/9NQhL6O`N728l9UdR?Bin:Ud^ORYM<YhbOCJN<Ydf_SJM>[hfWCJn>[dj
gSZn>]hj_SkN>[hngSZn@_h3?]h03T;n?]i2oSkN@_i2gT;n?]i2oT;N@_i2gTKn@]h2@_h0GdKn@_i6
oT;nAai2oTKn@_i77T;nAai2oTLO@_i77T;nAam6oTLNA_i77dKnAai6oTLOA_i77TKnBam6oTLNA_i;
7dKnAai6oT/OA_i;7TKnBam6oT/NA_i;7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dLNBai6oT/OAai;
7TKnBam77T/NA_i;7dLNBai6oT/OAai;7TKnBam77T/NAai;7dLNBai77T/OAai;7TLNBam77P00Aai;
7dLNBah017oo00<007ooOol05goo000YOol00`00Oomoo`0HOol01D/NCai?7TlNBah00dlN00E;7TlN
Cai?7T/N009?7P055QdF71HM3I/=^`036O`01AhL9SdV?BHm;Wh00bim00HbWS:M<YhbWSJn=Yh2=[h5
>[h01C[N?]hngSkN>]h013kN00E2gSkN@_hngT;N0092oP03@]i2oT;n00Q2oP03A_i2oTKn0096oP03
@_i6oTKn00A6oP0BAai6oTKnA_i77TKnAai6oTLNA_i77TKnAai6oTLNA_i77TKn0dLN00E6oTLNAai7
7TKn00977P05Bai77TLNAai;7P03Aah04T/NAai;7TLNBai77T/NAai;7TLNBai77T/NAai;7TLNBai7
7P=;7P05Aai;7T/NBai77P03Bah00dLNBai;7P07Bah00`00Bai;7P02Bah4Ool00`00Oomoo`0GOol0
01Aoo`<0019oo`03001oogoo01Qoo`0`001;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBadF7A7l
4M/=VPfk6O`N71Wl9UdV?2YM9Sd^ORYM;Wh^OCJN<YdfWS:M>[hfWCZn=YdjgSZm?]hj_S[N>[hngSZn
0SkN0752oSkN@]hngT;n?]i2oSkN@_i2gT;n?]i2oT;N@_i2gTKn@]i6oT;nA_i2oTKn@_i77T;nA_i2
oTLO@_i77T;nAam6oTLN@_i77dKnAai6oTLOA_i77TKnBam6oTLNA_i;7dKnBai6oT/OA_i;7TKnBam6
oT/NA_i;7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dKnBai6oT/OAai;7TKnBam77T/NA_i;7dLNBai6
oT/OAai;7TKnBam77T/NA_i;7dLNBai77T/OAai;7TLNBam77T/NAah004LNBai77T/O00Aoo`03001o
ogoo01Moo`005Goo00<007ooOol04Goo00<007ooOol06Goo00=?7T/NCah00TlN00E;7TlNCai?7T/N
00=?7P05Bai?7PFK1K/F70024K/47Q`01BIM9SdVGBim;Wh00Rim00HbWSJN<YdbWSJn>[h2=[h5>[h:
?]h2@]h00d;n?]i2oP02@_h00d;N@_i2oP04@_h01TKn@_i6oT;nA_i2oP=6oP03@_i6oTKn00A6oP0>
Aai6oTKnA_i77TKnAai6oTLNA_i77TKnAai6oP=77P05A_i77TLNAai6oP06Aah01D/NAai77TLNBah0
0dLN019;7TLNBai77T/NAai;7TLNBai77T/NAai;7TLNBai77T/NAah3Bah01DLNBai;7T/NAah00d/N
00=77T/NBah01D/N00<004/NBah00T/N17oo00<007ooOol05goo000COol3000COol00`00Oomoo`0J
Ool09TlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??PFJ1K/=^a7K3K/N7AWl7QdVGBYM9S`ZGBim
;Wh^OC:N<YdfWS:M=YhfWCZn=Yd2>[h0NSkN>[dngSZn?]hj_SkN>]i2gSkN@_hngT;N?]i2oSkN@_hn
gT;n@]i2oSkNA_i2oTKn@]i6oT;nA_i2oTKn@_i6oT;nAai2oTKn@_i77T;nAai2oTLNA_i77T;nAam6
oTLNA_i77dKnAai6oT/OA_i77TKnBam6oT/NA_i;7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dKnBai6
oT/OA_i;7TKnBam6oT/NA_i;7dLNBai6oT/OAai;7TKnBam77T/NA_i;7dLNBai6oT/OAai;7TLNBam7
7T/NAai;7dLNBai77T/OAah004LNBam77T/NAah4Ool00`00Oomoo`0FOol0019oo`04001oogoo000C
Ool00`00Oomoo`0KOol00dlNBai?7P02Cah01D/NCai?7TlNBah00dlN00E;7PEj1GX5^a7K008A^`03
8QdN71hL008ZG@049Ud^OBim;Wh2;Wd00c:N=YhbW@02=[h01CZn=[hf_SZn>]h00SZn2CkN00I2oSkN
@]i2gT;n@]h3@_h00d;N@_i2oP04@_h01TKn@_i6oT;nA_i2oPY6oP0>Aai6oTKnA_i77TKnAai6oTLN
A_i77TKnAai6oP=77P05A_i77TLNAai6oP02Aah01D/NAai77TLNBah00dLN019;7TLNBai77T/NAai;
7TLNBai77T/NAai;7TLNBai77T/NAah3Bah01DLNBai;7T/NAah00d/N00E77T/NBai;7TLN00E;7P03
001;7T/N00=;7PAoo`03001oogoo01Ioo`004Woo00@007ooOol001=oo`03001oogoo01aoo`0^Cai;
7DlnBae?7T/MCci;7DlNBae??T/MCai;7@Ej1ET5NQ6k5M`A^b8M7Q`ZGBIM:UdV?C:N;WdbWRim=[hb
WCJN<Ydj_SJm>[hfWCkN>[hngSZm?]hjgSkN>[h2?]h0L4;N?]i2oSkN@_hngT;n?]i2oT;N@_i2gT;n
@]i6oT;nA_i2gTKn@_i6oT;nA_i2oTKn@_i77T;nA_i2oTLN@_i77T;nAam6oTLN@_i77dKnAai6oTLO
A_i77TKnBam6oTLNA_i;7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dKnBai6oT/OA_i;7TKnBam6oT/N
A_i;7dLNBai6oT/OAai;7TKnBam77T/NA_i;7dLNBai6oT/OAai;7TKnBam77T/NAai;7dLNBai77T/O
Aai;7TLN00177T/NAai;7dLN17oo00<007ooOol05Woo000COol4000BOol00`00Oomoo`0MOol00dlN
Bai?7P02Cah01D/NCai?7TlNBah014Kn0PEj00HIg17K5M/R728m7Q`4:Ud2;Wd00c9n;WdfWP02=Yh0
1CJM>[hf_SZn=[h00SZn00<ngSZn>[h01CkN00I2gSkN?]i2gT;n?]h2@]h00d;n@]i2oP07@_h014Kn
@_i6oT;n0dKn00=2oTKnA_h024Kn00i77TKnAai6oTLNA_i77TKnAai6oTLNA_i77TKn0dLN00E6oTLN
Aai77TKn00977P05Bai77TLNAai;7P03Aah04T/NAai;7TLNBai77T/NAai;7TLNBai77T/NAai;7TLN
Bai77P=;7P05Aai;7T/NBai77P03Bah00dLNBai;7P05Bah00`00Bai;7P03Bah4Ool00`00Oomoo`0F
Ool002Uoo`03001oogoo01eoo`0H001?7T/MCci;7DlNBae??T/MCai2oTLN@_i77PEi2IX5FAWl5M/E
g28L8SdR72Ym0bYM010bWRim<YhbWCJn<Ydf_S:M>[hf_CZn>[dngSZn?]hj_@<ngP1b>[i2oSkN@_hn
gT;n?]i2oSkN@_hngT;n@]i2oT;N@_i2gTKn@_i6oT;NA_i2oTKn@_i6oT;nA_i2oTLN@_i77T;nAai6
oTLNA_i77dKnAai6oTLOA_i77TKnAam6oTLNA_i;7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dKnBai6
oT/OA_i;7TKnBam6oT/NA_i;7dKnBai6oT/OAai;7TKnBam77T/NA_i;7dLNBai6oT/OAai;7TLNBam7
7T/NAai;7dLNBai77T/OAai;7TLNBam77P00Aai;7dLNBai77T/O17oo00<007ooOol05Goo000YOol0
0`00Oomoo`0NOol2Cah01D/NCai?7TlNBah00dlN13Jn0PUj00LEfaWL5M/R?B8L8SdR7003:Ud3<Wd0
0c:N=YdfWP02=Yh5>[h013[N>[hngSZn1SkN00Q2gSkN?]i2gT;n@]i2oT;N2T;n00A6oT;nA_i2oP=6
oP03@_i6oTKn00A6oP0>Aai6oTKnA_i77TKnAai6oTLNA_i77TKnAai6oP=77P05A_i77TLNAai6oP03
Aah014KnAai77T/N0dLN019;7TLNAai77T/NAai;7TLNBai77T/NAai;7TLNBai77T/NAah3Bah01DLN
Bai;7T/NAah00d/N00E77T/NBai;7TLN00I;7P03001;7T/N00=;7PAoo`03001oogoo01Eoo`00:7oo
00<007ooOol087oo01U;7DlNBae??T/MCai;7DlnBae?7S:n=[lb_SJn1GT9VQWk6O`EfbHm8Q`R?BYM
;WhZG@02;Wd043:N;WdbWSJM=[hfWCJn=[dj_SZm>[hj_CkN>[hngSjn0ckN070n_T;n?]i2oSkN@_hn
gT;n?]i2oT;N@_i2gTKn@]i6oT;NA_i2oTKn@_i77T;nA_i2oTLN@_i77T;nAai6oTLN@_i77TKnAai6
oTLOA_i77TKnBam6oTLNA_i;7dKnAai6oT/OA_i;7TKnBam6oT/NA_i;7dKnBai6oT/OA_i;7TKnBam6
oT/NA_i;7dKnBai6oT/OA_i;7TKnBam77T/NA_i;7dLNBai6oT/OAai;7TKnBam77T/NAai;7dLNBai7
7T/OAai;7TLNBam77T/NAai;7`00Bai77T/OAai;7PAoo`03001oogoo01Eoo`00:7oo00<007ooOol0
8Goo0TlN00E;7TlNCai?7T/N00=?7P<RG@033I/=VQWl00<Io0<V?@<ZG@06;WdbOC:N<Ydf_SJM0SJN
1SZn00<ngSZn?]h01CkN00Q2gSkN@]hngT;n@]i2oT;N1T;n00Q6oT;n@_i2oTKn@_i6oT;n34Kn00i7
7TKnA_i6oTLNA_i77TKnAai6oTLNA_i77TKn0dLN00E6oTLNAai;7TKn00977P05Bai77TLNAai;7P03
Aah04T/NAai77TLNBai77T/NAai;7TLNBai77T/NAai;7TLNBai77P=;7P05Aai;7T/NBai77P0<Bah0
0`00Bai;7P03Bah4Ool00`00Oomoo`0EOol002Qoo`03001oogoo029oo`0YBae?7T/MCci;7DlNBae?
?T/M8UhNGB9N7Ud=V`fJ7O`InaWl9S`ZGB8l9SdZGBin:UdbWS9m<YhbOCJn=Ydj_SJM>[hf_CZn>[dn
gSZm?]hj_P02?]h0LD;N?]hngSkN@_hngT;n?]i2oT;N@_hngTKn@]i2oT;NA_i2oTKn@]i6oT;nA_i2
oTLN@_i77T;nAai2oTLN@_i77TKnAai2oTLNA_i77TKnAai6oTLNA_i;7dKnAai6oT/OA_i77TKnBam6
oT/NA_i;7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dKnBai6oT/OAai;7TKnBam77T/NA_i;7dLNBai6
oT/OAai;7TKnBam77T/NA_i;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBah004/OAai;7TLNBal0
17oo00<007ooOol05Goo000XOol00`00Oomoo`0ROol01000Cai?7T/N0dlN00A;7TlNCah9g08RG@8A
^`043IXMo1Wl6O`39Sd032im;Ud^OC:M<YhbWC:N<Ydf_SJN=[hfWP@j_P03?]hj_SkN00LngP08@]hn
gT;N@]i2oT;N@_i2gPI2oP03A_i2oT;n0096oP03@_i6oTKn00Q6oP05Aai6oTKnA_i77P03A_h01TLN
A_i77TKnAai6oP=77P05A_i77TLNAai6oP02Aah01D/NA_i77TLNBah00dLN019;7TLNBai77T/NAai;
7TLNBai77T/NAai;7TLNBai77T/NAah3Bah01DLNBai;7T/NAah00d/N00=77T/NBah024/N00<004/N
Bah014/N17oo00<007ooOol057oo000XOol00`00Oomoo`0SOol08000Bae?7T/MCci;7DlNBae??T/M
2M`5^`WL4KXE^agl7Q`Mo2IM9S`ZGBHl;WhZGBin<WdfWS9m=YhfWCZn=Yd3>[h0NCZm>]hj_SkN>[dn
gSZn@]hngT;N?]i2oSkN@_hngT;n?]i2oT;N@_i2gTKn@]i2oT;NA_i2oTKn@]i6oT;nA_i2oTLN@_i7
7T;nAai2oTLN@_i77TKnAai6oTLNA_i77TKnBam6oTLNA_i;7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;
7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dKnBai6oT/OAai;7TKnBam77T/NA_i;7dLNBai6oT/OAai;
7TKnBam77T/NA_i;7dLNBai77T/OAai;7TLNBam77T/NAai;7`00Bai77T/OAai;7TLN00Aoo`03001o
ogoo01Aoo`00:7oo00<007ooOol097oo0dlN00Y;7TlNCai?7T/NCah9VPWL2M/Ef`8A^`048Q`Mo1gl
:Ud29Sd3;Wd02C:N<YdbWS:M<Yhf_SZn=Yhf_P04>[h2?]h00cZn?]hngP04?]h01T;n?]i2gT;N@_i2
gPY2oP03A_i2oT;n0096oP03@_i6oTKn00A6oP05Aai6oTKnA_i77P03A_h01TLNA_i77TKnAai6oP=7
7P05A_i77TLNAai6oP06Aah01D/NAai77TLNBah00dLN00i;7TLNBai77T/NAai;7TLNBai77T/NAai;
7TLN0d/N00E77T/NBai;7TLN00=;7P05Aai;7T/NBai77P08Bah00`00Bai;7P04Bah4Ool00`00Oomo
o`0DOol002Qoo`03001oogoo02Eoo`0PCci;7DlNBae??T/MCai;7Dln2GX9V`Fk6M`E^b8L7O`R7AhL
:UdV?2YM;Ud^ORiM=YhbWCJN<Wdj_SJM>[hfW@8j_P06>]hj_CkN>[hngSZm0SkN0112gSkN@_hngT;n
?]i2oSkN@_hngT;n@]i2oT;NA_i2gP92oP1NA_i2oTKn@_i77T;nA_i2oTLN@_i77T;nAai2oTLN@_i7
7TKnAai6oTLNA_i77TKnBam6oTLNA_i;7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dKnBai6oT/OA_i;
7TKnBam6oT/NA_i;7dKnBai6oT/OAai;7TKnBam77T/NA_i;7dLNBai6oT/OAai;7TKnBam77T/NAai;
7dLNBai77T/OAai;7TLNBam77T/N001;7dLNBai77T/OAah4Ool00`00Oomoo`0DOol002Qoo`03001o
ogoo02Ioo`=?7P03Bai?7T;n0092oP<9VP<Ef`<R708ZG@0=9SdZGBim<Wd^OCJN<YdfWS:M>[hf_SZn
=[h013Zn2CkN00=2gT;n?]h00T;N00=2oT;N@_h01d;n00A6oT;nA_i2oP=6oP03@_i6oTKn00A6oP0>
Aai6oTKnA_i77TKnAai6oTLNA_i77TKnAai6oP=77P05A_i77TLNAai6oP02Aah01D/NAai77TLNBah0
0dLN019;7TLNBai77T/NAai;7TLNBai77T/NAai;7TLNBai77T/NAah3Bah01DLNBai;7T/NAah00d/N
00=77T/NBah014/N1@001d/N17oo00<007ooOol04goo000XOol00`00Oomoo`0VOol04P00Cci;7DlN
Bae??SkN@_hngPfK2GXMo1Fk6M`R72Hm7O`R7@8ZG@1`:S`bORim<Wh^OCJn<YdfWSJM>[hfWCZn=Ydn
gSZn?]hj_CkN?[hngSZm@_hngT;N?]i2oSkN@_hngT;n@]i2oT;N@_i2gTKn@]i6oT;NA_i2oTKn@_i6
oT;nAai2oTKn@_i77T;nAai2oTLNA_i77T;nAai6oTLNA_i77TKnAai6oT/OA_i77TKnBam6oT/NA_i;
7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dKnBai6oT/OA_i;7TKnBam77T/NA_i;7dLNBai6oT/OAai;
7TKnBam77T/NA_i;7dLNBah:000034LNBai77T/O001;7TLNBam77T/NAai;7`Aoo`03001oogoo01=o
o`00:7oo00<007ooOol09goo015;7TlNCai?7T/NCahZOT;n4IXEVPVJ7O`IfaGK8Q`V?B8L00@ZG@8b
O@05<WhfWCJN=YdfWP09>[h6?]h01D;N?]i2gT;N@_h00T;N0T;n00=2gT;n@_h014;n00I6oT;nA_i2
oTKn@_h:A_h03TLNA_i6oTKnAai6oTLNA_i77TKnAai6oTLNA_h3Aah01DKnAai77TLNA_h00TLN00E;
7TLNAai77T/N00=77P0?Bai77T/NAai;7TLNBai77T/NAai;7TLNBai77T/N00T00003Bai77T/N009;
7P03Aai;7T/N00M;7P03001;7T/N00A;7PAoo`03001oogoo01=oo`00:7oo00<007ooOol0:7oo01=;
7DlnBae?7T/M:YhVOBYn4IXE^aWK7O`IfbHm8Q`V?B8L;WdZG@02;Wd043:N;WdbWSJM=[hfWCJn=Ydj
_SJm>[hj_CkN>[hngSjm13kN00a2oSkN@]hngT;n?]i2oSkN@_i2gT;n@]h2@_h0>4Kn@]i6oT;nA_i2
oTKn@_i6oT;nAai2oTKn@_i77TKnAai2oTLNA_i77TKnAai6oTLNA_i77TKnAai6oT/OA_i;7TKnBam6
oT/NA_i;7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dKnBai6oT/OA_h:00007d/OAai;7TKnBam77T/N
A_i;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77P00Aai;7TLNBam77T/N00Aoo`03001oogoo
01=oo`009goo00<007ooOol0:Woo00E;7TlNCai?7T/N008ZOP0:6M/I^aFJ8O`Mo1WK9SdV?2Hm9S`3
;Ud3<Wd013JN=YdfWSJM13Zn00@ngSZn?[hj_PHngP08@]hngT;N?]i2oT;N@_i2gP=2oP04@]i2oT;n
A_h3@_h00dKn@_i6oP02A_h00d;nA_i6oP08A_h03TLNA_i77TKnAai6oTLNA_i77TKnAai6oTLNA_h3
Aah01DKnAai77T/NA_h00TLN00=;7TLN0000200000M77T/NAai;7TLNBai77P03Bah01DLNBai;7T/N
Aah00d/N00E77T/NBai;7TLN00=;7P03Aai;7T/N00E;7P03001;7T/N00A;7PAoo`03001oogoo01=o
o`009goo00<007ooOol0:goo02E;7DlnBae?7QGK5O`VOAWK6KXMfagk8Q`MnbXm9S`Z?BiM<WdZGC:N
<WdfWS9m=[hfWCJn=Ydj_SJm>[hj_CkN>[dngSZn?]hn_@02?]h0=4;n?]i2oSkN@_hngT;n?]i2oT;N
A_i2gT;n@]i6oT;nA_i2gTKn@_i6oT;nA_i2oTKn@_i77T;nAai2oTLNA_i77TKnAai6oTLNA_i;7TKn
Aai6oT/NA_i77TKnBai6oT/NA_i;7dKn2@0003=6oT/OA_i;7TKnBam6oT/NA_i;7dKnBai6oT/OAai;
7TKnBam77T/NA_i;7dLNBai6oT/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBam77P00Aai;
7dLNBai77T/OAah017oo00<007ooOol04Woo000WOol00`00Oomoo`0[Ool00dlNBai?7P02Cah25O`0
11Vk6M/I^bHL0R7l00hZ?2Xm9S`V?BiM;Wd^GC:N<WdbWC9m=[hfWCJN1CZn00@ngSZn?]hn_P@ngP04
@]hngT;N?]h2@]h014;n@]i2oT;N1T;n00I6oT;nA_i2oTKn@_h:A_h02DLNA_i6oTKnAai6oTLNA_i7
7P0:00000dLNBai6oP02Aah05T/NAai77TLNBai77T/NAai;7TLNBai77T/NAai;7TLNBai77T/NAai;
7TLN0d/N00E77T/NBai;7TLN00=;7P03Aai;7T/N00a;7P03001;7T/N00A;7PAoo`03001oogoo019o
o`009goo00<007ooOol0;7oo00/004KnBai6oRGK8KXEo1gK6M/I^RHL008R700E:S`ZGBXl;Wd^GC9m
;UdfWS9m=YhfWCZn=Ydj_SZm>[hj_Cjn>[dngSZm00<ngP0R?[e2gSkN@_hngT;n?]i2oSkN@_i2gT;n
@]i6oT;N@_i2gTKn@_i6oT;NAai2oTKn@_i77T;nAai2oTLNA_i77T;nAah90000ATLNA_i;7TKnAai6
oT/OA_i;7TKnBam6oT/NA_i;7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dLNBai6oT/OAai;7TKnBam7
7T/NA_i;7dLNBai6oT/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/NAai;7`00Bai7
7T/OAai;7TLN17oo00<007ooOol04Woo000WOol00`00Oomoo`0]Ool02CYL=Ua6oTKn8MXQ^R7J8M/Q
n`039Q`03RYM:S`Z?BXm<Wd^OC9m<YdfWS:M=YdfWSZn=Yd5>[h00cjn?]hn_P06?]h024;N?]i2gT;N
@_i2gT;n@]h4@_h01TKn@_i2oT;nA_i2oP96oPX00096oP0:Aai6oTKnA_i77TKnAai6oTLNA_h3Aah0
1DKnAai77TLNA_h00TLN00E;7TKnAai77T/N00=77P0>Bai77T/NAai;7TLNBai77T/NAai;7TLNBai7
7P=;7P05Aai;7T/NBai77P03Bah01DLNBai;7T/NAah034/N00<004/NBah014/N17oo00<007ooOol0
4Woo000WOol00`00Oomoo`0^Ool02CYL=U/jO26j9M/Q^RXL7M/Qn`029Q`05b8L;UdZ?2iM;WdbOBiM
<WhfWCJN<WdfWSJM>[hfWCZn>[dn_SZm?]hn_SkN>[d00SkN00i2gSkM@]hngT;n?]i2oT;N@_i2gT;n
@]i6oT;N2@0005Y2oTKn@_i77T;nAai2oTLNA_i77T;nAai6oTLNA_i77TKnAai6oT/NA_i;7TKnBai6
oT/NA_i;7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dKnBai6oT/OA_i;7TKnBam77T/NA_i;7dLNBai6
oT/OAai;7TKnBam77T/NA_i;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;7P00Bam7
7T/NAai;7dLNBah4Ool00`00Oomoo`0AOol002Moo`03001oogoo02ioo`8jG00:=U`]nbWk8MXQ^RHL
9Q/Z?2XL:S`2;Ud00bYM;UdbO@03<Wd013JM=YhfWCJM0SZn00<j_CZn>[h00SZn0ckN00@n_SkN?]i2
gP8ngPX000=2oP06A_i2oTKn@_i6oT;n2TKn00E77TKnA_i6oTLN00=6oP03Aai6oTLN00977P05A_i7
7TLNAai6oP03Aah014KnAai77T/N0dLN019;7TLNAai77T/NAai;7TLNBai77T/NAai;7TLNBai77T/N
Aah3Bah01DLNBai;7T/NAah00d/N00=77T/NBah03D/N00<004/NBah014/N17oo00<007ooOol04Goo
000WOol00`00Oomoo`0_Ool03chI>U`fFbhK:OX^6bGk:Q`UnbXl9Q`Z?BiM<Wd^G004<Wd02cZn=Ydf
WSJM>[hfWCZn=YdngSZm?]h02@0006e2oSkN@_hngT;n@]i2oT;N@_i2gTKn@]i6oT;NA_i2oTKn@_i6
oT;nAai2oTKn@_i77TKnAai6oTLNA_i77TKnAai6oTLNA_i77TKnAai6oT/NA_i;7TKnBai6oT/NA_i;
7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dKnBai6oT/OAai;7TKnBam77T/NA_i;7dLNBai6oT/OAai;
7TKnBam77T/NA_i;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/OAah004LNBam77T/NAai;
7`05000COol002Moo`03001oogoo02moo`0;?SXn6Shj:O/]nbWk;S`^72HL9Q/^?@02;S`01BiM<Ud^
GCJM=Wd00S9m2P0000<n_SkN?]h00ckN00A2gSkN@]hngP92gP03@_i2gT;n0092oP03@]i2oT;n00A2
oP03A_i2oTKn0096oP03@_i6oTKn00Q6oP0:Aai6oTKnA_i77TKnAai6oTLNA_h3Aah01DKnAai77TLN
A_h01TLN01I;7TLNAai77T/NAai;7TLNBai77T/NAai;7TLNBai77T/NAai;7TLNBai77P=;7P05Aai;
7T/NBai77P03Bah00dLNBai;7P0;Bah00`00Bai;7P04Bah4Ool00`00Oomoo`0AOol002Moo`03001o
ogoo031oo`0:@SXn6Chj<Q/^6bWj;S`Z6bhl:S`90000PCJM>[hfWCJN>Ydj_SZm>[hj_CkN>[dngSjm
?]hn_SkN?]e2oSkN@]hngD;n?]i2oSkNA_i2gT;n@]i6oT;nA_i2gTKn@_i6oT;nA_i2oTKn@_i77T;n
Aai2oTLNA_i77TKnAai6oTLNA_i;7TKnAai6oT/NA_i77TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKn
Bam6oT/NA_i;7dKnBai6oT/OA_i;7TKnBam77T/NA_i;7dLNBai6oT/OAai;7TKnBam77T/NA_i;7dLN
Bai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLN00177T/NAai;7dLNBai77P03Ool00`00
Oomoo`0AOol002Moo`03001oogoo031oo`X00003<U`^?Bhl00@bO@08=YdfOCJM=YdjWSJM>[hj_@@j
_P8n_PHngPA2gP04@_i2gT;n@]h6@_h01TKn@_i6oT;nA_i2oPY6oP0>Aai6oTKnA_i77TKnAai6oTLN
A_i77TKnAai6oP=77P05A_i77TLNBai6oP02Aah04T/NAai77TLNBai77T/NAai;7TLNBai77T/NAai;
7TLNBai77P=;7P05Aai;7T/NBai77P03Bah00dLNBai;7P0BBah00`00Bai;7P04Bah3Ool00`00Oomo
o`0AOol002Ioo`03001oogoo02Qoo`T0002DBUY6FDYJAUTf>c8K=S/b?2hl:Q/bGBiL<UdbG39m<Udb
OCIm=YhfOCZn=Ydj_SJM?[hj_Cjn>[dn_SZm?]hn_CkN?[e2gSkN@]hngD;n?]i2gSkM@_i2gT;n@]i6
oT;N@_i2gTKn@_i6oT;NA_i2oTKn@_i77T;nA_i2oTLNA_i77T;nAai6oTLNA_i77TKnAai6oT/NA_i7
7TKnBai6oTLNA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;
7dLNBai6oT/OAai;7TKnBam77T/NA_i;7dLNBai6oT/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;
7TLNBam77T/N001;7dLNBai77T/OAah3Ool00`00Oomoo`0AOol002Ioo`03001oogoo01moo`T000Uo
o`07AUY:FTIIAUXjFciK<Q/00S8l00HbG2iL<UdbG39M<Wd2=Wd4=Yd01SZn>Ydj_SZM>[hj_@8j_P05
?]hn_SkN?[i2gP03?]h02T;N?]i2gT;N@_i2gT;n@]i2oT;N1T;n00=6oT;nA_h00TKn00=2oTKnA_h0
24Kn00i77TKnA_i6oTLNA_i77TKnAai6oTLNA_i77TKn0dLN00E6oTLNAai;7TKn00977P0BBai77TLN
Aai;7TLNBai77T/NAai;7TLNBai77T/NAai;7TLN0d/N00E77T/NBai;7TLN00=;7P03Aai;7T/N011;
7P03001;7T/N00A;7P=oo`03001oogoo015oo`009Woo00<007ooOol05Goo2P004goo00U6FDYJAUU:
FSXk?U/j>cIL<S`00S9L01@fOC9L=WdbOCJM<WdjWSJM>YhfWCZn=Ydj_SZM?[hj_CkN>[dngSjm0SkN
07=2gSjm@]hngT;n?]e2oSkN@_i2gD;n@]i6oT;NA_i2gTKn@]i6oT;nA_i2oTKn@_i6oT;nAai2oTKn
@_i77TKnAai2oTLNA_i77TKnAai6oTLNA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/O
A_i;7TKnBam6oT/NA_i;7dLNBai6oT/OAai;7TKnBam77T/NA_i;7dLNBai6oT/OAai;7TKnBam77T/N
Aai;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/OAah004LNBam77T/NAai;7`02Ool00`00
Oomoo`0AOol002Ioo`03001oogoo00aoo`T001eoo`96FP0FBUY6FCiK>U/nFcIL>U`fG3YL<U`fOCIM
=YdfOCJM=WdjWCJM>YdfWCZn>[d2>[h00cjn>[dn_P02?]h01cjn?]hngT;N?]i2gSkN00A2gP03@_i2
gT;n00E2oP06A_i2oTKn@_i6oT;n3TKn00Y77TKnAai6oTLNA_i77TKnAai6oP=77P05A_i77TLNAai6
oP02Aah05T/NAai77TLNBai77T/NAai;7TLNBai77T/NAai;7TLNBai77T/NAai;7TLN0d/N00E77T/N
Bai;7TLN00=;7P03Aai;7T/N00m;7P03001;7T/N00A;7P=oo`03001oogoo011oo`009Woo00<007oo
Ool00Woo2P009Woo0156FDYJAUU:FSXk?U`j>ciK=U`jO3IL>WdfO3Im<U`jWCIm008jW@21>[hfWCZn
>Ydj_SZM?[hj_CkN>[dngSjm@]hn_D;N?]i2gSkM@]hngT;n?]e2oT;N@_i2gDKn@]i6oT;NA_i2gTKn
@]i6oT;nA_i2oTLN@_i6oT;nAai6oTLNA_i77TKnAai6oTLNA_i77TKnBai6oTLNA_i;7TKnBai6oT/N
A_i;7TKnBai6oT/NA_i;7TKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dLNBai6oT/OAai;7TKnBam77T/N
A_i;7dLNBai6oT/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77P00
Aai;7TLNBam77T/N00=oo`03001oogoo011oo`009Woo1@00<7oo00ABNTiiCWY>N@A2N`0;>U`fG3YL
=U`jOCIl>WdfOCJM=WdfW@04>Yd00cZm?[hj_@03?[h00cjm?]hngP02?]h3@]h02CkN@]i2gT;n@]i2
oT;N@_i2gP02@_h01TKn@_i2oT;nA_i2oPY6oP05Aai6oTKnA_i77P03A_h01TLNA_i77TKnAai6oP=7
7P05A_i77TLNBai6oP02Aah01D/NAai77TLNBah00dLN00i;7TLNBai77T/NAai;7TLNBai77T/NAai;
7TLN0d/N00E77T/NBai;7TLN01M;7P03001;7T/N00A;7P=oo`03001oogoo011oo`009goo00<007oo
Ool0<Woo00iBVTiiDYY>ND9k@U]6O49K?W`jO3il=W`jOCIl0SYm08@jWCIm>[hjWCZn=Ydn_SZm?[hj
WCkN?[dngSjm@]hngD;N?[e2oSkN@]hngD;n@]i2oSkMA_i2gT;n@]e6oT;NA_i2gTKn@_i6oT;nA_i2
oTKn@_i77T;nAai2oTLNA_i77TKnAai6oTLNA_i;7TKnAai6oT/NA_i77TKnBai6oT/NA_i;7TKnBai6
oT/NA_i;7TKnBai6oT/NA_i;7dKnBai6oT/OA_i;7TKnBam77T/NA_i;7dLNBai6oT/OAai;7TKnBam7
7T/NA_i;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/N001;7dLNBai7
7T/OAah2Ool00`00Oomoo`0@Ool002Qoo`03001oogoo035oo`04CWUBNTiiCWX4@W/2?W`01CYl?W`j
OCZM>W`013ZM00Pj_CZM>[djWCjn?[dn_Sjm0Sjn00HngSjm?]hngT;N?]h6@]h00d;n@]i2oP02@_h0
1D;N@_i2oTKn@_h00dKn00=2oTKnA_h024Kn00E77TKnA_i6oTLN00=6oP06Aai6oTLNA_i77TKn0dLN
00E6oTLNAai;7TKn00977P0BBai77TLNAai;7TLNBai77T/NAai;7TLNBai77T/NAai;7TLN0d/N00E7
7T/NBai;7TLN00=;7P03Aai;7T/N01A;7P03001;7T/N00A;7P9oo`03001oogoo011oo`00:Goo00<0
07ooOol0<7oo09AF^UJIEYUFVEJjAW]:VdIkBY/nO4:L?W`nWCYl?YdjO3jm>YdnWCZM?[hjWCjn>Ydn
_SZm?[hn_D;N?[e2gSjm@]hngD;N?]e2oSkN@]i2gD;n@]i2oT;MA_i2gTKn@]e6oT;nA_i2gTKn@_i6
oT;nAai2oTKn@_i77TKnAai2oTLNA_i77TKnAai6oTLNA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;
7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/OA_i;7TKnBam77T/NA_i;7dLNBai6oT/OAai;
7TKnBam77T/NA_i;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBal004/NAai;
7dLNBai77P9oo`03001oogoo011oo`00:Woo00<007ooOol0<7oo15JI0dZK00E6Nd:L@Ya2W49l00<n
W@04?Y`jWCZM?Yd3?[d023jn?[dn_Sjm?[hn_CkN?[h2?]h00d;N?]i2gP05@]h014;n@]i2oT;N0T;n
00I6oT;nA_i2oTKn@_h3A_h00d;nA_i6oP08A_h03TLNA_i6oTKnAai6oTLNA_i77TKnAai6oTLNA_h3
Aah014KnAai77T/N0dLN00i;7TLNBai77T/NAai;7TLNBai77T/NAai;7TLN0d/N00E77T/NBai;7TLN
00=;7P05Aai;7T/NBai77P0DBah00`00Bai;7P05Bah00goo001oo`0AOol002]oo`03001oogoo02mo
o`03EYUF^UJI009FV@0eBY]6NdZKAW]2W3il@Y`nW4:M?Y`nWCjL?[dnWCjm>Ydn_SZM?[hn_D;N?[dn
gSjm@]hn_D;N?]e2gSkM@_hngD;n@]i2oT;MA_i2gT;n@]e6oT;NA_i2gTKn@_i6oT;nA_i2oTKn@_i7
7P02A_h0FT;nAai6oTLNA_i77TKnAai6oTLNA_i77TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6
oT/NA_i;7TKnBai6oT/NA_i;7TKnBam6oT/NA_i;7dLNBai6oT/OAai;7TKnBam77T/NA_i;7dLNBai6
oT/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77P00Aai;7TLNBcm7
7T/NOol0019oo`00;7oo00<007ooOol0;goo0UJI0UZi0djK00=>^dJLAY`00TJL00<nW3jM?Yd00SjM
00<n_CjM?[d00cjm00Hn_Sjm?[hn_D;N?[d2?]h8@]h014;n@]i2oT;N0T;n00A6oT;nA_i2oQ96oP0:
Aai6oTKnA_i77TKnAai6oTLNA_h2Aah01T/NA_i77TLNBai6oP977P0BBai77TLNAai;7TLNBai77T/N
Aai;7TLNBai77T/NAai;7TLN0d/N00E77T/NBai;7TLN00=;7P03Aai;7T/N01E;7P03001;7T/N00A;
7P03Ool007oo015oo`00;Goo00<007ooOol0;Woo09EN^EZHG[UJ^EjiBYY>^djKC[]2W4Jl@Ya6_3jL
@[e2W4:m?Ye2_CjM?[hn_D:n?[e2gSjm@]hn_D;N?[e2gSjm@]hngD;n@]i2oT;M@_i2gTKn@]e6oT;N
A_i2gDKn@]i6oT;NA_i2oTKn@_i77T;nA_i2oTLNA_i77TKnAai6oTLNA_i;7TKnAai6oT/NA_i77TKn
Bai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBam6oT/NA_i;7dLN
Bai6oT/OAai;7TKnBam77T/NA_i;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLN
Bam77T/NAai;7dLN00177T/oAai;7TLNBcmoo`00019oo`00;Woo00<007ooOol0;Goo1EZi00A>^djK
CY]>V`A6W00?@[e2W4:M@Ye2_Cjm@[dn_D:m?[e2_Cjm@]hn_Cjn0092gP03?]e2gT;N00A2gP06@_i2
gT;N@]i6oT;N0T;n00I6oT;nA_i2oTKn@_h>A_h03TLNA_i6oTKnAai6oTLNA_i77TKnAai6oTLNA_h2
Aah01T/NA_i77TLNBai6oP977P0>Bai77T/NAai;7TLNBai77T/NAai;7TLNBai77P=;7P05Aai;7T/N
Bai77P03Bah00dLNBai;7P0HBah00`00Bai;7P03Bah00goo001oo`0AOol002moo`03001oogoo02eo
o`2@F[UN^EZHH]UB^U:kD[YB^e:jB[a6VdZlAYa6_D:LA[dnWD:m?Ye2_Cjm@[hn_D;N?[e2gSjm@]i2
gD;N?[e2gT;M@_i2gD;n@]i2oT;MA_i2gTKn@]e6oT;NA_i2gDKn@_i6oT;NA_i2oTKn@_i77T;nAai2
oTLNA_i77TKnAai6oTLNA_i;7TKnAai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6
oT/NA_i;7TKnBai6oT/NA_i;7TKnBam77T/NA_i;7dLNBai6oT/OAai;7TKnBam77T/NAai;7dLNBai7
7T/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/NAai;7`00Bai77T/o0T/N00=oo`00
Ool04Goo000`Ool00`00Oomoo`0/Ool01EZiG[QRfEjhG]T00U:k00=B^U:kB[`00dZl00A2_DJm@[a6
_@E2_@06@]e2_D;N@[e2gSjm0d;N00=2gD;N@]h014;N00I2oT;N@_i2oTKn@]h3A_h00d;nA_i6oP0<
A_h01DLNA_i6oTKnAah00dKn00I77TKnAai6oTLNA_h3Aah01DKnAai77T/NA_h00TLN00i;7TLNBai7
7T/NAai;7TLNBai77T/NAai;7TLN0d/N00E77T/NBai;7TLN00=;7P03Aai;7T/N01Y;7P03001;7T/N
00A;7P03001oogoo011oo`00<Goo00<007ooOol0:goo019N^6;IG[QRfEjhE]]F^UKKE[YFfdZkC]a:
^dkLA[a:gDJl@]d3@[d08D;N@[e2gSjm@]i2_D;N@[e2gT;M@]i2gD;N@]e6oT;MA_i2gTKn@]e6oT;N
A_i2gDKn@_i6oT;MA_i2oTKn@_e77P02A_h0ET;nAai6oTLNA_i77TKnAai6oT/NA_i77TKnBai6oT/N
A_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TLNBai6oT/N
Aai;7TKnBam77T/NA_i;7dLNBai6oT/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/N
Aai;7dLNBai77T/OAai;7P00Bal2Bah014LNBcm;7P004Woo000bOol00`00Oomoo`0ZOol02V;IG[QN
fEjhH]QF^UKJE[YFfeJj0djl00U:_4JmA[e6_DJlA[e2_DKM@[d014;M00A2gT;M@]i2g@=2gP03@]e2
gT;N0092gP08@_i2gTKn@]i6oT;nA_i2oP=6oP03@_i6oTKn00a6oP0>Aai6oTKnA_i77TKnAai6oTLN
A_i77TKnBai6oP977P05Bai6oTLNAai;7P03Aah02T/NAai;7TLNBai77T/NAai;7TLN0d/N00E77T/N
Bai;7TLN00=;7P03Aai;7T/N01e;7P03001;7T/N00=;7P03Ool007oo011oo`00<goo00<007ooOol0
:Woo03MRfEjhI]URf6KHE[YFfeJjE]]F^TkLB[]>g4ZkB]e6_4[MA[a6gD:mA]e2_DKN@[e6gT:mA]i2
gDKN@[e6oT;MA]i2gDKn@]e6oT;MA_i2gDKn@]e6oT;NA_i2gDKn@_i6oT;mA_i2oTKn@_e77P02A_h0
ET;nAai6oTLNA_i;7TKnAai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;
7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TLNBai6oT/OAai;7TKnBam77T/NA_i;7dLNBai6oT/OAai;
7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/oBah004LNBcl2Bah00dLN
Bcl0000AOol003Aoo`03001oogoo02Uoo`03G[QRf6;H009Rf0EJfP09C[]>g4kLD]a>^d[MB[a:gDZl
00=6g@09A[e6gDKMA]e2gD;N@]e2gT;M00I2gP06A_i2gTKn@_i6oT;n5TKn00Y77TKnAai6oTLNA_i7
7TKnAai6oP977P06Bai6oTLNAai;7TKn0TLN00i;7TLNBai77T/NAai;7TLNBai77T/NAai;7TLN0d/N
00E77T/NBai;7TLN00=;7P03Aai;7T/N01];7P03001;7T/N00A;7P03001oogoo00moo`00=Goo0P00
:Goo00UVfF;HI]QRf6KhI]MJfUKJF]/00U[J02E>^e;LC[]Bg4JlB]e:_4[MA[e6gDJmA]e2_DKN@]e6
gT;MA]i2gDKN@]e6oT;MA_i2gDKn@]e6oT;MA_i2gDKn@]e6oT;nA_i2o@03A_h00d;mAai6oP02A_h0
CDLNA_i77TKnBai6oTLNA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6
oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TLNBai6oT/OAai;7TKnBam77T/NA_i;7dLNBai7
7T/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBal01goo00<007ooOol017oo00<007ooOol0
3goo000gOol00`00Oomoo`0VOol3H]P00fKhI]QVf005F]X03E;LD]]Bg5;KD]a:g4kLB]a>gDKMB]e6
gD[M00M6g@0:A]i2gDKN@]i6oT;NA_i6gTKn@]hFA_h03TLNA_i6oTKnAai6oTLNA_i77TKnAai6oT/N
A_h2Aah05T/NA_i77TLNBai6oT/NAai;7TLNBai77T/NAai;7TLNBai77T/NAai;7TLN0d/N00E77T/N
Bai;7TLN00];7QEoo`03001oogoo00=oo`03001oogoo00moo`00>7oo00<007ooOol09Woo02eRf6KI
I]MVn6KGI_QJfUkjF]UNnU[JD]aBfeKLD]]>gDZlC]e:g4[MA[a:gDKMA]i6gDKNA]e6oT;MA_i2gDKn
@]e6oT;MA_i2gDKn@]e6oT;MA_i2gDKn@]d00dKn00I2oDKnA_i6oTKmAah3A_h0:D/NA_i77TKnBai6
oTLNA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6
oT/NAai;7TKnBah0:Woo00<007ooOol00goo00<007ooOol03goo000iOol00`00Oomoo`0UOol01V;H
I]QVf6KHI_QVe`9NfP03G_YJfUkJ01Aoo`03A]i6oTKM0096gP03A_i6gTKn01E6oP05Aai6oTKnA_i7
7P03A_h01TLNA_i77TKnBai6oP977T1oo`03001oogoo00=oo`03001oogoo00moo`00>Woo00<007oo
Ool097oo00UVefKhI]MVn6KGJ_QVeekjF]X0Pgoo00<007ooOol00goo00<007ooOol03goo000kOol0
0`00Oomoo`0TOol01VKHI_QVf6[gI_MZn8Ioo`03001oogoo009oo`03001oogoo00moo`00?7oo00<0
07ooOol08goo00EVn6KGJ_QVef[h08Moo`03001oogoo009oo`03001oogoo00moo`00?Goo00<007oo
Ool08goo00AZmfKgJ_QVehMoo`03001oogoo009oo`03001oogoo00moo`00?Woo00<007ooOol08Woo
00=Vef[hI]L0RGoo00D007ooOomoo`00015oo`00?goo00<007ooOol08Woo00=VegooOol0R7oo00D0
07ooOomoo`00015oo`00@7oo00<007ooOol08Goo00=Zn7ooOol0R7oo00D007ooOomoo`00015oo`00
@Goo00<007ooOol087oo00<007ooOol0R7oo00<007ooOol00Woo00<007ooOol03Woo0012Ool00`00
Oomoo`0OOol00`00Oomoo`29Ool01@00Oomoogoo000047oo0013Ool00`00Oomoo`0NOol00`00Oomo
o`29Ool01@00Oomoogoo000047oo0014Ool00`00Oomoo`0MOol00`00Oomoo`29Ool01@00Oomoogoo
000047oo0015Ool00`00Oomoo`0LOol00`00Oomoo`29Ool01@00Oomoogoo000047oo0016Ool00`00
Oomoo`0KOol00`00Oomoo`2:Ool01000Oomoo`0047oo0017Ool00`00Oomoo`0IOol00`00Oomoo`2;
Ool01000Oomoo`0047oo0018Ool00`00Oomoo`0HOol00`00Oomoo`2;Ool01000Oomoo`0047oo0019
Ool00`00Oomoo`0GOol00`00Oomoo`2<Ool00`00Ool0000@Ool004Yoo`03001oogoo01Ioo`03001o
ogoo08aoo`03001oo`00011oo`00Bgoo00<007ooOol05Goo00<007ooOol0S7oo00<007oo000047oo
001<Ool00`00Oomoo`0DOol00`00Oomoo`2<Ool00`00Ool0000@Ool004eoo`03001oogoo01=oo`03
001oogoo08eoo`80011oo`00CWoo00<007ooOol04Woo00<007ooOol0SGoo0P0047oo001?Ool00`00
Oomoo`0AOol00`00Oomoo`2=Ool00`00Ool0000?Ool0051oo`03001oogoo011oo`03001oogoo08eo
o`03001oo`0000moo`00DGoo00<007ooOol03goo00<007ooOol0SWoo0P003goo001BOol00`00Oomo
o`0>Ool00`00Oomoo`2>Ool2000?Ool005=oo`8000ioo`03001oogoo08ioo`8000moo`00EGoo00<0
07ooOol02goo00<007ooOol0SWoo0P003goo001FOol00`00Oomoo`0:Ool00`00Oomoo`2?Ool00`00
Oomoo`0=Ool005Moo`03001oogoo00Uoo`03001oogoo08Uoo`L000moo`00F7oo00<007ooOol027oo
00<007ooOol0Ngoo3P005Woo001IOol00`00Oomoo`07Ool00`00Oomoo`1^Ool=000TOol005Yoo`03
001oogoo00Eoo`03001oogoo069oo`d0035oo`00Fgoo00<007ooOol017oo00<007ooOol0E7oo3P00
?Woo001LOol00`00Oomoo`03Ool00`00Oomoo`17Ool=001<Ool004Aoo`<001Ioo`03001oogoo009o
o`03001oogoo03Yoo`d005Uoo`00AGoo00<007ooOol05Woo00D007ooOomoo`0002ioo`h006Ioo`00
AGoo0`005goo00@007ooOol0025oo`d007Aoo`00AGoo00@007ooOol001Moo`03001oo`0001Aoo`d0
085oo`00AGoo00@007ooOol001Qoo`8000Ioo`h008ioo`00A7oo10006Woo1`00W7oo003oOol6Ool0
0?moo`Ioo`00ogoo1Woo003oOol6Ool00?moo`Ioo`00ogoo1Woo003oOol6Ool007aoo`800003Ool0
0000009oo`@000=oo`8000Aoo`8000Aoo`8000Aoo`8006Moo`00OGoo00<007oo00002Goo00@007oo
Ool000Qoo`04001oogoo0002Ool01000Oomoo`00IWoo001nOol00`00Oomoo`02Ool40002Ool01000
Oomoo`0027oo00@007ooOol000Aoo`03001oogoo06Eoo`00O7oo0P0000=oo`00000027oo00@007oo
Ool000Qoo`04001oogoo0005Ool00`00Oomoo`1TOol008Uoo`04001oogoo0008Ool01000Oomoo`00
0Woo00@007ooOol006Ioo`00RWoo0P002Woo0P0017oo0P00Igoo003oOol6Ool00?moo`Ioo`00ogoo
1Woo003oOol6Ool00001\
\>"],
  ImageRangeCache->{{{0, 260.563}, {184.125, 0}} -> {-0.170508, 0.0461608, \
0.00439067, 0.00439067}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .70824 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1.10169 -0.148196 1.10169 [
[.5 .72074 -20 0 ]
[.5 .72074 20 15 ]
[.44797 -0.02478 -4.90556 -15 ]
[.44797 -0.02478 5.09444 0 ]
[.15892 .66839 -5.31917 0 ]
[.15892 .66839 4.68083 15 ]
[-0.06694 .27471 -10 -6.62571 ]
[-0.06694 .27471 0 8.37429 ]
[ 0 0 0 0 ]
[ 1 .70824 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .72074 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.437500 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(=) show
75.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.04) show
99.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math1Mono
%%DocumentNeededResources: + font Courier
%%DocumentNeededFonts: Math1Mono
%%DocumentNeededFont: + Courier
%%DocumentFonts: font Math1Mono
%%DocumentFonts: + font Courier
grestore
.25 Mabswid
.02946 .11175 m
.89362 0 L
s
gsave
.44797 -0.02478 -65.9056 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(u) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
0 .4272 m
.29069 .70824 L
s
gsave
.15892 .66839 -66.3192 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(p) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.02946 .11175 m
0 .4272 L
s
gsave
-0.06694 .27471 -71 -10.6257 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(q) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.02946 .11175 m
0 .4272 L
s
0 .4272 m
.29069 .70824 L
s
.29069 .70824 m
.30155 .45044 L
s
.30155 .45044 m
.02946 .11175 L
s
.89362 0 m
.98022 .38351 L
s
.98022 .38351 m
1 .65325 L
s
1 .65325 m
.91448 .33294 L
s
.91448 .33294 m
.89362 0 L
s
.02946 .11175 m
0 .4272 L
s
0 .4272 m
.91448 .33294 L
s
.91448 .33294 m
.89362 0 L
s
.89362 0 m
.02946 .11175 L
s
.30155 .45044 m
.98022 .38351 L
s
.98022 .38351 m
1 .65325 L
s
1 .65325 m
.29069 .70824 L
s
.29069 .70824 m
.30155 .45044 L
s
0 0 m
1 0 L
1 .70824 L
0 .70824 L
closepath
clip
newpath
.872 .759 .735 r
.28887 .59047 .29487 .60897 .31582 .56837 .30978 .55403 Mtetra
.804 .762 .815 r
.30978 .55403 .31582 .56837 .33577 .55052 .32976 .53834 Mtetra
.736 .76 .872 r
.32976 .53834 .33577 .55052 .35538 .54176 .34944 .53085 Mtetra
.682 .756 .907 r
.34944 .53085 .35538 .54176 .37489 .5371 .36904 .527 Mtetra
.644 .754 .929 r
.36904 .527 .37489 .5371 .39439 .53445 .38863 .5249 Mtetra
.62 .753 .942 r
.38863 .5249 .39439 .53445 .41392 .53281 .40827 .52364 Mtetra
.604 .755 .95 r
.40827 .52364 .41392 .53281 .43351 .5317 .42796 .5228 Mtetra
.595 .757 .955 r
.42796 .5228 .43351 .5317 .45315 .53084 .44772 .52215 Mtetra
.589 .759 .959 r
.44772 .52215 .45315 .53084 .47287 .5301 .46755 .52157 Mtetra
.586 .762 .962 r
.46755 .52157 .47287 .5301 .49265 .5294 .48746 .52099 Mtetra
.585 .764 .964 r
.48746 .52099 .49265 .5294 .51251 .52869 .50743 .52038 Mtetra
.584 .767 .966 r
.50743 .52038 .51251 .52869 .53243 .52795 .52748 .51971 Mtetra
.584 .769 .967 r
.52748 .51971 .53243 .52795 .55243 .52717 .5476 .51898 Mtetra
.584 .771 .968 r
.5476 .51898 .55243 .52717 .5725 .52633 .5678 .51819 Mtetra
.584 .773 .969 r
.5678 .51819 .5725 .52633 .59264 .52544 .58807 .51733 Mtetra
.585 .775 .97 r
.58807 .51733 .59264 .52544 .61285 .52449 .6084 .51641 Mtetra
.585 .776 .97 r
.6084 .51641 .61285 .52449 .63313 .52349 .62882 .51543 Mtetra
.586 .778 .971 r
.62882 .51543 .63313 .52349 .65349 .52244 .6493 .51439 Mtetra
.586 .779 .971 r
.6493 .51439 .65349 .52244 .67391 .52134 .66985 .5133 Mtetra
.587 .78 .972 r
.66985 .5133 .67391 .52134 .6944 .5202 .69048 .51216 Mtetra
.588 .781 .972 r
.69048 .51216 .6944 .5202 .71497 .51901 .71118 .51097 Mtetra
.588 .782 .972 r
.71118 .51097 .71497 .51901 .73561 .51778 .73195 .50974 Mtetra
.589 .783 .972 r
.73195 .50974 .73561 .51778 .75631 .51651 .75279 .50847 Mtetra
.589 .784 .973 r
.75279 .50847 .75631 .51651 .77709 .51521 .77371 .50716 Mtetra
.59 .784 .973 r
.77371 .50716 .77709 .51521 .79794 .51387 .79469 .50581 Mtetra
.59 .785 .973 r
.79469 .50581 .79794 .51387 .81886 .5125 .81575 .50443 Mtetra
.59 .786 .973 r
.81575 .50443 .81886 .5125 .83985 .5111 .83688 .50301 Mtetra
.591 .786 .973 r
.83688 .50301 .83985 .5111 .86091 .50966 .85809 .50157 Mtetra
.591 .787 .973 r
.85809 .50157 .86091 .50966 .88204 .50821 .87936 .5001 Mtetra
.591 .787 .974 r
.87936 .5001 .88204 .50821 .90325 .50672 .90071 .4986 Mtetra
.592 .788 .974 r
.90071 .4986 .90325 .50672 .92453 .50521 .92213 .49707 Mtetra
.92213 .49707 .92453 .50521 .94588 .50368 .94363 .49552 Mtetra
.592 .789 .974 r
.94363 .49552 .94588 .50368 .9673 .50213 .9652 .49395 Mtetra
.9652 .49395 .9673 .50213 .9888 .50055 .98684 .49236 Mtetra
.859 .754 .745 r
.28282 .57179 .28887 .59047 .30978 .55403 .30367 .53953 Mtetra
.787 .755 .824 r
.30367 .53953 .30978 .55403 .32976 .53834 .32368 .52602 Mtetra
.719 .752 .878 r
.32368 .52602 .32976 .53834 .34944 .53085 .34343 .51981 Mtetra
.667 .749 .911 r
.34343 .51981 .34944 .53085 .36904 .527 .36311 .51678 Mtetra
.632 .748 .931 r
.36311 .51678 .36904 .527 .38863 .5249 .3828 .51522 Mtetra
.61 .748 .943 r
.3828 .51522 .38863 .5249 .40827 .52364 .40254 .51435 Mtetra
.597 .751 .951 r
.40254 .51435 .40827 .52364 .42796 .5228 .42235 .5138 Mtetra
.589 .754 .956 r
.42235 .5138 .42796 .5228 .44772 .52215 .44222 .51336 Mtetra
.585 .757 .96 r
.44222 .51336 .44772 .52215 .46755 .52157 .46217 .51293 Mtetra
.583 .76 .963 r
.46217 .51293 .46755 .52157 .48746 .52099 .48219 .51247 Mtetra
.582 .763 .965 r
.48219 .51247 .48746 .52099 .50743 .52038 .50229 .51195 Mtetra
.581 .765 .966 r
.50229 .51195 .50743 .52038 .52748 .51971 .52246 .51135 Mtetra
.582 .768 .968 r
.52246 .51135 .52748 .51971 .5476 .51898 .54271 .51068 Mtetra
.582 .77 .969 r
.54271 .51068 .5476 .51898 .5678 .51819 .56303 .50993 Mtetra
.583 .772 .969 r
.56303 .50993 .5678 .51819 .58807 .51733 .58343 .50911 Mtetra
.583 .774 .97 r
.58343 .50911 .58807 .51733 .6084 .51641 .6039 .50821 Mtetra
.584 .776 .971 r
.6039 .50821 .6084 .51641 .62882 .51543 .62444 .50725 Mtetra
.585 .777 .971 r
.62444 .50725 .62882 .51543 .6493 .51439 .64505 .50623 Mtetra
.586 .778 .971 r
.64505 .50623 .6493 .51439 .66985 .5133 .66574 .50515 Mtetra
.586 .78 .972 r
.66574 .50515 .66985 .5133 .69048 .51216 .6865 .50401 Mtetra
.587 .781 .972 r
.6865 .50401 .69048 .51216 .71118 .51097 .70734 .50282 Mtetra
.588 .782 .972 r
.70734 .50282 .71118 .51097 .73195 .50974 .72824 .50159 Mtetra
.588 .783 .973 r
.72824 .50159 .73195 .50974 .75279 .50847 .74922 .50031 Mtetra
.589 .783 .973 r
.74922 .50031 .75279 .50847 .77371 .50716 .77028 .49899 Mtetra
.589 .784 .973 r
.77028 .49899 .77371 .50716 .79469 .50581 .7914 .49764 Mtetra
.59 .785 .973 r
.7914 .49764 .79469 .50581 .81575 .50443 .8126 .49625 Mtetra
.8126 .49625 .81575 .50443 .83688 .50301 .83388 .49482 Mtetra
.59 .786 .973 r
.83388 .49482 .83688 .50301 .85809 .50157 .85522 .49336 Mtetra
.591 .787 .973 r
.85522 .49336 .85809 .50157 .87936 .5001 .87664 .49188 Mtetra
.591 .787 .974 r
.87664 .49188 .87936 .5001 .90071 .4986 .89814 .49036 Mtetra
.592 .788 .974 r
.89814 .49036 .90071 .4986 .92213 .49707 .9197 .48882 Mtetra
.9197 .48882 .92213 .49707 .94363 .49552 .94135 .48725 Mtetra
.94135 .48725 .94363 .49552 .9652 .49395 .96307 .48566 Mtetra
.592 .789 .974 r
.96307 .48566 .9652 .49395 .98684 .49236 .98486 .48405 Mtetra
.845 .747 .756 r
.2767 .55293 .28282 .57179 .30367 .53953 .2975 .52487 Mtetra
.769 .747 .833 r
.2975 .52487 .30367 .53953 .32368 .52602 .31753 .51355 Mtetra
.701 .743 .885 r
.31753 .51355 .32368 .52602 .34343 .51981 .33734 .50863 Mtetra
.651 .741 .915 r
.33734 .50863 .34343 .51981 .36311 .51678 .35711 .50642 Mtetra
.619 .741 .933 r
.35711 .50642 .36311 .51678 .3828 .51522 .3769 .50542 Mtetra
.6 .743 .945 r
.3769 .50542 .3828 .51522 .40254 .51435 .39674 .50494 Mtetra
.589 .747 .952 r
.39674 .50494 .40254 .51435 .42235 .5138 .41666 .50467 Mtetra
.583 .75 .957 r
.41666 .50467 .42235 .5138 .44222 .51336 .43665 .50444 Mtetra
.58 .754 .961 r
.43665 .50444 .44222 .51336 .46217 .51293 .45671 .50417 Mtetra
.579 .758 .963 r
.45671 .50417 .46217 .51293 .48219 .51247 .47686 .50384 Mtetra
.578 .761 .965 r
.47686 .50384 .48219 .51247 .50229 .51195 .49708 .50341 Mtetra
.579 .764 .967 r
.49708 .50341 .50229 .51195 .52246 .51135 .51738 .50289 Mtetra
.579 .767 .968 r
.51738 .50289 .52246 .51135 .54271 .51068 .53775 .50227 Mtetra
.58 .769 .969 r
.53775 .50227 .54271 .51068 .56303 .50993 .5582 .50157 Mtetra
.581 .771 .969 r
.5582 .50157 .56303 .50993 .58343 .50911 .57873 .50078 Mtetra
.582 .773 .97 r
.57873 .50078 .58343 .50911 .6039 .50821 .59933 .49991 Mtetra
.583 .775 .971 r
.59933 .49991 .6039 .50821 .62444 .50725 .62 .49896 Mtetra
.584 .777 .971 r
.62 .49896 .62444 .50725 .64505 .50623 .64075 .49795 Mtetra
.585 .778 .971 r
.64075 .49795 .64505 .50623 .66574 .50515 .66157 .49688 Mtetra
.586 .779 .972 r
.66157 .49688 .66574 .50515 .6865 .50401 .68247 .49575 Mtetra
.586 .78 .972 r
.68247 .49575 .6865 .50401 .70734 .50282 .70344 .49456 Mtetra
.587 .781 .972 r
.70344 .49456 .70734 .50282 .72824 .50159 .72449 .49333 Mtetra
.588 .782 .973 r
.72449 .49333 .72824 .50159 .74922 .50031 .74561 .49204 Mtetra
.588 .783 .973 r
.74561 .49204 .74922 .50031 .77028 .49899 .7668 .49072 Mtetra
.589 .784 .973 r
.7668 .49072 .77028 .49899 .7914 .49764 .78807 .48935 Mtetra
.589 .785 .973 r
.78807 .48935 .7914 .49764 .8126 .49625 .80941 .48795 Mtetra
.59 .785 .973 r
.80941 .48795 .8126 .49625 .83388 .49482 .83083 .48651 Mtetra
.59 .786 .973 r
.83083 .48651 .83388 .49482 .85522 .49336 .85232 .48504 Mtetra
.591 .786 .973 r
.85232 .48504 .85522 .49336 .87664 .49188 .87388 .48354 Mtetra
.591 .787 .974 r
.87388 .48354 .87664 .49188 .89814 .49036 .89552 .48201 Mtetra
.89552 .48201 .89814 .49036 .9197 .48882 .91724 .48045 Mtetra
.592 .788 .974 r
.91724 .48045 .9197 .48882 .94135 .48725 .93903 .47886 Mtetra
.93903 .47886 .94135 .48725 .96307 .48566 .9609 .47725 Mtetra
.592 .789 .974 r
.9609 .47725 .96307 .48566 .98486 .48405 .98285 .47562 Mtetra
.827 .739 .767 r
.27053 .53388 .2767 .55293 .2975 .52487 .29125 .51005 Mtetra
.748 .737 .842 r
.29125 .51005 .2975 .52487 .31753 .51355 .31131 .50094 Mtetra
.681 .734 .891 r
.31131 .50094 .31753 .51355 .33734 .50863 .33118 .49732 Mtetra
.634 .733 .919 r
.33118 .49732 .33734 .50863 .35711 .50642 .35103 .49594 Mtetra
.606 .734 .936 r
.35103 .49594 .35711 .50642 .3769 .50542 .37091 .49549 Mtetra
.59 .738 .946 r
.37091 .49549 .3769 .50542 .39674 .50494 .39087 .49541 Mtetra
.581 .743 .953 r
.39087 .49541 .39674 .50494 .41666 .50467 .41089 .49542 Mtetra
.577 .747 .958 r
.41089 .49542 .41666 .50467 .43665 .50444 .431 .49541 Mtetra
.575 .752 .961 r
.431 .49541 .43665 .50444 .45671 .50417 .45119 .4953 Mtetra
.575 .756 .964 r
.45119 .4953 .45671 .50417 .47686 .50384 .47145 .49509 Mtetra
.575 .759 .965 r
.47145 .49509 .47686 .50384 .49708 .50341 .4918 .49476 Mtetra
.576 .763 .967 r
.4918 .49476 .49708 .50341 .51738 .50289 .51222 .49431 Mtetra
.577 .766 .968 r
.51222 .49431 .51738 .50289 .53775 .50227 .53273 .49375 Mtetra
.579 .768 .969 r
.53273 .49375 .53775 .50227 .5582 .50157 .55331 .49309 Mtetra
.58 .771 .97 r
.55331 .49309 .5582 .50157 .57873 .50078 .57396 .49233 Mtetra
.581 .773 .97 r
.57396 .49233 .57873 .50078 .59933 .49991 .5947 .49149 Mtetra
.582 .774 .971 r
.5947 .49149 .59933 .49991 .62 .49896 .6155 .49056 Mtetra
.583 .776 .971 r
.6155 .49056 .62 .49896 .64075 .49795 .63639 .48957 Mtetra
.584 .777 .972 r
.63639 .48957 .64075 .49795 .66157 .49688 .65735 .4885 Mtetra
.585 .779 .972 r
.65735 .4885 .66157 .49688 .68247 .49575 .67838 .48737 Mtetra
.586 .78 .972 r
.67838 .48737 .68247 .49575 .70344 .49456 .69949 .48619 Mtetra
.587 .781 .972 r
.69949 .48619 .70344 .49456 .72449 .49333 .72068 .48495 Mtetra
.587 .782 .973 r
.72068 .48495 .72449 .49333 .74561 .49204 .74194 .48366 Mtetra
.588 .783 .973 r
.74194 .48366 .74561 .49204 .7668 .49072 .76328 .48233 Mtetra
.588 .784 .973 r
.76328 .48233 .7668 .49072 .78807 .48935 .78469 .48095 Mtetra
.589 .784 .973 r
.78469 .48095 .78807 .48935 .80941 .48795 .80617 .47954 Mtetra
.59 .785 .973 r
.80617 .47954 .80941 .48795 .83083 .48651 .82773 .47809 Mtetra
.59 .786 .973 r
.82773 .47809 .83083 .48651 .85232 .48504 .84937 .4766 Mtetra
.84937 .4766 .85232 .48504 .87388 .48354 .87109 .47508 Mtetra
.591 .787 .974 r
.87109 .47508 .87388 .48354 .89552 .48201 .89288 .47354 Mtetra
.89288 .47354 .89552 .48201 .91724 .48045 .91474 .47196 Mtetra
.591 .788 .974 r
.91474 .47196 .91724 .48045 .93903 .47886 .93669 .47036 Mtetra
.592 .788 .974 r
.93669 .47036 .93903 .47886 .9609 .47725 .95871 .46873 Mtetra
.592 .789 .974 r
.95871 .46873 .9609 .47725 .98285 .47562 .9808 .46707 Mtetra
.806 .729 .779 r
.26429 .51465 .27053 .53388 .29125 .51005 .28494 .49506 Mtetra
.724 .726 .851 r
.28494 .49506 .29125 .51005 .31131 .50094 .30501 .48817 Mtetra
.659 .723 .896 r
.30501 .48817 .31131 .50094 .33118 .49732 .32494 .48586 Mtetra
.617 .723 .922 r
.32494 .48586 .33118 .49732 .35103 .49594 .34487 .48532 Mtetra
.592 .727 .938 r
.34487 .48532 .35103 .49594 .37091 .49549 .36486 .48544 Mtetra
.58 .733 .947 r
.36486 .48544 .37091 .49549 .39087 .49541 .38491 .48575 Mtetra
.573 .738 .954 r
.38491 .48575 .39087 .49541 .41089 .49542 .40505 .48605 Mtetra
.571 .744 .958 r
.40505 .48605 .41089 .49542 .431 .49541 .42528 .48625 Mtetra
.57 .749 .962 r
.42528 .48625 .431 .49541 .45119 .4953 .44558 .48631 Mtetra
.571 .754 .964 r
.44558 .48631 .45119 .4953 .47145 .49509 .46597 .48622 Mtetra
.572 .758 .966 r
.46597 .48622 .47145 .49509 .4918 .49476 .48645 .48598 Mtetra
.574 .761 .967 r
.48645 .48598 .4918 .49476 .51222 .49431 .507 .48561 Mtetra
.575 .764 .968 r
.507 .48561 .51222 .49431 .53273 .49375 .52763 .48511 Mtetra
.577 .767 .969 r
.52763 .48511 .53273 .49375 .55331 .49309 .54834 .48449 Mtetra
.578 .77 .97 r
.54834 .48449 .55331 .49309 .57396 .49233 .56913 .48377 Mtetra
.58 .772 .97 r
.56913 .48377 .57396 .49233 .5947 .49149 .59 .48295 Mtetra
.581 .774 .971 r
.59 .48295 .5947 .49149 .6155 .49056 .61094 .48205 Mtetra
.582 .775 .971 r
.61094 .48205 .6155 .49056 .63639 .48957 .63197 .48106 Mtetra
.583 .777 .972 r
.63197 .48106 .63639 .48957 .65735 .4885 .65306 .48 Mtetra
.584 .778 .972 r
.65306 .48 .65735 .4885 .67838 .48737 .67424 .47888 Mtetra
.585 .78 .972 r
.67424 .47888 .67838 .48737 .69949 .48619 .69549 .47769 Mtetra
.586 .781 .972 r
.69549 .47769 .69949 .48619 .72068 .48495 .71682 .47645 Mtetra
.587 .782 .973 r
.71682 .47645 .72068 .48495 .74194 .48366 .73822 .47516 Mtetra
.587 .783 .973 r
.73822 .47516 .74194 .48366 .76328 .48233 .7597 .47382 Mtetra
.588 .783 .973 r
.7597 .47382 .76328 .48233 .78469 .48095 .78126 .47243 Mtetra
.589 .784 .973 r
.78126 .47243 .78469 .48095 .80617 .47954 .80289 .47101 Mtetra
.589 .785 .973 r
.80289 .47101 .80617 .47954 .82773 .47809 .8246 .46954 Mtetra
.59 .786 .973 r
.8246 .46954 .82773 .47809 .84937 .4766 .84639 .46804 Mtetra
.59 .786 .974 r
.84639 .46804 .84937 .4766 .87109 .47508 .86825 .46651 Mtetra
.591 .787 .974 r
.86825 .46651 .87109 .47508 .89288 .47354 .89019 .46494 Mtetra
.89019 .46494 .89288 .47354 .91474 .47196 .91221 .46335 Mtetra
.591 .788 .974 r
.91221 .46335 .91474 .47196 .93669 .47036 .93431 .46173 Mtetra
.592 .788 .974 r
.93431 .46173 .93669 .47036 .95871 .46873 .95648 .46008 Mtetra
.95648 .46008 .95871 .46873 .9808 .46707 .97873 .4584 Mtetra
.782 .717 .791 r
.258 .49523 .26429 .51465 .28494 .49506 .27856 .47991 Mtetra
.697 .712 .86 r
.27856 .47991 .28494 .49506 .30501 .48817 .29864 .47525 Mtetra
.635 .71 .901 r
.29864 .47525 .30501 .48817 .32494 .48586 .31863 .47426 Mtetra
.598 .714 .925 r
.31863 .47426 .32494 .48586 .34487 .48532 .33864 .47456 Mtetra
.578 .72 .939 r
.33864 .47456 .34487 .48532 .36486 .48544 .35872 .47525 Mtetra
.569 .727 .949 r
.35872 .47525 .36486 .48544 .38491 .48575 .37888 .47597 Mtetra
.565 .734 .955 r
.37888 .47597 .38491 .48575 .40505 .48605 .39914 .47656 Mtetra
.565 .741 .959 r
.39914 .47656 .40505 .48605 .42528 .48625 .41948 .47697 Mtetra
.566 .746 .962 r
.41948 .47697 .42528 .48625 .44558 .48631 .43991 .47719 Mtetra
.567 .752 .964 r
.43991 .47719 .44558 .48631 .46597 .48622 .46042 .47723 Mtetra
.569 .756 .966 r
.46042 .47723 .46597 .48622 .48645 .48598 .48102 .47709 Mtetra
.571 .76 .967 r
.48102 .47709 .48645 .48598 .507 .48561 .5017 .47679 Mtetra
.573 .763 .968 r
.5017 .47679 .507 .48561 .52763 .48511 .52247 .47635 Mtetra
.575 .766 .969 r
.52247 .47635 .52763 .48511 .54834 .48449 .54331 .47578 Mtetra
.577 .769 .97 r
.54331 .47578 .54834 .48449 .56913 .48377 .56423 .47509 Mtetra
.579 .771 .97 r
.56423 .47509 .56913 .48377 .59 .48295 .58524 .4743 Mtetra
.58 .773 .971 r
.58524 .4743 .59 .48295 .61094 .48205 .60632 .47341 Mtetra
.581 .775 .971 r
.60632 .47341 .61094 .48205 .63197 .48106 .62748 .47244 Mtetra
.583 .777 .972 r
.62748 .47244 .63197 .48106 .65306 .48 .64872 .47139 Mtetra
.584 .778 .972 r
.64872 .47139 .65306 .48 .67424 .47888 .67003 .47026 Mtetra
.585 .779 .972 r
.67003 .47026 .67424 .47888 .69549 .47769 .69143 .46908 Mtetra
.586 .78 .972 r
.69143 .46908 .69549 .47769 .71682 .47645 .7129 .46783 Mtetra
.586 .781 .973 r
.7129 .46783 .71682 .47645 .73822 .47516 .73445 .46653 Mtetra
.587 .782 .973 r
.73445 .46653 .73822 .47516 .7597 .47382 .75607 .46519 Mtetra
.588 .783 .973 r
.75607 .46519 .7597 .47382 .78126 .47243 .77778 .46379 Mtetra
.588 .784 .973 r
.77778 .46379 .78126 .47243 .80289 .47101 .79956 .46235 Mtetra
.589 .785 .973 r
.79956 .46235 .80289 .47101 .8246 .46954 .82142 .46087 Mtetra
.82142 .46087 .8246 .46954 .84639 .46804 .84336 .45936 Mtetra
.59 .786 .974 r
.84336 .45936 .84639 .46804 .86825 .46651 .86537 .45781 Mtetra
.59 .787 .974 r
.86537 .45781 .86825 .46651 .89019 .46494 .88747 .45623 Mtetra
.591 .787 .974 r
.88747 .45623 .89019 .46494 .91221 .46335 .90964 .45461 Mtetra
.591 .788 .974 r
.90964 .45461 .91221 .46335 .93431 .46173 .93189 .45297 Mtetra
.93189 .45297 .93431 .46173 .95648 .46008 .95422 .4513 Mtetra
.592 .788 .974 r
.95422 .4513 .95648 .46008 .97873 .4584 .97663 .4496 Mtetra
.752 .701 .804 r
.25164 .47562 .258 .49523 .27856 .47991 .2721 .46458 Mtetra
.666 .696 .868 r
.2721 .46458 .27856 .47991 .29864 .47525 .29219 .46218 Mtetra
.609 .697 .906 r
.29219 .46218 .29864 .47525 .31863 .47426 .31223 .46252 Mtetra
.578 .703 .928 r
.31223 .46252 .31863 .47426 .33864 .47456 .33232 .46367 Mtetra
.563 .712 .941 r
.33232 .46367 .33864 .47456 .35872 .47525 .3525 .46494 Mtetra
.558 .721 .949 r
.3525 .46494 .35872 .47525 .37888 .47597 .37277 .46605 Mtetra
.557 .729 .955 r
.37277 .46605 .37888 .47597 .39914 .47656 .39314 .46694 Mtetra
.558 .737 .959 r
.39314 .46694 .39914 .47656 .41948 .47697 .4136 .46757 Mtetra
.561 .744 .962 r
.4136 .46757 .41948 .47697 .43991 .47719 .43415 .46796 Mtetra
.563 .749 .965 r
.43415 .46796 .43991 .47719 .46042 .47723 .45479 .46812 Mtetra
.566 .754 .966 r
.45479 .46812 .46042 .47723 .48102 .47709 .47552 .46808 Mtetra
.569 .759 .968 r
.47552 .46808 .48102 .47709 .5017 .47679 .49633 .46785 Mtetra
.571 .762 .969 r
.49633 .46785 .5017 .47679 .52247 .47635 .51723 .46747 Mtetra
.573 .765 .969 r
.51723 .46747 .52247 .47635 .54331 .47578 .53821 .46694 Mtetra
.575 .768 .97 r
.53821 .46694 .54331 .47578 .56423 .47509 .55927 .46629 Mtetra
.577 .77 .971 r
.55927 .46629 .56423 .47509 .58524 .4743 .58041 .46552 Mtetra
.579 .773 .971 r
.58041 .46552 .58524 .4743 .60632 .47341 .60163 .46465 Mtetra
.58 .774 .971 r
.60163 .46465 .60632 .47341 .62748 .47244 .62293 .46369 Mtetra
.582 .776 .972 r
.62293 .46369 .62748 .47244 .64872 .47139 .64431 .46265 Mtetra
.583 .778 .972 r
.64431 .46265 .64872 .47139 .67003 .47026 .66577 .46153 Mtetra
.584 .779 .972 r
.66577 .46153 .67003 .47026 .69143 .46908 .68731 .46034 Mtetra
.585 .78 .973 r
.68731 .46034 .69143 .46908 .7129 .46783 .70893 .45909 Mtetra
.586 .781 .973 r
.70893 .45909 .7129 .46783 .73445 .46653 .73062 .45779 Mtetra
.587 .782 .973 r
.73062 .45779 .73445 .46653 .75607 .46519 .7524 .45643 Mtetra
.587 .783 .973 r
.7524 .45643 .75607 .46519 .77778 .46379 .77425 .45503 Mtetra
.588 .784 .973 r
.77425 .45503 .77778 .46379 .79956 .46235 .79618 .45357 Mtetra
.589 .785 .973 r
.79618 .45357 .79956 .46235 .82142 .46087 .81819 .45208 Mtetra
.81819 .45208 .82142 .46087 .84336 .45936 .84028 .45055 Mtetra
.59 .786 .974 r
.84028 .45055 .84336 .45936 .86537 .45781 .86245 .44899 Mtetra
.86245 .44899 .86537 .45781 .88747 .45623 .8847 .44738 Mtetra
.591 .787 .974 r
.8847 .44738 .88747 .45623 .90964 .45461 .90703 .44575 Mtetra
.90703 .44575 .90964 .45461 .93189 .45297 .92944 .44409 Mtetra
.591 .788 .974 r
.92944 .44409 .93189 .45297 .95422 .4513 .95193 .4424 Mtetra
.592 .788 .974 r
.95193 .4424 .95422 .4513 .97663 .4496 .9745 .44068 Mtetra
.715 .681 .815 r
.24522 .45582 .25164 .47562 .2721 .46458 .26557 .44908 Mtetra
.631 .676 .875 r
.26557 .44908 .2721 .46458 .29219 .46218 .28566 .44895 Mtetra
.581 .681 .909 r
.28566 .44895 .29219 .46218 .31223 .46252 .30575 .45063 Mtetra
.557 .691 .929 r
.30575 .45063 .31223 .46252 .33232 .46367 .32593 .45263 Mtetra
.548 .703 .942 r
.32593 .45263 .33232 .46367 .3525 .46494 .3462 .45448 Mtetra
.546 .715 .95 r
.3462 .45448 .3525 .46494 .37277 .46605 .36658 .45601 Mtetra
.548 .725 .956 r
.36658 .45601 .37277 .46605 .39314 .46694 .38706 .45719 Mtetra
.552 .734 .96 r
.38706 .45719 .39314 .46694 .4136 .46757 .40764 .45804 Mtetra
.556 .741 .963 r
.40764 .45804 .4136 .46757 .43415 .46796 .42832 .45859 Mtetra
.559 .747 .965 r
.42832 .45859 .43415 .46796 .45479 .46812 .44908 .45888 Mtetra
.563 .753 .966 r
.44908 .45888 .45479 .46812 .47552 .46808 .46994 .45894 Mtetra
.566 .757 .968 r
.46994 .45894 .47552 .46808 .49633 .46785 .49089 .45879 Mtetra
.569 .761 .969 r
.49089 .45879 .49633 .46785 .51723 .46747 .51192 .45847 Mtetra
.572 .764 .97 r
.51192 .45847 .51723 .46747 .53821 .46694 .53303 .45798 Mtetra
.574 .767 .97 r
.53303 .45798 .53821 .46694 .55927 .46629 .55423 .45736 Mtetra
.576 .77 .971 r
.55423 .45736 .55927 .46629 .58041 .46552 .57551 .45662 Mtetra
.578 .772 .971 r
.57551 .45662 .58041 .46552 .60163 .46465 .59688 .45577 Mtetra
.579 .774 .971 r
.59688 .45577 .60163 .46465 .62293 .46369 .61832 .45482 Mtetra
.581 .776 .972 r
.61832 .45482 .62293 .46369 .64431 .46265 .63984 .45378 Mtetra
.582 .777 .972 r
.63984 .45378 .64431 .46265 .66577 .46153 .66145 .45267 Mtetra
.583 .779 .972 r
.66145 .45267 .66577 .46153 .68731 .46034 .68313 .45148 Mtetra
.584 .78 .973 r
.68313 .45148 .68731 .46034 .70893 .45909 .7049 .45023 Mtetra
.585 .781 .973 r
.7049 .45023 .70893 .45909 .73062 .45779 .72674 .44892 Mtetra
.586 .782 .973 r
.72674 .44892 .73062 .45779 .7524 .45643 .74867 .44755 Mtetra
.587 .783 .973 r
.74867 .44755 .7524 .45643 .77425 .45503 .77067 .44613 Mtetra
.588 .784 .973 r
.77067 .44613 .77425 .45503 .79618 .45357 .79275 .44467 Mtetra
.79275 .44467 .79618 .45357 .81819 .45208 .81492 .44316 Mtetra
.589 .785 .973 r
.81492 .44316 .81819 .45208 .84028 .45055 .83716 .44162 Mtetra
.589 .786 .974 r
.83716 .44162 .84028 .45055 .86245 .44899 .85949 .44003 Mtetra
.59 .786 .974 r
.85949 .44003 .86245 .44899 .8847 .44738 .8819 .43841 Mtetra
.59 .787 .974 r
.8819 .43841 .8847 .44738 .90703 .44575 .90438 .43676 Mtetra
.591 .787 .974 r
.90438 .43676 .90703 .44575 .92944 .44409 .92695 .43508 Mtetra
.591 .788 .974 r
.92695 .43508 .92944 .44409 .95193 .4424 .9496 .43336 Mtetra
.9496 .43336 .95193 .4424 .9745 .44068 .97234 .43162 Mtetra
.67 .655 .826 r
.23874 .43582 .24522 .45582 .26557 .44908 .25897 .43341 Mtetra
.591 .653 .88 r
.25897 .43341 .26557 .44908 .28566 .44895 .27905 .43555 Mtetra
.55 .664 .912 r
.27905 .43555 .28566 .44895 .30575 .45063 .29919 .43858 Mtetra
.535 .679 .931 r
.29919 .43858 .30575 .45063 .32593 .45263 .31945 .44146 Mtetra
.532 .694 .943 r
.31945 .44146 .32593 .45263 .3462 .45448 .33982 .44389 Mtetra
.535 .708 .951 r
.33982 .44389 .3462 .45448 .36658 .45601 .3603 .44582 Mtetra
.54 .72 .956 r
.3603 .44582 .36658 .45601 .38706 .45719 .3809 .4473 Mtetra
.545 .73 .96 r
.3809 .4473 .38706 .45719 .40764 .45804 .4016 .44838 Mtetra
.55 .738 .963 r
.4016 .44838 .40764 .45804 .42832 .45859 .4224 .4491 Mtetra
.555 .745 .965 r
.4224 .4491 .42832 .45859 .44908 .45888 .4433 .44951 Mtetra
.56 .751 .967 r
.4433 .44951 .44908 .45888 .46994 .45894 .46429 .44967 Mtetra
.564 .756 .968 r
.46429 .44967 .46994 .45894 .49089 .45879 .48537 .4496 Mtetra
.567 .76 .969 r
.48537 .4496 .49089 .45879 .51192 .45847 .50653 .44933 Mtetra
.57 .763 .97 r
.50653 .44933 .51192 .45847 .53303 .45798 .52779 .4489 Mtetra
.572 .766 .97 r
.52779 .4489 .53303 .45798 .55423 .45736 .54913 .44831 Mtetra
.575 .769 .971 r
.54913 .44831 .55423 .45736 .57551 .45662 .57055 .4476 Mtetra
.577 .771 .971 r
.57055 .4476 .57551 .45662 .59688 .45577 .59205 .44676 Mtetra
.579 .773 .972 r
.59205 .44676 .59688 .45577 .61832 .45482 .61364 .44582 Mtetra
.58 .775 .972 r
.61364 .44582 .61832 .45482 .63984 .45378 .63531 .4448 Mtetra
.582 .777 .972 r
.63531 .4448 .63984 .45378 .66145 .45267 .65706 .44368 Mtetra
.583 .778 .972 r
.65706 .44368 .66145 .45267 .68313 .45148 .67889 .44249 Mtetra
.584 .779 .973 r
.67889 .44249 .68313 .45148 .7049 .45023 .70081 .44124 Mtetra
.585 .781 .973 r
.70081 .44124 .7049 .45023 .72674 .44892 .7228 .43992 Mtetra
.586 .782 .973 r
.7228 .43992 .72674 .44892 .74867 .44755 .74488 .43854 Mtetra
.587 .783 .973 r
.74488 .43854 .74867 .44755 .77067 .44613 .76704 .43711 Mtetra
.76704 .43711 .77067 .44613 .79275 .44467 .78928 .43564 Mtetra
.588 .784 .973 r
.78928 .43564 .79275 .44467 .81492 .44316 .8116 .43411 Mtetra
.589 .785 .973 r
.8116 .43411 .81492 .44316 .83716 .44162 .834 .43255 Mtetra
.589 .786 .974 r
.834 .43255 .83716 .44162 .85949 .44003 .85648 .43095 Mtetra
.59 .786 .974 r
.85648 .43095 .85949 .44003 .8819 .43841 .87905 .42931 Mtetra
.59 .787 .974 r
.87905 .42931 .8819 .43841 .90438 .43676 .9017 .42764 Mtetra
.591 .787 .974 r
.9017 .42764 .90438 .43676 .92695 .43508 .92443 .42593 Mtetra
.591 .788 .974 r
.92443 .42593 .92695 .43508 .9496 .43336 .94724 .4242 Mtetra
.94724 .4242 .9496 .43336 .97234 .43162 .97014 .42243 Mtetra
.615 .622 .834 r
.23219 .41562 .23874 .43582 .25897 .43341 .25229 .41755 Mtetra
.545 .627 .884 r
.25229 .41755 .25897 .43341 .27905 .43555 .27236 .42199 Mtetra
.517 .644 .913 r
.27236 .42199 .27905 .43555 .29919 .43858 .29255 .42638 Mtetra
.511 .665 .932 r
.29255 .42638 .29919 .43858 .31945 .44146 .31288 .43013 Mtetra
.515 .685 .943 r
.31288 .43013 .31945 .44146 .33982 .44389 .33335 .43315 Mtetra
.523 .701 .951 r
.33335 .43315 .33982 .44389 .3603 .44582 .35394 .4355 Mtetra
.531 .715 .957 r
.35394 .4355 .3603 .44582 .3809 .4473 .37465 .43728 Mtetra
.538 .726 .961 r
.37465 .43728 .3809 .4473 .4016 .44838 .39548 .43858 Mtetra
.545 .735 .963 r
.39548 .43858 .4016 .44838 .4224 .4491 .4164 .43947 Mtetra
.551 .743 .965 r
.4164 .43947 .4224 .4491 .4433 .44951 .43743 .44002 Mtetra
.556 .749 .967 r
.43743 .44002 .4433 .44951 .46429 .44967 .45855 .44027 Mtetra
.561 .754 .968 r
.45855 .44027 .46429 .44967 .48537 .4496 .47977 .44028 Mtetra
.565 .759 .969 r
.47977 .44028 .48537 .4496 .50653 .44933 .50107 .44007 Mtetra
.568 .762 .97 r
.50107 .44007 .50653 .44933 .52779 .4489 .52247 .43968 Mtetra
.571 .766 .97 r
.52247 .43968 .52779 .4489 .54913 .44831 .54395 .43913 Mtetra
.574 .768 .971 r
.54395 .43913 .54913 .44831 .57055 .4476 .56551 .43844 Mtetra
.576 .771 .971 r
.56551 .43844 .57055 .4476 .59205 .44676 .58716 .43762 Mtetra
.578 .773 .972 r
.58716 .43762 .59205 .44676 .61364 .44582 .60889 .4367 Mtetra
.579 .775 .972 r
.60889 .4367 .61364 .44582 .63531 .4448 .63071 .43568 Mtetra
.581 .776 .972 r
.63071 .43568 .63531 .4448 .65706 .44368 .65261 .43456 Mtetra
.582 .778 .972 r
.65261 .43456 .65706 .44368 .67889 .44249 .6746 .43337 Mtetra
.583 .779 .973 r
.6746 .43337 .67889 .44249 .70081 .44124 .69666 .43211 Mtetra
.584 .78 .973 r
.69666 .43211 .70081 .44124 .7228 .43992 .71881 .43079 Mtetra
.585 .781 .973 r
.71881 .43079 .7228 .43992 .74488 .43854 .74104 .4294 Mtetra
.586 .782 .973 r
.74104 .4294 .74488 .43854 .76704 .43711 .76335 .42796 Mtetra
.587 .783 .973 r
.76335 .42796 .76704 .43711 .78928 .43564 .78575 .42647 Mtetra
.588 .784 .973 r
.78575 .42647 .78928 .43564 .8116 .43411 .80823 .42493 Mtetra
.588 .785 .973 r
.80823 .42493 .8116 .43411 .834 .43255 .83079 .42335 Mtetra
.589 .785 .974 r
.83079 .42335 .834 .43255 .85648 .43095 .85343 .42173 Mtetra
.589 .786 .974 r
.85343 .42173 .85648 .43095 .87905 .42931 .87616 .42007 Mtetra
.59 .787 .974 r
.87616 .42007 .87905 .42931 .9017 .42764 .89897 .41838 Mtetra
.89897 .41838 .9017 .42764 .92443 .42593 .92187 .41665 Mtetra
.591 .788 .974 r
.92187 .41665 .92443 .42593 .94724 .4242 .94485 .41489 Mtetra
.94485 .41489 .94724 .4242 .97014 .42243 .96791 .41311 Mtetra
.548 .58 .839 r
.22558 .39522 .23219 .41562 .25229 .41755 .24553 .40151 Mtetra
.493 .595 .884 r
.24553 .40151 .25229 .41755 .27236 .42199 .26559 .40826 Mtetra
.481 .623 .913 r
.26559 .40826 .27236 .42199 .29255 .42638 .28582 .41403 Mtetra
.487 .651 .932 r
.28582 .41403 .29255 .42638 .31288 .43013 .30623 .41865 Mtetra
.498 .675 .944 r
.30623 .41865 .31288 .43013 .33335 .43315 .32679 .42227 Mtetra
.51 .694 .952 r
.32679 .42227 .33335 .43315 .35394 .4355 .34749 .42504 Mtetra
.522 .71 .957 r
.34749 .42504 .35394 .4355 .37465 .43728 .36832 .42713 Mtetra
.532 .722 .961 r
.36832 .42713 .37465 .43728 .39548 .43858 .38927 .42865 Mtetra
.54 .732 .964 r
.38927 .42865 .39548 .43858 .4164 .43947 .41032 .42971 Mtetra
.547 .741 .966 r
.41032 .42971 .4164 .43947 .43743 .44002 .43148 .43039 Mtetra
.553 .747 .967 r
.43148 .43039 .43743 .44002 .45855 .44027 .45274 .43074 Mtetra
.558 .753 .968 r
.45274 .43074 .45855 .44027 .47977 .44028 .47409 .43083 Mtetra
.563 .757 .969 r
.47409 .43083 .47977 .44028 .50107 .44007 .49553 .43068 Mtetra
.566 .761 .97 r
.49553 .43068 .50107 .44007 .52247 .43968 .51707 .43033 Mtetra
.57 .765 .971 r
.51707 .43033 .52247 .43968 .54395 .43913 .53869 .42982 Mtetra
.572 .768 .971 r
.53869 .42982 .54395 .43913 .56551 .43844 .5604 .42915 Mtetra
.575 .77 .971 r
.5604 .42915 .56551 .43844 .58716 .43762 .5822 .42835 Mtetra
.577 .772 .972 r
.5822 .42835 .58716 .43762 .60889 .4367 .60408 .42744 Mtetra
.579 .774 .972 r
.60408 .42744 .60889 .4367 .63071 .43568 .62605 .42642 Mtetra
.58 .776 .972 r
.62605 .42642 .63071 .43568 .65261 .43456 .6481 .42531 Mtetra
.582 .777 .972 r
.6481 .42531 .65261 .43456 .6746 .43337 .67023 .42412 Mtetra
.583 .779 .973 r
.67023 .42412 .6746 .43337 .69666 .43211 .69245 .42286 Mtetra
.584 .78 .973 r
.69245 .42286 .69666 .43211 .71881 .43079 .71476 .42152 Mtetra
.585 .781 .973 r
.71476 .42152 .71881 .43079 .74104 .4294 .73714 .42012 Mtetra
.586 .782 .973 r
.73714 .42012 .74104 .4294 .76335 .42796 .75961 .41867 Mtetra
.587 .783 .973 r
.75961 .41867 .76335 .42796 .78575 .42647 .78217 .41717 Mtetra
.587 .784 .973 r
.78217 .41717 .78575 .42647 .80823 .42493 .80481 .41561 Mtetra
.588 .785 .973 r
.80481 .41561 .80823 .42493 .83079 .42335 .82753 .41401 Mtetra
.589 .785 .974 r
.82753 .41401 .83079 .42335 .85343 .42173 .85034 .41237 Mtetra
.589 .786 .974 r
.85034 .41237 .85343 .42173 .87616 .42007 .87323 .4107 Mtetra
.59 .786 .974 r
.87323 .4107 .87616 .42007 .89897 .41838 .89621 .40898 Mtetra
.59 .787 .974 r
.89621 .40898 .89897 .41838 .92187 .41665 .91927 .40723 Mtetra
.591 .787 .974 r
.91927 .40723 .92187 .41665 .94485 .41489 .94242 .40545 Mtetra
.591 .788 .974 r
.94242 .40545 .94485 .41489 .96791 .41311 .96565 .40364 Mtetra
.465 .526 .836 r
.2189 .37462 .22558 .39522 .24553 .40151 .23869 .38528 Mtetra
.435 .558 .881 r
.23869 .38528 .24553 .40151 .26559 .40826 .25873 .39436 Mtetra
.442 .599 .911 r
.25873 .39436 .26559 .40826 .28582 .41403 .27901 .40151 Mtetra
.461 .635 .931 r
.27901 .40151 .28582 .41403 .30623 .41865 .29949 .40702 Mtetra
.48 .664 .943 r
.29949 .40702 .30623 .41865 .32679 .42227 .32014 .41124 Mtetra
.498 .687 .952 r
.32014 .41124 .32679 .42227 .34749 .42504 .34095 .41444 Mtetra
.513 .705 .957 r
.34095 .41444 .34749 .42504 .36832 .42713 .3619 .41683 Mtetra
.525 .719 .961 r
.3619 .41683 .36832 .42713 .38927 .42865 .38297 .41858 Mtetra
.535 .73 .964 r
.38297 .41858 .38927 .42865 .41032 .42971 .40415 .41981 Mtetra
.543 .738 .966 r
.40415 .41981 .41032 .42971 .43148 .43039 .42545 .42062 Mtetra
.55 .745 .967 r
.42545 .42062 .43148 .43039 .45274 .43074 .44684 .42108 Mtetra
.556 .751 .969 r
.44684 .42108 .45274 .43074 .47409 .43083 .46833 .42124 Mtetra
.56 .756 .969 r
.46833 .42124 .47409 .43083 .49553 .43068 .48991 .42115 Mtetra
.565 .76 .97 r
.48991 .42115 .49553 .43068 .51707 .43033 .51159 .42085 Mtetra
.568 .764 .971 r
.51159 .42085 .51707 .43033 .53869 .42982 .53336 .42037 Mtetra
.571 .767 .971 r
.53336 .42037 .53869 .42982 .5604 .42915 .55522 .41973 Mtetra
.574 .77 .971 r
.55522 .41973 .5604 .42915 .5822 .42835 .57716 .41895 Mtetra
.576 .772 .972 r
.57716 .41895 .5822 .42835 .60408 .42744 .59919 .41805 Mtetra
.578 .774 .972 r
.59919 .41805 .60408 .42744 .62605 .42642 .62131 .41704 Mtetra
.579 .776 .972 r
.62131 .41704 .62605 .42642 .6481 .42531 .64352 .41593 Mtetra
.581 .777 .973 r
.64352 .41593 .6481 .42531 .67023 .42412 .66581 .41473 Mtetra
.582 .779 .973 r
.66581 .41473 .67023 .42412 .69245 .42286 .68818 .41346 Mtetra
.584 .78 .973 r
.68818 .41346 .69245 .42286 .71476 .42152 .71064 .41212 Mtetra
.585 .781 .973 r
.71064 .41212 .71476 .42152 .73714 .42012 .73319 .41071 Mtetra
.586 .782 .973 r
.73319 .41071 .73714 .42012 .75961 .41867 .75582 .40925 Mtetra
.586 .783 .973 r
.75582 .40925 .75961 .41867 .78217 .41717 .77854 .40772 Mtetra
.587 .784 .973 r
.77854 .40772 .78217 .41717 .80481 .41561 .80134 .40615 Mtetra
.588 .784 .974 r
.80134 .40615 .80481 .41561 .82753 .41401 .82422 .40454 Mtetra
.588 .785 .974 r
.82422 .40454 .82753 .41401 .85034 .41237 .8472 .40288 Mtetra
.589 .786 .974 r
.8472 .40288 .85034 .41237 .87323 .4107 .87026 .40118 Mtetra
.59 .786 .974 r
.87026 .40118 .87323 .4107 .89621 .40898 .8934 .39944 Mtetra
.59 .787 .974 r
.8934 .39944 .89621 .40898 .91927 .40723 .91663 .39767 Mtetra
.91663 .39767 .91927 .40723 .94242 .40545 .93995 .39586 Mtetra
.591 .788 .974 r
.93995 .39586 .94242 .40545 .96565 .40364 .96336 .39403 Mtetra
.366 .459 .824 r
.21215 .3538 .2189 .37462 .23869 .38528 .23178 .36886 Mtetra
.37 .516 .873 r
.23178 .36886 .23869 .38528 .25873 .39436 .25179 .38029 Mtetra
.4 .573 .907 r
.25179 .38029 .25873 .39436 .27901 .40151 .2721 .38883 Mtetra
.433 .619 .929 r
.2721 .38883 .27901 .40151 .29949 .40702 .29266 .39524 Mtetra
.462 .653 .943 r
.29266 .39524 .29949 .40702 .32014 .41124 .31341 .40006 Mtetra
.485 .68 .952 r
.31341 .40006 .32014 .41124 .34095 .41444 .33433 .40368 Mtetra
.503 .699 .958 r
.33433 .40368 .34095 .41444 .3619 .41683 .35539 .40638 Mtetra
.518 .715 .961 r
.35539 .40638 .3619 .41683 .38297 .41858 .37659 .40837 Mtetra
.529 .727 .964 r
.37659 .40837 .38297 .41858 .40415 .41981 .3979 .40977 Mtetra
.539 .736 .966 r
.3979 .40977 .40415 .41981 .42545 .42062 .41932 .41071 Mtetra
.547 .744 .968 r
.41932 .41071 .42545 .42062 .44684 .42108 .44085 .41127 Mtetra
.553 .75 .969 r
.44085 .41127 .44684 .42108 .46833 .42124 .46249 .41151 Mtetra
.558 .755 .97 r
.46249 .41151 .46833 .42124 .48991 .42115 .48421 .41148 Mtetra
.563 .759 .97 r
.48421 .41148 .48991 .42115 .51159 .42085 .50604 .41123 Mtetra
.567 .763 .971 r
.50604 .41123 .51159 .42085 .53336 .42037 .52795 .41078 Mtetra
.57 .766 .971 r
.52795 .41078 .53336 .42037 .55522 .41973 .54996 .41017 Mtetra
.573 .769 .972 r
.54996 .41017 .55522 .41973 .57716 .41895 .57205 .40941 Mtetra
.575 .771 .972 r
.57205 .40941 .57716 .41895 .59919 .41805 .59424 .40851 Mtetra
.577 .773 .972 r
.59424 .40851 .59919 .41805 .62131 .41704 .61651 .40751 Mtetra
.579 .775 .972 r
.61651 .40751 .62131 .41704 .64352 .41593 .63887 .4064 Mtetra
.58 .777 .973 r
.63887 .4064 .64352 .41593 .66581 .41473 .66132 .40521 Mtetra
.582 .778 .973 r
.66132 .40521 .66581 .41473 .68818 .41346 .68385 .40393 Mtetra
.583 .779 .973 r
.68385 .40393 .68818 .41346 .71064 .41212 .70647 .40258 Mtetra
.584 .781 .973 r
.70647 .40258 .71064 .41212 .73319 .41071 .72918 .40116 Mtetra
.585 .782 .973 r
.72918 .40116 .73319 .41071 .75582 .40925 .75197 .39968 Mtetra
.586 .783 .973 r
.75197 .39968 .75582 .40925 .77854 .40772 .77485 .39814 Mtetra
.587 .783 .973 r
.77485 .39814 .77854 .40772 .80134 .40615 .79781 .39655 Mtetra
.588 .784 .974 r
.79781 .39655 .80134 .40615 .82422 .40454 .82087 .39492 Mtetra
.588 .785 .974 r
.82087 .39492 .82422 .40454 .8472 .40288 .84401 .39324 Mtetra
.589 .786 .974 r
.84401 .39324 .8472 .40288 .87026 .40118 .86724 .39152 Mtetra
.86724 .39152 .87026 .40118 .8934 .39944 .89055 .38976 Mtetra
.59 .787 .974 r
.89055 .38976 .8934 .39944 .91663 .39767 .91395 .38796 Mtetra
.91395 .38796 .91663 .39767 .93995 .39586 .93745 .38613 Mtetra
.591 .788 .974 r
.93745 .38613 .93995 .39586 .96336 .39403 .96103 .38427 Mtetra
.249 .378 .798 r
.20533 .33277 .21215 .3538 .23178 .36886 .22478 .35225 Mtetra
.298 .467 .859 r
.22478 .35225 .23178 .36886 .25179 .38029 .24476 .36604 Mtetra
.355 .544 .901 r
.24476 .36604 .25179 .38029 .2721 .38883 .26511 .37599 Mtetra
.405 .601 .926 r
.26511 .37599 .2721 .38883 .29266 .39524 .28573 .38329 Mtetra
.443 .642 .942 r
.28573 .38329 .29266 .39524 .31341 .40006 .30658 .38873 Mtetra
.472 .672 .951 r
.30658 .38873 .31341 .40006 .33433 .40368 .32761 .39278 Mtetra
.494 .694 .957 r
.32761 .39278 .33433 .40368 .35539 .40638 .34879 .39579 Mtetra
.511 .711 .962 r
.34879 .39579 .35539 .40638 .37659 .40837 .37011 .39801 Mtetra
.524 .723 .964 r
.37011 .39801 .37659 .40837 .3979 .40977 .39155 .39959 Mtetra
.535 .734 .966 r
.39155 .39959 .3979 .40977 .41932 .41071 .41312 .40066 Mtetra
.543 .742 .968 r
.41312 .40066 .41932 .41071 .44085 .41127 .43478 .40132 Mtetra
.55 .748 .969 r
.43478 .40132 .44085 .41127 .46249 .41151 .45656 .40164 Mtetra
.556 .754 .97 r
.45656 .40164 .46249 .41151 .48421 .41148 .47843 .40168 Mtetra
.561 .758 .97 r
.47843 .40168 .48421 .41148 .50604 .41123 .5004 .40147 Mtetra
.565 .762 .971 r
.5004 .40147 .50604 .41123 .52795 .41078 .52246 .40106 Mtetra
.569 .766 .971 r
.52246 .40106 .52795 .41078 .54996 .41017 .54462 .40047 Mtetra
.571 .768 .972 r
.54462 .40047 .54996 .41017 .57205 .40941 .56687 .39972 Mtetra
.574 .771 .972 r
.56687 .39972 .57205 .40941 .59424 .40851 .58921 .39884 Mtetra
.576 .773 .972 r
.58921 .39884 .59424 .40851 .61651 .40751 .61163 .39784 Mtetra
.578 .775 .972 r
.61163 .39784 .61651 .40751 .63887 .4064 .63415 .39674 Mtetra
.58 .776 .973 r
.63415 .39674 .63887 .4064 .66132 .40521 .65676 .39554 Mtetra
.581 .778 .973 r
.65676 .39554 .66132 .40521 .68385 .40393 .67945 .39425 Mtetra
.583 .779 .973 r
.67945 .39425 .68385 .40393 .70647 .40258 .70223 .39289 Mtetra
.584 .78 .973 r
.70223 .39289 .70647 .40258 .72918 .40116 .7251 .39146 Mtetra
.585 .781 .973 r
.7251 .39146 .72918 .40116 .75197 .39968 .74806 .38997 Mtetra
.586 .782 .973 r
.74806 .38997 .75197 .39968 .77485 .39814 .7711 .38841 Mtetra
.587 .783 .973 r
.7711 .38841 .77485 .39814 .79781 .39655 .79424 .38681 Mtetra
.587 .784 .974 r
.79424 .38681 .79781 .39655 .82087 .39492 .81746 .38515 Mtetra
.588 .785 .974 r
.81746 .38515 .82087 .39492 .84401 .39324 .84077 .38345 Mtetra
.589 .785 .974 r
.84077 .38345 .84401 .39324 .86724 .39152 .86417 .38171 Mtetra
.589 .786 .974 r
.86417 .38171 .86724 .39152 .89055 .38976 .88766 .37993 Mtetra
.59 .787 .974 r
.88766 .37993 .89055 .38976 .91395 .38796 .91124 .37811 Mtetra
.91124 .37811 .91395 .38796 .93745 .38613 .9349 .37625 Mtetra
.591 .788 .974 r
.9349 .37625 .93745 .38613 .96103 .38427 .95866 .37436 Mtetra
.038 .383 .846 r
.19785 .32135 .20533 .33277 .22478 .35225 .2177 .33545 Mtetra
.219 .413 .84 r
.2177 .33545 .22478 .35225 .24476 .36604 .23764 .3516 Mtetra
.308 .512 .892 r
.23764 .3516 .24476 .36604 .26511 .37599 .25802 .36297 Mtetra
.375 .582 .923 r
.25802 .36297 .26511 .37599 .28573 .38329 .27871 .37119 Mtetra
.423 .63 .94 r
.27871 .37119 .28573 .38329 .30658 .38873 .29966 .37724 Mtetra
.458 .664 .951 r
.29966 .37724 .30658 .38873 .32761 .39278 .32079 .38172 Mtetra
.484 .688 .957 r
.32079 .38172 .32761 .39278 .34879 .39579 .34209 .38505 Mtetra
.504 .706 .962 r
.34209 .38505 .34879 .39579 .37011 .39801 .36354 .3875 Mtetra
.519 .72 .964 r
.36354 .3875 .37011 .39801 .39155 .39959 .38512 .38926 Mtetra
.531 .731 .966 r
.38512 .38926 .39155 .39959 .41312 .40066 .40682 .39047 Mtetra
.54 .74 .968 r
.40682 .39047 .41312 .40066 .43478 .40132 .42863 .39123 Mtetra
.548 .747 .969 r
.42863 .39123 .43478 .40132 .45656 .40164 .45054 .39163 Mtetra
.554 .753 .97 r
.45054 .39163 .45656 .40164 .47843 .40168 .47256 .39173 Mtetra
.559 .757 .97 r
.47256 .39173 .47843 .40168 .5004 .40147 .49468 .39157 Mtetra
.564 .761 .971 r
.49468 .39157 .5004 .40147 .52246 .40106 .51689 .39119 Mtetra
.567 .765 .971 r
.51689 .39119 .52246 .40106 .54462 .40047 .5392 .39062 Mtetra
.57 .768 .972 r
.5392 .39062 .54462 .40047 .56687 .39972 .56161 .38989 Mtetra
.573 .77 .972 r
.56161 .38989 .56687 .39972 .58921 .39884 .5841 .38902 Mtetra
.575 .772 .972 r
.5841 .38902 .58921 .39884 .61163 .39784 .60669 .38803 Mtetra
.577 .774 .972 r
.60669 .38803 .61163 .39784 .63415 .39674 .62936 .38692 Mtetra
.579 .776 .973 r
.62936 .38692 .63415 .39674 .65676 .39554 .65213 .38572 Mtetra
.581 .778 .973 r
.65213 .38572 .65676 .39554 .67945 .39425 .67498 .38443 Mtetra
.582 .779 .973 r
.67498 .38443 .67945 .39425 .70223 .39289 .69793 .38306 Mtetra
.583 .78 .973 r
.69793 .38306 .70223 .39289 .7251 .39146 .72097 .38162 Mtetra
.584 .781 .973 r
.72097 .38162 .7251 .39146 .74806 .38997 .74409 .38011 Mtetra
.585 .782 .973 r
.74409 .38011 .74806 .38997 .7711 .38841 .7673 .37854 Mtetra
.586 .783 .973 r
.7673 .37854 .7711 .38841 .79424 .38681 .79061 .37691 Mtetra
.587 .784 .974 r
.79061 .37691 .79424 .38681 .81746 .38515 .814 .37524 Mtetra
.588 .785 .974 r
.814 .37524 .81746 .38515 .84077 .38345 .83748 .37352 Mtetra
.83748 .37352 .84077 .38345 .86417 .38171 .86106 .37175 Mtetra
.589 .786 .974 r
.86106 .37175 .86417 .38171 .88766 .37993 .88472 .36994 Mtetra
.88472 .36994 .88766 .37993 .91124 .37811 .90847 .3681 Mtetra
.59 .787 .974 r
.90847 .3681 .91124 .37811 .9349 .37625 .93232 .36622 Mtetra
.93232 .36622 .9349 .37625 .95866 .37436 .95626 .3643 Mtetra
.294 .608 .954 r
.19013 .31175 .19785 .32135 .2177 .33545 .21054 .31844 Mtetra
.135 .352 .813 r
.21054 .31844 .2177 .33545 .23764 .3516 .23043 .33699 Mtetra
.258 .478 .881 r
.23043 .33699 .23764 .3516 .25802 .36297 .25083 .34978 Mtetra
.343 .562 .918 r
.25083 .34978 .25802 .36297 .27871 .37119 .2716 .35892 Mtetra
.402 .617 .938 r
.2716 .35892 .27871 .37119 .29966 .37724 .29263 .36559 Mtetra
.444 .655 .95 r
.29263 .36559 .29966 .37724 .32079 .38172 .31388 .37051 Mtetra
.474 .682 .957 r
.31388 .37051 .32079 .38172 .34209 .38505 .3353 .37416 Mtetra
.496 .702 .962 r
.3353 .37416 .34209 .38505 .36354 .3875 .35688 .37684 Mtetra
.513 .717 .965 r
.35688 .37684 .36354 .3875 .38512 .38926 .37859 .37878 Mtetra
.526 .729 .967 r
.37859 .37878 .38512 .38926 .40682 .39047 .40043 .38012 Mtetra
.537 .738 .968 r
.40043 .38012 .40682 .39047 .42863 .39123 .42238 .38099 Mtetra
.545 .745 .969 r
.42238 .38099 .42863 .39123 .45054 .39163 .44444 .38147 Mtetra
.552 .751 .97 r
.44444 .38147 .45054 .39163 .47256 .39173 .46661 .38163 Mtetra
.557 .756 .971 r
.46661 .38163 .47256 .39173 .49468 .39157 .48887 .38151 Mtetra
.562 .761 .971 r
.48887 .38151 .49468 .39157 .51689 .39119 .51124 .38117 Mtetra
.566 .764 .971 r
.51124 .38117 .51689 .39119 .5392 .39062 .53371 .38063 Mtetra
.569 .767 .972 r
.53371 .38063 .5392 .39062 .56161 .38989 .55626 .37992 Mtetra
.572 .77 .972 r
.55626 .37992 .56161 .38989 .5841 .38902 .57892 .37906 Mtetra
.575 .772 .972 r
.57892 .37906 .5841 .38902 .60669 .38803 .60166 .37807 Mtetra
.577 .774 .973 r
.60166 .37807 .60669 .38803 .62936 .38692 .6245 .37696 Mtetra
.579 .776 .973 r
.6245 .37696 .62936 .38692 .65213 .38572 .64743 .37576 Mtetra
.58 .777 .973 r
.64743 .37576 .65213 .38572 .67498 .38443 .67045 .37446 Mtetra
.582 .779 .973 r
.67045 .37446 .67498 .38443 .69793 .38306 .69356 .37308 Mtetra
.583 .78 .973 r
.69356 .37308 .69793 .38306 .72097 .38162 .71677 .37162 Mtetra
.584 .781 .973 r
.71677 .37162 .72097 .38162 .74409 .38011 .74006 .3701 Mtetra
.585 .782 .973 r
.74006 .3701 .74409 .38011 .7673 .37854 .76344 .36851 Mtetra
.586 .783 .973 r
.76344 .36851 .7673 .37854 .79061 .37691 .78692 .36687 Mtetra
.587 .784 .974 r
.78692 .36687 .79061 .37691 .814 .37524 .81049 .36517 Mtetra
.588 .784 .974 r
.81049 .36517 .814 .37524 .83748 .37352 .83415 .36343 Mtetra
.588 .785 .974 r
.83415 .36343 .83748 .37352 .86106 .37175 .85789 .36164 Mtetra
.589 .786 .974 r
.85789 .36164 .86106 .37175 .88472 .36994 .88174 .3598 Mtetra
.88174 .3598 .88472 .36994 .90847 .3681 .90567 .35793 Mtetra
.59 .787 .974 r
.90567 .35793 .90847 .3681 .93232 .36622 .9297 .35603 Mtetra
.9297 .35603 .93232 .36622 .95626 .3643 .95381 .35408 Mtetra
.575 .767 .97 r
.18231 .30201 .19013 .31175 .21054 .31844 .20329 .30123 Mtetra
.047 .287 .779 r
.20329 .30123 .21054 .31844 .23043 .33699 .22312 .32218 Mtetra
.205 .441 .866 r
.22312 .32218 .23043 .33699 .25083 .34978 .24355 .33641 Mtetra
.311 .54 .911 r
.24355 .33641 .25083 .34978 .2716 .35892 .26439 .34647 Mtetra
.381 .604 .936 r
.26439 .34647 .2716 .35892 .29263 .36559 .28552 .35377 Mtetra
.43 .647 .949 r
.28552 .35377 .29263 .36559 .31388 .37051 .30687 .35914 Mtetra
.464 .676 .957 r
.30687 .35914 .31388 .37051 .3353 .37416 .32842 .36311 Mtetra
.489 .698 .962 r
.32842 .36311 .3353 .37416 .35688 .37684 .35012 .36603 Mtetra
.508 .714 .965 r
.35012 .36603 .35688 .37684 .37859 .37878 .37197 .36815 Mtetra
.522 .726 .967 r
.37197 .36815 .37859 .37878 .40043 .38012 .39394 .36963 Mtetra
.533 .736 .968 r
.39394 .36963 .40043 .38012 .42238 .38099 .41604 .3706 Mtetra
.542 .744 .969 r
.41604 .3706 .42238 .38099 .44444 .38147 .43825 .37116 Mtetra
.55 .75 .97 r
.43825 .37116 .44444 .38147 .46661 .38163 .46056 .37138 Mtetra
.556 .755 .971 r
.46056 .37138 .46661 .38163 .48887 .38151 .48298 .37131 Mtetra
.561 .76 .971 r
.48298 .37131 .48887 .38151 .51124 .38117 .5055 .371 Mtetra
.565 .763 .972 r
.5055 .371 .51124 .38117 .53371 .38063 .52813 .37048 Mtetra
.568 .766 .972 r
.52813 .37048 .53371 .38063 .55626 .37992 .55084 .36979 Mtetra
.571 .769 .972 r
.55084 .36979 .55626 .37992 .57892 .37906 .57366 .36894 Mtetra
.574 .771 .972 r
.57366 .36894 .57892 .37906 .60166 .37807 .59656 .36796 Mtetra
.576 .774 .973 r
.59656 .36796 .60166 .37807 .6245 .37696 .61957 .36685 Mtetra
.578 .775 .973 r
.61957 .36685 .6245 .37696 .64743 .37576 .64266 .36564 Mtetra
.58 .777 .973 r
.64266 .36564 .64743 .37576 .67045 .37446 .66585 .36433 Mtetra
.581 .778 .973 r
.66585 .36433 .67045 .37446 .69356 .37308 .68913 .36294 Mtetra
.583 .78 .973 r
.68913 .36294 .69356 .37308 .71677 .37162 .7125 .36147 Mtetra
.584 .781 .973 r
.7125 .36147 .71677 .37162 .74006 .3701 .73597 .35993 Mtetra
.585 .782 .973 r
.73597 .35993 .74006 .3701 .76344 .36851 .75953 .35833 Mtetra
.586 .783 .974 r
.75953 .35833 .76344 .36851 .78692 .36687 .78318 .35666 Mtetra
.587 .784 .974 r
.78318 .35666 .78692 .36687 .81049 .36517 .80692 .35495 Mtetra
.80692 .35495 .81049 .36517 .83415 .36343 .83076 .35318 Mtetra
.588 .785 .974 r
.83076 .35318 .83415 .36343 .85789 .36164 .85468 .35137 Mtetra
.589 .786 .974 r
.85468 .35137 .85789 .36164 .88174 .3598 .87871 .34951 Mtetra
.87871 .34951 .88174 .3598 .90567 .35793 .90282 .34761 Mtetra
.59 .787 .974 r
.90282 .34761 .90567 .35793 .9297 .35603 .92703 .34567 Mtetra
.92703 .34567 .9297 .35603 .95381 .35408 .95134 .3437 Mtetra
.617 .786 .963 r
.17437 .29213 .18231 .30201 .20329 .30123 .19559 .28974 Mtetra
0 .254 .76 r
.19559 .28974 .20329 .30123 .22312 .32218 .21572 .30719 Mtetra
.15 .402 .849 r
.21572 .30719 .22312 .32218 .24355 .33641 .23618 .32286 Mtetra
.277 .517 .904 r
.23618 .32286 .24355 .33641 .26439 .34647 .25708 .33386 Mtetra
.36 .59 .932 r
.25708 .33386 .26439 .34647 .28552 .35377 .2783 .34179 Mtetra
.415 .638 .948 r
.2783 .34179 .28552 .35377 .30687 .35914 .29976 .34761 Mtetra
.454 .67 .956 r
.29976 .34761 .30687 .35914 .32842 .36311 .32143 .3519 Mtetra
.481 .694 .961 r
.32143 .3519 .32842 .36311 .35012 .36603 .34326 .35506 Mtetra
.502 .711 .965 r
.34326 .35506 .35012 .36603 .37197 .36815 .36524 .35736 Mtetra
.518 .724 .967 r
.36524 .35736 .37197 .36815 .39394 .36963 .38736 .35898 Mtetra
.53 .734 .968 r
.38736 .35898 .39394 .36963 .41604 .3706 .4096 .36005 Mtetra
.54 .742 .969 r
.4096 .36005 .41604 .3706 .43825 .37116 .43196 .36069 Mtetra
.547 .749 .97 r
.43196 .36069 .43825 .37116 .46056 .37138 .45443 .36097 Mtetra
.554 .754 .971 r
.45443 .36097 .46056 .37138 .48298 .37131 .477 .36095 Mtetra
.559 .759 .971 r
.477 .36095 .48298 .37131 .5055 .371 .49968 .36068 Mtetra
.563 .763 .972 r
.49968 .36068 .5055 .371 .52813 .37048 .52246 .36019 Mtetra
.567 .766 .972 r
.52246 .36019 .52813 .37048 .55084 .36979 .54534 .35951 Mtetra
.57 .769 .972 r
.54534 .35951 .55084 .36979 .57366 .36894 .56831 .35867 Mtetra
.573 .771 .972 r
.56831 .35867 .57366 .36894 .59656 .36796 .59139 .35769 Mtetra
.575 .773 .973 r
.59139 .35769 .59656 .36796 .61957 .36685 .61455 .35658 Mtetra
.577 .775 .973 r
.61455 .35658 .61957 .36685 .64266 .36564 .63782 .35537 Mtetra
.579 .777 .973 r
.63782 .35537 .64266 .36564 .66585 .36433 .66118 .35405 Mtetra
.581 .778 .973 r
.66118 .35405 .66585 .36433 .68913 .36294 .68463 .35265 Mtetra
.582 .779 .973 r
.68463 .35265 .68913 .36294 .7125 .36147 .70817 .35116 Mtetra
.583 .781 .973 r
.70817 .35116 .7125 .36147 .73597 .35993 .73181 .34961 Mtetra
.584 .782 .973 r
.73181 .34961 .73597 .35993 .75953 .35833 .75555 .34798 Mtetra
.585 .782 .974 r
.75555 .34798 .75953 .35833 .78318 .35666 .77937 .3463 Mtetra
.586 .783 .974 r
.77937 .3463 .78318 .35666 .80692 .35495 .8033 .34456 Mtetra
.587 .784 .974 r
.8033 .34456 .80692 .35495 .83076 .35318 .82731 .34277 Mtetra
.588 .785 .974 r
.82731 .34277 .83076 .35318 .85468 .35137 .85142 .34093 Mtetra
.85142 .34093 .85468 .35137 .87871 .34951 .87563 .33905 Mtetra
.589 .786 .974 r
.87563 .33905 .87871 .34951 .90282 .34761 .89993 .33712 Mtetra
.589 .787 .974 r
.89993 .33712 .90282 .34761 .92703 .34567 .92432 .33516 Mtetra
.59 .787 .974 r
.92432 .33516 .92703 .34567 .95134 .3437 .94882 .33316 Mtetra
.617 .786 .963 r
.16632 .28211 .17437 .29213 .19559 .28974 .18767 .27968 Mtetra
.021 .414 .86 r
.18767 .27968 .19559 .28974 .21572 .30719 .20823 .29199 Mtetra
.094 .361 .828 r
.20823 .29199 .21572 .30719 .23618 .32286 .2287 .30913 Mtetra
.242 .493 .895 r
.2287 .30913 .23618 .32286 .25708 .33386 .24966 .32107 Mtetra
.337 .575 .929 r
.24966 .32107 .25708 .33386 .2783 .34179 .27097 .32964 Mtetra
.4 .628 .946 r
.27097 .32964 .2783 .34179 .29976 .34761 .29255 .3359 Mtetra
.443 .664 .956 r
.29255 .3359 .29976 .34761 .32143 .3519 .31434 .34052 Mtetra
.474 .689 .961 r
.31434 .34052 .32143 .3519 .34326 .35506 .3363 .34393 Mtetra
.496 .708 .965 r
.3363 .34393 .34326 .35506 .36524 .35736 .35842 .34641 Mtetra
.513 .721 .967 r
.35842 .34641 .36524 .35736 .38736 .35898 .38068 .34816 Mtetra
.526 .732 .968 r
.38068 .34816 .38736 .35898 .4096 .36005 .40307 .34935 Mtetra
.537 .741 .969 r
.40307 .34935 .4096 .36005 .43196 .36069 .42558 .35007 Mtetra
.545 .748 .97 r
.42558 .35007 .43196 .36069 .45443 .36097 .4482 .35041 Mtetra
.552 .753 .971 r
.4482 .35041 .45443 .36097 .477 .36095 .47093 .35044 Mtetra
.558 .758 .971 r
.47093 .35044 .477 .36095 .49968 .36068 .49377 .3502 Mtetra
.562 .762 .972 r
.49377 .3502 .49968 .36068 .52246 .36019 .51671 .34973 Mtetra
.566 .765 .972 r
.51671 .34973 .52246 .36019 .54534 .35951 .53975 .34907 Mtetra
.569 .768 .972 r
.53975 .34907 .54534 .35951 .56831 .35867 .56289 .34824 Mtetra
.572 .771 .972 r
.56289 .34824 .56831 .35867 .59139 .35769 .58613 .34726 Mtetra
.575 .773 .973 r
.58613 .34726 .59139 .35769 .61455 .35658 .60947 .34616 Mtetra
.577 .775 .973 r
.60947 .34616 .61455 .35658 .63782 .35537 .6329 .34493 Mtetra
.579 .776 .973 r
.6329 .34493 .63782 .35537 .66118 .35405 .65643 .34361 Mtetra
.58 .778 .973 r
.65643 .34361 .66118 .35405 .68463 .35265 .68005 .34219 Mtetra
.582 .779 .973 r
.68005 .34219 .68463 .35265 .70817 .35116 .70377 .3407 Mtetra
.583 .78 .973 r
.70377 .3407 .70817 .35116 .73181 .34961 .72759 .33912 Mtetra
.584 .781 .973 r
.72759 .33912 .73181 .34961 .75555 .34798 .7515 .33748 Mtetra
.585 .782 .974 r
.7515 .33748 .75555 .34798 .77937 .3463 .77551 .33578 Mtetra
.586 .783 .974 r
.77551 .33578 .77937 .3463 .8033 .34456 .79961 .33401 Mtetra
.587 .784 .974 r
.79961 .33401 .8033 .34456 .82731 .34277 .82381 .3322 Mtetra
.588 .785 .974 r
.82381 .3322 .82731 .34277 .85142 .34093 .84811 .33033 Mtetra
.84811 .33033 .85142 .34093 .87563 .33905 .8725 .32842 Mtetra
.589 .786 .974 r
.8725 .32842 .87563 .33905 .89993 .33712 .89699 .32647 Mtetra
.589 .787 .974 r
.89699 .32647 .89993 .33712 .92432 .33516 .92157 .32448 Mtetra
.59 .787 .974 r
.92157 .32448 .92432 .33516 .94882 .33316 .94626 .32244 Mtetra
.617 .786 .963 r
.15814 .27193 .16632 .28211 .18767 .27968 .17964 .26947 Mtetra
.282 .598 .95 r
.17964 .26947 .18767 .27968 .20823 .29199 .20063 .2766 Mtetra
.036 .318 .804 r
.20063 .2766 .20823 .29199 .2287 .30913 .22112 .29521 Mtetra
.206 .468 .885 r
.22112 .29521 .2287 .30913 .24966 .32107 .24214 .3081 Mtetra
.314 .56 .924 r
.24214 .3081 .24966 .32107 .27097 .32964 .26355 .31731 Mtetra
.385 .619 .944 r
.26355 .31731 .27097 .32964 .29255 .3359 .28523 .32403 Mtetra
.432 .657 .955 r
.28523 .32403 .29255 .3359 .31434 .34052 .30714 .32898 Mtetra
.466 .685 .961 r
.30714 .32898 .31434 .34052 .3363 .34393 .32924 .33263 Mtetra
.491 .704 .965 r
.32924 .33263 .3363 .34393 .35842 .34641 .3515 .33529 Mtetra
.509 .719 .967 r
.3515 .33529 .35842 .34641 .38068 .34816 .3739 .33719 Mtetra
.523 .73 .969 r
.3739 .33719 .38068 .34816 .40307 .34935 .39644 .33848 Mtetra
.534 .739 .97 r
.39644 .33848 .40307 .34935 .42558 .35007 .4191 .33929 Mtetra
.543 .746 .97 r
.4191 .33929 .42558 .35007 .4482 .35041 .44188 .33969 Mtetra
.55 .752 .971 r
.44188 .33969 .4482 .35041 .47093 .35044 .46477 .33976 Mtetra
.556 .757 .971 r
.46477 .33976 .47093 .35044 .49377 .3502 .48776 .33956 Mtetra
.561 .761 .972 r
.48776 .33956 .49377 .3502 .51671 .34973 .51087 .33911 Mtetra
.565 .765 .972 r
.51087 .33911 .51671 .34973 .53975 .34907 .53407 .33847 Mtetra
.568 .768 .972 r
.53407 .33847 .53975 .34907 .56289 .34824 .55738 .33765 Mtetra
.571 .77 .973 r
.55738 .33765 .56289 .34824 .58613 .34726 .58079 .33667 Mtetra
.574 .772 .973 r
.58079 .33667 .58613 .34726 .60947 .34616 .6043 .33557 Mtetra
.576 .774 .973 r
.6043 .33557 .60947 .34616 .6329 .34493 .6279 .33434 Mtetra
.578 .776 .973 r
.6279 .33434 .6329 .34493 .65643 .34361 .65161 .33301 Mtetra
.58 .777 .973 r
.65161 .33301 .65643 .34361 .68005 .34219 .67541 .33158 Mtetra
.581 .779 .973 r
.67541 .33158 .68005 .34219 .70377 .3407 .69931 .33006 Mtetra
.583 .78 .973 r
.69931 .33006 .70377 .3407 .72759 .33912 .7233 .32847 Mtetra
.584 .781 .973 r
.7233 .32847 .72759 .33912 .7515 .33748 .7474 .32681 Mtetra
.585 .782 .974 r
.7474 .32681 .7515 .33748 .77551 .33578 .77159 .32508 Mtetra
.586 .783 .974 r
.77159 .32508 .77551 .33578 .79961 .33401 .79587 .3233 Mtetra
.587 .784 .974 r
.79587 .3233 .79961 .33401 .82381 .3322 .82026 .32146 Mtetra
.587 .785 .974 r
.82026 .32146 .82381 .3322 .84811 .33033 .84474 .31957 Mtetra
.588 .785 .974 r
.84474 .31957 .84811 .33033 .8725 .32842 .86932 .31763 Mtetra
.589 .786 .974 r
.86932 .31763 .8725 .32842 .89699 .32647 .894 .31564 Mtetra
.894 .31564 .89699 .32647 .92157 .32448 .91878 .31362 Mtetra
.59 .787 .974 r
.91878 .31362 .92157 .32448 .94626 .32244 .94366 .31156 Mtetra
.617 .786 .963 r
.14985 .2616 .15814 .27193 .17964 .26947 .17149 .2591 Mtetra
.49 .723 .975 r
.17149 .2591 .17964 .26947 .20063 .2766 .19294 .26101 Mtetra
0 .273 .777 r
.19294 .26101 .20063 .2766 .22112 .29521 .21343 .2811 Mtetra
.169 .442 .874 r
.21343 .2811 .22112 .29521 .24214 .3081 .23452 .29494 Mtetra
.291 .545 .919 r
.23452 .29494 .24214 .3081 .26355 .31731 .25601 .30481 Mtetra
.369 .609 .942 r
.25601 .30481 .26355 .31731 .28523 .32403 .27781 .31199 Mtetra
.422 .651 .954 r
.27781 .31199 .28523 .32403 .30714 .32898 .29984 .31727 Mtetra
.458 .68 .96 r
.29984 .31727 .30714 .32898 .32924 .33263 .32207 .32116 Mtetra
.485 .701 .964 r
.32207 .32116 .32924 .33263 .3515 .33529 .34447 .32401 Mtetra
.504 .716 .967 r
.34447 .32401 .3515 .33529 .3739 .33719 .36702 .32605 Mtetra
.52 .728 .969 r
.36702 .32605 .3739 .33719 .39644 .33848 .38971 .32745 Mtetra
.531 .738 .97 r
.38971 .32745 .39644 .33848 .4191 .33929 .41252 .32834 Mtetra
.541 .745 .97 r
.41252 .32834 .4191 .33929 .44188 .33969 .43546 .3288 Mtetra
.548 .751 .971 r
.43546 .3288 .44188 .33969 .46477 .33976 .45851 .32892 Mtetra
.554 .756 .972 r
.45851 .32892 .46477 .33976 .48776 .33956 .48167 .32875 Mtetra
.56 .76 .972 r
.48167 .32875 .48776 .33956 .51087 .33911 .50494 .32833 Mtetra
.564 .764 .972 r
.50494 .32833 .51087 .33911 .53407 .33847 .52831 .3277 Mtetra
.568 .767 .972 r
.52831 .3277 .53407 .33847 .55738 .33765 .55179 .32689 Mtetra
.571 .77 .973 r
.55179 .32689 .55738 .33765 .58079 .33667 .57537 .32592 Mtetra
.573 .772 .973 r
.57537 .32592 .58079 .33667 .6043 .33557 .59905 .32481 Mtetra
.576 .774 .973 r
.59905 .32481 .6043 .33557 .6279 .33434 .62283 .32358 Mtetra
.578 .776 .973 r
.62283 .32358 .6279 .33434 .65161 .33301 .64671 .32223 Mtetra
.579 .777 .973 r
.64671 .32223 .65161 .33301 .67541 .33158 .67069 .32079 Mtetra
.581 .779 .973 r
.67069 .32079 .67541 .33158 .69931 .33006 .69477 .31926 Mtetra
.582 .78 .973 r
.69477 .31926 .69931 .33006 .7233 .32847 .71895 .31765 Mtetra
.583 .781 .973 r
.71895 .31765 .7233 .32847 .7474 .32681 .74322 .31597 Mtetra
.584 .782 .974 r
.74322 .31597 .7474 .32681 .77159 .32508 .7676 .31422 Mtetra
.585 .783 .974 r
.7676 .31422 .77159 .32508 .79587 .3233 .79208 .31241 Mtetra
.586 .784 .974 r
.79208 .31241 .79587 .3233 .82026 .32146 .81665 .31054 Mtetra
.587 .784 .974 r
.81665 .31054 .82026 .32146 .84474 .31957 .84132 .30862 Mtetra
.588 .785 .974 r
.84132 .30862 .84474 .31957 .86932 .31763 .8661 .30666 Mtetra
.588 .786 .974 r
.8661 .30666 .86932 .31763 .894 .31564 .89097 .30464 Mtetra
.589 .786 .974 r
.89097 .30464 .894 .31564 .91878 .31362 .91594 .30259 Mtetra
.589 .787 .974 r
.91594 .30259 .91878 .31362 .94366 .31156 .94101 .3005 Mtetra
.617 .786 .963 r
.14142 .25112 .14985 .2616 .17149 .2591 .16322 .24858 Mtetra
.16322 .24858 .17149 .2591 .19294 .26101 .18509 .24603 Mtetra
0 .233 .752 r
.18509 .24603 .19294 .26101 .21343 .2811 .20564 .26679 Mtetra
.131 .415 .861 r
.20564 .26679 .21343 .2811 .23452 .29494 .22679 .2816 Mtetra
.267 .528 .914 r
.22679 .2816 .23452 .29494 .25601 .30481 .24837 .29212 Mtetra
.353 .598 .939 r
.24837 .29212 .25601 .30481 .27781 .31199 .27027 .29976 Mtetra
.411 .644 .953 r
.27027 .29976 .27781 .31199 .29984 .31727 .29243 .30538 Mtetra
.45 .675 .96 r
.29243 .30538 .29984 .31727 .32207 .32116 .31479 .30953 Mtetra
.479 .697 .964 r
.31479 .30953 .32207 .32116 .34447 .32401 .33734 .31256 Mtetra
.5 .714 .967 r
.33734 .31256 .34447 .32401 .36702 .32605 .36003 .31474 Mtetra
.516 .726 .969 r
.36003 .31474 .36702 .32605 .38971 .32745 .38287 .31625 Mtetra
.529 .736 .97 r
.38287 .31625 .38971 .32745 .41252 .32834 .40584 .31722 Mtetra
.538 .744 .971 r
.40584 .31722 .41252 .32834 .43546 .3288 .42894 .31775 Mtetra
.546 .75 .971 r
.42894 .31775 .43546 .3288 .45851 .32892 .45215 .31792 Mtetra
.553 .755 .972 r
.45215 .31792 .45851 .32892 .48167 .32875 .47548 .31778 Mtetra
.558 .76 .972 r
.47548 .31778 .48167 .32875 .50494 .32833 .49891 .31738 Mtetra
.563 .763 .972 r
.49891 .31738 .50494 .32833 .52831 .3277 .52246 .31677 Mtetra
.567 .766 .972 r
.52246 .31677 .52831 .3277 .55179 .32689 .54611 .31596 Mtetra
.57 .769 .973 r
.54611 .31596 .55179 .32689 .57537 .32592 .56986 .315 Mtetra
.573 .771 .973 r
.56986 .315 .57537 .32592 .59905 .32481 .59372 .31388 Mtetra
.575 .774 .973 r
.59372 .31388 .59905 .32481 .62283 .32358 .61767 .31264 Mtetra
.577 .775 .973 r
.61767 .31264 .62283 .32358 .64671 .32223 .64174 .31129 Mtetra
.579 .777 .973 r
.64174 .31129 .64671 .32223 .67069 .32079 .6659 .30983 Mtetra
.58 .778 .973 r
.6659 .30983 .67069 .32079 .69477 .31926 .69016 .30829 Mtetra
.582 .78 .973 r
.69016 .30829 .69477 .31926 .71895 .31765 .71452 .30666 Mtetra
.583 .781 .974 r
.71452 .30666 .71895 .31765 .74322 .31597 .73899 .30495 Mtetra
.584 .782 .974 r
.73899 .30495 .74322 .31597 .7676 .31422 .76355 .30318 Mtetra
.585 .783 .974 r
.76355 .30318 .7676 .31422 .79208 .31241 .78821 .30134 Mtetra
.586 .784 .974 r
.78821 .30134 .79208 .31241 .81665 .31054 .81298 .29945 Mtetra
.587 .784 .974 r
.81298 .29945 .81665 .31054 .84132 .30862 .83785 .2975 Mtetra
.588 .785 .974 r
.83785 .2975 .84132 .30862 .8661 .30666 .86281 .29551 Mtetra
.588 .786 .974 r
.86281 .29551 .8661 .30666 .89097 .30464 .88788 .29346 Mtetra
.589 .786 .974 r
.88788 .29346 .89097 .30464 .91594 .30259 .91305 .29138 Mtetra
.589 .787 .974 r
.91305 .29138 .91594 .30259 .94101 .3005 .93833 .28925 Mtetra
.617 .786 .963 r
.13287 .24047 .14142 .25112 .16322 .24858 .15482 .2379 Mtetra
.15482 .2379 .16322 .24858 .18509 .24603 .17684 .23531 Mtetra
0 .241 .741 r
.17684 .23531 .18509 .24603 .20564 .26679 .19774 .25229 Mtetra
.093 .387 .846 r
.19774 .25229 .20564 .26679 .22679 .2816 .21894 .26807 Mtetra
.242 .512 .907 r
.21894 .26807 .22679 .2816 .24837 .29212 .24061 .27925 Mtetra
.337 .588 .937 r
.24061 .27925 .24837 .29212 .27027 .29976 .26263 .28736 Mtetra
.399 .637 .951 r
.26263 .28736 .27027 .29976 .29243 .30538 .28491 .29332 Mtetra
.442 .67 .959 r
.28491 .29332 .29243 .30538 .31479 .30953 .30741 .29771 Mtetra
.473 .694 .964 r
.30741 .29771 .31479 .30953 .33734 .31256 .33009 .30093 Mtetra
.495 .711 .967 r
.33009 .30093 .33734 .31256 .36003 .31474 .35294 .30326 Mtetra
.513 .724 .969 r
.35294 .30326 .36003 .31474 .38287 .31625 .37593 .30488 Mtetra
.526 .734 .97 r
.37593 .30488 .38287 .31625 .40584 .31722 .39906 .30593 Mtetra
.536 .742 .971 r
.39906 .30593 .40584 .31722 .42894 .31775 .42232 .30652 Mtetra
.545 .749 .971 r
.42232 .30652 .42894 .31775 .45215 .31792 .44569 .30673 Mtetra
.551 .754 .972 r
.44569 .30673 .45215 .31792 .47548 .31778 .46919 .30663 Mtetra
.557 .759 .972 r
.46919 .30663 .47548 .31778 .49891 .31738 .49279 .30626 Mtetra
.562 .763 .972 r
.49279 .30626 .49891 .31738 .52246 .31677 .51651 .30566 Mtetra
.566 .766 .973 r
.51651 .30566 .52246 .31677 .54611 .31596 .54033 .30486 Mtetra
.569 .769 .973 r
.54033 .30486 .54611 .31596 .56986 .315 .56426 .3039 Mtetra
.572 .771 .973 r
.56426 .3039 .56986 .315 .59372 .31388 .5883 .30278 Mtetra
.574 .773 .973 r
.5883 .30278 .59372 .31388 .61767 .31264 .61244 .30153 Mtetra
.577 .775 .973 r
.61244 .30153 .61767 .31264 .64174 .31129 .63668 .30017 Mtetra
.578 .777 .973 r
.63668 .30017 .64174 .31129 .6659 .30983 .66103 .2987 Mtetra
.58 .778 .973 r
.66103 .2987 .6659 .30983 .69016 .30829 .68547 .29713 Mtetra
.581 .779 .973 r
.68547 .29713 .69016 .30829 .71452 .30666 .71002 .29548 Mtetra
.583 .781 .974 r
.71002 .29548 .71452 .30666 .73899 .30495 .73468 .29376 Mtetra
.584 .782 .974 r
.73468 .29376 .73899 .30495 .76355 .30318 .75943 .29196 Mtetra
.585 .782 .974 r
.75943 .29196 .76355 .30318 .78821 .30134 .78429 .2901 Mtetra
.586 .783 .974 r
.78429 .2901 .78821 .30134 .81298 .29945 .80925 .28818 Mtetra
.587 .784 .974 r
.80925 .28818 .81298 .29945 .83785 .2975 .83431 .2862 Mtetra
.587 .785 .974 r
.83431 .2862 .83785 .2975 .86281 .29551 .85948 .28418 Mtetra
.588 .785 .974 r
.85948 .28418 .86281 .29551 .88788 .29346 .88475 .2821 Mtetra
.589 .786 .974 r
.88475 .2821 .88788 .29346 .91305 .29138 .91012 .27998 Mtetra
.589 .787 .974 r
.91012 .27998 .91305 .29138 .93833 .28925 .9356 .27782 Mtetra
.617 .786 .963 r
.12419 .22967 .13287 .24047 .15482 .2379 .14629 .22705 Mtetra
.14629 .22705 .15482 .2379 .17684 .23531 .16847 .22442 Mtetra
.002 .397 .849 r
.16847 .22442 .17684 .23531 .19774 .25229 .18973 .23758 Mtetra
.054 .358 .83 r
.18973 .23758 .19774 .25229 .21894 .26807 .21098 .25434 Mtetra
.217 .494 .9 r
.21098 .25434 .21894 .26807 .24061 .27925 .23274 .26619 Mtetra
.32 .577 .933 r
.23274 .26619 .24061 .27925 .26263 .28736 .25487 .27477 Mtetra
.388 .63 .95 r
.25487 .27477 .26263 .28736 .28491 .29332 .27727 .28107 Mtetra
.434 .665 .959 r
.27727 .28107 .28491 .29332 .30741 .29771 .29991 .28571 Mtetra
.467 .69 .964 r
.29991 .28571 .30741 .29771 .33009 .30093 .32274 .28913 Mtetra
.491 .708 .967 r
.32274 .28913 .33009 .30093 .35294 .30326 .34573 .2916 Mtetra
.509 .722 .969 r
.34573 .2916 .35294 .30326 .37593 .30488 .36888 .29332 Mtetra
.523 .733 .97 r
.36888 .29332 .37593 .30488 .39906 .30593 .39217 .29446 Mtetra
.534 .741 .971 r
.39217 .29446 .39906 .30593 .42232 .30652 .41559 .29512 Mtetra
.543 .748 .971 r
.41559 .29512 .42232 .30652 .44569 .30673 .43913 .29538 Mtetra
.55 .754 .972 r
.43913 .29538 .44569 .30673 .46919 .30663 .4628 .29531 Mtetra
.556 .758 .972 r
.4628 .29531 .46919 .30663 .49279 .30626 .48658 .29496 Mtetra
.561 .762 .972 r
.48658 .29496 .49279 .30626 .51651 .30566 .51047 .29437 Mtetra
.565 .765 .973 r
.51047 .29437 .51651 .30566 .54033 .30486 .53447 .29359 Mtetra
.568 .768 .973 r
.53447 .29359 .54033 .30486 .56426 .3039 .55858 .29262 Mtetra
.571 .771 .973 r
.55858 .29262 .56426 .3039 .5883 .30278 .58279 .2915 Mtetra
.574 .773 .973 r
.58279 .2915 .5883 .30278 .61244 .30153 .60712 .29024 Mtetra
.576 .775 .973 r
.60712 .29024 .61244 .30153 .63668 .30017 .63154 .28887 Mtetra
.578 .776 .973 r
.63154 .28887 .63668 .30017 .66103 .2987 .65608 .28738 Mtetra
.58 .778 .973 r
.65608 .28738 .66103 .2987 .68547 .29713 .68071 .2858 Mtetra
.581 .779 .973 r
.68071 .2858 .68547 .29713 .71002 .29548 .70545 .28413 Mtetra
.582 .78 .974 r
.70545 .28413 .71002 .29548 .73468 .29376 .7303 .28238 Mtetra
.584 .781 .974 r
.7303 .28238 .73468 .29376 .75943 .29196 .75525 .28056 Mtetra
.585 .782 .974 r
.75525 .28056 .75943 .29196 .78429 .2901 .7803 .27867 Mtetra
.586 .783 .974 r
.7803 .27867 .78429 .2901 .80925 .28818 .80546 .27672 Mtetra
.586 .784 .974 r
.80546 .27672 .80925 .28818 .83431 .2862 .83072 .27471 Mtetra
.587 .785 .974 r
.83072 .27471 .83431 .2862 .85948 .28418 .85609 .27266 Mtetra
.588 .785 .974 r
.85609 .27266 .85948 .28418 .88475 .2821 .88156 .27055 Mtetra
.588 .786 .974 r
.88156 .27055 .88475 .2821 .91012 .27998 .90714 .2684 Mtetra
.589 .787 .974 r
.90714 .2684 .91012 .27998 .9356 .27782 .93282 .2662 Mtetra
.617 .786 .963 r
.11538 .21869 .12419 .22967 .14629 .22705 .13763 .21604 Mtetra
.13763 .21604 .14629 .22705 .16847 .22442 .15996 .21337 Mtetra
.193 .537 .926 r
.15996 .21337 .16847 .22442 .18973 .23758 .1816 .22265 Mtetra
.015 .328 .813 r
.1816 .22265 .18973 .23758 .21098 .25434 .20291 .24041 Mtetra
.191 .476 .893 r
.20291 .24041 .21098 .25434 .23274 .26619 .22475 .25293 Mtetra
.304 .566 .93 r
.22475 .25293 .23274 .26619 .25487 .27477 .24699 .26199 Mtetra
.377 .623 .948 r
.24699 .26199 .25487 .27477 .27727 .28107 .26952 .26863 Mtetra
.426 .66 .958 r
.26952 .26863 .27727 .28107 .29991 .28571 .29229 .27353 Mtetra
.461 .687 .964 r
.29229 .27353 .29991 .28571 .32274 .28913 .31527 .27714 Mtetra
.486 .706 .967 r
.31527 .27714 .32274 .28913 .34573 .2916 .33842 .27975 Mtetra
.505 .72 .969 r
.33842 .27975 .34573 .2916 .36888 .29332 .36172 .28159 Mtetra
.52 .731 .97 r
.36172 .28159 .36888 .29332 .39217 .29446 .38517 .28281 Mtetra
.532 .74 .971 r
.38517 .28281 .39217 .29446 .41559 .29512 .40876 .28353 Mtetra
.541 .747 .971 r
.40876 .28353 .41559 .29512 .43913 .29538 .43247 .28384 Mtetra
.548 .753 .972 r
.43247 .28384 .43913 .29538 .4628 .29531 .45631 .2838 Mtetra
.554 .757 .972 r
.45631 .2838 .4628 .29531 .48658 .29496 .48026 .28348 Mtetra
.56 .761 .972 r
.48026 .28348 .48658 .29496 .51047 .29437 .50433 .28291 Mtetra
.564 .765 .973 r
.50433 .28291 .51047 .29437 .53447 .29359 .52851 .28213 Mtetra
.567 .768 .973 r
.52851 .28213 .53447 .29359 .55858 .29262 .5528 .28116 Mtetra
.57 .77 .973 r
.5528 .28116 .55858 .29262 .58279 .2915 .5772 .28004 Mtetra
.573 .772 .973 r
.5772 .28004 .58279 .2915 .60712 .29024 .60171 .27877 Mtetra
.575 .774 .973 r
.60171 .27877 .60712 .29024 .63154 .28887 .62632 .27738 Mtetra
.577 .776 .973 r
.62632 .27738 .63154 .28887 .65608 .28738 .65104 .27588 Mtetra
.579 .778 .973 r
.65104 .27588 .65608 .28738 .68071 .2858 .67587 .27428 Mtetra
.581 .779 .973 r
.67587 .27428 .68071 .2858 .70545 .28413 .70081 .27259 Mtetra
.582 .78 .974 r
.70081 .27259 .70545 .28413 .7303 .28238 .72585 .27081 Mtetra
.583 .781 .974 r
.72585 .27081 .7303 .28238 .75525 .28056 .75099 .26897 Mtetra
.584 .782 .974 r
.75099 .26897 .75525 .28056 .7803 .27867 .77625 .26705 Mtetra
.585 .783 .974 r
.77625 .26705 .7803 .27867 .80546 .27672 .80161 .26507 Mtetra
.586 .784 .974 r
.80161 .26507 .80546 .27672 .83072 .27471 .82707 .26303 Mtetra
.587 .785 .974 r
.82707 .26303 .83072 .27471 .85609 .27266 .85264 .26094 Mtetra
.588 .785 .974 r
.85264 .26094 .85609 .27266 .88156 .27055 .87832 .2588 Mtetra
.588 .786 .974 r
.87832 .2588 .88156 .27055 .90714 .2684 .90411 .25661 Mtetra
.589 .786 .974 r
.90411 .25661 .90714 .2684 .93282 .2662 .93 .25438 Mtetra
.617 .786 .963 r
.10642 .20755 .11538 .21869 .13763 .21604 .12883 .20485 Mtetra
.12883 .20485 .13763 .21604 .15996 .21337 .15132 .20214 Mtetra
.363 .649 .965 r
.15132 .20214 .15996 .21337 .1816 .22265 .17336 .20752 Mtetra
0 .298 .794 r
.17336 .20752 .1816 .22265 .20291 .24041 .19471 .22627 Mtetra
.165 .458 .884 r
.19471 .22627 .20291 .24041 .22475 .25293 .21664 .23947 Mtetra
.286 .554 .926 r
.21664 .23947 .22475 .25293 .24699 .26199 .23899 .24901 Mtetra
.365 .615 .947 r
.23899 .24901 .24699 .26199 .26952 .26863 .26165 .256 Mtetra
.418 .655 .957 r
.26165 .256 .26952 .26863 .29229 .27353 .28456 .26116 Mtetra
.455 .683 .963 r
.28456 .26116 .29229 .27353 .31527 .27714 .30768 .26496 Mtetra
.482 .703 .967 r
.30768 .26496 .31527 .27714 .33842 .27975 .33098 .26772 Mtetra
.502 .718 .969 r
.33098 .26772 .33842 .27975 .36172 .28159 .35445 .26967 Mtetra
.517 .729 .97 r
.35445 .26967 .36172 .28159 .38517 .28281 .37806 .27098 Mtetra
.529 .739 .971 r
.37806 .27098 .38517 .28281 .40876 .28353 .40182 .27176 Mtetra
.539 .746 .971 r
.40182 .27176 .40876 .28353 .43247 .28384 .4257 .27211 Mtetra
.547 .752 .972 r
.4257 .27211 .43247 .28384 .45631 .2838 .44971 .27211 Mtetra
.553 .757 .972 r
.44971 .27211 .45631 .2838 .48026 .28348 .47384 .27181 Mtetra
.558 .761 .972 r
.47384 .27181 .48026 .28348 .50433 .28291 .49809 .27125 Mtetra
.563 .764 .973 r
.49809 .27125 .50433 .28291 .52851 .28213 .52245 .27048 Mtetra
.567 .767 .973 r
.52245 .27048 .52851 .28213 .5528 .28116 .54693 .26952 Mtetra
.57 .77 .973 r
.54693 .26952 .5528 .28116 .5772 .28004 .57151 .26839 Mtetra
.573 .772 .973 r
.57151 .26839 .5772 .28004 .60171 .27877 .59621 .26711 Mtetra
.575 .774 .973 r
.59621 .26711 .60171 .27877 .62632 .27738 .62101 .26571 Mtetra
.577 .776 .973 r
.62101 .26571 .62632 .27738 .65104 .27588 .64593 .26419 Mtetra
.579 .777 .973 r
.64593 .26419 .65104 .27588 .67587 .27428 .67095 .26257 Mtetra
.58 .779 .974 r
.67095 .26257 .67587 .27428 .70081 .27259 .69608 .26085 Mtetra
.582 .78 .974 r
.69608 .26085 .70081 .27259 .72585 .27081 .72132 .25906 Mtetra
.583 .781 .974 r
.72132 .25906 .72585 .27081 .75099 .26897 .74667 .25718 Mtetra
.584 .782 .974 r
.74667 .25718 .75099 .26897 .77625 .26705 .77212 .25524 Mtetra
.585 .783 .974 r
.77212 .25524 .77625 .26705 .80161 .26507 .79769 .25323 Mtetra
.586 .784 .974 r
.79769 .25323 .80161 .26507 .82707 .26303 .82336 .25116 Mtetra
.587 .784 .974 r
.82336 .25116 .82707 .26303 .85264 .26094 .84914 .24903 Mtetra
.588 .785 .974 r
.84914 .24903 .85264 .26094 .87832 .2588 .87503 .24686 Mtetra
.588 .786 .974 r
.87503 .24686 .87832 .2588 .90411 .25661 .90102 .24464 Mtetra
.589 .786 .974 r
.90102 .24464 .90411 .25661 .93 .25438 .92713 .24237 Mtetra
.617 .786 .963 r
.09733 .19623 .10642 .20755 .12883 .20485 .1199 .19349 Mtetra
.1199 .19349 .12883 .20485 .15132 .20214 .14255 .19074 Mtetra
.503 .729 .974 r
.14255 .19074 .15132 .20214 .17336 .20752 .165 .19217 Mtetra
0 .267 .774 r
.165 .19217 .17336 .20752 .19471 .22627 .1864 .21193 Mtetra
.139 .439 .875 r
.1864 .21193 .19471 .22627 .21664 .23947 .20841 .22582 Mtetra
.269 .543 .922 r
.20841 .22582 .21664 .23947 .23899 .24901 .23087 .23583 Mtetra
.353 .607 .945 r
.23087 .23583 .23899 .24901 .26165 .256 .25365 .24318 Mtetra
.409 .65 .956 r
.25365 .24318 .26165 .256 .28456 .26116 .2767 .2486 Mtetra
.449 .679 .963 r
.2767 .2486 .28456 .26116 .30768 .26496 .29997 .25259 Mtetra
.477 .7 .966 r
.29997 .25259 .30768 .26496 .33098 .26772 .32343 .2555 Mtetra
.498 .716 .969 r
.32343 .2555 .33098 .26772 .35445 .26967 .34706 .25756 Mtetra
.514 .728 .97 r
.34706 .25756 .35445 .26967 .37806 .27098 .37084 .25895 Mtetra
.527 .737 .971 r
.37084 .25895 .37806 .27098 .40182 .27176 .39476 .2598 Mtetra
.537 .745 .972 r
.39476 .2598 .40182 .27176 .4257 .27211 .41882 .2602 Mtetra
.545 .751 .972 r
.41882 .2602 .4257 .27211 .44971 .27211 .44301 .26023 Mtetra
.552 .756 .972 r
.44301 .26023 .44971 .27211 .47384 .27181 .46732 .25995 Mtetra
.557 .76 .973 r
.46732 .25995 .47384 .27181 .49809 .27125 .49175 .25941 Mtetra
.562 .764 .973 r
.49175 .25941 .49809 .27125 .52245 .27048 .51629 .25864 Mtetra
.566 .767 .973 r
.51629 .25864 .52245 .27048 .54693 .26952 .54096 .25768 Mtetra
.569 .769 .973 r
.54096 .25768 .54693 .26952 .57151 .26839 .56573 .25654 Mtetra
.572 .772 .973 r
.56573 .25654 .57151 .26839 .59621 .26711 .59062 .25526 Mtetra
.574 .774 .973 r
.59062 .25526 .59621 .26711 .62101 .26571 .61562 .25384 Mtetra
.576 .775 .973 r
.61562 .25384 .62101 .26571 .64593 .26419 .64073 .2523 Mtetra
.578 .777 .973 r
.64073 .2523 .64593 .26419 .67095 .26257 .66595 .25066 Mtetra
.58 .778 .974 r
.66595 .25066 .67095 .26257 .69608 .26085 .69128 .24893 Mtetra
.581 .78 .974 r
.69128 .24893 .69608 .26085 .72132 .25906 .71672 .2471 Mtetra
.583 .781 .974 r
.71672 .2471 .72132 .25906 .74667 .25718 .74227 .2452 Mtetra
.584 .782 .974 r
.74227 .2452 .74667 .25718 .77212 .25524 .76793 .24322 Mtetra
.585 .783 .974 r
.76793 .24322 .77212 .25524 .79769 .25323 .7937 .24118 Mtetra
.586 .784 .974 r
.7937 .24118 .79769 .25323 .82336 .25116 .81958 .23908 Mtetra
.587 .784 .974 r
.81958 .23908 .82336 .25116 .84914 .24903 .84557 .23692 Mtetra
.587 .785 .974 r
.84557 .23692 .84914 .24903 .87503 .24686 .87167 .23471 Mtetra
.588 .786 .974 r
.87167 .23471 .87503 .24686 .90102 .24464 .89789 .23245 Mtetra
.589 .786 .974 r
.89789 .23245 .90102 .24464 .92713 .24237 .92421 .23014 Mtetra
.617 .786 .963 r
.0881 .18473 .09733 .19623 .1199 .19349 .11082 .18195 Mtetra
.11082 .18195 .1199 .19349 .14255 .19074 .13364 .17915 Mtetra
.611 .783 .964 r
.13364 .17915 .14255 .19074 .165 .19217 .15652 .1766 Mtetra
0 .236 .753 r
.15652 .1766 .165 .19217 .1864 .21193 .17796 .19737 Mtetra
.112 .419 .865 r
.17796 .19737 .1864 .21193 .20841 .22582 .20006 .21195 Mtetra
.251 .53 .918 r
.20006 .21195 .20841 .22582 .23087 .23583 .22262 .22246 Mtetra
.341 .6 .943 r
.22262 .22246 .23087 .23583 .25365 .24318 .24554 .23015 Mtetra
.401 .645 .956 r
.24554 .23015 .25365 .24318 .2767 .2486 .26873 .23584 Mtetra
.442 .675 .962 r
.26873 .23584 .2767 .2486 .29997 .25259 .29214 .24003 Mtetra
.472 .697 .966 r
.29214 .24003 .29997 .25259 .32343 .2555 .31576 .24308 Mtetra
.495 .714 .969 r
.31576 .24308 .32343 .2555 .34706 .25756 .33955 .24526 Mtetra
.512 .726 .97 r
.33955 .24526 .34706 .25756 .37084 .25895 .3635 .24673 Mtetra
.525 .736 .971 r
.3635 .24673 .37084 .25895 .39476 .2598 .3876 .24764 Mtetra
.535 .744 .972 r
.3876 .24764 .39476 .2598 .41882 .2602 .41183 .24809 Mtetra
.544 .75 .972 r
.41183 .24809 .41882 .2602 .44301 .26023 .43619 .24816 Mtetra
.55 .755 .972 r
.43619 .24816 .44301 .26023 .46732 .25995 .46069 .2479 Mtetra
.556 .759 .973 r
.46069 .2479 .46732 .25995 .49175 .25941 .4853 .24737 Mtetra
.561 .763 .973 r
.4853 .24737 .49175 .25941 .51629 .25864 .51004 .24661 Mtetra
.565 .766 .973 r
.51004 .24661 .51629 .25864 .54096 .25768 .53489 .24564 Mtetra
.568 .769 .973 r
.53489 .24564 .54096 .25768 .56573 .25654 .55986 .2445 Mtetra
.571 .771 .973 r
.55986 .2445 .56573 .25654 .59062 .25526 .58494 .24321 Mtetra
.574 .773 .973 r
.58494 .24321 .59062 .25526 .61562 .25384 .61013 .24177 Mtetra
.576 .775 .973 r
.61013 .24177 .61562 .25384 .64073 .2523 .63544 .24022 Mtetra
.578 .777 .973 r
.63544 .24022 .64073 .2523 .66595 .25066 .66086 .23856 Mtetra
.58 .778 .974 r
.66086 .23856 .66595 .25066 .69128 .24893 .6864 .23679 Mtetra
.581 .779 .974 r
.6864 .23679 .69128 .24893 .71672 .2471 .71204 .23494 Mtetra
.582 .781 .974 r
.71204 .23494 .71672 .2471 .74227 .2452 .7378 .23301 Mtetra
.584 .782 .974 r
.7378 .23301 .74227 .2452 .76793 .24322 .76367 .23101 Mtetra
.585 .783 .974 r
.76367 .23101 .76793 .24322 .7937 .24118 .78965 .22893 Mtetra
.586 .783 .974 r
.78965 .22893 .7937 .24118 .81958 .23908 .81574 .2268 Mtetra
.586 .784 .974 r
.81574 .2268 .81958 .23908 .84557 .23692 .84195 .2246 Mtetra
.587 .785 .974 r
.84195 .2246 .84557 .23692 .87167 .23471 .86827 .22236 Mtetra
.588 .786 .974 r
.86827 .22236 .87167 .23471 .89789 .23245 .8947 .22006 Mtetra
.8947 .22006 .89789 .23245 .92421 .23014 .92124 .21771 Mtetra
.617 .786 .963 r
.07871 .17305 .0881 .18473 .11082 .18195 .1016 .17022 Mtetra
.1016 .17022 .11082 .18195 .13364 .17915 .12458 .16738 Mtetra
.12458 .16738 .13364 .17915 .15652 .1766 .14765 .16453 Mtetra
0 .234 .738 r
.14765 .16453 .15652 .1766 .17796 .19737 .16939 .18259 Mtetra
.086 .399 .855 r
.16939 .18259 .17796 .19737 .20006 .21195 .19157 .19787 Mtetra
.233 .518 .913 r
.19157 .19787 .20006 .21195 .22262 .22246 .21425 .20887 Mtetra
.329 .592 .94 r
.21425 .20887 .22262 .22246 .24554 .23015 .23729 .21692 Mtetra
.392 .639 .954 r
.23729 .21692 .24554 .23015 .26873 .23584 .26062 .22287 Mtetra
.436 .672 .962 r
.26062 .22287 .26873 .23584 .29214 .24003 .28419 .22726 Mtetra
.468 .695 .966 r
.28419 .22726 .29214 .24003 .31576 .24308 .30797 .23047 Mtetra
.491 .712 .969 r
.30797 .23047 .31576 .24308 .33955 .24526 .33192 .23275 Mtetra
.509 .724 .97 r
.33192 .23275 .33955 .24526 .3635 .24673 .35604 .23431 Mtetra
.522 .735 .971 r
.35604 .23431 .3635 .24673 .3876 .24764 .38031 .23529 Mtetra
.533 .743 .972 r
.38031 .23529 .3876 .24764 .41183 .24809 .40472 .23578 Mtetra
.542 .749 .972 r
.40472 .23578 .41183 .24809 .43619 .24816 .42927 .23588 Mtetra
.549 .754 .972 r
.42927 .23588 .43619 .24816 .46069 .2479 .45395 .23565 Mtetra
.555 .759 .973 r
.45395 .23565 .46069 .2479 .4853 .24737 .47875 .23513 Mtetra
.56 .763 .973 r
.47875 .23513 .4853 .24737 .51004 .24661 .50367 .23437 Mtetra
.564 .766 .973 r
.50367 .23437 .51004 .24661 .53489 .24564 .52872 .23341 Mtetra
.568 .769 .973 r
.52872 .23341 .53489 .24564 .55986 .2445 .55388 .23226 Mtetra
.571 .771 .973 r
.55388 .23226 .55986 .2445 .58494 .24321 .57916 .23095 Mtetra
.573 .773 .973 r
.57916 .23095 .58494 .24321 .61013 .24177 .60456 .2295 Mtetra
.576 .775 .973 r
.60456 .2295 .61013 .24177 .63544 .24022 .63007 .22793 Mtetra
.578 .777 .974 r
.63007 .22793 .63544 .24022 .66086 .23856 .65569 .22624 Mtetra
.579 .778 .974 r
.65569 .22624 .66086 .23856 .6864 .23679 .68143 .22446 Mtetra
.581 .779 .974 r
.68143 .22446 .6864 .23679 .71204 .23494 .70729 .22258 Mtetra
.582 .78 .974 r
.70729 .22258 .71204 .23494 .7378 .23301 .73325 .22062 Mtetra
.583 .781 .974 r
.73325 .22062 .7378 .23301 .76367 .23101 .75933 .21858 Mtetra
.584 .782 .974 r
.75933 .21858 .76367 .23101 .78965 .22893 .78553 .21648 Mtetra
.585 .783 .974 r
.78553 .21648 .78965 .22893 .81574 .2268 .81184 .2143 Mtetra
.586 .784 .974 r
.81184 .2143 .81574 .2268 .84195 .2246 .83826 .21207 Mtetra
.587 .785 .974 r
.83826 .21207 .84195 .2246 .86827 .22236 .8648 .20979 Mtetra
.588 .785 .974 r
.8648 .20979 .86827 .22236 .8947 .22006 .89145 .20745 Mtetra
.588 .786 .974 r
.89145 .20745 .8947 .22006 .92124 .21771 .91822 .20506 Mtetra
.617 .786 .963 r
.06918 .16119 .07871 .17305 .1016 .17022 .09223 .15831 Mtetra
.09223 .15831 .1016 .17022 .12458 .16738 .11538 .15542 Mtetra
.11538 .15542 .12458 .16738 .14765 .16453 .13862 .15252 Mtetra
0 .343 .815 r
.13862 .15252 .14765 .16453 .16939 .18259 .1607 .16759 Mtetra
.058 .379 .843 r
.1607 .16759 .16939 .18259 .19157 .19787 .18296 .18357 Mtetra
.215 .505 .907 r
.18296 .18357 .19157 .19787 .21425 .20887 .20574 .19507 Mtetra
.316 .583 .938 r
.20574 .19507 .21425 .20887 .23729 .21692 .22891 .20348 Mtetra
.383 .634 .953 r
.22891 .20348 .23729 .21692 .26062 .22287 .25239 .2097 Mtetra
.43 .668 .961 r
.25239 .2097 .26062 .22287 .28419 .22726 .27611 .21429 Mtetra
.463 .692 .966 r
.27611 .21429 .28419 .22726 .30797 .23047 .30004 .21764 Mtetra
.487 .709 .968 r
.30004 .21764 .30797 .23047 .33192 .23275 .32417 .22005 Mtetra
.506 .723 .97 r
.32417 .22005 .33192 .23275 .35604 .23431 .34846 .22169 Mtetra
.52 .733 .971 r
.34846 .22169 .35604 .23431 .38031 .23529 .3729 .22273 Mtetra
.531 .741 .972 r
.3729 .22273 .38031 .23529 .40472 .23578 .3975 .22327 Mtetra
.54 .748 .972 r
.3975 .22327 .40472 .23578 .42927 .23588 .42223 .2234 Mtetra
.548 .754 .972 r
.42223 .2234 .42927 .23588 .45395 .23565 .44709 .22319 Mtetra
.554 .758 .973 r
.44709 .22319 .45395 .23565 .47875 .23513 .47209 .22269 Mtetra
.559 .762 .973 r
.47209 .22269 .47875 .23513 .50367 .23437 .4972 .22193 Mtetra
.563 .765 .973 r
.4972 .22193 .50367 .23437 .52872 .23341 .52244 .22097 Mtetra
.567 .768 .973 r
.52244 .22097 .52872 .23341 .55388 .23226 .5478 .21981 Mtetra
.57 .771 .973 r
.5478 .21981 .55388 .23226 .57916 .23095 .57329 .21849 Mtetra
.573 .773 .973 r
.57329 .21849 .57916 .23095 .60456 .2295 .59888 .21702 Mtetra
.575 .775 .973 r
.59888 .21702 .60456 .2295 .63007 .22793 .6246 .21543 Mtetra
.577 .776 .974 r
.6246 .21543 .63007 .22793 .65569 .22624 .65043 .21372 Mtetra
.579 .778 .974 r
.65043 .21372 .65569 .22624 .68143 .22446 .67638 .21191 Mtetra
.58 .779 .974 r
.67638 .21191 .68143 .22446 .70729 .22258 .70244 .21 Mtetra
.582 .78 .974 r
.70244 .21 .70729 .22258 .73325 .22062 .72863 .20801 Mtetra
.583 .781 .974 r
.72863 .20801 .73325 .22062 .75933 .21858 .75492 .20594 Mtetra
.584 .782 .974 r
.75492 .20594 .75933 .21858 .78553 .21648 .78133 .2038 Mtetra
.585 .783 .974 r
.78133 .2038 .78553 .21648 .81184 .2143 .80786 .20159 Mtetra
.586 .784 .974 r
.80786 .20159 .81184 .2143 .83826 .21207 .83451 .19932 Mtetra
.587 .785 .974 r
.83451 .19932 .83826 .21207 .8648 .20979 .86127 .197 Mtetra
.86127 .197 .8648 .20979 .89145 .20745 .88815 .19462 Mtetra
.588 .786 .974 r
.88815 .19462 .89145 .20745 .91822 .20506 .91514 .19219 Mtetra
.617 .786 .963 r
.05949 .14913 .06918 .16119 .09223 .15831 .08271 .1462 Mtetra
.08271 .1462 .09223 .15831 .11538 .15542 .10603 .14327 Mtetra
.10603 .14327 .11538 .15542 .13862 .15252 .12944 .14032 Mtetra
.082 .455 .884 r
.12944 .14032 .13862 .15252 .1607 .16759 .15187 .15236 Mtetra
.031 .358 .831 r
.15187 .15236 .1607 .16759 .18296 .18357 .17421 .16905 Mtetra
.197 .492 .902 r
.17421 .16905 .18296 .18357 .20574 .19507 .1971 .18105 Mtetra
.304 .575 .935 r
.1971 .18105 .20574 .19507 .22891 .20348 .2204 .18983 Mtetra
.375 .628 .952 r
.2204 .18983 .22891 .20348 .25239 .2097 .24402 .19631 Mtetra
.423 .664 .961 r
.24402 .19631 .25239 .2097 .27611 .21429 .26789 .2011 Mtetra
.458 .689 .966 r
.26789 .2011 .27611 .21429 .30004 .21764 .29199 .20461 Mtetra
.484 .707 .968 r
.29199 .20461 .30004 .21764 .32417 .22005 .31628 .20713 Mtetra
.503 .721 .97 r
.31628 .20713 .32417 .22005 .34846 .22169 .34075 .20886 Mtetra
.518 .732 .971 r
.34075 .20886 .34846 .22169 .3729 .22273 .36538 .20996 Mtetra
.529 .74 .972 r
.36538 .20996 .3729 .22273 .3975 .22327 .39015 .21055 Mtetra
.539 .747 .972 r
.39015 .21055 .3975 .22327 .42223 .2234 .41507 .21072 Mtetra
.547 .753 .973 r
.41507 .21072 .42223 .2234 .44709 .22319 .44012 .21052 Mtetra
.553 .758 .973 r
.44012 .21052 .44709 .22319 .47209 .22269 .46531 .21003 Mtetra
.558 .762 .973 r
.46531 .21003 .47209 .22269 .4972 .22193 .49062 .20928 Mtetra
.563 .765 .973 r
.49062 .20928 .4972 .22193 .52244 .22097 .51606 .20831 Mtetra
.566 .768 .973 r
.51606 .20831 .52244 .22097 .5478 .21981 .54163 .20715 Mtetra
.569 .77 .973 r
.54163 .20715 .5478 .21981 .57329 .21849 .56731 .20581 Mtetra
.572 .772 .973 r
.56731 .20581 .57329 .21849 .59888 .21702 .59311 .20433 Mtetra
.575 .774 .973 r
.59311 .20433 .59888 .21702 .6246 .21543 .61904 .20272 Mtetra
.577 .776 .974 r
.61904 .20272 .6246 .21543 .65043 .21372 .64508 .20098 Mtetra
.578 .778 .974 r
.64508 .20098 .65043 .21372 .67638 .21191 .67124 .19914 Mtetra
.58 .779 .974 r
.67124 .19914 .67638 .21191 .70244 .21 .69752 .19721 Mtetra
.582 .78 .974 r
.69752 .19721 .70244 .21 .72863 .20801 .72392 .19518 Mtetra
.583 .781 .974 r
.72392 .19518 .72863 .20801 .75492 .20594 .75043 .19308 Mtetra
.584 .782 .974 r
.75043 .19308 .75492 .20594 .78133 .2038 .77707 .1909 Mtetra
.585 .783 .974 r
.77707 .1909 .78133 .2038 .80786 .20159 .80382 .18866 Mtetra
.586 .784 .974 r
.80382 .18866 .80786 .20159 .83451 .19932 .83069 .18635 Mtetra
.587 .785 .974 r
.83069 .18635 .83451 .19932 .86127 .197 .85768 .18398 Mtetra
.85768 .18398 .86127 .197 .88815 .19462 .88479 .18156 Mtetra
.588 .786 .974 r
.88479 .18156 .88815 .19462 .91514 .19219 .91201 .17909 Mtetra
.617 .786 .963 r
.04964 .13687 .05949 .14913 .08271 .1462 .07304 .1339 Mtetra
.07304 .1339 .08271 .1462 .10603 .14327 .09653 .13092 Mtetra
.09653 .13092 .10603 .14327 .12944 .14032 .12011 .12792 Mtetra
.222 .555 .933 r
.12011 .12792 .12944 .14032 .15187 .15236 .14291 .1369 Mtetra
.004 .337 .819 r
.14291 .1369 .15187 .15236 .17421 .16905 .16532 .15431 Mtetra
.178 .479 .896 r
.16532 .15431 .17421 .16905 .1971 .18105 .18832 .16681 Mtetra
.291 .566 .933 r
.18832 .16681 .1971 .18105 .2204 .18983 .21175 .17596 Mtetra
.366 .622 .951 r
.21175 .17596 .2204 .18983 .24402 .19631 .23551 .18271 Mtetra
.417 .66 .96 r
.23551 .18271 .24402 .19631 .26789 .2011 .25954 .1877 Mtetra
.453 .686 .965 r
.25954 .1877 .26789 .2011 .29199 .20461 .28381 .19136 Mtetra
.48 .705 .968 r
.28381 .19136 .29199 .20461 .31628 .20713 .30827 .19399 Mtetra
.5 .719 .97 r
.30827 .19399 .31628 .20713 .34075 .20886 .33291 .19581 Mtetra
.515 .73 .971 r
.33291 .19581 .34075 .20886 .36538 .20996 .35772 .19698 Mtetra
.528 .739 .972 r
.35772 .19698 .36538 .20996 .39015 .21055 .38268 .19762 Mtetra
.537 .746 .972 r
.38268 .19762 .39015 .21055 .41507 .21072 .40779 .19781 Mtetra
.545 .752 .973 r
.40779 .19781 .41507 .21072 .44012 .21052 .43304 .19764 Mtetra
.552 .757 .973 r
.43304 .19764 .44012 .21052 .46531 .21003 .45842 .19716 Mtetra
.557 .761 .973 r
.45842 .19716 .46531 .21003 .49062 .20928 .48393 .19641 Mtetra
.562 .764 .973 r
.48393 .19641 .49062 .20928 .51606 .20831 .50957 .19544 Mtetra
.566 .767 .973 r
.50957 .19544 .51606 .20831 .54163 .20715 .53534 .19427 Mtetra
.569 .77 .973 r
.53534 .19427 .54163 .20715 .56731 .20581 .56123 .19292 Mtetra
.572 .772 .973 r
.56123 .19292 .56731 .20581 .59311 .20433 .58724 .19142 Mtetra
.574 .774 .974 r
.58724 .19142 .59311 .20433 .61904 .20272 .61338 .18978 Mtetra
.576 .776 .974 r
.61338 .18978 .61904 .20272 .64508 .20098 .63964 .18802 Mtetra
.578 .777 .974 r
.63964 .18802 .64508 .20098 .67124 .19914 .66601 .18615 Mtetra
.58 .779 .974 r
.66601 .18615 .67124 .19914 .69752 .19721 .69251 .18419 Mtetra
.581 .78 .974 r
.69251 .18419 .69752 .19721 .72392 .19518 .71913 .18213 Mtetra
.583 .781 .974 r
.71913 .18213 .72392 .19518 .75043 .19308 .74587 .17999 Mtetra
.584 .782 .974 r
.74587 .17999 .75043 .19308 .77707 .1909 .77272 .17778 Mtetra
.585 .783 .974 r
.77272 .17778 .77707 .1909 .80382 .18866 .7997 .17549 Mtetra
.586 .784 .974 r
.7997 .17549 .80382 .18866 .83069 .18635 .8268 .17315 Mtetra
.8268 .17315 .83069 .18635 .85768 .18398 .85402 .17074 Mtetra
.587 .785 .974 r
.85402 .17074 .85768 .18398 .88479 .18156 .88137 .16827 Mtetra
.588 .786 .974 r
.88137 .16827 .88479 .18156 .91201 .17909 .90883 .16576 Mtetra
.617 .786 .963 r
.03963 .12441 .04964 .13687 .07304 .1339 .0632 .12139 Mtetra
.0632 .12139 .07304 .1339 .09653 .13092 .08686 .11836 Mtetra
.08686 .11836 .09653 .13092 .12011 .12792 .11062 .11531 Mtetra
.348 .638 .962 r
.11062 .11531 .12011 .12792 .14291 .1369 .1338 .1212 Mtetra
0 .316 .806 r
.1338 .1212 .14291 .1369 .16532 .15431 .1563 .13933 Mtetra
.159 .466 .89 r
.1563 .13933 .16532 .15431 .18832 .16681 .1794 .15234 Mtetra
.278 .558 .93 r
.1794 .15234 .18832 .16681 .21175 .17596 .20296 .16185 Mtetra
.357 .616 .949 r
.20296 .16185 .21175 .17596 .23551 .18271 .22687 .16888 Mtetra
.41 .656 .959 r
.22687 .16888 .23551 .18271 .25954 .1877 .25106 .17408 Mtetra
.448 .683 .965 r
.25106 .17408 .25954 .1877 .28381 .19136 .27548 .17789 Mtetra
.476 .703 .968 r
.27548 .17789 .28381 .19136 .30827 .19399 .30012 .18064 Mtetra
.497 .718 .97 r
.30012 .18064 .30827 .19399 .33291 .19581 .32494 .18255 Mtetra
.513 .729 .971 r
.32494 .18255 .33291 .19581 .35772 .19698 .34993 .18378 Mtetra
.526 .738 .972 r
.34993 .18378 .35772 .19698 .38268 .19762 .37509 .18446 Mtetra
.536 .745 .972 r
.37509 .18446 .38268 .19762 .40779 .19781 .40039 .18469 Mtetra
.544 .751 .973 r
.40039 .18469 .40779 .19781 .43304 .19764 .42583 .18454 Mtetra
.551 .756 .973 r
.42583 .18454 .43304 .19764 .45842 .19716 .45141 .18407 Mtetra
.556 .76 .973 r
.45141 .18407 .45842 .19716 .48393 .19641 .47712 .18332 Mtetra
.561 .764 .973 r
.47712 .18332 .48393 .19641 .50957 .19544 .50297 .18235 Mtetra
.565 .767 .973 r
.50297 .18235 .50957 .19544 .53534 .19427 .52894 .18116 Mtetra
.568 .77 .973 r
.52894 .18116 .53534 .19427 .56123 .19292 .55504 .1798 Mtetra
.571 .772 .973 r
.55504 .1798 .56123 .19292 .58724 .19142 .58127 .17828 Mtetra
.574 .774 .974 r
.58127 .17828 .58724 .19142 .61338 .18978 .60762 .17662 Mtetra
.576 .775 .974 r
.60762 .17662 .61338 .18978 .63964 .18802 .63409 .17483 Mtetra
.578 .777 .974 r
.63409 .17483 .63964 .18802 .66601 .18615 .66069 .17294 Mtetra
.579 .778 .974 r
.66069 .17294 .66601 .18615 .69251 .18419 .68741 .17094 Mtetra
.581 .78 .974 r
.68741 .17094 .69251 .18419 .71913 .18213 .71425 .16885 Mtetra
.582 .781 .974 r
.71425 .16885 .71913 .18213 .74587 .17999 .74122 .16667 Mtetra
.583 .782 .974 r
.74122 .16667 .74587 .17999 .77272 .17778 .7683 .16442 Mtetra
.584 .783 .974 r
.7683 .16442 .77272 .17778 .7997 .17549 .79551 .16209 Mtetra
.585 .784 .974 r
.79551 .16209 .7997 .17549 .8268 .17315 .82285 .15971 Mtetra
.586 .784 .974 r
.82285 .15971 .8268 .17315 .85402 .17074 .8503 .15725 Mtetra
.587 .785 .974 r
.8503 .15725 .85402 .17074 .88137 .16827 .87788 .15475 Mtetra
.588 .786 .974 r
.87788 .15475 .88137 .16827 .90883 .16576 .90559 .15219 Mtetra
.617 .786 .963 r
.02946 .11175 .03963 .12441 .0632 .12139 .0532 .10868 Mtetra
.0532 .10868 .0632 .12139 .08686 .11836 .07704 .10559 Mtetra
.07704 .10559 .08686 .11836 .11062 .11531 .10098 .1025 Mtetra
.458 .704 .973 r
.10098 .1025 .11062 .11531 .1338 .1212 .12456 .10525 Mtetra
0 .294 .792 r
.12456 .10525 .1338 .1212 .1563 .13933 .14713 .12411 Mtetra
.14 .452 .883 r
.14713 .12411 .1563 .13933 .1794 .15234 .17034 .13763 Mtetra
.265 .549 .926 r
.17034 .13763 .1794 .15234 .20296 .16185 .19403 .14752 Mtetra
.348 .61 .948 r
.19403 .14752 .20296 .16185 .22687 .16888 .21808 .15482 Mtetra
.404 .651 .959 r
.21808 .15482 .22687 .16888 .25106 .17408 .24243 .16023 Mtetra
.443 .68 .965 r
.24243 .16023 .25106 .17408 .27548 .17789 .26702 .1642 Mtetra
.472 .7 .968 r
.26702 .1642 .27548 .17789 .30012 .18064 .29183 .16706 Mtetra
.494 .716 .97 r
.29183 .16706 .30012 .18064 .32494 .18255 .31684 .16906 Mtetra
.511 .728 .971 r
.31684 .16906 .32494 .18255 .34993 .18378 .34202 .17035 Mtetra
.524 .737 .972 r
.34202 .17035 .34993 .18378 .37509 .18446 .36736 .17108 Mtetra
.534 .744 .972 r
.36736 .17108 .37509 .18446 .40039 .18469 .39285 .17134 Mtetra
.543 .751 .973 r
.39285 .17134 .40039 .18469 .42583 .18454 .4185 .17121 Mtetra
.55 .756 .973 r
.4185 .17121 .42583 .18454 .45141 .18407 .44428 .17075 Mtetra
.555 .76 .973 r
.44428 .17075 .45141 .18407 .47712 .18332 .4702 .17001 Mtetra
.56 .763 .973 r
.4702 .17001 .47712 .18332 .50297 .18235 .49625 .16902 Mtetra
.564 .766 .973 r
.49625 .16902 .50297 .18235 .52894 .18116 .52244 .16783 Mtetra
.568 .769 .973 r
.52244 .16783 .52894 .18116 .55504 .1798 .54875 .16645 Mtetra
.571 .771 .973 r
.54875 .16645 .55504 .1798 .58127 .17828 .57519 .16491 Mtetra
.573 .773 .974 r
.57519 .16491 .58127 .17828 .60762 .17662 .60176 .16322 Mtetra
.575 .775 .974 r
.60176 .16322 .60762 .17662 .63409 .17483 .62846 .16141 Mtetra
.577 .777 .974 r
.62846 .16141 .63409 .17483 .66069 .17294 .65528 .15948 Mtetra
.579 .778 .974 r
.65528 .15948 .66069 .17294 .68741 .17094 .68222 .15745 Mtetra
.581 .779 .974 r
.68222 .15745 .68741 .17094 .71425 .16885 .70929 .15532 Mtetra
.582 .781 .974 r
.70929 .15532 .71425 .16885 .74122 .16667 .73649 .15311 Mtetra
.583 .782 .974 r
.73649 .15311 .74122 .16667 .7683 .16442 .76381 .15082 Mtetra
.584 .783 .974 r
.76381 .15082 .7683 .16442 .79551 .16209 .79125 .14845 Mtetra
.585 .783 .974 r
.79125 .14845 .79551 .16209 .82285 .15971 .81882 .14602 Mtetra
.586 .784 .974 r
.81882 .14602 .82285 .15971 .8503 .15725 .84652 .14353 Mtetra
.587 .785 .974 r
.84652 .14353 .8503 .15725 .87788 .15475 .87434 .14097 Mtetra
.588 .785 .974 r
.87434 .14097 .87788 .15475 .90559 .15219 .90229 .13837 Mtetra
0 g
.89362 0 m
.98022 .38351 L
s
.98022 .38351 m
1 .65325 L
s
1 .65325 m
.91448 .33294 L
s
.91448 .33294 m
.89362 0 L
s
.02946 .11175 m
0 .4272 L
s
0 .4272 m
.91448 .33294 L
s
.91448 .33294 m
.89362 0 L
s
.89362 0 m
.02946 .11175 L
s
.02946 .11175 m
.89362 0 L
s
gsave
.44797 -0.02478 -65.9056 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(u) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
0 .4272 m
.29069 .70824 L
s
gsave
.15892 .66839 -66.3192 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(p) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{261.563, 185.125},
  ImageMargins->{{30.3125, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.095767,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000450000^A000`40O003h00Oogoo1Woo003oOol6
Ool00?moo`Ioo`00ogoo1Woo003oOol6Ool00?moo`Ioo`00PWoo1000Ogoo0021Ool01000Oomoo`00
P7oo0021Ool01000Oomoo`00P7oo0020Ool200000goo00000020Ool00?moo`Ioo`00ogoo1Woo003o
Ool6Ool00?moo`Ioo`00ogoo1Woo003oOol6Ool00?moo`Ioo`00ogoo1Woo003oOol6Ool00?moo`Io
o`00g7oo10009Goo003DOol80003Ool00`00Oomoo`0SOol00<eoo`L000]oo`03001oogoo02=oo`00
aGoo20004Woo0P0097oo002nOol7000JOol2000TOol00;Ioo`P0025oo`8002Aoo`00[goo1`00:Goo
0P0097oo002XOol7000`Ool00`00Ool0000SOol00:1oo`P003Moo`03001oo`0002=oo`00VGoo1`00
@7oo0P008goo002AOol80017Ool2000SOol008Yoo`L004moo`8002=oo`00PWoo2000EWoo00<007oo
00008Woo001kOol7001NOol00`00Ool0000ROol007=oo`P006Eoo`03001oo`00029oo`00K7oo1`00
KGoo00<007oo00008Woo001TOol8001dOol01000Oomoo`008Goo001MOol7001lOol01000Oomoo`00
8Goo001FOol70023Ool01000Oomoo`008Goo001>Ool8002:Ool01000Oomoo`008Goo0017Ool7002B
Ool01@00Oomoogoo000087oo000oOol8002IOol01@00Oomoogoo000087oo000hOol7002QOol01@00
Oomoogoo000087oo000`Ool80002Cah01d/NCahj_S[N=[hjgSZn09moo`05001oogooOol0000POol0
02aoo`@0000BCci;7DlNBae??T/MCai;7DlnBae?7T/MCchf_S[N=[hjg`4HWWoo00D007ooOomoo`00
021oo`00;7oo00D004lNCai?7T/N00=?7P05Bai?7TlNCai;7P03Cah024/NCahZOS[N=[hjgP4H0CRL
Ool00`00Oomoo`02Ool00`00Oomoo`0MOol002aoo`0I001oo`00Bae?7T/MCci;7DlNBae??T/MCai;
7DlnBae?7T/M;YhZOBZN:Wd1>@4H0CT0W7oo00D007ooOomoo`0001moo`00;7oo00@007oo001oo`9?
7P05Bai?7TlNCai;7P03Cah01D/NCai?7TlNBah00RYn00DZWRYn0AP1604h09]oo`05001oogooOol0
000OOol002aoo`0L001oogoo001??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7AXm:WdZWP4h
0CT1617L3K^IOol01@00Oomoogoo00007goo000/Ool01@00Oomoogoo00000dlN00E;7TlNCai?7T/N
00=?7P04Bai?7TlNCah46Sd30CT00a7K3K/=^`2GOol00`00Oomoo`02Ool00`00Oomoo`0LOol002]o
o`03001oogoo00=oo`0K001??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCahJ71Xm6Q`J?@4h0CT1
>17L3K/R?AhL08moo`07Aai;7TLNBam77T/N000017oo00<007ooOol077oo000[Ool00`00Oomoo`04
Ool01@00Cai?7TlNBah00dlN00E;7TlNCai?7T/N00=?7P031K/J?AXm0081F@070CTAfa7L3K/N?AhM
8Sd0PWoo4D/N00<007ooOol00Woo00<007ooOol077oo000[Ool00`00Oomoo`05Ool07@00Cci;7DlN
Bae??T/MCai;7DlnBae?7T/MCci;7DlN1K/9g0Fk0ET1>@EJ4M/Ag1hL8SdN728m:Ud0M7oo01i;7dLN
Bai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/O0004Ool0
0`00Oomoo`0LOol002]oo`03001oogoo00Eoo`03001;7TlN009?7P05Bai?7TlNCai;7P03Cah01d/N
Cai?7TlN1K/9f`Fk0081F@0:5M`Afa7L8SdN?AhM:WdZGBYm:UeVOol024/NAai;7TLNBai77T/NAah3
Bah01DLNBai;7T/NAah00d/N00=77T/NBah04T/N00<007ooOol00Woo00<007ooOol077oo000[Ool0
0`00Oomoo`06Ool09000Bae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/M0ET1>@WL1ET5NP4i5O`A
fb8m7Q`R?B8L:WhZGBin:UdbWRim<YhbOE1oo`0jBai6oT/OA_i;7TKnBam77T/NA_i;7dLNBai6oT/O
Aai;7TKnBam77T/NA_i;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/N
Aai;7dLNBai77T/OAai;7TLNBcm77T/N0005Ool00`00Oomoo`0KOol002]oo`03001oogoo00Moo`03
001;7TlN009?7P05Bai?7TlNCai;7P03Cah00d/NCai?7P030ET00`EI1GXAf`025M`48Sd01Rim:UdZ
OBYm<YhbW@8bWPDf_P<j_P03>]hj_Woo03Uoo`03Aai6oTLN00977P04A_i77TLNBah3Aah05T/NAai7
7TLNBai77T/NAai;7TLNBai77T/NAai;7TLNBai77T/NAai;7TLN0d/N00E77T/NBai;7TLN00=;7P05
Aai;7T/NBai77P0BBah00`00Oomoo`03Ool00`00Oomoo`0KOol002]oo`03001oogoo00Qoo`0b001;
7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBad1F@4i1IX5F@Ej4M/Eo17K9SdN728m:Ud^ORYM;WhZ
GC:N<WdbWS:M=[hfWCZn=Yhf_SZm>]hj_S[N>[hngS[N?]hj_P8ngP03@_hngT;n01]oo`1JAam6oTLN
@_i77dKnAai6oTLOA_i77TKnBam6oTLNA_i;7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dKnBai6oT/O
A_i;7TKnBam6oT/NA_i;7dLNBai6oT/OAai;7TKnBam77T/NA_i;7dLNBai6oT/OAai;7TLNBam77T/N
Aai;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/NAai;?`001Goo00<0
07ooOol06goo000[Ool00`00Oomoo`09Ool00`00Bai?7P02Cah01D/NCai?7TlNBah00dlN00E;7TlN
Cah0m`5I0085NP035O`Eg1GL00@R?@04:Wd^OBYM:Wd2<Yh00c:M<YhbWP04=[h01C[N>[hj_SZn>]h0
2SkN00E2gT;n@]i2oT;N00Q2oP08A_i2oTKn@_i6oT;nA_i2oPQ6oP0>Aai6oTKnA_i77TKnAai6oTLN
A_i77TKnAai6oP=77P05A_i77TLNAai6oP06Aah01D/NAai77TLNBah00dLN019;7TLNBai77T/NAai;
7TLNBai77T/NAai;7TLNBai77T/NAah3Bah01DLNBai;7T/NAah064/N00<004/NOol00goo00<007oo
Ool06goo000[Ool00`00Oomoo`09Ool0@@00Cai;7DlnBae?7T/MCci;7DlNBae?7T/MCai;7DlN0=L0
m`Ei1IX5NQWl5M/Io28l9SdR?2Hm:Wd^ORYM;WhbWC:N<WdbWSJN>[hfWCZn=YhjgSZm?]hj_SkN>[hn
gS[N?]hj_T;n?]i2oSkN@_hngT;n?]i2oT;N@_i2gT;n@]h00T;n06U6od;nA_i2oTLO@_i6oT;nAam2
oTLN@_i77d;nAai2oTLOA_i77T;nAam6oTLNA_i77dKnAai6oT/OA_i77TKnBam6oT/NA_i;7dKnBai6
oT/OA_i;7TKnBam6oT/NA_i;7dKnBai6oT/OA_i;7TKnBam77T/NA_i;7dLNBai6oT/OAai;7TKnBam7
7T/NAai;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai7
7T/oAai;7P00Bcl01Goo00<007ooOol06Woo000[Ool00`00Oomoo`0:Ool00`00Cai;7P03Cah034/N
Cai?7TlNBai?7T/NCai;7TlN0=L0m`<5NP045O`Eg1Gl9Sd28Sd2;Wd00bin:Wd^O@02<Yh00c:M<Yhf
_P03=[h00cZn>]hj_P02>[h8?]h01T;N?]i2oT;N@_i2gPI2oP0:A_i2oT;n@_i6oT;nA_i2oTKn@_h6
A_h02TLNA_i6oTKnAai6oTLNA_i77TKn0dLN00E6oTLNAai77TKn00=77P03A_i77TLN00A77P05Bai7
7TLNAai;7P03Aah03T/NAai77TLNBai77T/NAai;7TLNBai77T/NAah3Bah01DLNBai;7T/NAah00d/N
00E77T/NBai;7TLN01I;7P03001;7T/N00Aoo`03001oogoo01Yoo`00:goo00<007ooOol02goo01@0
04lNBae??T/MCai;7DlnBae?7T/MCai;7DlNBad0m`3G2I/5NPFJ0QWl014EfbIM8SdVGB8l;WhZOBin
:UdfWS:M=YhbWCJN=[hj_SJM008j_P03>]hj_CkN008ngP03>[hngSkN008ngP1h@_hngT;n?]i2oSkN
@_hngT;n@]i2oT;NA_i2gTKn@_i6od;nA_i2oTLO@_i6oT;nAam2oTLN@_i77d;nAai2oTLOA_i77TKn
Aam6oTLNA_i77dKnAai6oT/OA_i;7TKnBam6oT/NA_i;7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dKn
Bai6oT/OAai;7TKnBam77T/NA_i;7dLNBai6oT/OAai;7TKnBam77T/NAai;7dLNBai77T/OAai;7TLN
Bam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/o001;7TLN17oo00<007ooOol0
6Woo000ZOol00`00Oomoo`0=Ool2Cah01D/NCai?7TlNBah00dlN00=;7SkN?]h00SkN00<0m`3G2IX0
0PVJ0aWl0RHm00HVGB8m;Wd^OBin;Wd3<Yh013:M=[hf_SZn0SJn00@j_S[N>[hjgPDngP04@]hngSkN
?]h2@]h014;n@]i2oT;N1T;n00I6oT;n@_i2oTKn@_h3A_h00d;nA_i6oP04A_h02TLNA_i6oTKnAai6
oTLNA_i77TKn0dLN00E6oTLNAai77TKn00Y77P05Bai77TLNAai;7P03Aah03T/NAai;7TLNBai77T/N
Aai;7TLNBai77T/NAah3Bah01DLNBai;7T/NAah00d/N00E77T/NBai;7TLN01A;7P03001;7T/N00Ao
o`03001oogoo01Yoo`00:Woo00<007ooOol03Woo00i;7DlNBae??T/MCai;7DlnBae?7T/M?_lngSkn
0P3g00@0e`VK1GX9V`8Io00E5O`VGB8m9UdZOBin;Wd^ORYm=[hbWCJN<Ydj_SJn>[hfWCkN>[hngSZm
00<ngP1k>]hngSkN@_hngT;n?]i2oSkN@_i2gT;n?]i6oT;N@_i2gTKn@_i6oT;nA_m2oTKn@_i77d;n
A_i2oTLO@_i77T;nAam6oTLN@_i77dKnAai6oTLOA_i77TKnBam6oTLNA_i;7dKnBai6oT/OA_i;7TKn
Bam6oT/NA_i;7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dLNBai6oT/OAai;7TKnBam77T/NA_i;7dLN
Bai6oT/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLN
Bam77T/N001;?dLN00Aoo`03001oogoo01Yoo`00:Woo00<007ooOol03Woo00@004lNCai;7P=?7P0>
Bai?7TlNCahZWRjN:Yh^WP3h0AP9V`fk2IXJ708Io0049SdVGBIM9Ud3;Wd01Rin<YhfWS:N=Yhf_P<j
_P06=[hjgSZn>]hj_S[N1CkN00I2gSkN?]hngT;n@]h:@_h01TKn@_i2oT;nA_i2oPY6oP0:Aai6oTKn
A_i77TKnAai6oTLNA_h3Aah01DKnAai77TLNA_h00TLN00E;7TLNAai77T/N00=77P05Bai77TLNAai;
7P03Aah03T/NAai;7TLNBai77T/NAai;7TLNBai77T/NAah3Bah01DLNBai;7T/NAah00d/N00=77T/N
Bah054/N00<004/NBah01Goo00<007ooOol06Goo000ZOol00`00Oomoo`0?Ool0;000Bae?7T/MCci;
7DlNBae??T/MCahZOBjN:Wh^WP3g0AP9VPfk2IXN7AWl7Q`V?BIM9SdVGBim<Yh^OC:N<Ydf_S:M=Yhf
_CZn=[hj_SJm?]hj_SkN>[d6?]h0MT;n?]i2oSkN@_hngT;n@]i2oT;NA_i2gT;n@]i6od;nA_i2oTKo
@_i6oT;nAam2oTKn@_i77d;nAai2oTLOA_i77T;nAam6oTLNA_i77dKnAai6oT/OA_i77TKnBam6oT/N
A_i;7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dLNBai6oT/OAai;7TKnBam77T/NA_i;7dLNBai6oT/O
Aai;7TKnBam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/N
Aai;7dLNBai77T/oAah004LN1Goo00<007ooOol06Goo000ZOol00`00Oomoo`0@Ool3Cah01D/NCai?
7TlNBah00TlN00T^WRZN;YhZWP4i0?P160VK3K/00QhL00HIo1hL9UdZGBIM;Wh3;Wd01SJn=YhfWSJN
>[hf_P@j_P04>]hj_SkN>[h6?]h00d;n?]i2gP02@_h00d;N@_i2oP06@_h014Kn@_i6oT;n0dKn00A2
oTKnA_i77P=6oP05Aai6oTKnA_i77P03A_h01TLNA_i77TKnAai6oP=77P05A_i77TLNAai6oP02Aah0
1D/NAai77TLNBah00dLN019;7TLNBai77T/NAai;7TLNBai77T/NAai;7TLNBai77T/NAah3Bah01DLN
Bai;7T/NAah00d/N00E77T/NBai;7TLN01E;7P03001;7T/N00Aoo`03001oogoo01Uoo`00:Woo00<0
07ooOol04Goo015??T/MCai;7DlnBae?7T/MCci;7AHM:Wd^WRYn0CT1616k008=^`0G7O`N7AhL:UdV
?BYM9UdbWRim<Yh^OCJn<Ydf_S:M>[hf_C[N=[hj_SZm?]hj_P06?]h03D;n?]i2oSkN@_i2gT;n?]i2
oT;N@_i2gTKn00=2oP1WA_m2oTKn@_i77d;nAai2oTLO@_i77T;nAam2oTLNA_i77dKnAai6oTLOA_i7
7TKnAam6oTLNA_i;7dKnAai6oT/OA_i;7TKnBam6oT/NA_i;7dKnBai6oT/OA_i;7TKnBam77T/NA_i;
7dLNBai6oT/OAai;7TKnBam77T/NA_i;7dLNBai6oT/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;
7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/NAah004LNBah017oo00<007ooOol06Goo000Z
Ool00`00Oomoo`0BOol3Cah01D/NCai?7TlNBah00TlN00HF7AHL5Qd1604i0AP23K/03AhM7Q`N71hL
:UdVGBYM;WdbWRim<WhfWSJn00<fWP@j_P04?]hj_SkN>]h6?]h2@]h00d;n?]i2oP02@_h00d;N@_i2
oP06@_h014Kn@_i6oT;n0dKn00A2oTKnA_i77P=6oP0:Aai6oTKnA_i77TKnAai6oTLNA_h3Aah01DKn
Aai77TLNA_h00dLN00A6oTLNAai;7P=77P0FBai77TLNAai;7TLNBai77T/NAai;7TLNBai77T/NAai;
7TLNBai77T/NAah3Bah01DLNBai;7T/NAah00d/N00E77T/NBai;7TLN01=;7P03001;7T/N00Eoo`03
001oogoo01Qoo`00:Woo00<007ooOol04goo00m??T/MCai;7DlnBae?7T/MCci;7AHM5Q`J?@4H0CT0
0Q6k00@=^b8m7O`N7@8ZG@0C9UdZORim<Yh^OC:N=Ydf_S:M=[hfWCZn=[djgSZn?]hj_CkN>[h00SkN
07U2oSkN?]hngT;n?]i2oSkN@_i2gT;n?]i2oT;NA_i2gTKn@_i6oT;nAai2oTKn@_i77d;nAai2oTLO
A_i77T;nAam6oTLNA_i77dKnAai6oT/OA_i77TKnBam6oTLNA_i;7dKnBai6oT/OA_i;7TKnBam6oT/N
A_i;7dKnBai6oT/OA_i;7TKnBam77T/NA_i;7dLNBai6oT/OAai;7TKnBam77T/NA_i;7dLNBai6oT/O
Aai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/oAai;7TLNBcm77P00
Aai;?`05Ool00`00Oomoo`0HOol002Yoo`03001oogoo01=oo`05001?7TlNCai;7P03Cah01D/NCai?
7P6J5Q`00`4i00HA^a7K7Q`R?AhL8Qd4:Ud023:M<YhbOC:N=Yhf_SJN=[h5>[h00ckN>]hngP07?]h2
@]h00d;n?]i2oP02@_h00d;N@_i2oP04@_h01TKn@_i6oT;nA_i2oP=6oP04@_i6oTKnAah3A_h02TLN
A_i6oTKnAai6oTLNA_i77TKn0dLN00E6oTLNAai77TKn00I77P05Bai77TLNAai;7P03Aah04T/NAai;
7TLNBai77T/NAai;7TLNBai77T/NAai;7TLNBai77P=;7P05Aai;7T/NBai77P0IBah00`00Bai;7P05
Ool00`00Oomoo`0HOol002Yoo`03001oogoo01Aoo`0F001??T/MCai;7DlnBae?7T/MCci;7@6J0GX5
F@4i5M`A^aGL7Q`R?AhL8Sd2:Ud02BIM<Yh^OC:N;WdbWSJM=[hfW@03>[h0PCJm>]hj_SkN>[hngSZn
@]hngT;n?]i2oSkN@_hngT;n@]i2oT;N@_i2gTKn@_i6oT;NA_i2oTKn@_i77T;nA_i2oTLO@_i77T;n
Aam6oTLN@_i77dKnAai6oTLOA_i77TKnBam6oTLNA_i;7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dKn
Bai6oT/OA_i;7TKnBam77T/NA_i;7dLNBai6oT/OAai;7TKnBam77T/NA_i;7dLNBai77T/OAai;7TLN
Bam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBcm77T/NAah004LN
Bai77P04Ool00`00Oomoo`0HOol002Yoo`03001oogoo01Eoo`05001?7TlNCai;7P03Cah01D/NCai?
7P6J1ET00P4i00<Afa6k4M/00R8m00dN72YM:UdZOBYM<YhbWC:N<Wdf_SJN=[hfWP05>[h2?]h00c[N
?]hngP04?]h014;n?]i2oT;N34;n00A6oT;nA_i2oPQ6oP0>Aai6oTKnA_i77TKnAai6oTLNA_i77TKn
Aai6oP=77P05A_i77TLNAai6oP02Aah01D/NAai77TLNBah00dLN019;7TLNAai77T/NAai;7TLNBai7
7T/NAai;7TLNBai77T/NAah3Bah01DLNBai;7T/NAah06d/N00@004/NBai;7PAoo`03001oogoo01Qo
o`00:Goo00<007ooOol05goo02T004lnBae?7T/MCci;7DlNBae??P3G0IX5F@Ej5M/Eg16k9SdR728m
8Q`^ORYM;WdZGC:N<WdbWS9m>[hfWCJn=YdjgSZn>]hj_C[N>[hngSZn008ngP1i@]hngT;n?]i2oSkN
@_hngT;n@]i2oT;N@_i2gTKn@_i6oT;NA_i2oTKn@_i77T;nAai2oTLO@_i77T;nAam6oTLN@_i77dKn
Aai6oTLOA_i77TKnBam6oT/NA_i;7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dKnBai6oT/OA_i;7TKn
Bam77T/NA_i;7dLNBai6oT/OAai;7TKnBam77T/NA_i;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLN
Bai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/oAai;7TLNBcm77P00Aai;?dLNBah017oo00<007oo
Ool05goo000YOol00`00Oomoo`0HOol01D/NCai?7TlNBah00dlN00U;7TlN0=L5NPEI1EXEfaGL5M/0
0b8m00TZGBim;Wd^OC:M<YhbWC:N<Yd00cJn1CZn1SkN00Q2gSkN?]i2gT;n@]i2oT;N24;n00Q6oT;n
@_i2oTKn@_i6oT;n24Kn00i77TKnAai6oTLNA_i77TKnAai6oTLNA_i77TKn0dLN00E6oTLNAai77TKn
00977P05Bai77TLNAai;7P03Aah03T/NAai;7TLNBai77T/NAai;7TLNBai77T/NAah3Bah01DLNBai;
7T/NAah00d/N00=77T/NBah05d/N00<004/NBah00T/N17oo00<007ooOol05goo000DOol3000BOol0
0`00Oomoo`0HOol09P00Bae??T/MCai;7DlnBae?7T/M0?L0ePEj1ET5NQGK5M`R?2Hm8Q`R?BYM;WhZ
GBin<WdfWS:M=YhfWCZn=Ydj_SZm?]hj_SkN>[d3?]h0NSZn@_hngT;N?]i2oSkN@_hngT;n?]i2oT;N
@_i2gT;n@]i6oT;nA_i2gTLN@_i6oT;nAai2oTLN@_i77d;nAai2oTLOA_i77TKnAam6oTLNA_i;7dKn
Aai6oT/OA_i;7TKnBam6oT/NA_i;7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dKnBai6oT/OAai;7TKn
Bam77T/NA_i;7dLNBai6oT/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLN
Bai77T/OAai;7TLNBam77T/NAai;?dLNBai77P00Aai;7TLNBcl4Ool00`00Oomoo`0GOol001Eoo`03
001oogoo015oo`03001oogoo01Uoo`03Cai;7TlN009?7P09BahngSkN?]hjgP3G2GX9VPEI008Io006
5M`R?BHm9Sd^OBYM0Rim00PfWS:M<YhbWCJN=[hj_SJn13Zn00<jgSkN?]h01CkN00I2gSkN@_i2gT;n
@]h6@_h01TKn@_i2oT;nA_i2oP=6oP03@_i6oTKn00A6oP0>Aai6oTKnA_i77TKnAai6oTLNA_i77TKn
Aai6oP=77P03A_i77TLN00Q77P05Bai77TLNAai;7P03Aah02T/NAai;7TLNBai77T/NAai;7TLN0d/N
00E77T/NBai;7TLN00=;7P05Aai;7T/NBai77P0GBah00`00Bai;7P02Bah4Ool00`00Oomoo`0GOol0
01=oo`<001=oo`03001oogoo01Yoo`09Cai;7DlnBae?7S[N?_ljgSkN0080m`0K2GX9VPEj6O`IfbHm
8S`V?B8l;Wh^GBin;WdfWS9m=YhbWCZn=Ydj_SJM>[hj_CkN>[hngSZn00<ngP1h>[i2oSkN@_hngT;n
?]i2oSkN@_i2gT;n@]i6oT;NA_i2oTKn@_i6oT;nAai2oTKn@_i77d;nAai2oTLOA_i77T;nAam6oTLN
A_i77dKnAai6oT/OA_i77TKnBam6oT/NA_i;7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dKnBai6oT/O
A_i;7TKnBam77T/NA_i;7dLNBai6oT/OAai;7TKnBam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/N
Aai;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/oAah004LNBcm77T/N1Goo00<007ooOol0
5Woo000BOol01000Oomoo`004goo00<007ooOol06goo00=?7T/NCah00TlN00`RGCkN?]hngP3G3I/9
NPVJ6O`Mo1Wl9Ud39Sd4;Wd02CJN<YdfWSJN>[hf_SZn=[hngP03>[h6?]h024;N?]i2gT;N@_i2gT;n
@]h6@_h01TKn@_i2oT;nA_i2oPY6oP0:Aai6oTKnA_i77TKnAai6oTLNA_h3Aah01DKnAai77TLNA_h0
0TLN00E;7TLNAai77T/N00=77P0BBai77T/NAai;7TLNBai77T/NAai;7TLNBai77T/NAai;7TLN0d/N
00E77T/NBai;7TLN00=;7P05Aai;7T/NBai77P0EBah00`00Bai;7P03Bah4Ool00`00Oomoo`0FOol0
019oo`04001oogoo000COol00`00Oomoo`0LOol09TlNBae??T/MCahRGB9n8Ud1603G4K/=VPVJ6O`N
71Wl9UdV?2YM9S`bORiM;WhbWCJN<YdfWSJm>[hfWCZn=[dngSZm?]hj_SkN?[h4?]h0MT;n?]i2oSkN
@_i2gT;n?]i6oT;N@_i2gTKn@_i6oT;nA_i2oTKn@_i77T;nA_i2oTLN@_i77T;nAam6oTLNA_i77dKn
Aai6oT/OA_i77TKnBam6oTLNA_i;7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dKnBai6oT/OAai;7TKn
Bam77T/NA_i;7dLNBai6oT/OAai;7TKnBam77T/NA_i;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLN
Bai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/oAai;7TLN00177T/NAai;?dLN17oo00<007ooOol0
5Woo000COol4000BOol00`00Oomoo`0MOol00dlNBai?7P02Cah28Ud01`Di0AP=VPfK3IXN71Wl008M
o005:UdV?BHm;WdbOP02;Wd2=Yh00c:M=Yhj_P04>[h013kN>[hngSZn13kN00A2gSkN@]hngP92gP=2
oP03@]i2oT;n00A2oP06A_i2oTKn@_i6oT;n2TKn00Y77TKnA_i6oTLNA_i77TKnAai6oP=77P05A_i7
7TLNAai6oP02Aah01D/NAai77TLNBah00dLN019;7TLNBai77T/NAai;7TLNBai77T/NAai;7TLNBai7
7T/NAah3Bah01DLNBai;7T/NAah06d/N00<004/NBah00d/N17oo00<007ooOol05Woo000YOol00`00
Oomoo`0MOol07`00Cai;7DlnBae?7P6J8Wh5>04H4KXA^`fJ8Q`Io1hL9SdZGBHl:Ud^OC9n;WdbWSJM
=[hbWCZn=[dj_SJM008j_P03?]hj_CkN00<ngP1h@]hngT;n?]i2oSkN@_i2gT;n@]i2oT;NA_i2oTKn
@]i6oT;nA_i2oTKn@_i6oT;nAai2oTKn@_i77TKnAai2oTLOA_i77TKnAam6oTLNA_i;7dKnAai6oT/O
A_i77TKnBam6oT/NA_i;7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dLNBai6oT/OAai;7TKnBam77T/N
A_i;7dLNBai6oT/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/O
Aai;7TLNBam77T/NAai;?dLN00177T/oAai;7TLN1Goo00<007ooOol05Goo000YOol00`00Oomoo`0N
Ool2Cah01D/NCai?7P3g0IX00PDi00LE^a6k4K/A^b8L7Q`R7004:Ud00c9m<YhbO@03=Yh00cJM>[hj
_P03>[h2?]h00cZn?]hngP04?]h01T;n?]i2gT;N@_i2gPQ2oP04A_i2oTKn@_h3A_h00d;nA_i6oP08
A_h01TLNA_i77TKnAai6oP=77P05A_i77TLNAai6oP06Aah01D/NAai77TLNBah00dLN00i;7TLNBai7
7T/NAai;7TLNBai77T/NAai;7TLN0d/N00E77T/NBai;7TLN01i;7P03001;7T/N009;7PEoo`03001o
ogoo01Eoo`00:7oo00<007ooOol087oo00a;7DlNBae??T/M0?P1VPEI1CPE^a6j5M/28Q`05Agl;WdZ
GBiM:UdbWRim<Yh^OCZn=Ydf_SJM>[hj_CZn=[dngSZn?]hj_@02?]h0ND;N?]i2gSkN@_hngT;n?]i2
oT;N@_i2gTKn@]i6oT;nA_i2oTKn@_i6oT;nAai2oTLN@_i77TKnAai2oTLNA_i77TKnAam6oTLNA_i;
7dKnAai6oT/OA_i;7TKnBam6oT/NA_i;7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dLNBai6oT/OAai;
7TKnBam77T/NA_i;7dLNBai6oT/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/NAai;
7dLNBai77T/OAai;7TLNBcm77T/NAai;?dLNBai77T/o001;7TLNBcm77T/N00Aoo`03001oogoo01Eo
o`00:7oo00<007ooOol08Goo0TlN00Q;7TlN0?L0m`UI2GT5>AWK0Q6k00<R728m7Q`012YM00@bWC9m
<YhfW@8fWP03=[hfWCZn00<j_P<ngP03>[hngSkN00<ngP04@]i2oSkN@]h2@_h014;N@_i2oTKn0d;n
00I6oT;nA_i2oTKn@_h6A_h01DLNA_i6oTKnAah00dKn00I77TKnAai6oTLNA_h3Aah01DKnAai77TLN
A_h00TLN00E;7TLNAai77T/N00=77P0>Bai77T/NAai;7TLNBai77T/NAai;7TLNBai77P=;7P05Aai;
7T/NBai77P03Bah00dLNBai;7P0JBah00`00Bai;7P03Bah4Ool00`00Oomoo`0EOol002Qoo`03001o
ogoo029oo`2LA_i;7TKnBah0m`3h2ET9NPUI6M`E^bHm8Q`V?BYM;WdZGBiM<WdfWS9m<YhfWCZn=Ydf
_SZm?]hj_CZn>[dngSZn?]hj_D;n?]i2gSkN@_hngT;n?]i2oT;N@_i2gT;n@]i6oT;NA_i2oTKn@_i7
7T;nA_i2oTLN@_i77T;nAai6oTLN@_i77TKnAai6oTLOA_i77TKnBam6oTLNA_i;7dKnBai6oT/OA_i;
7TKnBam6oT/NA_i;7dKnBai6oT/OA_i;7TKnBam77T/NA_i;7dLNBai6oT/OAai;7TKnBam77T/NAai;
7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/oAai;
7TLNBcm77T/N001;?dLNBai77T/o17oo00<007ooOol05Goo000XOol00`00Oomoo`0ROol03`00A_i;
7TKn1AP0ma6J2ET9NAgl6M/EfbHm8Q`R?@03;Ud022im<WdbWC9m<YhfWCJn=Yh5>[h7?]h01D;N?]i2
gT;N@_h00T;N0T;n00A2gT;n@_i6oP=2oP03A_i2oTKn00U6oP0>Aai6oTKnA_i77TKnAai6oTLNA_i7
7TKnAai6oP=77P05A_i77TLNAai6oP02Aah01D/NAai77TLNBah00dLN00i;7TLNBai77T/NAai;7TLN
Bai77T/NAai;7TLN0d/N00E77T/NBai;7TLN00=;7P03Aai;7T/N01Q;7P03001;7T/N00=;7PEoo`03
001oogoo01Aoo`00:7oo00<007ooOol08goo0280029M9WhRG@Dh0?LAVPej2GXIfagl9Q`V?BHl9SdZ
GBin:Ud^OC9m=YhbOCZn=Ydj_SJM?]hj_CkN>[dngSZm?]hn_P8ngP1e@_hngT;N?]i2oSkN@_hngTKn
@]i2oT;NA_i2oTKn@]i6oT;nA_i2oTLN@_i6oT;nAai2oTLN@_i77TKnAai2oTLOA_i77TKnAam6oTLN
A_i;7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dLNBai6oT/O
Aai;7TKnBam77T/NA_i;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/N
Aai;7dLNBai77T/oAai;7TLNBcm77T/NAai;?`00Bai77T/o009;7P03Aaioogoo009oo`03001oogoo
01Aoo`00:7oo00<007ooOol097oo00DRGR9M9Wh=F@DH00<AVP<Mo0039S`V?BHl00@^O@06=YhbWCJN
<Ydj_SJm1cZn1CkN00Q2gSkN@]i2gT;n@]i2oT;N1T;n00I6oT;n@_i2oTKn@_h:A_h03TLNA_i77TKn
Aai6oTLNA_i77TKnAai6oTLNA_h6Aah01D/NAai77TLNBah00dLN00i;7TLNBai77T/NAai;7TLNBai7
7T/NAai;7TLN0d/N00E77T/NBai;7TLN00=;7P05Aai;7T/NBai77P0HBah00`00Bai;7P04Bah4Ool0
0`00Oomoo`0DOol002Qoo`03001oogoo02Eoo`2E9WhRGBIn3ET5>0ej4IX=NQgl6M/ZGBHl9SdV?39m
;UdbORiM=YhbOCJN=Ydj_SJM>[hfWCkN>[dngSZm?]hn_D;N?]i2gSkN@_hngT;N?]i2oT;N@_hngTKn
@]i2oT;NA_i2oTKn@]i6oT;nA_i2oTLN@_i77T;nAai2oTLNA_i77TKnAai6oT/NA_i77TKnBam6oTLN
A_i;7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dLNBai6oT/O
Aai;7TKnBam77T/NA_i;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/N
Aai;7dLNBai77T/oAai;7TLNBcm77T/N001;?`02Bah00dLNBcm;7P04Ool00`00Oomoo`0DOol002Qo
o`03001oogoo02Ioo`0=1GXRG@eI3ETI^aFk4IXQo28L7O`ZGBXl:Sd012im00@fWCJN=YdfWP8j_P07
=[dj_SZn?]hj_Sjn>[h013kN00=2gSkN@]h00d;N00=2oT;N@_h01D;n00A6oT;nA_i2oP=6oP03@_i6
oTKn00A6oP0:Aai6oTKnA_i77TKnAai6oTLNA_h3Aah01DKnAai77TLNA_h00TLN00E;7TLNAai77T/N
00=77P0>Bai77T/NAai;7TLNBai77T/NAai;7TLNBai77P=;7P05Aai;7T/NBai77P03Bah00dLNBai;
7P0HBah50006Bah5Ool00`00Oomoo`0COol002Qoo`03001oogoo02Ioo`0I6GP5VPeI4GT=FAVk5KXI
^agk8Q`V?2YM9S`ZGBim<Wh^OC9n<YdfWS:M=Yhj_CZn=Yd00SZn00<ngSZm?]h00SkN06@n_D;N?]i2
oSkN@_hngT;n?]i2oT;N@_i2gTKn@]i6oT;nA_i2oTKn@_i77T;nA_i2oTLNA_i77T;nAai6oTLNA_i7
7TKnAai6oT/NA_i77TKnBam6oT/NA_i;7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dKnBai6oT/OA_i;
7TKnBam77T/NA_i;7dLNBai6oT/OAai;7TKnBam77T/NA_i;7dLNBai77T/OAai;7TLNBam77T/NAai;
7dLNBai77T/OAai;7PX00008Aai;7TLNBcl004/NAai;?`9;7P03Aaioogoo00=oo`03001oogoo01=o
o`00:7oo00<007ooOol09Woo00<MNAeh1GX00PeI00<MfaVk5K/00RHL00DR72YM;UdZGBiM00@bO@03
=YdfWSJM00@j_P04?]hn_SkN>[h6?]h01T;N?]i2gT;N@_i2gPQ2oP04A_i2oTKn@_h3A_h00d;nA_i6
oP04A_h02TLNA_i6oTKnAai6oTLNA_i77TKn0dLN00E6oTLNAai77TKn00977P05Bai77TLNAai;7P03
Aah02T/NAai;7TLNBai77T/NAai;7TLN0d/N00E77T/NBai;7TLN00=;7P05Aai;7T/NBai77P05Bah9
000?Bah00`00Bai;7P04Bah4Ool00`00Oomoo`0COol002Qoo`03001oogoo02Moo`1`7GTIN1Vj6IXA
NAgK8O`E^RHl8Q`V?BYL;UdZ?3JN<WdfWS9m>[hfWCJN=Ydn_SZm>[hj_CkN>[hngSZm@]hngT;N?]e2
gSkN@_hngT;n@]i2oT;N@_i2gTKn@]i6oT;NA_i2oTKn@_i6oT;nAai2oTKn@_i77TKnAai2oTLNA_i7
7TKnAai6oTLNA_i;7TKnAai6oT/OA_i;7TKnBam6oT/NA_i;7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;
7dLNBai6oT/OAai;7TKnBam77T/NA_i;7dLNBai6oT/OAah:00007D/OAai;7TLNBam77T/NAai;7dLN
Bai77T/OAai;7TLNBcm77T/NAai;?dLNBai77P00Aai;7TLNBcl00T/N17oo00<007ooOol04goo000W
Ool00`00Oomoo`0XOol00aeh7GTMN0026IX37M/39Q`3;Ud02BYM<WdbOC:M<WdjWSJM>[hfW@04>[h3
?]h01Cjn?]hngT;N?]h00T;N00=2oT;N@]h00T;n00A2gT;n@_i6oP=2oP04A_i2oTKn@_h<A_h02TLN
A_i6oTKnAai6oTLNA_i77TKn0dLN00E6oTLNAai;7TKn00977P0BBai77TLNAai;7TLNBai77T/NAai;
7TLNBai77T/NAai;7TLN2@000T/N00=77T/NBah07D/N00<004/NBah01D/N0goo00<007ooOol04goo
000WOol00`00Oomoo`0XOol0GQei7GPMNB6j6KXIVR7k7M/Qo2Xl9S`R739m;Ud^OC9m=YhbOCJN=Ydj
_SJM>[hj_CkN>[dn_SZm?]hj_SkN>[e2gSkN@]hngD;n?]i2oSkM@_i2gT;n@]i6oT;nA_i2gTKn@_i6
oT;nA_i2oTKn@_i77T;nAai2oTLNA_i77T;nAai6oTLNA_i77TKnAai6oT/NA_i;7TKnBai6oT/NA_i;
7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dLN2@0002i6oT/OAai;7TKnBam77T/NAai;7dLNBai77T/O
Aai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/NAai;?dLNBai77T/oAai;7TLNBcm;7P00
Aai;?`9;7P03Aai;?d/N00Aoo`03001oogoo019oo`009goo00<007ooOol0:Goo00PMNAeh7GTQfRGJ
9O/V71gK0RXl00<Z?BiM;Ud00RiM00<fOCJM=Yd00SJM00<jWSJM>[h00cZn00<n_SkN?]h00ckN00=2
gSkN@]h00d;N00=2oT;N@_h00T;n00A2gT;n@_i6oP92oP96oP03@_i6oTKn00Q6oP0:Aai6oTKnA_i7
7TKnAai6oTLNA_h3Aah01DKnAai77T/NA_h00TLN00=;7P000000200000]77T/NAai;7TLNBai77T/N
Aai;7TLN00=;7P05Aai;7T/NBai77P0RBah00`00Bai;7P04Bah4Ool00`00Oomoo`0BOol002Moo`03
001oogoo02Uoo`0?:KT]fQeh9M/Q^RGK8O/V727k:SdZ?2Xm;UdbOBiM008bO@0i=YhbOCJN=Ydj_SJM
?[hj_CkN>[dn_Sjm?]hn_SkN?]e2oSkN@]hngD;n@]i2oSkMA_i2gTKn@]i6oT;nA_i2gTKn@_i6oT;n
Aai2oTLN@_i77TKnAai6oTLNA_i77TKnBai6oTLNA_i;7TKnAai6oT/N00T00013Bai6oT/OA_i;7TKn
Bam6oT/NA_i;7dLNBai6oT/OAai;7TKnBam77T/NA_i;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLN
Bai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/oAai;7TLNBcm77T/NAai;?dLNBai77T/o001;7TLN
Bcl00T/N00=77WooOol00Woo00<007ooOol04Woo000WOol00`00Oomoo`0ZOol01BVi;MTQfRGK8MX0
0RXL00HV72Gk;Ud^?2iM<Ud3<Wd3=Yd01SZn>Ydj_SZm?[hj_P<n_P<ngP04@]hngT;N?]h4@]h00d;n
@]i2oP02@_h01D;NA_i2oTKn@_h00dKn00=2oTKnA_h014Kn00A77TKnA_i6oPX000=77P04A_i77TLN
Bah3Aah03T/NAai77TLNBai77T/NAai;7TLNBai77T/NAah3Bah01DLNBai;7T/NAah00d/N00=77T/N
Bah08T/N00<004/NBah01D/N0goo00<007ooOol04Woo000WOol00`00Oomoo`0ZOol0=RgJ:KT]fRWk
9M/Q^Rhl:Q/^?2Xl;Ud^?3Im<WdfWC9m=YhfOCZN=Ydj_SZM?[hjWCkN>[dngSZm@]hn_D;N?[i2gSkM
@_hngT;N@]e2oT;N@_i2gTKn@]i6oT;NA_i2oTKn@]i6oT;nA_i2oPT0001@A_i77TKnBai6oTLNA_i;
7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dLNBai6oT/OAai;
7TKnBam77T/NA_i;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/NAai;
7dLNBai77T/oAai;7TLNBcm77T/NAai;?`9;7P06001;?d/NBai77T/o0T/N17oo00<007ooOol04Goo
000WOol00`00Oomoo`0ZOol2>QX012Vi;Q/]nbhK0bXL00XZ?39L;Ud^?3Im<WdfOC9m>YhfW@8jW@05
>[hj_CZn>[dngP02?[h00ckN@]hngP02?]h024;N?]i2gT;N@_i2gT;n@]h3@_h:0007A_h03TLNA_i6
oTKnAai6oTLNA_i77TKnAai6oTLNA_h3Aah014KnAai77T/N0dLN00i;7TLNBai77T/NAai;7TLNBai7
7T/NAai;7TLN0d/N00E77T/NBai;7TLN00=;7P03Aai;7T/N025;7P03001;7T/N00A;7PAoo`03001o
ogoo015oo`009goo00<007ooOol0:goo00HinCXJ=OT^6bWk;Q/2;S`00bXK<Ud^G002<Wd03SIm<Wdf
WCJM>YhfWCZn>[dn_SZm?[hj_CkN>[d2?]h01D;N?[e2gSkN@_h02@000656oT;NA_i2oTKn@_i6oT;n
Aai2oTKn@_i77TKnAai2oTLNA_i77TKnAai6oTLNA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7dKn
Bai6oT/OA_i;7TKnBam6oT/NA_i;7dKnBai6oT/OAai;7TKnBam77T/NA_i;7dLNBai6oT/OAai;7TLN
Bam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBcm77T/NAai;?`02
Bah01TLNBcm;7P00Aai;?`9;7P03Aai;?`0000@001=oo`009goo00<007ooOol0:goo0cXJ0SHk00<]
nc8l<S`00S8l00hbGC9L<UdfOCJM=WdfWCZM>YhfWCZM>[dn_SZm2P0014;N00E2oT;N@_i2gTKn00=2
oP03A_i2oTKn00e6oP06Aai6oTKnA_i77TKn0dLN00E6oTLNAai;7TKn00977P0FBai77TLNAai;7TLN
Bai77T/NAai;7TLNBai77T/NAai;7TLNBai77T/NAah3Bah01DLNBai;7T/NAah00d/N00=77T/NBah0
7d/N00<004/NBah014/N17oo00<007ooOol04Goo000WOol00`00Oomoo`0[Ool02CGi>QXinCXJ<Q/f
?3HK<U`^?002<U`013Im<U`fOCIm2@0000Tj_D;N?[dngSjm@]hngD;N?]d00T;N01=2oSkM@_i2gTKn
@]e6oT;NA_i2gTKn@_i6oT;nA_i2oTKn@_i77P02A_h0DT;nAai6oTLNA_i;7TKnAai6oT/NA_i77TKn
Bai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7dKnBai6oT/OAai;7TKnBam77T/NA_i;7dLN
Bai6oT/OAai;7TKnBam77T/NA_i;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLN
Bcm77T/NAai;?dLNBai77T/o0T/N00I77T/oBai;7TLN0002Bah014LNBcm;7T/N17oo00<007ooOol0
4Goo000WOol00`00Oomoo`0[Ool01DIJ@SXj6SXJ=S/02P000cZM00Pj_CZM>[hjWCjn?[dn_Sjm13kN
00A2gSkN@]hngP92gP03@_i2gT;N0092oP05@]i2oT;nA_i2oP03A_h00d;nA_i6oP0<A_h01TLNA_i7
7TKnAai6oP=77P05A_i77TLNBai6oP02Aah03T/NAai77TLNBai77T/NAai;7TLNBai77T/NAah3Bah0
1DLNBai;7T/NAah00d/N00=77T/NBah09T/N00<004/NBah014/N0goo00<007ooOol04Goo000VOol0
0`00Oomoo`0XOol900000cHk<Q/f?003=U`0:3Im<U`fOC9L>YhfWCZM=Wdn_SZM?[hj_CkN>[dn_Sjm
@]hn_D;N?[e2oSkM@]hngD;n@]i2oT;M@_i2gTKn@]e6oT;nA_i2gTKn@_i6oT;n0TKn05=77T;nAai6
oTLNA_i77TKnAai6oT/NA_i77TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6
oT/OA_i;7TKnBam77T/NA_i;7dLNBai6oT/OAai;7TKnBam77T/NAai;7dLNBai77T/OAai;7TLNBam7
7T/NAai;7dLNBai77T/OAai;7TLNBam77T/NAai;?dLNBai77T/o009;7P06Aai;?d/NBai77T/o0T/N
00L004/oBai;7TLNBcm;7P03Ool00`00Oomoo`0AOol002Ioo`03001oogoo01moo`T000Eoo`03@SY6
FT8j00@nF`@fG0<jO@@jW@05>[dn_CZm?[hn_@03?[h4?]h7@]h02T;n@]i2oT;nA_i2gTKn@_i6oT;n
2TKn00i77TKnA_i6oTLNA_i77TKnAai6oTLNA_i77TKn0dLN00E6oTLNAai;7TKn00977P0>Bai77TLN
Aai;7TLNBai77T/NAai;7TLNBai77P=;7P05Aai;7T/NBai77P03Bah00dLNBai;7P0TBah00`00Bai;
7P04Bah3Ool00`00Oomoo`0AOol002Ioo`03001oogoo01Eoo`X000ioo`0>AUY2>DIJ@STnG3YK?U`j
Fcim>W`nO3Il>YdfO08jW@1e?[hjWCjM>Ydn_SZM?[hn_CkN?[dngSjm@]hngD;N?]e2oT;M@_hngDKn
@]i2oT;MA_i2gTKn@]i6oT;nA_i2gTLN@_i6oT;nAai6oTLN@_i77TKnAai6oT/NA_i77TKnBai6oTLN
A_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBam6oT/NA_i;7dLNBai6oT/O
Aai;7TKnBam77T/NA_i;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/N
Aai;?dLNBai77T/o009;7P06Aai;?d/NBai77T/o0T/N00I77T/oBah004LNBcl2Bah01DLNOomoogoo
00004goo000VOol00`00Oomoo`0<Ool9000HOol014YiCWY>NTij13iK0cYl00DnO3ZM?YdjWCjM00@j
W@<n_@08?[hn_CkN?[e2gSkN@]hngPI2gP08@_i2gT;n@_i6oT;nA_i2oP=6oP03@_i6oTKn00Q6oP0>
Aai6oTKnA_i77TKnAai6oTLNA_i77TKnAai6oP977P0FBai6oTLNAai;7TKnBai77T/NAai;7TLNBai7
7T/NAai;7TLNBai77T/NAah3Bah01DLNBai;7T/NAah0:D/N00<004/NBah014/N0goo00<007ooOol0
47oo000VOol00`00Oomoo`02Ool:000ROol0QTYICWY:NDij@W]6O49kAW`jG3im>W`nWCYl?YdjO3jM
>Ydn_SjM?[hjWCjn?[e2gSjm@]hn_D;N?]e2gSkM@]i2gD;n@]e2oT;MA_i2gTKn@]e6oT;NA_i2gTKn
@_i6oT;nAai2oTKn@_i77TKnAai6oT/NA_i77TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/N
A_i;7TKnBai6oT/NA_i;7TKnBam6oT/NA_i;7dLNBai6oT/OAai;7TKnBam77T/NA_i;7dLNBai6oT/O
Aai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/oAai;7TLNBcl2Bah0
1TLNBcm;7T/NAai;?`9;7P06Aah004/NBai77T/o0T/N0goo00<007ooOol047oo000VOol5000/Ool0
1DijBWU>NTijAW/00d9k00e2W3il@Y`nO3jM>YdnWCZM?[dnWCjm?Ydn_P03?[d00d;N?[e2gP09@]h0
24Kn@]i2oT;NA_i2oTKn@_h@A_h01TLNA_i6oTKnAai6oP=77P05A_i77TLNBai6oP02Aah03T/NAai7
7TLNBai77T/NAai;7TLNBai77T/NAah3Bah01DLNBai;7T/NAah00d/N00=77T/NBah0:D/N00<004/N
Bah014/N0goo00<007ooOol047oo000WOol00`00Oomoo`0^Ool0<dijBUU>NTYiAWa2NdIl@W]2W3il
@YdnO4:m?Ya2_Cjm@[dnWD:n?[e2_Sjm@]hn_D;N?[e2gT;M@]i2gD;N@]e6oT;MA_i2gDKn@]e6oT;N
A_i2gDKn@_i6oT;nA_i2oTKn@_i77P03A_h0BDLNA_i77TKnBai6oTLNA_i;7TKnBai6oT/NA_i;7TKn
Bai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/OAai;7TKnBam77T/NA_i;7dLN
Bai6oT/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/O009;7P06
Aai;?d/NBai77T/o0T/N00I77T/oBai;7TLNBcl2Bah01P00Bcm;7T/NAai;?`=oo`03001oogoo011o
o`00:7oo00<007ooOol0;Goo00ABVEJJDYUBV@A:V`04?Wa2W3il@Y`4?Yd02cjm@[dn_Cjm@[e2gSjm
@[e2gD;N?[d01T;N00Y2oT;N@]i2oTKn@]i6oT;nA_i2oQ96oP06Aai6oTLNA_i77TKn0TLN00I;7TKn
Aai77T/NA_h2Aah03T/NAai;7TLNBai77T/NAai;7TLNBai77T/NAah3Bah01DLNBai;7T/NAah00d/N
00=77T/NBah0:4/N00<004/NBah014/N0Woo00<007ooOol047oo000YOol00`00Oomoo`0/Ool01EJJ
DYUFVU9iEYX00TZK07Y6NdZL@Ya6W4:LA[e2W4:m@Ya2_Sjm@[dnWD:n?[e2gSjm@]i2gD;N?[e2gT;M
@]i2gDKn@]e6oT;MA_i2gTKn@]e6oT;NA_i2gDKn@_i6oT;mA_i2oTLNA_i77TKnAai6oT/NA_i77TKn
Bai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TLN
Bai6oT/OAai;7TKnBam77T/NA_i;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLN
Bam77T/NAai;?dLNBai77T/o0T/N00I77T/oBai;7TLNBcl2Bah02TLNBcm;7T/NAai;?`00Bai77T/o
0T/N00A77WooOol0019oo`00:Woo00<007ooOol0;7oo0U:I00=FVU:IBY/00dZK00A6W4:LAYa2W0=2
_@03@Ye2_D:m00=2_@07@]e2gT:m@]i2gD;N@]d014;N00E2oT;NA_i2gT;n0096oP03@_i6oTKn00a6
oP0>Aai6oTKnA_i77TKnAai6oTLNA_i77TKnAai6oP977P0BBai6oTLNAai;7TKnBai77T/NAai;7TLN
Bai77T/NAai;7TLN0d/N00E77T/NBai;7TLN00=;7P03Aai;7T/N02Y;7P03001;7T/N00A;7P9oo`03
001oogoo011oo`00:goo00<007ooOol0:goo019BNEJJFYUJ^EJID[]>VdjkCYY:_4JLB[a6W4:m@Ya2
_D:L@]h3@[d054;N@[e2gT:mA]i2gDKN@]e6oT;MA_i2gDKn@]e6oT;MA_i2gTKn@]d3A_h0DT;mA_i6
oTKnA_e77TKnAai6oT/NA_i77TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6
oT/NA_i;7TKnBai6oT/NA_i;7TLNBai6oT/NAai;7TKnBam77T/NA_i;7dLNBai77T/OAai;7TLNBam7
7T/NAai;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/o0T/N00I77T/oBai;7TLNBcl2Bah0
1TLNBcm;7T/NAai;?`9;7P06Aah004/NBai77T/o0T/N00=oo`00Ool04Goo000/Ool00`00Oomoo`0Z
Ool5F[T02DjKC[]>^djkA[a:_4JlB[a6_003A[d014JlA[e2_DKM0d;M00I6gT;M@]i2gD;N@]d2@]h0
1TKN@]e6oT;NA_i2gQ96oP0>Aai6oTKnA_i77TKnAai6oT/NA_i77TKnBai6oP977P0>Bai6oT/NAai;
7TLNBai77T/NAai;7TLNBai77P=;7P05Aai;7T/NBai77P03Bah00dLNBai;7P0]Bah00`00Bai;7P04
Bah00goo001oo`0AOol002eoo`03001oogoo02Uoo`0WFYUJ^EJIF[UJVEZiCYYB^djKC[]6W4ZlAYa:
_4:lA[e2_4Jm@[e6gT:mA]e2_DKN@]e6gT;MA_i2gDKN@]e6oT;MA_i2gDKn@]e6oT;M00=6oP06@]e6
oTKnA_i6oDLN0TKn04Y6oDLNA_i77TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKn
Bai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NAai;7TKnBam77T/NA_i;7dLNBai6oT/OAai;7TLN
Bam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/O0T/N00I77T/oBai;7TLNBcl2
Bah01TLNBcm;7T/NAai;?`9;7P06Aai;?d/N00177T/o0T/N00A77T/oOol0019oo`00;Woo00<007oo
Ool0:Goo1EZi15:k00I>_4ZlB[a:_4[MA[`2A[d4A]d02TKN@]e2gD;MA]i2gDKN@]e6gT;M0TKN00=6
oTKNA_h05DKn00I77TKnA_i6oTLNA_h2Aah01T/NA_i77TLNBai6oP977P0:Bai77T/NAai;7TLNBai7
7T/NAah3Bah01DLNBai;7T/NAah00d/N00=77T/NBah0<4/N00<004/NBah00d/N00=oo`00Ool04Goo
000_Ool00`00Oomoo`0XOol0:5ZiFYUJ^EjhG]UB^UKKD[YFfe:jC]a:^dkLB[a:gDJlB]e6_4KMA[e6
gDJmA]i2gDKN@]e6oT;MA_i2gDKn@]e6oT;MA_i2gDKnA]e6oTKM0dKn04i6oDLNA_i6oTKmBai6oTLN
A_e;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/N
A_i;7TKnBai77T/NA_i;7TLNBai6oT/NAai;7TKnBai77T/NA_i;7dLNBai77T/OAai;7TLNBam77T/N
Aai;7dLNBai77T/OAai;7TLNBcl2Bah01TLNBcm;7T/NAai;?`9;7P06Aai;?d/NBai77T/o0T/N00Y7
7T/oBai;7TLNBcl004/NAai;?`9;7P03Aah007oo015oo`00<7oo00<007ooOol09goo00IN^5jiG[UN
fEjhG[T4D[/024ZlC[a:_4ZlA[e:gDJlA[d9A]d024KNA]e6gTKMA_i6gDKnA]hDA_h02TLNA_i6oTKn
Aai6oTLNA_i;7TKn0TLN00i;7TKnBai77T/NA_i;7TLNBai77T/NAai;7TLN0d/N00E77T/NBai;7TLN
03Q;7P03001;7T/N00A;7P03001oogoo011oo`00<Goo00<007ooOol09goo02iN^5kIG[QNfEjhF]]F
^U[KE[YJfdjkD]a>^e;LB[a:gDZlC]e6gD[MA]e:gDKMA_i6gD[nA]e6oTKMA_i6gDKnA]e6oTKMA_i6
gDKnA]e6oTKmB_i6oDKnA_e;7P96oP12A_e;7TKnBai6oD/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/N
A_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai77T/NA_i;7TLNBai6oT/NAai;7TKnBai77T/N
Aai;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/O0T/N00I77T/OBai;7TLNBcl2Bah01TLN
Bcm;7T/NAai;?`9;7P06Aai;?d/NBai77T/o0T/N00I77T/oBai;7P00Bcl2Bah014LNBcm;7P004Woo
000bOol00`00Oomoo`0VOol02UkIG[QN^EjiH]QFfUKKE]YFfeKJ0dkL00Q>_4kLB]a:gD[LB]e6gD[M
1dKM00=6oTKMA]h00TKn00=6gDKnA_h044Kn01Y77TKnA_i6oT/NA_i77TKnBai6oTLNA_i;7TKnBai7
7T/NA_i;7TLNBai77T/NAai;7TLN0d/N00E77T/NBai;7TLN00=;7P03Aai;7T/N03E;7P03001;7T/N
00=;7P03Ool007oo011oo`00<goo00<007ooOol09Woo00MNfF:hH]URf6;IE[YJf`03F]X0JE;lD]]B
g5;KD_a:g4kMB]a>oD[MB_e6gD[mA]e:oTKMB_i6gD[nA]e:oTKMB_i6gD[nA_e6oTKMB_i6oD[nA_e;
7TKmBai6oD/NA_i;7TKmBai6oT/NA_e;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;
7TKnBai6oT/NA_i;7TKnBai6oT/NAai;7TKnBai77T/NA_i;7TLNBai6oT/NAai;7TLNBam77T/NAai;
7dLNBai77T/OAai;7TLNBam77T/NAai;7`02Bah01TLNBam;7T/NAai;?`9;7P06Aai;?d/NBai77T/o
0T/N00I77T/oBai;7TLNBcl2Bah01TLNBcm;7P00Aai;?`9;7P03Aaioo`00015oo`00=7oo00<007oo
Ool09Goo1F;H1E[J00UBfe;LD]aBg5;KC]e>g4kMB]`01D[M00M6gD[mA]e6oTKMA_i6g@03A_h00dKm
A_i6oP0@A_h05T/NA_i6oTKnBai6oT/NA_i;7TKnBai77T/NA_i;7TLNBai77T/NAai;7TLN0d/N00E7
7T/NBai;7TLN00=;7P03Aai;7T/N03M;7P03001;7T/N00A;7P03001oogoo00moo`00=Goo0P009Goo
00IRfF;HH]UR^6KhH]P2F]X0JEkkF]YJfU;KE_aBfeKlC]aBoDkLD_e>g4kmB]e>oD[LB_i:gD[nA]e:
oTKMB_i6gD[nA_e:oTKMB_i6oD[nA_e:oTKmB_i6oD/NA_i;7TKmBai6oT/NA_e;7TKnBai6oD/NA_i;
7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NAai;7TKnBai77T/NA_i;
7TLNBai6oT/NAai;7TKnBai77T/NAai;7dLNBai77T/OAai;7TLNBam77T/NAai;7`02Bah01TLNBam;
7T/NAai;?`9;7P06Aai;?d/NBai77T/o0T/N00I77T/oBai;7TLNBcl2Bah01TLNBcm;7T/NAah0009;
7P05Aai;?d/NBah0000AOol003Moo`03001oogoo02=oo`9Rf0=Vf0=JfP07G_YNfUKlE]]Fg5KKE_`0
0dkL00i>oD[MB]e:gDkmB]e:oD[MB_e6oD[mA_e:oTKm0TKn00E:oTKmA_i6oT[n00=6oP0NB_i6oTKn
A_i:oTKnB_i6oT/NA_i:oTKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TLNBai6oT/NAai;7TLN0d/N00E7
7T/NBai;7TLN03e;7P=oo`03001oogoo00=oo`03001oogoo00moo`00>7oo00<007ooOol08Woo06YR
^6KhH]QVn6;GI_QNfUkjF]UNnUkJE_aBfeKlD]]BoDkLD_e>g5;mB]a>oD[LC_e:gDknB]e:oDKMB_i6
oD[nA]e:oTKmB_i6gD/NA_e:oTKmBai6oD/NA_e;7TKnBai6oD/NA_i;7TKmBai6oT/NA_e;7TKnBai6
oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TLNBai6oT/NAai;7TKnBai7
7T/NAai;7TLNBai77T/OAai;7TLNBam77T/NAai;7`9;7P06Aai;7d/NBai77T/O0T/N00I77T/oBai;
7TLNBcl2Bah014LNBcm;7T/N47oo00<007ooOol00goo00<007ooOol03goo000iOol00`00Oomoo`0Q
Ool5I]P026KGG_YNfUkjG]YNnUKkF_/3E_/01U;lD]aBo5;lC_e>g@9>o@Q:o@0:B_i6oD[nB_e:oTKn
B_i6oT[nA_h3B_h04DKnB_i6oT/NA_i:oTKnBai6oT/NA_i;7TKnBai77T/NA_h00d/N00E6oT/NBai;
7TLN00=;7P05Aai;7T/NBai77P0PBahROol00`00Oomoo`03Ool00`00Oomoo`0?Ool003Yoo`03001o
ogoo021oo`1QH]QVn6;GI_QVef[hI]MNnUkJH_YNfF;jE]]Jo5KKF_aBo5KlD]aFoE;lC_e>g5;mC_a>
oD[MC_i:oDkmB_e:oT[mB_i6oD/NA_e:oTKmBai6oD[nA_e;7TKmBai6oD/NA_i;7TKmBai6oT/NA_e;
7TKnBai6oD/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai77T/NA_i;7TLNBai6oT/NAai;
7TKnBai77T/NA_i;7TLNBai77T/NAah0;goo00<007ooOol00goo00<007ooOol03goo000kOol00`00
Oomoo`0POol2I]P02FKGI_QVmf[hG_URnUkjH_YNn@05F_/5D_`5C_d014[mC_e:oD[n0d[m00I:oT[m
B_i:oD[nB_d6B_h03T/NA_i:oT[nBai6oT/NB_i;7TKnBai:oT/NA_h3Bah01DKnBai;7T/NA_h00d/N
00E77T/NBai;7TLN00A;7T5oo`03001oogoo009oo`03001oogoo00moo`00?7oo00<007ooOol07goo
00aVn6KGJ_QVef[hJ_MRnUkIH_YNnF;jH_T5F_/09E;lE_aBo5LLC_aBoDklDae>o4kmB_e>oT[mC_i:
oDlNB_e:oT[mBai:oD/NA_e;7TKmBai6oD/NA_e;7TKmBai6oD/NA_e;7TKn05Yoo`03001oogoo009o
o`03001oogoo00moo`00?Goo00<007ooOol07Woo00EVefKhI_MZn6KG009Zm`03H_YRnF;i009Rn@=J
n`03G_]Jnekk00AFo004C_eBoDklD_d4C_ebOol00`00Oomoo`02Ool00`00Oomoo`0?Ool003ioo`03
001oogoo01ioo`0EI]MZn6KGJ_MZef[hH_URnV;iIaYRnF;jF_YO6e[kGa]JnULLD_aFo5;l07]oo`05
001oogooOol0000AOol003moo`03001oogoo01eoo`03J_QVef[g00=Zm`ERn@04I_UW6E[kG_^1Ool0
1@00Oomoogoo00004Goo0010Ool00`00Oomoo`0MOol036[hJ]MZn6[gK_MZmVLJH_UW6F;iIaURnH=o
o`05001oogooOol0000AOol0045oo`03001oogoo01aoo`EZm`06K_MRnFKiI_UW6F;iQ7oo00<007oo
Ool00Woo00<007ooOol03Woo0012Ool00`00Oomoo`0KOol02V[hJ_MZmf[fKaMZmVlGH_UW6F;iQWoo
00D007ooOomoo`00011oo`00@goo00<007ooOol06goo0V[g00I^mf[gK_M^mVLIH_V7Ool01@00Oomo
ogoo000047oo0014Ool00`00Oomoo`0JOol01f[GKaMZmVkgJ_I_5fkf08Qoo`05001oogooOol0000@
Ool004Eoo`03001oogoo01Uoo`06K_MZmf[gK_I^mfkfRGoo00D007ooOomoo`00011oo`00AWoo00<0
07ooOol067oo00IZmVkgJ_I_5fkfKaN:Ool01000Oomoo`0047oo0017Ool00`00Oomoo`0HOol016[g
K_M^mVkgRgoo00@007ooOol0011oo`00B7oo00<007ooOol05goo00A_5fkfKaMZmX]oo`04001oogoo
000@Ool004Uoo`03001oogoo01Ioo`03K_I^mfkf08eoo`03001oo`00011oo`00BWoo00<007ooOol0
5Goo00=_5f[fOol0SGoo00<007oo000047oo001;Ool00`00Oomoo`0EOol00fkgOomoo`2<Ool00`00
Ool0000@Ool004aoo`03001oogoo01Aoo`03001oogoo08aoo`03001oo`00011oo`00CGoo00<007oo
Ool04goo00<007ooOol0SGoo0P0047oo001>Ool00`00Oomoo`0BOol00`00Oomoo`2=Ool2000@Ool0
04moo`03001oogoo015oo`03001oogoo08eoo`03001oo`0000moo`00D7oo00<007ooOol047oo00<0
07ooOol0SGoo00<007oo00003goo001AOol00`00Oomoo`0?Ool00`00Oomoo`2>Ool2000?Ool0059o
o`03001oogoo00ioo`03001oogoo08ioo`8000moo`00Dgoo0P003Woo00<007ooOol0SWoo0P003goo
001EOol00`00Oomoo`0;Ool00`00Oomoo`2>Ool2000?Ool005Ioo`03001oogoo00Yoo`03001oogoo
08moo`03001oogoo00eoo`00Egoo00<007ooOol02Goo00<007ooOol0RGoo1`003goo001HOol00`00
Oomoo`08Ool00`00Oomoo`1kOol>000FOol005Uoo`03001oogoo00Moo`03001oogoo06ioo`d002Ao
o`00FWoo00<007ooOol01Goo00<007ooOol0HWoo3@00<Goo001KOol00`00Oomoo`04Ool00`00Oomo
o`1DOol>000nOol005aoo`03001oogoo00=oo`03001oogoo04Moo`d004aoo`00A7oo0`005Woo00<0
07ooOol00Woo00<007ooOol0>Woo3@00FGoo0015Ool00`00Oomoo`0FOol01@00Oomoogoo0000;Woo
3P00IWoo0015Ool3000GOol01000Oomoo`008Goo3@00M7oo0015Ool01000Oomoo`005goo00<007oo
000057oo3@00PGoo0015Ool01000Oomoo`0067oo0P001Woo3P00SWoo0014Ool4000JOol7002LOol0
0?moo`Ioo`00ogoo1Woo003oOol6Ool00?moo`Ioo`00ogoo1Woo003oOol6Ool00?moo`Ioo`00O7oo
0P0000=oo`0000000Woo10000goo0P0017oo0P0017oo0P001Goo0`00IGoo001mOol00`00Ool00009
Ool01000Oomoo`0027oo00@007ooOol000Eoo`03001oogoo06Aoo`00OWoo00<007ooOol00Woo1000
0Woo00@007ooOol000Qoo`04001oogoo0002Ool5001UOol007aoo`800003Ool0000000Qoo`04001o
ogoo0008Ool01000Oomoo`000Woo00@007ooOol006Ioo`00RGoo00@007ooOol000Qoo`04001oogoo
0003Ool00`00Ool0001VOol008Yoo`8000Yoo`8000Eoo`8006Ioo`00ogoo1Woo003oOol6Ool00?mo
o`Ioo`00ogoo1Woo0000\
\>"],
  ImageRangeCache->{{{0, 260.563}, {184.125, 0}} -> {-0.170508, 0.0461608, \
0.00439067, 0.00439067}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .70824 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1.10169 -0.148196 1.10169 [
[.5 .72074 -20 0 ]
[.5 .72074 20 15 ]
[.44797 -0.02478 -4.90556 -15 ]
[.44797 -0.02478 5.09444 0 ]
[.15892 .66839 -5.31917 0 ]
[.15892 .66839 4.68083 15 ]
[-0.06694 .27471 -10 -6.62571 ]
[-0.06694 .27471 0 8.37429 ]
[ 0 0 0 0 ]
[ 1 .70824 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .72074 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.437500 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(=) show
75.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.05) show
99.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math1Mono
%%DocumentNeededResources: + font Courier
%%DocumentNeededFonts: Math1Mono
%%DocumentNeededFont: + Courier
%%DocumentFonts: font Math1Mono
%%DocumentFonts: + font Courier
grestore
.25 Mabswid
.02946 .11175 m
.89362 0 L
s
gsave
.44797 -0.02478 -65.9056 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(u) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
0 .4272 m
.29069 .70824 L
s
gsave
.15892 .66839 -66.3192 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(p) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.02946 .11175 m
0 .4272 L
s
gsave
-0.06694 .27471 -71 -10.6257 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(q) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.02946 .11175 m
0 .4272 L
s
0 .4272 m
.29069 .70824 L
s
.29069 .70824 m
.30155 .45044 L
s
.30155 .45044 m
.02946 .11175 L
s
.89362 0 m
.98022 .38351 L
s
.98022 .38351 m
1 .65325 L
s
1 .65325 m
.91448 .33294 L
s
.91448 .33294 m
.89362 0 L
s
.02946 .11175 m
0 .4272 L
s
0 .4272 m
.91448 .33294 L
s
.91448 .33294 m
.89362 0 L
s
.89362 0 m
.02946 .11175 L
s
.30155 .45044 m
.98022 .38351 L
s
.98022 .38351 m
1 .65325 L
s
1 .65325 m
.29069 .70824 L
s
.29069 .70824 m
.30155 .45044 L
s
0 0 m
1 0 L
1 .70824 L
0 .70824 L
closepath
clip
newpath
.889 .767 .721 r
.28746 .62326 .29349 .64171 .31483 .59392 .30875 .57966 Mtetra
.832 .775 .798 r
.30875 .57966 .31483 .59392 .33502 .57155 .32899 .55945 Mtetra
.771 .776 .857 r
.32899 .55945 .33502 .57155 .3548 .55966 .34884 .54882 Mtetra
.718 .774 .897 r
.34884 .54882 .3548 .55966 .37443 .5527 .36856 .54267 Mtetra
.678 .772 .921 r
.36856 .54267 .37443 .5527 .39403 .54828 .38826 .53879 Mtetra
.65 .77 .937 r
.38826 .53879 .39403 .54828 .41364 .54524 .40797 .53613 Mtetra
.631 .769 .946 r
.40797 .53613 .41364 .54524 .43328 .54299 .42773 .53415 Mtetra
.618 .77 .953 r
.42773 .53415 .43328 .54299 .45298 .54119 .44754 .53256 Mtetra
.609 .771 .958 r
.44754 .53256 .45298 .54119 .47274 .53965 .46742 .53117 Mtetra
.603 .772 .961 r
.46742 .53117 .47274 .53965 .49257 .53827 .48736 .52991 Mtetra
.599 .773 .963 r
.48736 .52991 .49257 .53827 .51245 .53698 .50737 .5287 Mtetra
.596 .775 .965 r
.50737 .5287 .51245 .53698 .53241 .53572 .52745 .52752 Mtetra
.595 .776 .967 r
.52745 .52752 .53241 .53572 .55243 .53449 .5476 .52634 Mtetra
.593 .778 .968 r
.5476 .52634 .55243 .53449 .57253 .53325 .56782 .52514 Mtetra
.593 .779 .969 r
.56782 .52514 .57253 .53325 .59269 .532 .58811 .52392 Mtetra
.592 .78 .97 r
.58811 .52392 .59269 .532 .61292 .53073 .60847 .52268 Mtetra
.592 .781 .97 r
.60847 .52268 .61292 .53073 .63322 .52944 .62889 .52141 Mtetra
.592 .782 .971 r
.62889 .52141 .63322 .52944 .65358 .52813 .64939 .52011 Mtetra
.592 .783 .971 r
.64939 .52011 .65358 .52813 .67402 .52679 .66996 .51877 Mtetra
.592 .784 .972 r
.66996 .51877 .67402 .52679 .69453 .52542 .6906 .51741 Mtetra
.592 .785 .972 r
.6906 .51741 .69453 .52542 .71511 .52403 .71131 .51602 Mtetra
.71131 .51602 .71511 .52403 .73575 .52261 .7321 .5146 Mtetra
.592 .786 .973 r
.7321 .5146 .73575 .52261 .75647 .52117 .75295 .51315 Mtetra
.592 .787 .973 r
.75295 .51315 .75647 .52117 .77726 .5197 .77388 .51168 Mtetra
.593 .787 .973 r
.77388 .51168 .77726 .5197 .79812 .51822 .79487 .51018 Mtetra
.593 .788 .973 r
.79487 .51018 .79812 .51822 .81905 .5167 .81594 .50866 Mtetra
.81594 .50866 .81905 .5167 .84004 .51517 .83708 .50711 Mtetra
.593 .789 .974 r
.83708 .50711 .84004 .51517 .86112 .51362 .85829 .50555 Mtetra
.85829 .50555 .86112 .51362 .88226 .51205 .87957 .50396 Mtetra
.87957 .50396 .88226 .51205 .90347 .51045 .90093 .50235 Mtetra
.594 .79 .974 r
.90093 .50235 .90347 .51045 .92476 .50884 .92236 .50072 Mtetra
.92236 .50072 .92476 .50884 .94611 .50721 .94386 .49908 Mtetra
.94386 .49908 .94611 .50721 .96754 .50557 .96544 .49741 Mtetra
.594 .791 .974 r
.96544 .49741 .96754 .50557 .98905 .5039 .98709 .49573 Mtetra
.879 .763 .73 r
.28136 .60463 .28746 .62326 .30875 .57966 .30261 .56524 Mtetra
.819 .77 .807 r
.30261 .56524 .30875 .57966 .32899 .55945 .32288 .54721 Mtetra
.757 .77 .864 r
.32288 .54721 .32899 .55945 .34884 .54882 .3428 .53786 Mtetra
.705 .768 .901 r
.3428 .53786 .34884 .54882 .36856 .54267 .36261 .53252 Mtetra
.667 .766 .924 r
.36261 .53252 .36856 .54267 .38826 .53879 .38241 .52918 Mtetra
.641 .766 .939 r
.38241 .52918 .38826 .53879 .40797 .53613 .40223 .52691 Mtetra
.624 .766 .948 r
.40223 .52691 .40797 .53613 .42773 .53415 .4221 .5252 Mtetra
.612 .767 .954 r
.4221 .5252 .42773 .53415 .44754 .53256 .44203 .52381 Mtetra
.604 .769 .958 r
.44203 .52381 .44754 .53256 .46742 .53117 .46203 .52258 Mtetra
.599 .77 .961 r
.46203 .52258 .46742 .53117 .48736 .52991 .48209 .52144 Mtetra
.596 .772 .964 r
.48209 .52144 .48736 .52991 .50737 .5287 .50222 .52032 Mtetra
.594 .774 .966 r
.50222 .52032 .50737 .5287 .52745 .52752 .52243 .51921 Mtetra
.593 .775 .967 r
.52243 .51921 .52745 .52752 .5476 .52634 .5427 .51808 Mtetra
.592 .777 .968 r
.5427 .51808 .5476 .52634 .56782 .52514 .56305 .51693 Mtetra
.591 .778 .969 r
.56305 .51693 .56782 .52514 .58811 .52392 .58346 .51574 Mtetra
.591 .779 .97 r
.58346 .51574 .58811 .52392 .60847 .52268 .60395 .51452 Mtetra
.591 .78 .97 r
.60395 .51452 .60847 .52268 .62889 .52141 .62451 .51327 Mtetra
.591 .782 .971 r
.62451 .51327 .62889 .52141 .64939 .52011 .64514 .51197 Mtetra
.591 .783 .971 r
.64514 .51197 .64939 .52011 .66996 .51877 .66585 .51065 Mtetra
.591 .783 .972 r
.66585 .51065 .66996 .51877 .6906 .51741 .68662 .50929 Mtetra
.591 .784 .972 r
.68662 .50929 .6906 .51741 .71131 .51602 .70747 .5079 Mtetra
.592 .785 .972 r
.70747 .5079 .71131 .51602 .7321 .5146 .72839 .50647 Mtetra
.592 .786 .973 r
.72839 .50647 .7321 .5146 .75295 .51315 .74938 .50502 Mtetra
.74938 .50502 .75295 .51315 .77388 .51168 .77044 .50354 Mtetra
.592 .787 .973 r
.77044 .50354 .77388 .51168 .79487 .51018 .79158 .50203 Mtetra
.79158 .50203 .79487 .51018 .81594 .50866 .81279 .5005 Mtetra
.593 .788 .973 r
.81279 .5005 .81594 .50866 .83708 .50711 .83407 .49894 Mtetra
.593 .788 .974 r
.83407 .49894 .83708 .50711 .85829 .50555 .85543 .49736 Mtetra
.593 .789 .974 r
.85543 .49736 .85829 .50555 .87957 .50396 .87685 .49576 Mtetra
.87685 .49576 .87957 .50396 .90093 .50235 .89836 .49413 Mtetra
.593 .79 .974 r
.89836 .49413 .90093 .50235 .92236 .50072 .91993 .49249 Mtetra
.594 .79 .974 r
.91993 .49249 .92236 .50072 .94386 .49908 .94158 .49082 Mtetra
.94158 .49082 .94386 .49908 .96544 .49741 .96331 .48914 Mtetra
.594 .791 .974 r
.96331 .48914 .96544 .49741 .98709 .49573 .98511 .48744 Mtetra
.868 .758 .74 r
.2752 .58583 .28136 .60463 .30261 .56524 .29641 .55066 Mtetra
.804 .764 .816 r
.29641 .55066 .30261 .56524 .32288 .54721 .3167 .53482 Mtetra
.741 .764 .871 r
.3167 .53482 .32288 .54721 .3428 .53786 .33669 .52676 Mtetra
.691 .762 .906 r
.33669 .52676 .3428 .53786 .36261 .53252 .35659 .52224 Mtetra
.656 .761 .927 r
.35659 .52224 .36261 .53252 .38241 .52918 .37649 .51945 Mtetra
.632 .761 .94 r
.37649 .51945 .38241 .52918 .40223 .52691 .39642 .51756 Mtetra
.616 .762 .949 r
.39642 .51756 .40223 .52691 .4221 .5252 .4164 .51613 Mtetra
.606 .764 .955 r
.4164 .51613 .4221 .5252 .44203 .52381 .43645 .51495 Mtetra
.6 .766 .959 r
.43645 .51495 .44203 .52381 .46203 .52258 .45656 .51388 Mtetra
.596 .768 .962 r
.45656 .51388 .46203 .52258 .48209 .52144 .47675 .51285 Mtetra
.593 .77 .964 r
.47675 .51285 .48209 .52144 .50222 .52032 .497 .51183 Mtetra
.592 .772 .966 r
.497 .51183 .50222 .52032 .52243 .51921 .51733 .51079 Mtetra
.591 .774 .967 r
.51733 .51079 .52243 .51921 .5427 .51808 .53774 .50971 Mtetra
.59 .776 .968 r
.53774 .50971 .5427 .51808 .56305 .51693 .55821 .5086 Mtetra
.59 .777 .969 r
.55821 .5086 .56305 .51693 .58346 .51574 .57876 .50745 Mtetra
.59 .779 .97 r
.57876 .50745 .58346 .51574 .60395 .51452 .59938 .50625 Mtetra
.59 .78 .971 r
.59938 .50625 .60395 .51452 .62451 .51327 .62007 .50501 Mtetra
.59 .781 .971 r
.62007 .50501 .62451 .51327 .64514 .51197 .64084 .50373 Mtetra
.59 .782 .971 r
.64084 .50373 .64514 .51197 .66585 .51065 .66168 .50241 Mtetra
.591 .783 .972 r
.66168 .50241 .66585 .51065 .68662 .50929 .68259 .50106 Mtetra
.591 .784 .972 r
.68259 .50106 .68662 .50929 .70747 .5079 .70357 .49966 Mtetra
.591 .785 .972 r
.70357 .49966 .70747 .5079 .72839 .50647 .72463 .49824 Mtetra
.591 .785 .973 r
.72463 .49824 .72839 .50647 .74938 .50502 .74576 .49678 Mtetra
.592 .786 .973 r
.74576 .49678 .74938 .50502 .77044 .50354 .76697 .49529 Mtetra
.592 .787 .973 r
.76697 .49529 .77044 .50354 .79158 .50203 .78824 .49377 Mtetra
.78824 .49377 .79158 .50203 .81279 .5005 .8096 .49223 Mtetra
.592 .788 .973 r
.8096 .49223 .81279 .5005 .83407 .49894 .83102 .49066 Mtetra
.593 .788 .974 r
.83102 .49066 .83407 .49894 .85543 .49736 .85252 .48906 Mtetra
.593 .789 .974 r
.85252 .48906 .85543 .49736 .87685 .49576 .8741 .48744 Mtetra
.8741 .48744 .87685 .49576 .89836 .49413 .89574 .4858 Mtetra
.89574 .4858 .89836 .49413 .91993 .49249 .91747 .48414 Mtetra
.593 .79 .974 r
.91747 .48414 .91993 .49249 .94158 .49082 .93927 .48246 Mtetra
.594 .79 .974 r
.93927 .48246 .94158 .49082 .96331 .48914 .96114 .48075 Mtetra
.96114 .48075 .96331 .48914 .98511 .48744 .98309 .47903 Mtetra
.854 .753 .75 r
.26899 .56684 .2752 .58583 .29641 .55066 .29013 .53592 Mtetra
.787 .757 .825 r
.29013 .53592 .29641 .55066 .3167 .53482 .31045 .52229 Mtetra
.725 .756 .878 r
.31045 .52229 .3167 .53482 .33669 .52676 .33051 .51552 Mtetra
.677 .755 .91 r
.33051 .51552 .33669 .52676 .35659 .52224 .3505 .51182 Mtetra
.644 .755 .93 r
.3505 .51182 .35659 .52224 .37649 .51945 .37049 .50959 Mtetra
.623 .757 .942 r
.37049 .50959 .37649 .51945 .39642 .51756 .39053 .50809 Mtetra
.609 .759 .95 r
.39053 .50809 .39642 .51756 .4164 .51613 .41062 .50694 Mtetra
.601 .761 .956 r
.41062 .50694 .4164 .51613 .43645 .51495 .43079 .50597 Mtetra
.595 .764 .96 r
.43079 .50597 .43645 .51495 .45656 .51388 .45102 .50505 Mtetra
.592 .766 .962 r
.45102 .50505 .45656 .51388 .47675 .51285 .47133 .50415 Mtetra
.59 .769 .965 r
.47133 .50415 .47675 .51285 .497 .51183 .49171 .50322 Mtetra
.589 .771 .966 r
.49171 .50322 .497 .51183 .51733 .51079 .51217 .50225 Mtetra
.589 .773 .968 r
.51217 .50225 .51733 .51079 .53774 .50971 .5327 .50123 Mtetra
.588 .775 .969 r
.5327 .50123 .53774 .50971 .55821 .5086 .55331 .50016 Mtetra
.588 .776 .969 r
.55331 .50016 .55821 .5086 .57876 .50745 .57399 .49904 Mtetra
.589 .778 .97 r
.57399 .49904 .57876 .50745 .59938 .50625 .59474 .49786 Mtetra
.589 .779 .971 r
.59474 .49786 .59938 .50625 .62007 .50501 .61557 .49664 Mtetra
.589 .781 .971 r
.61557 .49664 .62007 .50501 .64084 .50373 .63647 .49537 Mtetra
.59 .782 .972 r
.63647 .49537 .64084 .50373 .66168 .50241 .65745 .49406 Mtetra
.59 .783 .972 r
.65745 .49406 .66168 .50241 .68259 .50106 .6785 .49271 Mtetra
.59 .784 .972 r
.6785 .49271 .68259 .50106 .70357 .49966 .69962 .49132 Mtetra
.591 .784 .972 r
.69962 .49132 .70357 .49966 .72463 .49824 .72082 .48989 Mtetra
.591 .785 .973 r
.72082 .48989 .72463 .49824 .74576 .49678 .74209 .48842 Mtetra
.591 .786 .973 r
.74209 .48842 .74576 .49678 .76697 .49529 .76344 .48692 Mtetra
.592 .786 .973 r
.76344 .48692 .76697 .49529 .78824 .49377 .78486 .4854 Mtetra
.592 .787 .973 r
.78486 .4854 .78824 .49377 .8096 .49223 .80636 .48384 Mtetra
.592 .788 .973 r
.80636 .48384 .8096 .49223 .83102 .49066 .82793 .48225 Mtetra
.592 .788 .974 r
.82793 .48225 .83102 .49066 .85252 .48906 .84958 .48064 Mtetra
.593 .788 .974 r
.84958 .48064 .85252 .48906 .8741 .48744 .8713 .47901 Mtetra
.593 .789 .974 r
.8713 .47901 .8741 .48744 .89574 .4858 .8931 .47735 Mtetra
.8931 .47735 .89574 .4858 .91747 .48414 .91497 .47567 Mtetra
.593 .79 .974 r
.91497 .47567 .91747 .48414 .93927 .48246 .93692 .47397 Mtetra
.93692 .47397 .93927 .48246 .96114 .48075 .95895 .47225 Mtetra
.594 .79 .974 r
.95895 .47225 .96114 .48075 .98309 .47903 .98105 .4705 Mtetra
.839 .746 .761 r
.26271 .54766 .26899 .56684 .29013 .53592 .28378 .52102 Mtetra
.769 .748 .835 r
.28378 .52102 .29013 .53592 .31045 .52229 .30413 .50961 Mtetra
.707 .748 .884 r
.30413 .50961 .31045 .52229 .33051 .51552 .32425 .50415 Mtetra
.662 .748 .914 r
.32425 .50415 .33051 .51552 .3505 .51182 .34432 .50128 Mtetra
.632 .749 .933 r
.34432 .50128 .3505 .51182 .37049 .50959 .36441 .4996 Mtetra
.613 .752 .944 r
.36441 .4996 .37049 .50959 .39053 .50809 .38456 .49849 Mtetra
.602 .755 .951 r
.38456 .49849 .39053 .50809 .41062 .50694 .40477 .49763 Mtetra
.595 .758 .957 r
.40477 .49763 .41062 .50694 .43079 .50597 .42505 .49687 Mtetra
.591 .761 .96 r
.42505 .49687 .43079 .50597 .45102 .50505 .44541 .49611 Mtetra
.588 .764 .963 r
.44541 .49611 .45102 .50505 .47133 .50415 .46584 .49533 Mtetra
.587 .767 .965 r
.46584 .49533 .47133 .50415 .49171 .50322 .48635 .49449 Mtetra
.587 .77 .967 r
.48635 .49449 .49171 .50322 .51217 .50225 .50694 .49359 Mtetra
.587 .772 .968 r
.50694 .49359 .51217 .50225 .5327 .50123 .5276 .49263 Mtetra
.587 .774 .969 r
.5276 .49263 .5327 .50123 .55331 .50016 .54834 .4916 Mtetra
.587 .776 .97 r
.54834 .4916 .55331 .50016 .57399 .49904 .56915 .49051 Mtetra
.587 .777 .97 r
.56915 .49051 .57399 .49904 .59474 .49786 .59004 .48936 Mtetra
.588 .779 .971 r
.59004 .48936 .59474 .49786 .61557 .49664 .61101 .48816 Mtetra
.588 .78 .971 r
.61101 .48816 .61557 .49664 .63647 .49537 .63205 .4869 Mtetra
.589 .781 .972 r
.63205 .4869 .63647 .49537 .65745 .49406 .65316 .4856 Mtetra
.589 .782 .972 r
.65316 .4856 .65745 .49406 .6785 .49271 .67435 .48424 Mtetra
.59 .783 .972 r
.67435 .48424 .6785 .49271 .69962 .49132 .69561 .48285 Mtetra
.59 .784 .973 r
.69561 .48285 .69962 .49132 .72082 .48989 .71696 .48142 Mtetra
.59 .785 .973 r
.71696 .48142 .72082 .48989 .74209 .48842 .73837 .47995 Mtetra
.591 .786 .973 r
.73837 .47995 .74209 .48842 .76344 .48692 .75986 .47844 Mtetra
.75986 .47844 .76344 .48692 .78486 .4854 .78143 .4769 Mtetra
.591 .787 .973 r
.78143 .4769 .78486 .4854 .80636 .48384 .80307 .47533 Mtetra
.592 .787 .973 r
.80307 .47533 .80636 .48384 .82793 .48225 .82479 .47373 Mtetra
.592 .788 .974 r
.82479 .47373 .82793 .48225 .84958 .48064 .84659 .47211 Mtetra
.84659 .47211 .84958 .48064 .8713 .47901 .86846 .47046 Mtetra
.593 .789 .974 r
.86846 .47046 .8713 .47901 .8931 .47735 .89041 .46878 Mtetra
.89041 .46878 .8931 .47735 .91497 .47567 .91244 .46708 Mtetra
.593 .79 .974 r
.91244 .46708 .91497 .47567 .93692 .47397 .93454 .46536 Mtetra
.93454 .46536 .93692 .47397 .95895 .47225 .95672 .46362 Mtetra
.95672 .46362 .95895 .47225 .98105 .4705 .97898 .46185 Mtetra
.82 .737 .773 r
.25638 .5283 .26271 .54766 .28378 .52102 .27737 .50594 Mtetra
.747 .738 .844 r
.27737 .50594 .28378 .52102 .30413 .50961 .29773 .49677 Mtetra
.687 .739 .89 r
.29773 .49677 .30413 .50961 .32425 .50415 .31791 .49263 Mtetra
.645 .74 .918 r
.31791 .49263 .32425 .50415 .34432 .50128 .33807 .49059 Mtetra
.619 .743 .935 r
.33807 .49059 .34432 .50128 .36441 .4996 .35826 .48949 Mtetra
.603 .747 .946 r
.35826 .48949 .36441 .4996 .38456 .49849 .37851 .48877 Mtetra
.594 .751 .953 r
.37851 .48877 .38456 .49849 .40477 .49763 .39884 .4882 Mtetra
.589 .755 .957 r
.39884 .4882 .40477 .49763 .42505 .49687 .41924 .48764 Mtetra
.586 .759 .961 r
.41924 .48764 .42505 .49687 .44541 .49611 .43972 .48705 Mtetra
.585 .762 .963 r
.43972 .48705 .44541 .49611 .46584 .49533 .46028 .48639 Mtetra
.584 .766 .965 r
.46028 .48639 .46584 .49533 .48635 .49449 .48092 .48564 Mtetra
.584 .768 .967 r
.48092 .48564 .48635 .49449 .50694 .49359 .50164 .48482 Mtetra
.584 .771 .968 r
.50164 .48482 .50694 .49359 .5276 .49263 .52243 .48391 Mtetra
.585 .773 .969 r
.52243 .48391 .5276 .49263 .54834 .4916 .5433 .48293 Mtetra
.586 .775 .97 r
.5433 .48293 .54834 .4916 .56915 .49051 .56425 .48187 Mtetra
.586 .777 .97 r
.56425 .48187 .56915 .49051 .59004 .48936 .58528 .48074 Mtetra
.587 .778 .971 r
.58528 .48074 .59004 .48936 .61101 .48816 .60638 .47956 Mtetra
.587 .78 .971 r
.60638 .47956 .61101 .48816 .63205 .4869 .62756 .47831 Mtetra
.588 .781 .972 r
.62756 .47831 .63205 .4869 .65316 .4856 .64881 .47701 Mtetra
.589 .782 .972 r
.64881 .47701 .65316 .4856 .67435 .48424 .67014 .47566 Mtetra
.589 .783 .972 r
.67014 .47566 .67435 .48424 .69561 .48285 .69155 .47427 Mtetra
.59 .784 .973 r
.69155 .47427 .69561 .48285 .71696 .48142 .71304 .47283 Mtetra
.59 .785 .973 r
.71304 .47283 .71696 .48142 .73837 .47995 .7346 .47135 Mtetra
.7346 .47135 .73837 .47995 .75986 .47844 .75623 .46983 Mtetra
.591 .786 .973 r
.75623 .46983 .75986 .47844 .78143 .4769 .77795 .46829 Mtetra
.591 .787 .973 r
.77795 .46829 .78143 .4769 .80307 .47533 .79974 .4667 Mtetra
.79974 .4667 .80307 .47533 .82479 .47373 .82161 .46509 Mtetra
.592 .788 .974 r
.82161 .46509 .82479 .47373 .84659 .47211 .84356 .46345 Mtetra
.84356 .46345 .84659 .47211 .86846 .47046 .86558 .46178 Mtetra
.592 .789 .974 r
.86558 .46178 .86846 .47046 .89041 .46878 .88768 .46009 Mtetra
.593 .789 .974 r
.88768 .46009 .89041 .46878 .91244 .46708 .90987 .45837 Mtetra
.90987 .45837 .91244 .46708 .93454 .46536 .93213 .45663 Mtetra
.593 .79 .974 r
.93213 .45663 .93454 .46536 .95672 .46362 .95446 .45486 Mtetra
.95446 .45486 .95672 .46362 .97898 .46185 .97688 .45308 Mtetra
.797 .726 .785 r
.24998 .50875 .25638 .5283 .27737 .50594 .27087 .4907 Mtetra
.723 .727 .853 r
.27087 .4907 .27737 .50594 .29773 .49677 .29125 .48378 Mtetra
.665 .728 .896 r
.29125 .48378 .29773 .49677 .31791 .49263 .31149 .48096 Mtetra
.628 .731 .922 r
.31149 .48096 .31791 .49263 .33807 .49059 .33173 .47977 Mtetra
.606 .736 .937 r
.33173 .47977 .33807 .49059 .35826 .48949 .35202 .47924 Mtetra
.593 .742 .947 r
.35202 .47924 .35826 .48949 .37851 .48877 .37239 .47892 Mtetra
.586 .747 .954 r
.37239 .47892 .37851 .48877 .39884 .4882 .39283 .47864 Mtetra
.583 .752 .958 r
.39283 .47864 .39884 .4882 .41924 .48764 .41335 .4783 Mtetra
.581 .756 .961 r
.41335 .4783 .41924 .48764 .43972 .48705 .43396 .47786 Mtetra
.581 .76 .964 r
.43396 .47786 .43972 .48705 .46028 .48639 .45464 .47732 Mtetra
.581 .764 .966 r
.45464 .47732 .46028 .48639 .48092 .48564 .47541 .47667 Mtetra
.582 .767 .967 r
.47541 .47667 .48092 .48564 .50164 .48482 .49626 .47592 Mtetra
.582 .77 .968 r
.49626 .47592 .50164 .48482 .52243 .48391 .51719 .47507 Mtetra
.583 .772 .969 r
.51719 .47507 .52243 .48391 .5433 .48293 .53819 .47413 Mtetra
.584 .774 .97 r
.53819 .47413 .5433 .48293 .56425 .48187 .55928 .4731 Mtetra
.585 .776 .97 r
.55928 .4731 .56425 .48187 .58528 .48074 .58044 .472 Mtetra
.586 .778 .971 r
.58044 .472 .58528 .48074 .60638 .47956 .60168 .47083 Mtetra
.587 .779 .971 r
.60168 .47083 .60638 .47956 .62756 .47831 .623 .4696 Mtetra
.587 .78 .972 r
.623 .4696 .62756 .47831 .64881 .47701 .6444 .4683 Mtetra
.588 .781 .972 r
.6444 .4683 .64881 .47701 .67014 .47566 .66588 .46696 Mtetra
.588 .782 .972 r
.66588 .46696 .67014 .47566 .69155 .47427 .68743 .46556 Mtetra
.589 .783 .973 r
.68743 .46556 .69155 .47427 .71304 .47283 .70906 .46412 Mtetra
.59 .784 .973 r
.70906 .46412 .71304 .47283 .7346 .47135 .73077 .46263 Mtetra
.59 .785 .973 r
.73077 .46263 .7346 .47135 .75623 .46983 .75256 .46111 Mtetra
.59 .786 .973 r
.75256 .46111 .75623 .46983 .77795 .46829 .77442 .45955 Mtetra
.591 .786 .973 r
.77442 .45955 .77795 .46829 .79974 .4667 .79636 .45795 Mtetra
.591 .787 .974 r
.79636 .45795 .79974 .4667 .82161 .46509 .81838 .45632 Mtetra
.592 .788 .974 r
.81838 .45632 .82161 .46509 .84356 .46345 .84048 .45466 Mtetra
.84048 .45466 .84356 .46345 .86558 .46178 .86266 .45298 Mtetra
.86266 .45298 .86558 .46178 .88768 .46009 .88492 .45127 Mtetra
.592 .789 .974 r
.88492 .45127 .88768 .46009 .90987 .45837 .90726 .44953 Mtetra
.593 .789 .974 r
.90726 .44953 .90987 .45837 .93213 .45663 .92967 .44776 Mtetra
.593 .79 .974 r
.92967 .44776 .93213 .45663 .95446 .45486 .95217 .44598 Mtetra
.95217 .44598 .95446 .45486 .97688 .45308 .97475 .44417 Mtetra
.77 .712 .797 r
.24351 .489 .24998 .50875 .27087 .4907 .26431 .47528 Mtetra
.695 .713 .862 r
.26431 .47528 .27087 .4907 .29125 .48378 .28469 .47063 Mtetra
.642 .716 .902 r
.28469 .47063 .29125 .48378 .31149 .48096 .30499 .46915 Mtetra
.61 .722 .925 r
.30499 .46915 .31149 .48096 .33173 .47977 .32531 .46881 Mtetra
.592 .729 .939 r
.32531 .46881 .33173 .47977 .35202 .47924 .3457 .46885 Mtetra
.582 .736 .948 r
.3457 .46885 .35202 .47924 .37239 .47892 .36618 .46894 Mtetra
.578 .743 .954 r
.36618 .46894 .37239 .47892 .39283 .47864 .38673 .46894 Mtetra
.577 .749 .959 r
.38673 .46894 .39283 .47864 .41335 .4783 .40738 .46882 Mtetra
.576 .754 .962 r
.40738 .46882 .41335 .4783 .43396 .47786 .42811 .46855 Mtetra
.577 .758 .964 r
.42811 .46855 .43396 .47786 .45464 .47732 .44892 .46813 Mtetra
.578 .762 .966 r
.44892 .46813 .45464 .47732 .47541 .47667 .46982 .46758 Mtetra
.579 .766 .967 r
.46982 .46758 .47541 .47667 .49626 .47592 .49081 .4669 Mtetra
.58 .769 .968 r
.49081 .4669 .49626 .47592 .51719 .47507 .51187 .46611 Mtetra
.582 .771 .969 r
.51187 .46611 .51719 .47507 .53819 .47413 .53301 .46521 Mtetra
.583 .773 .97 r
.53301 .46521 .53819 .47413 .55928 .4731 .55424 .46422 Mtetra
.584 .775 .971 r
.55424 .46422 .55928 .4731 .58044 .472 .57554 .46314 Mtetra
.585 .777 .971 r
.57554 .46314 .58044 .472 .60168 .47083 .59692 .46199 Mtetra
.586 .779 .971 r
.59692 .46199 .60168 .47083 .623 .4696 .61839 .46076 Mtetra
.586 .78 .972 r
.61839 .46076 .623 .4696 .6444 .4683 .63993 .45947 Mtetra
.587 .781 .972 r
.63993 .45947 .6444 .4683 .66588 .46696 .66155 .45813 Mtetra
.588 .782 .972 r
.66155 .45813 .66588 .46696 .68743 .46556 .68325 .45673 Mtetra
.589 .783 .973 r
.68325 .45673 .68743 .46556 .70906 .46412 .70503 .45528 Mtetra
.589 .784 .973 r
.70503 .45528 .70906 .46412 .73077 .46263 .72689 .45379 Mtetra
.59 .785 .973 r
.72689 .45379 .73077 .46263 .75256 .46111 .74882 .45225 Mtetra
.59 .786 .973 r
.74882 .45225 .75256 .46111 .77442 .45955 .77084 .45068 Mtetra
.591 .786 .973 r
.77084 .45068 .77442 .45955 .79636 .45795 .79293 .44907 Mtetra
.591 .787 .974 r
.79293 .44907 .79636 .45795 .81838 .45632 .81511 .44743 Mtetra
.81511 .44743 .81838 .45632 .84048 .45466 .83736 .44575 Mtetra
.592 .788 .974 r
.83736 .44575 .84048 .45466 .86266 .45298 .8597 .44405 Mtetra
.8597 .44405 .86266 .45298 .88492 .45127 .88212 .44232 Mtetra
.592 .789 .974 r
.88212 .44232 .88492 .45127 .90726 .44953 .90461 .44056 Mtetra
.90461 .44056 .90726 .44953 .92967 .44776 .92719 .43877 Mtetra
.593 .79 .974 r
.92719 .43877 .92967 .44776 .95217 .44598 .94985 .43697 Mtetra
.94985 .43697 .95217 .44598 .97475 .44417 .97259 .43514 Mtetra
.737 .694 .81 r
.23698 .46905 .24351 .489 .26431 .47528 .25767 .45968 Mtetra
.664 .696 .87 r
.25767 .45968 .26431 .47528 .28469 .47063 .27805 .45732 Mtetra
.616 .703 .906 r
.27805 .45732 .28469 .47063 .30499 .46915 .2984 .45719 Mtetra
.59 .712 .928 r
.2984 .45719 .30499 .46915 .32531 .46881 .31881 .45771 Mtetra
.577 .721 .941 r
.31881 .45771 .32531 .46881 .3457 .46885 .3393 .45832 Mtetra
.572 .73 .949 r
.3393 .45832 .3457 .46885 .36618 .46894 .35988 .45882 Mtetra
.57 .738 .955 r
.35988 .45882 .36618 .46894 .38673 .46894 .38056 .45912 Mtetra
.57 .745 .959 r
.38056 .45912 .38673 .46894 .40738 .46882 .40133 .45921 Mtetra
.571 .751 .962 r
.40133 .45921 .40738 .46882 .42811 .46855 .42218 .45911 Mtetra
.573 .756 .965 r
.42218 .45911 .42811 .46855 .44892 .46813 .44313 .45882 Mtetra
.575 .761 .966 r
.44313 .45882 .44892 .46813 .46982 .46758 .46416 .45836 Mtetra
.577 .764 .968 r
.46416 .45836 .46982 .46758 .49081 .4669 .48528 .45776 Mtetra
.578 .767 .969 r
.48528 .45776 .49081 .4669 .51187 .46611 .50648 .45702 Mtetra
.58 .77 .969 r
.50648 .45702 .51187 .46611 .53301 .46521 .52776 .45616 Mtetra
.581 .773 .97 r
.52776 .45616 .53301 .46521 .55424 .46422 .54912 .4552 Mtetra
.583 .775 .971 r
.54912 .4552 .55424 .46422 .57554 .46314 .57057 .45415 Mtetra
.584 .776 .971 r
.57057 .45415 .57554 .46314 .59692 .46199 .5921 .45301 Mtetra
.585 .778 .972 r
.5921 .45301 .59692 .46199 .61839 .46076 .6137 .4518 Mtetra
.586 .779 .972 r
.6137 .4518 .61839 .46076 .63993 .45947 .63539 .45052 Mtetra
.587 .781 .972 r
.63539 .45052 .63993 .45947 .66155 .45813 .65716 .44917 Mtetra
.587 .782 .972 r
.65716 .44917 .66155 .45813 .68325 .45673 .67901 .44777 Mtetra
.588 .783 .973 r
.67901 .44777 .68325 .45673 .70503 .45528 .70094 .44632 Mtetra
.589 .784 .973 r
.70094 .44632 .70503 .45528 .72689 .45379 .72295 .44482 Mtetra
.589 .785 .973 r
.72295 .44482 .72689 .45379 .74882 .45225 .74504 .44327 Mtetra
.59 .785 .973 r
.74504 .44327 .74882 .45225 .77084 .45068 .76721 .44168 Mtetra
.59 .786 .973 r
.76721 .44168 .77084 .45068 .79293 .44907 .78946 .44006 Mtetra
.591 .787 .974 r
.78946 .44006 .79293 .44907 .81511 .44743 .81179 .4384 Mtetra
.81179 .4384 .81511 .44743 .83736 .44575 .8342 .43671 Mtetra
.591 .788 .974 r
.8342 .43671 .83736 .44575 .8597 .44405 .85669 .43499 Mtetra
.592 .788 .974 r
.85669 .43499 .8597 .44405 .88212 .44232 .87927 .43324 Mtetra
.592 .789 .974 r
.87927 .43324 .88212 .44232 .90461 .44056 .90193 .43146 Mtetra
.90193 .43146 .90461 .44056 .92719 .43877 .92467 .42965 Mtetra
.593 .789 .974 r
.92467 .42965 .92719 .43877 .94985 .43697 .94749 .42782 Mtetra
.593 .79 .974 r
.94749 .42782 .94985 .43697 .97259 .43514 .97039 .42597 Mtetra
.697 .672 .822 r
.23039 .4489 .23698 .46905 .25767 .45968 .25095 .4439 Mtetra
.628 .676 .877 r
.25095 .4439 .25767 .45968 .27805 .45732 .27133 .44384 Mtetra
.588 .687 .91 r
.27133 .44384 .27805 .45732 .2984 .45719 .29173 .44507 Mtetra
.57 .701 .93 r
.29173 .44507 .2984 .45719 .31881 .45771 .31222 .44646 Mtetra
.562 .713 .942 r
.31222 .44646 .31881 .45771 .3393 .45832 .33281 .44766 Mtetra
.561 .724 .951 r
.33281 .44766 .3393 .45832 .35988 .45882 .3535 .44856 Mtetra
.562 .734 .956 r
.3535 .44856 .35988 .45882 .38056 .45912 .3743 .44916 Mtetra
.564 .742 .96 r
.3743 .44916 .38056 .45912 .40133 .45921 .39519 .44948 Mtetra
.567 .749 .963 r
.39519 .44948 .40133 .45921 .42218 .45911 .41617 .44953 Mtetra
.569 .754 .965 r
.41617 .44953 .42218 .45911 .44313 .45882 .43725 .44937 Mtetra
.572 .759 .967 r
.43725 .44937 .44313 .45882 .46416 .45836 .45842 .44901 Mtetra
.574 .763 .968 r
.45842 .44901 .46416 .45836 .48528 .45776 .47967 .44848 Mtetra
.576 .766 .969 r
.47967 .44848 .48528 .45776 .50648 .45702 .50101 .4478 Mtetra
.578 .769 .97 r
.50101 .4478 .50648 .45702 .52776 .45616 .52243 .44699 Mtetra
.58 .772 .97 r
.52243 .44699 .52776 .45616 .54912 .4552 .54394 .44606 Mtetra
.581 .774 .971 r
.54394 .44606 .54912 .4552 .57057 .45415 .56553 .44503 Mtetra
.583 .776 .971 r
.56553 .44503 .57057 .45415 .5921 .45301 .5872 .44391 Mtetra
.584 .777 .972 r
.5872 .44391 .5921 .45301 .6137 .4518 .60895 .44271 Mtetra
.585 .779 .972 r
.60895 .44271 .6137 .4518 .63539 .45052 .63079 .44143 Mtetra
.586 .78 .972 r
.63079 .44143 .63539 .45052 .65716 .44917 .65271 .44008 Mtetra
.587 .781 .973 r
.65271 .44008 .65716 .44917 .67901 .44777 .67471 .43868 Mtetra
.587 .782 .973 r
.67471 .43868 .67901 .44777 .70094 .44632 .69679 .43722 Mtetra
.588 .783 .973 r
.69679 .43722 .70094 .44632 .72295 .44482 .71895 .43571 Mtetra
.589 .784 .973 r
.71895 .43571 .72295 .44482 .74504 .44327 .74119 .43416 Mtetra
.589 .785 .973 r
.74119 .43416 .74504 .44327 .76721 .44168 .76352 .43256 Mtetra
.59 .786 .973 r
.76352 .43256 .76721 .44168 .78946 .44006 .78593 .43092 Mtetra
.59 .786 .974 r
.78593 .43092 .78946 .44006 .81179 .4384 .80842 .42924 Mtetra
.591 .787 .974 r
.80842 .42924 .81179 .4384 .8342 .43671 .83099 .42753 Mtetra
.591 .788 .974 r
.83099 .42753 .8342 .43671 .85669 .43499 .85364 .42579 Mtetra
.85364 .42579 .85669 .43499 .87927 .43324 .87638 .42402 Mtetra
.592 .789 .974 r
.87638 .42402 .87927 .43324 .90193 .43146 .8992 .42222 Mtetra
.8992 .42222 .90193 .43146 .92467 .42965 .92211 .42039 Mtetra
.92211 .42039 .92467 .42965 .94749 .42782 .94509 .41854 Mtetra
.593 .79 .974 r
.94509 .41854 .94749 .42782 .97039 .42597 .96817 .41666 Mtetra
.648 .643 .832 r
.22373 .42855 .23039 .4489 .25095 .4439 .24416 .42794 Mtetra
.587 .653 .882 r
.24416 .42794 .25095 .4439 .27133 .44384 .26452 .4302 Mtetra
.558 .67 .913 r
.26452 .4302 .27133 .44384 .29173 .44507 .28498 .43279 Mtetra
.548 .688 .932 r
.28498 .43279 .29173 .44507 .31222 .44646 .30555 .43506 Mtetra
.547 .705 .944 r
.30555 .43506 .31222 .44646 .33281 .44766 .32624 .43685 Mtetra
.549 .718 .951 r
.32624 .43685 .33281 .44766 .3535 .44856 .34704 .43817 Mtetra
.553 .729 .957 r
.34704 .43817 .3535 .44856 .3743 .44916 .36795 .43907 Mtetra
.557 .738 .961 r
.36795 .43907 .3743 .44916 .39519 .44948 .38897 .4396 Mtetra
.562 .746 .963 r
.38897 .4396 .39519 .44948 .41617 .44953 .41008 .43983 Mtetra
.565 .752 .965 r
.41008 .43983 .41617 .44953 .43725 .44937 .43129 .43979 Mtetra
.569 .757 .967 r
.43129 .43979 .43725 .44937 .45842 .44901 .45259 .43953 Mtetra
.572 .762 .968 r
.45259 .43953 .45842 .44901 .47967 .44848 .47398 .43907 Mtetra
.574 .765 .969 r
.47398 .43907 .47967 .44848 .50101 .4478 .49546 .43845 Mtetra
.576 .768 .97 r
.49546 .43845 .50101 .4478 .52243 .44699 .51703 .43768 Mtetra
.578 .771 .97 r
.51703 .43768 .52243 .44699 .54394 .44606 .53868 .43679 Mtetra
.58 .773 .971 r
.53868 .43679 .54394 .44606 .56553 .44503 .56041 .43578 Mtetra
.582 .775 .971 r
.56041 .43578 .56553 .44503 .5872 .44391 .58223 .43467 Mtetra
.583 .777 .972 r
.58223 .43467 .5872 .44391 .60895 .44271 .60413 .43348 Mtetra
.584 .779 .972 r
.60413 .43348 .60895 .44271 .63079 .44143 .62612 .43221 Mtetra
.585 .78 .972 r
.62612 .43221 .63079 .44143 .65271 .44008 .64819 .43087 Mtetra
.586 .781 .973 r
.64819 .43087 .65271 .44008 .67471 .43868 .67034 .42946 Mtetra
.587 .782 .973 r
.67034 .42946 .67471 .43868 .69679 .43722 .69258 .42799 Mtetra
.588 .783 .973 r
.69258 .42799 .69679 .43722 .71895 .43571 .71489 .42648 Mtetra
.588 .784 .973 r
.71489 .42648 .71895 .43571 .74119 .43416 .73729 .42491 Mtetra
.589 .785 .973 r
.73729 .42491 .74119 .43416 .76352 .43256 .75978 .4233 Mtetra
.59 .786 .973 r
.75978 .4233 .76352 .43256 .78593 .43092 .78235 .42164 Mtetra
.59 .786 .974 r
.78235 .42164 .78593 .43092 .80842 .42924 .805 .41995 Mtetra
.59 .787 .974 r
.805 .41995 .80842 .42924 .83099 .42753 .82773 .41822 Mtetra
.591 .787 .974 r
.82773 .41822 .83099 .42753 .85364 .42579 .85055 .41646 Mtetra
.591 .788 .974 r
.85055 .41646 .85364 .42579 .87638 .42402 .87345 .41467 Mtetra
.592 .788 .974 r
.87345 .41467 .87638 .42402 .8992 .42222 .89644 .41284 Mtetra
.592 .789 .974 r
.89644 .41284 .8992 .42222 .92211 .42039 .91951 .41099 Mtetra
.91951 .41099 .92211 .42039 .94509 .41854 .94266 .40912 Mtetra
.592 .79 .974 r
.94266 .40912 .94509 .41854 .96817 .41666 .9659 .40721 Mtetra
.586 .606 .838 r
.217 .408 .22373 .42855 .24416 .42794 .23728 .4118 Mtetra
.54 .626 .886 r
.23728 .4118 .24416 .42794 .26452 .4302 .25763 .41639 Mtetra
.525 .651 .915 r
.25763 .41639 .26452 .4302 .28498 .43279 .27813 .42036 Mtetra
.525 .676 .933 r
.27813 .42036 .28498 .43279 .30555 .43506 .29878 .42351 Mtetra
.53 .696 .944 r
.29878 .42351 .30555 .43506 .32624 .43685 .31957 .42589 Mtetra
.538 .712 .952 r
.31957 .42589 .32624 .43685 .34704 .43817 .34048 .42763 Mtetra
.545 .725 .957 r
.34048 .42763 .34704 .43817 .36795 .43907 .36152 .42883 Mtetra
.551 .735 .961 r
.36152 .42883 .36795 .43907 .38897 .4396 .38266 .42959 Mtetra
.557 .743 .964 r
.38266 .42959 .38897 .4396 .41008 .43983 .4039 .42998 Mtetra
.561 .75 .966 r
.4039 .42998 .41008 .43983 .43129 .43979 .42524 .43007 Mtetra
.565 .755 .967 r
.42524 .43007 .43129 .43979 .45259 .43953 .44668 .42991 Mtetra
.569 .76 .968 r
.44668 .42991 .45259 .43953 .47398 .43907 .46821 .42953 Mtetra
.572 .764 .969 r
.46821 .42953 .47398 .43907 .49546 .43845 .48983 .42896 Mtetra
.575 .767 .97 r
.48983 .42896 .49546 .43845 .51703 .43768 .51154 .42824 Mtetra
.577 .77 .971 r
.51154 .42824 .51703 .43768 .53868 .43679 .53334 .42738 Mtetra
.579 .772 .971 r
.53334 .42738 .53868 .43679 .56041 .43578 .55522 .42639 Mtetra
.58 .775 .971 r
.55522 .42639 .56041 .43578 .58223 .43467 .57719 .42531 Mtetra
.582 .776 .972 r
.57719 .42531 .58223 .43467 .60413 .43348 .59924 .42412 Mtetra
.583 .778 .972 r
.59924 .42412 .60413 .43348 .62612 .43221 .62138 .42285 Mtetra
.584 .779 .972 r
.62138 .42285 .62612 .43221 .64819 .43087 .64361 .42151 Mtetra
.585 .781 .973 r
.64361 .42151 .64819 .43087 .67034 .42946 .66591 .4201 Mtetra
.586 .782 .973 r
.66591 .4201 .67034 .42946 .69258 .42799 .6883 .41863 Mtetra
.587 .783 .973 r
.6883 .41863 .69258 .42799 .71489 .42648 .71078 .4171 Mtetra
.588 .784 .973 r
.71078 .4171 .71489 .42648 .73729 .42491 .73334 .41552 Mtetra
.589 .785 .973 r
.73334 .41552 .73729 .42491 .75978 .4233 .75598 .4139 Mtetra
.75598 .4139 .75978 .4233 .78235 .42164 .77871 .41223 Mtetra
.59 .786 .974 r
.77871 .41223 .78235 .42164 .805 .41995 .80152 .41052 Mtetra
.59 .787 .974 r
.80152 .41052 .805 .41995 .82773 .41822 .82442 .40877 Mtetra
.591 .787 .974 r
.82442 .40877 .82773 .41822 .85055 .41646 .84741 .40699 Mtetra
.591 .788 .974 r
.84741 .40699 .85055 .41646 .87345 .41467 .87047 .40517 Mtetra
.87047 .40517 .87345 .41467 .89644 .41284 .89363 .40333 Mtetra
.592 .789 .974 r
.89363 .40333 .89644 .41284 .91951 .41099 .91687 .40145 Mtetra
.91687 .40145 .91951 .41099 .94266 .40912 .9402 .39955 Mtetra
.9402 .39955 .94266 .40912 .9659 .40721 .96361 .39762 Mtetra
.511 .558 .84 r
.2102 .38723 .217 .408 .23728 .4118 .23033 .39546 Mtetra
.487 .593 .886 r
.23033 .39546 .23728 .4118 .25763 .41639 .25066 .4024 Mtetra
.489 .63 .915 r
.25066 .4024 .25763 .41639 .27813 .42036 .2712 .40776 Mtetra
.501 .662 .933 r
.2712 .40776 .27813 .42036 .29878 .42351 .29193 .4118 Mtetra
.514 .686 .945 r
.29193 .4118 .29878 .42351 .31957 .42589 .31281 .41478 Mtetra
.526 .705 .953 r
.31281 .41478 .31957 .42589 .34048 .42763 .33384 .41694 Mtetra
.536 .72 .958 r
.33384 .41694 .34048 .42763 .36152 .42883 .35499 .41845 Mtetra
.544 .731 .961 r
.35499 .41845 .36152 .42883 .38266 .42959 .37626 .41943 Mtetra
.551 .74 .964 r
.37626 .41943 .38266 .42959 .4039 .42998 .39763 .42 Mtetra
.557 .748 .966 r
.39763 .42 .4039 .42998 .42524 .43007 .41911 .42022 Mtetra
.562 .754 .967 r
.41911 .42022 .42524 .43007 .44668 .42991 .44069 .42015 Mtetra
.566 .759 .968 r
.44069 .42015 .44668 .42991 .46821 .42953 .46236 .41985 Mtetra
.57 .763 .969 r
.46236 .41985 .46821 .42953 .48983 .42896 .48412 .41934 Mtetra
.573 .766 .97 r
.48412 .41934 .48983 .42896 .51154 .42824 .50598 .41866 Mtetra
.575 .769 .971 r
.50598 .41866 .51154 .42824 .53334 .42738 .52792 .41783 Mtetra
.578 .772 .971 r
.52792 .41783 .53334 .42738 .55522 .42639 .54996 .41687 Mtetra
.579 .774 .972 r
.54996 .41687 .55522 .42639 .57719 .42531 .57208 .4158 Mtetra
.581 .776 .972 r
.57208 .4158 .57719 .42531 .59924 .42412 .59428 .41462 Mtetra
.583 .778 .972 r
.59428 .41462 .59924 .42412 .62138 .42285 .61657 .41336 Mtetra
.584 .779 .972 r
.61657 .41336 .62138 .42285 .64361 .42151 .63895 .41202 Mtetra
.585 .78 .973 r
.63895 .41202 .64361 .42151 .66591 .4201 .66142 .41061 Mtetra
.586 .782 .973 r
.66142 .41061 .66591 .4201 .6883 .41863 .68397 .40913 Mtetra
.587 .783 .973 r
.68397 .40913 .6883 .41863 .71078 .4171 .7066 .40759 Mtetra
.588 .784 .973 r
.7066 .40759 .71078 .4171 .73334 .41552 .72932 .406 Mtetra
.72932 .406 .73334 .41552 .75598 .4139 .75213 .40436 Mtetra
.589 .785 .974 r
.75213 .40436 .75598 .4139 .77871 .41223 .77502 .40267 Mtetra
.589 .786 .974 r
.77502 .40267 .77871 .41223 .80152 .41052 .798 .40094 Mtetra
.59 .787 .974 r
.798 .40094 .80152 .41052 .82442 .40877 .82106 .39918 Mtetra
.82106 .39918 .82442 .40877 .84741 .40699 .84422 .39737 Mtetra
.591 .788 .974 r
.84422 .39737 .84741 .40699 .87047 .40517 .86745 .39554 Mtetra
.86745 .39554 .87047 .40517 .89363 .40333 .89078 .39367 Mtetra
.592 .789 .974 r
.89078 .39367 .89363 .40333 .91687 .40145 .91419 .39177 Mtetra
.91419 .39177 .91687 .40145 .9402 .39955 .93769 .38984 Mtetra
.93769 .38984 .9402 .39955 .96361 .39762 .96128 .38789 Mtetra
.42 .498 .833 r
.20334 .36626 .2102 .38723 .23033 .39546 .22329 .37893 Mtetra
.427 .555 .882 r
.22329 .37893 .23033 .39546 .25066 .4024 .24359 .38823 Mtetra
.451 .607 .913 r
.24359 .38823 .25066 .4024 .2712 .40776 .26418 .395 Mtetra
.475 .646 .933 r
.26418 .395 .2712 .40776 .29193 .4118 .28498 .39993 Mtetra
.496 .676 .945 r
.28498 .39993 .29193 .4118 .31281 .41478 .30596 .40352 Mtetra
.513 .698 .953 r
.30596 .40352 .31281 .41478 .33384 .41694 .3271 .40611 Mtetra
.527 .715 .958 r
.3271 .40611 .33384 .41694 .35499 .41845 .34837 .40792 Mtetra
.538 .728 .962 r
.34837 .40792 .35499 .41845 .37626 .41943 .36977 .40913 Mtetra
.546 .738 .964 r
.36977 .40913 .37626 .41943 .39763 .42 .39128 .40987 Mtetra
.553 .746 .966 r
.39128 .40987 .39763 .42 .41911 .42022 .41289 .41022 Mtetra
.559 .752 .968 r
.41289 .41022 .41911 .42022 .44069 .42015 .43461 .41026 Mtetra
.564 .757 .969 r
.43461 .41026 .44069 .42015 .46236 .41985 .45642 .41003 Mtetra
.568 .762 .97 r
.45642 .41003 .46236 .41985 .48412 .41934 .47833 .40958 Mtetra
.571 .765 .97 r
.47833 .40958 .48412 .41934 .50598 .41866 .50034 .40894 Mtetra
.574 .768 .971 r
.50034 .40894 .50598 .41866 .52792 .41783 .52243 .40814 Mtetra
.576 .771 .971 r
.52243 .40814 .52792 .41783 .54996 .41687 .54461 .40721 Mtetra
.578 .773 .972 r
.54461 .40721 .54996 .41687 .57208 .4158 .56689 .40615 Mtetra
.58 .775 .972 r
.56689 .40615 .57208 .4158 .59428 .41462 .58925 .40499 Mtetra
.582 .777 .972 r
.58925 .40499 .59428 .41462 .61657 .41336 .6117 .40373 Mtetra
.583 .779 .973 r
.6117 .40373 .61657 .41336 .63895 .41202 .63423 .40238 Mtetra
.584 .78 .973 r
.63423 .40238 .63895 .41202 .66142 .41061 .65685 .40097 Mtetra
.585 .781 .973 r
.65685 .40097 .66142 .41061 .68397 .40913 .67956 .39948 Mtetra
.586 .782 .973 r
.67956 .39948 .68397 .40913 .7066 .40759 .70236 .39793 Mtetra
.587 .783 .973 r
.70236 .39793 .7066 .40759 .72932 .406 .72525 .39633 Mtetra
.588 .784 .973 r
.72525 .39633 .72932 .406 .75213 .40436 .74822 .39467 Mtetra
.589 .785 .974 r
.74822 .39467 .75213 .40436 .77502 .40267 .77128 .39297 Mtetra
.589 .786 .974 r
.77128 .39297 .77502 .40267 .798 .40094 .79442 .39122 Mtetra
.59 .786 .974 r
.79442 .39122 .798 .40094 .82106 .39918 .81766 .38944 Mtetra
.59 .787 .974 r
.81766 .38944 .82106 .39918 .84422 .39737 .84098 .38761 Mtetra
.591 .787 .974 r
.84098 .38761 .84422 .39737 .86745 .39554 .86439 .38575 Mtetra
.591 .788 .974 r
.86439 .38575 .86745 .39554 .89078 .39367 .88788 .38386 Mtetra
.88788 .38386 .89078 .39367 .91419 .39177 .91147 .38194 Mtetra
.592 .789 .974 r
.91147 .38194 .91419 .39177 .93769 .38984 .93515 .37998 Mtetra
.93515 .37998 .93769 .38984 .96128 .38789 .95891 .378 Mtetra
.311 .423 .815 r
.1964 .34506 .20334 .36626 .22329 .37893 .21617 .36221 Mtetra
.36 .512 .873 r
.21617 .36221 .22329 .37893 .24359 .38823 .23644 .37389 Mtetra
.409 .581 .91 r
.23644 .37389 .24359 .38823 .26418 .395 .25706 .38207 Mtetra
.448 .63 .932 r
.25706 .38207 .26418 .395 .28498 .39993 .27794 .38791 Mtetra
.478 .665 .945 r
.27794 .38791 .28498 .39993 .30596 .40352 .29902 .39211 Mtetra
.501 .691 .953 r
.29902 .39211 .30596 .40352 .3271 .40611 .32027 .39512 Mtetra
.518 .71 .958 r
.32027 .39512 .3271 .40611 .34837 .40792 .34166 .39724 Mtetra
.531 .724 .962 r
.34166 .39724 .34837 .40792 .36977 .40913 .36318 .39869 Mtetra
.541 .735 .965 r
.36318 .39869 .36977 .40913 .39128 .40987 .38483 .3996 Mtetra
.549 .743 .966 r
.38483 .3996 .39128 .40987 .41289 .41022 .40658 .40008 Mtetra
.556 .75 .968 r
.40658 .40008 .41289 .41022 .43461 .41026 .42844 .40021 Mtetra
.561 .756 .969 r
.42844 .40021 .43461 .41026 .45642 .41003 .4504 .40006 Mtetra
.566 .76 .97 r
.4504 .40006 .45642 .41003 .47833 .40958 .47246 .39967 Mtetra
.569 .764 .97 r
.47246 .39967 .47833 .40958 .50034 .40894 .49461 .39908 Mtetra
.572 .768 .971 r
.49461 .39908 .50034 .40894 .52243 .40814 .51685 .39831 Mtetra
.575 .77 .971 r
.51685 .39831 .52243 .40814 .54461 .40721 .53919 .3974 Mtetra
.577 .773 .972 r
.53919 .3974 .54461 .40721 .56689 .40615 .56162 .39636 Mtetra
.579 .775 .972 r
.56162 .39636 .56689 .40615 .58925 .40499 .58414 .3952 Mtetra
.581 .777 .972 r
.58414 .3952 .58925 .40499 .6117 .40373 .60674 .39395 Mtetra
.582 .778 .973 r
.60674 .39395 .6117 .40373 .63423 .40238 .62944 .39261 Mtetra
.584 .78 .973 r
.62944 .39261 .63423 .40238 .65685 .40097 .65222 .39118 Mtetra
.585 .781 .973 r
.65222 .39118 .65685 .40097 .67956 .39948 .6751 .38969 Mtetra
.586 .782 .973 r
.6751 .38969 .67956 .39948 .70236 .39793 .69806 .38813 Mtetra
.587 .783 .973 r
.69806 .38813 .70236 .39793 .72525 .39633 .72111 .38651 Mtetra
.588 .784 .973 r
.72111 .38651 .72525 .39633 .74822 .39467 .74425 .38484 Mtetra
.588 .785 .974 r
.74425 .38484 .74822 .39467 .77128 .39297 .76747 .38312 Mtetra
.589 .785 .974 r
.76747 .38312 .77128 .39297 .79442 .39122 .79079 .38136 Mtetra
.589 .786 .974 r
.79079 .38136 .79442 .39122 .81766 .38944 .81419 .37955 Mtetra
.59 .787 .974 r
.81419 .37955 .81766 .38944 .84098 .38761 .83769 .3777 Mtetra
.83769 .3777 .84098 .38761 .86439 .38575 .86127 .37582 Mtetra
.591 .788 .974 r
.86127 .37582 .86439 .38575 .88788 .38386 .88495 .3739 Mtetra
.88495 .3739 .88788 .38386 .91147 .38194 .90871 .37195 Mtetra
.592 .789 .974 r
.90871 .37195 .91147 .38194 .93515 .37998 .93256 .36997 Mtetra
.93256 .36997 .93515 .37998 .95891 .378 .95651 .36796 Mtetra
.185 .333 .781 r
.18939 .32365 .1964 .34506 .21617 .36221 .20896 .34528 Mtetra
.286 .462 .859 r
.20896 .34528 .21617 .36221 .23644 .37389 .22919 .35936 Mtetra
.364 .552 .904 r
.22919 .35936 .23644 .37389 .25706 .38207 .24984 .36896 Mtetra
.42 .613 .93 r
.24984 .36896 .25706 .38207 .27794 .38791 .2708 .37571 Mtetra
.459 .654 .944 r
.2708 .37571 .27794 .38791 .29902 .39211 .29197 .38053 Mtetra
.488 .683 .953 r
.29197 .38053 .29902 .39211 .32027 .39512 .31333 .38398 Mtetra
.508 .704 .959 r
.31333 .38398 .32027 .39512 .34166 .39724 .33485 .38642 Mtetra
.524 .72 .962 r
.33485 .38642 .34166 .39724 .36318 .39869 .35651 .38809 Mtetra
.536 .732 .965 r
.35651 .38809 .36318 .39869 .38483 .3996 .37828 .38917 Mtetra
.545 .741 .967 r
.37828 .38917 .38483 .3996 .40658 .40008 .40018 .38979 Mtetra
.553 .748 .968 r
.40018 .38979 .40658 .40008 .42844 .40021 .42218 .39002 Mtetra
.559 .754 .969 r
.42218 .39002 .42844 .40021 .4504 .40006 .44429 .38995 Mtetra
.563 .759 .97 r
.44429 .38995 .4504 .40006 .47246 .39967 .46649 .38962 Mtetra
.568 .763 .971 r
.46649 .38962 .47246 .39967 .49461 .39908 .48879 .38907 Mtetra
.571 .767 .971 r
.48879 .38907 .49461 .39908 .51685 .39831 .51119 .38834 Mtetra
.574 .77 .971 r
.51119 .38834 .51685 .39831 .53919 .3974 .53369 .38745 Mtetra
.576 .772 .972 r
.53369 .38745 .53919 .3974 .56162 .39636 .55627 .38642 Mtetra
.578 .774 .972 r
.55627 .38642 .56162 .39636 .58414 .3952 .57895 .38527 Mtetra
.58 .776 .972 r
.57895 .38527 .58414 .3952 .60674 .39395 .60172 .38402 Mtetra
.582 .778 .973 r
.60172 .38402 .60674 .39395 .62944 .39261 .62457 .38268 Mtetra
.583 .779 .973 r
.62457 .38268 .62944 .39261 .65222 .39118 .64752 .38125 Mtetra
.584 .781 .973 r
.64752 .38125 .65222 .39118 .6751 .38969 .67056 .37975 Mtetra
.585 .782 .973 r
.67056 .37975 .6751 .38969 .69806 .38813 .69369 .37818 Mtetra
.586 .783 .973 r
.69369 .37818 .69806 .38813 .72111 .38651 .71691 .37655 Mtetra
.587 .784 .973 r
.71691 .37655 .72111 .38651 .74425 .38484 .74021 .37486 Mtetra
.588 .785 .974 r
.74021 .37486 .74425 .38484 .76747 .38312 .76361 .37312 Mtetra
.589 .785 .974 r
.76361 .37312 .76747 .38312 .79079 .38136 .7871 .37134 Mtetra
.589 .786 .974 r
.7871 .37134 .79079 .38136 .81419 .37955 .81068 .36951 Mtetra
.59 .787 .974 r
.81068 .36951 .81419 .37955 .83769 .3777 .83435 .36764 Mtetra
.83435 .36764 .83769 .3777 .86127 .37582 .85811 .36573 Mtetra
.591 .788 .974 r
.85811 .36573 .86127 .37582 .88495 .3739 .88196 .36379 Mtetra
.88196 .36379 .88495 .3739 .90871 .37195 .90591 .36181 Mtetra
.591 .789 .974 r
.90591 .36181 .90871 .37195 .93256 .36997 .92994 .3598 Mtetra
.592 .789 .974 r
.92994 .3598 .93256 .36997 .95651 .36796 .95407 .35776 Mtetra
.045 .23 .729 r
.18231 .30201 .18939 .32365 .20896 .34528 .20167 .32815 Mtetra
.206 .405 .838 r
.20167 .32815 .20896 .34528 .22919 .35936 .22185 .34464 Mtetra
.317 .521 .896 r
.22185 .34464 .22919 .35936 .24984 .36896 .24253 .35568 Mtetra
.39 .594 .926 r
.24253 .35568 .24984 .36896 .2708 .37571 .26356 .36335 Mtetra
.44 .643 .943 r
.26356 .36335 .2708 .37571 .29197 .38053 .28483 .36879 Mtetra
.474 .675 .953 r
.28483 .36879 .29197 .38053 .31333 .38398 .30631 .37268 Mtetra
.499 .699 .959 r
.30631 .37268 .31333 .38398 .33485 .38642 .32795 .37543 Mtetra
.517 .716 .963 r
.32795 .37543 .33485 .38642 .35651 .38809 .34973 .37734 Mtetra
.53 .729 .965 r
.34973 .37734 .35651 .38809 .37828 .38917 .37165 .3786 Mtetra
.541 .739 .967 r
.37165 .3786 .37828 .38917 .40018 .38979 .39368 .37935 Mtetra
.549 .747 .968 r
.39368 .37935 .40018 .38979 .42218 .39002 .41583 .37968 Mtetra
.556 .753 .969 r
.41583 .37968 .42218 .39002 .44429 .38995 .43808 .37969 Mtetra
.561 .758 .97 r
.43808 .37969 .44429 .38995 .46649 .38962 .46044 .37941 Mtetra
.566 .762 .971 r
.46044 .37941 .46649 .38962 .48879 .38907 .48289 .37891 Mtetra
.569 .766 .971 r
.48289 .37891 .48879 .38907 .51119 .38834 .50545 .37821 Mtetra
.573 .769 .972 r
.50545 .37821 .51119 .38834 .53369 .38745 .5281 .37734 Mtetra
.575 .772 .972 r
.5281 .37734 .53369 .38745 .55627 .38642 .55084 .37633 Mtetra
.577 .774 .972 r
.55084 .37633 .55627 .38642 .57895 .38527 .57368 .37519 Mtetra
.579 .776 .972 r
.57368 .37519 .57895 .38527 .60172 .38402 .59661 .37395 Mtetra
.581 .777 .973 r
.59661 .37395 .60172 .38402 .62457 .38268 .61963 .3726 Mtetra
.582 .779 .973 r
.61963 .3726 .62457 .38268 .64752 .38125 .64275 .37117 Mtetra
.584 .78 .973 r
.64275 .37117 .64752 .38125 .67056 .37975 .66595 .36965 Mtetra
.585 .781 .973 r
.66595 .36965 .67056 .37975 .69369 .37818 .68925 .36807 Mtetra
.586 .783 .973 r
.68925 .36807 .69369 .37818 .71691 .37655 .71264 .36643 Mtetra
.587 .783 .973 r
.71264 .36643 .71691 .37655 .74021 .37486 .73612 .36472 Mtetra
.588 .784 .974 r
.73612 .36472 .74021 .37486 .76361 .37312 .75969 .36297 Mtetra
.588 .785 .974 r
.75969 .36297 .76361 .37312 .7871 .37134 .78336 .36116 Mtetra
.589 .786 .974 r
.78336 .36116 .7871 .37134 .81068 .36951 .80711 .35931 Mtetra
.80711 .35931 .81068 .36951 .83435 .36764 .83096 .35741 Mtetra
.59 .787 .974 r
.83096 .35741 .83435 .36764 .85811 .36573 .8549 .35548 Mtetra
.59 .788 .974 r
.8549 .35548 .85811 .36573 .88196 .36379 .87893 .35351 Mtetra
.591 .788 .974 r
.87893 .35351 .88196 .36379 .90591 .36181 .90306 .35151 Mtetra
.591 .789 .974 r
.90306 .35151 .90591 .36181 .92994 .3598 .92728 .34947 Mtetra
.592 .789 .974 r
.92728 .34947 .92994 .3598 .95407 .35776 .95159 .34741 Mtetra
0 .13 .648 r
.17437 .29213 .18231 .30201 .20167 .32815 .19429 .31082 Mtetra
.12 .344 .809 r
.19429 .31082 .20167 .32815 .22185 .34464 .21442 .32973 Mtetra
.267 .487 .885 r
.21442 .32973 .22185 .34464 .24253 .35568 .23513 .34222 Mtetra
.36 .575 .922 r
.23513 .34222 .24253 .35568 .26356 .36335 .25622 .35082 Mtetra
.42 .63 .941 r
.25622 .35082 .26356 .36335 .28483 .36879 .27759 .35689 Mtetra
.46 .667 .952 r
.27759 .35689 .28483 .36879 .30631 .37268 .29918 .36121 Mtetra
.489 .693 .959 r
.29918 .36121 .30631 .37268 .32795 .37543 .32094 .36428 Mtetra
.51 .712 .963 r
.32094 .36428 .32795 .37543 .34973 .37734 .34286 .36643 Mtetra
.525 .726 .965 r
.34286 .36643 .34973 .37734 .37165 .3786 .36491 .36787 Mtetra
.537 .736 .967 r
.36491 .36787 .37165 .3786 .39368 .37935 .38709 .36875 Mtetra
.546 .745 .968 r
.38709 .36875 .39368 .37935 .41583 .37968 .40938 .36919 Mtetra
.553 .751 .969 r
.40938 .36919 .41583 .37968 .43808 .37969 .43178 .36927 Mtetra
.559 .757 .97 r
.43178 .36927 .43808 .37969 .46044 .37941 .45429 .36906 Mtetra
.564 .761 .971 r
.45429 .36906 .46044 .37941 .48289 .37891 .47691 .3686 Mtetra
.568 .765 .971 r
.47691 .3686 .48289 .37891 .50545 .37821 .49962 .36793 Mtetra
.571 .768 .972 r
.49962 .36793 .50545 .37821 .5281 .37734 .52243 .36709 Mtetra
.574 .771 .972 r
.52243 .36709 .5281 .37734 .55084 .37633 .54533 .36609 Mtetra
.577 .773 .972 r
.54533 .36609 .55084 .37633 .57368 .37519 .56833 .36496 Mtetra
.579 .775 .973 r
.56833 .36496 .57368 .37519 .59661 .37395 .59143 .36371 Mtetra
.58 .777 .973 r
.59143 .36371 .59661 .37395 .61963 .3726 .61462 .36237 Mtetra
.582 .779 .973 r
.61462 .36237 .61963 .3726 .64275 .37117 .6379 .36093 Mtetra
.583 .78 .973 r
.6379 .36093 .64275 .37117 .66595 .36965 .66128 .3594 Mtetra
.584 .781 .973 r
.66128 .3594 .66595 .36965 .68925 .36807 .68475 .35781 Mtetra
.585 .782 .973 r
.68475 .35781 .68925 .36807 .71264 .36643 .70831 .35615 Mtetra
.586 .783 .974 r
.70831 .35615 .71264 .36643 .73612 .36472 .73196 .35443 Mtetra
.587 .784 .974 r
.73196 .35443 .73612 .36472 .75969 .36297 .75571 .35265 Mtetra
.588 .785 .974 r
.75571 .35265 .75969 .36297 .78336 .36116 .77955 .35082 Mtetra
.589 .786 .974 r
.77955 .35082 .78336 .36116 .80711 .35931 .80349 .34895 Mtetra
.80349 .34895 .80711 .35931 .83096 .35741 .82751 .34703 Mtetra
.59 .787 .974 r
.82751 .34703 .83096 .35741 .8549 .35548 .85164 .34507 Mtetra
.85164 .34507 .8549 .35548 .87893 .35351 .87585 .34308 Mtetra
.591 .788 .974 r
.87585 .34308 .87893 .35351 .90306 .35151 .90016 .34105 Mtetra
.90016 .34105 .90306 .35151 .92728 .34947 .92457 .33898 Mtetra
.591 .789 .974 r
.92457 .33898 .92728 .34947 .95159 .34741 .94907 .33689 Mtetra
.072 .455 .883 r
.16632 .28211 .17437 .29213 .19429 .31082 .18681 .29327 Mtetra
.031 .277 .774 r
.18681 .29327 .19429 .31082 .21442 .32973 .20688 .31462 Mtetra
.214 .45 .871 r
.20688 .31462 .21442 .32973 .23513 .34222 .22762 .32857 Mtetra
.327 .554 .916 r
.22762 .32857 .23513 .34222 .25622 .35082 .24878 .33811 Mtetra
.399 .617 .939 r
.24878 .33811 .25622 .35082 .27759 .35689 .27024 .34481 Mtetra
.446 .659 .951 r
.27024 .34481 .27759 .35689 .29918 .36121 .29194 .34958 Mtetra
.479 .687 .958 r
.29194 .34958 .29918 .36121 .32094 .36428 .31383 .35298 Mtetra
.502 .708 .963 r
.31383 .35298 .32094 .36428 .34286 .36643 .33588 .35536 Mtetra
.52 .723 .965 r
.33588 .35536 .34286 .36643 .36491 .36787 .35807 .35697 Mtetra
.533 .734 .967 r
.35807 .35697 .36491 .36787 .38709 .36875 .38039 .35799 Mtetra
.543 .743 .969 r
.38039 .35799 .38709 .36875 .40938 .36919 .40284 .35854 Mtetra
.551 .75 .97 r
.40284 .35854 .40938 .36919 .43178 .36927 .42539 .3587 Mtetra
.557 .756 .97 r
.42539 .3587 .43178 .36927 .45429 .36906 .44806 .35854 Mtetra
.562 .76 .971 r
.44806 .35854 .45429 .36906 .47691 .3686 .47083 .35813 Mtetra
.566 .764 .971 r
.47083 .35813 .47691 .3686 .49962 .36793 .4937 .35749 Mtetra
.57 .768 .972 r
.4937 .35749 .49962 .36793 .52243 .36709 .51667 .35667 Mtetra
.573 .77 .972 r
.51667 .35667 .52243 .36709 .54533 .36609 .53974 .35569 Mtetra
.576 .773 .972 r
.53974 .35569 .54533 .36609 .56833 .36496 .5629 .35457 Mtetra
.578 .775 .973 r
.5629 .35457 .56833 .36496 .59143 .36371 .58617 .35332 Mtetra
.58 .777 .973 r
.58617 .35332 .59143 .36371 .61462 .36237 .60952 .35197 Mtetra
.581 .778 .973 r
.60952 .35197 .61462 .36237 .6379 .36093 .63298 .35053 Mtetra
.583 .78 .973 r
.63298 .35053 .6379 .36093 .66128 .3594 .65653 .349 Mtetra
.584 .781 .973 r
.65653 .349 .66128 .3594 .68475 .35781 .68017 .34739 Mtetra
.585 .782 .973 r
.68017 .34739 .68475 .35781 .70831 .35615 .70391 .34571 Mtetra
.586 .783 .974 r
.70391 .34571 .70831 .35615 .73196 .35443 .72774 .34397 Mtetra
.587 .784 .974 r
.72774 .34397 .73196 .35443 .75571 .35265 .75167 .34218 Mtetra
.588 .785 .974 r
.75167 .34218 .75571 .35265 .77955 .35082 .77569 .34033 Mtetra
.77569 .34033 .77955 .35082 .80349 .34895 .7998 .33843 Mtetra
.589 .786 .974 r
.7998 .33843 .80349 .34895 .82751 .34703 .82402 .33649 Mtetra
.59 .787 .974 r
.82402 .33649 .82751 .34703 .85164 .34507 .84832 .3345 Mtetra
.84832 .3345 .85164 .34507 .87585 .34308 .87273 .33248 Mtetra
.59 .788 .974 r
.87273 .33248 .87585 .34308 .90016 .34105 .89722 .33042 Mtetra
.591 .788 .974 r
.89722 .33042 .90016 .34105 .92457 .33898 .92182 .32832 Mtetra
.591 .789 .974 r
.92182 .32832 .92457 .33898 .94907 .33689 .94651 .3262 Mtetra
.428 .69 .973 r
.15814 .27193 .16632 .28211 .18681 .29327 .17925 .27551 Mtetra
0 .207 .731 r
.17925 .27551 .18681 .29327 .20688 .31462 .19925 .29932 Mtetra
.159 .411 .853 r
.19925 .29932 .20688 .31462 .22762 .32857 .22 .31474 Mtetra
.294 .531 .91 r
.22 .31474 .22762 .32857 .24878 .33811 .24123 .32522 Mtetra
.378 .604 .937 r
.24123 .32522 .24878 .33811 .27024 .34481 .26279 .33256 Mtetra
.432 .65 .95 r
.26279 .33256 .27024 .34481 .29194 .34958 .2846 .33778 Mtetra
.469 .681 .958 r
.2846 .33778 .29194 .34958 .31383 .35298 .30662 .3415 Mtetra
.495 .703 .963 r
.30662 .3415 .31383 .35298 .33588 .35536 .3288 .34413 Mtetra
.514 .719 .966 r
.3288 .34413 .33588 .35536 .35807 .35697 .35113 .34592 Mtetra
.528 .732 .967 r
.35113 .34592 .35807 .35697 .38039 .35799 .3736 .34707 Mtetra
.539 .741 .969 r
.3736 .34707 .38039 .35799 .40284 .35854 .39619 .34772 Mtetra
.548 .748 .97 r
.39619 .34772 .40284 .35854 .42539 .3587 .4189 .34796 Mtetra
.555 .754 .97 r
.4189 .34796 .42539 .3587 .44806 .35854 .44172 .34787 Mtetra
.56 .759 .971 r
.44172 .34787 .44806 .35854 .47083 .35813 .46465 .3475 Mtetra
.565 .763 .971 r
.46465 .3475 .47083 .35813 .4937 .35749 .48768 .34689 Mtetra
.569 .767 .972 r
.48768 .34689 .4937 .35749 .51667 .35667 .51082 .3461 Mtetra
.572 .77 .972 r
.51082 .3461 .51667 .35667 .53974 .35569 .53405 .34513 Mtetra
.575 .772 .972 r
.53405 .34513 .53974 .35569 .5629 .35457 .55739 .34401 Mtetra
.577 .774 .973 r
.55739 .34401 .5629 .35457 .58617 .35332 .58082 .34277 Mtetra
.579 .776 .973 r
.58082 .34277 .58617 .35332 .60952 .35197 .60435 .34142 Mtetra
.581 .778 .973 r
.60435 .34142 .60952 .35197 .63298 .35053 .62798 .33996 Mtetra
.582 .779 .973 r
.62798 .33996 .63298 .35053 .65653 .349 .6517 .33842 Mtetra
.583 .781 .973 r
.6517 .33842 .65653 .349 .68017 .34739 .67552 .3368 Mtetra
.585 .782 .973 r
.67552 .3368 .68017 .34739 .70391 .34571 .69944 .33511 Mtetra
.586 .783 .974 r
.69944 .33511 .70391 .34571 .72774 .34397 .72345 .33335 Mtetra
.587 .784 .974 r
.72345 .33335 .72774 .34397 .75167 .34218 .74756 .33153 Mtetra
.587 .785 .974 r
.74756 .33153 .75167 .34218 .77569 .34033 .77176 .32966 Mtetra
.588 .785 .974 r
.77176 .32966 .77569 .34033 .7998 .33843 .79606 .32774 Mtetra
.589 .786 .974 r
.79606 .32774 .7998 .33843 .82402 .33649 .82046 .32577 Mtetra
.589 .787 .974 r
.82046 .32577 .82402 .33649 .84832 .3345 .84496 .32376 Mtetra
.59 .787 .974 r
.84496 .32376 .84832 .3345 .87273 .33248 .86955 .32171 Mtetra
.59 .788 .974 r
.86955 .32171 .87273 .33248 .89722 .33042 .89424 .31962 Mtetra
.591 .788 .974 r
.89424 .31962 .89722 .33042 .92182 .32832 .91903 .31749 Mtetra
.591 .789 .974 r
.91903 .31749 .92182 .32832 .94651 .3262 .94391 .31533 Mtetra
.617 .786 .963 r
.14985 .2616 .15814 .27193 .17925 .27551 .17149 .2591 Mtetra
0 .139 .685 r
.17149 .2591 .17925 .27551 .19925 .29932 .19152 .28381 Mtetra
.102 .369 .833 r
.19152 .28381 .19925 .29932 .22 .31474 .21228 .30071 Mtetra
.259 .508 .901 r
.21228 .30071 .22 .31474 .24123 .32522 .23358 .31215 Mtetra
.356 .59 .933 r
.23358 .31215 .24123 .32522 .26279 .33256 .25523 .32013 Mtetra
.417 .641 .949 r
.25523 .32013 .26279 .33256 .2846 .33778 .27716 .32581 Mtetra
.459 .675 .958 r
.27716 .32581 .2846 .33778 .30662 .3415 .29929 .32986 Mtetra
.488 .699 .963 r
.29929 .32986 .30662 .3415 .3288 .34413 .32161 .33272 Mtetra
.508 .716 .966 r
.32161 .33272 .3288 .34413 .35113 .34592 .34409 .3347 Mtetra
.524 .729 .968 r
.34409 .3347 .35113 .34592 .3736 .34707 .3667 .33599 Mtetra
.536 .739 .969 r
.3667 .33599 .3736 .34707 .39619 .34772 .38945 .33674 Mtetra
.545 .747 .97 r
.38945 .33674 .39619 .34772 .4189 .34796 .41231 .33706 Mtetra
.553 .753 .971 r
.41231 .33706 .4189 .34796 .44172 .34787 .43529 .33703 Mtetra
.559 .758 .971 r
.43529 .33703 .44172 .34787 .46465 .3475 .45838 .3367 Mtetra
.563 .763 .972 r
.45838 .3367 .46465 .3475 .48768 .34689 .48158 .33613 Mtetra
.567 .766 .972 r
.48158 .33613 .48768 .34689 .51082 .3461 .50488 .33536 Mtetra
.571 .769 .972 r
.50488 .33536 .51082 .3461 .53405 .34513 .52828 .3344 Mtetra
.574 .772 .972 r
.52828 .3344 .53405 .34513 .55739 .34401 .55179 .33329 Mtetra
.576 .774 .973 r
.55179 .33329 .55739 .34401 .58082 .34277 .57539 .33205 Mtetra
.578 .776 .973 r
.57539 .33205 .58082 .34277 .60435 .34142 .5991 .3307 Mtetra
.58 .778 .973 r
.5991 .3307 .60435 .34142 .62798 .33996 .6229 .32924 Mtetra
.582 .779 .973 r
.6229 .32924 .62798 .33996 .6517 .33842 .6468 .32768 Mtetra
.583 .78 .973 r
.6468 .32768 .6517 .33842 .67552 .3368 .6708 .32605 Mtetra
.584 .782 .973 r
.6708 .32605 .67552 .3368 .69944 .33511 .6949 .32434 Mtetra
.585 .783 .974 r
.6949 .32434 .69944 .33511 .72345 .33335 .71909 .32256 Mtetra
.586 .784 .974 r
.71909 .32256 .72345 .33335 .74756 .33153 .74338 .32072 Mtetra
.587 .784 .974 r
.74338 .32072 .74756 .33153 .77176 .32966 .76777 .31882 Mtetra
.588 .785 .974 r
.76777 .31882 .77176 .32966 .79606 .32774 .79226 .31688 Mtetra
.588 .786 .974 r
.79226 .31688 .79606 .32774 .82046 .32577 .81685 .31488 Mtetra
.589 .786 .974 r
.81685 .31488 .82046 .32577 .84496 .32376 .84153 .31284 Mtetra
.59 .787 .974 r
.84153 .31284 .84496 .32376 .86955 .32171 .86632 .31076 Mtetra
.59 .788 .974 r
.86632 .31076 .86955 .32171 .89424 .31962 .8912 .30864 Mtetra
.591 .788 .974 r
.8912 .30864 .89424 .31962 .91903 .31749 .91619 .30648 Mtetra
.591 .789 .974 r
.91619 .30648 .91903 .31749 .94391 .31533 .94127 .30429 Mtetra
.617 .786 .963 r
.14142 .25112 .14985 .2616 .17149 .2591 .16322 .24858 Mtetra
0 .122 .643 r
.16322 .24858 .17149 .2591 .19152 .28381 .18368 .2681 Mtetra
.043 .326 .809 r
.18368 .2681 .19152 .28381 .21228 .30071 .20446 .28649 Mtetra
.223 .483 .892 r
.20446 .28649 .21228 .30071 .23358 .31215 .22581 .29889 Mtetra
.333 .575 .929 r
.22581 .29889 .23358 .31215 .25523 .32013 .24756 .30753 Mtetra
.402 .632 .948 r
.24756 .30753 .25523 .32013 .27716 .32581 .2696 .31366 Mtetra
.448 .669 .957 r
.2696 .31366 .27716 .32581 .29929 .32986 .29186 .31804 Mtetra
.48 .695 .962 r
.29186 .31804 .29929 .32986 .32161 .33272 .31432 .32115 Mtetra
.503 .713 .966 r
.31432 .32115 .32161 .33272 .34409 .3347 .33694 .32331 Mtetra
.52 .727 .968 r
.33694 .32331 .34409 .3347 .3667 .33599 .3597 .32474 Mtetra
.532 .737 .969 r
.3597 .32474 .3667 .33599 .38945 .33674 .3826 .32559 Mtetra
.542 .745 .97 r
.3826 .32559 .38945 .33674 .41231 .33706 .40562 .32599 Mtetra
.55 .752 .971 r
.40562 .32599 .41231 .33706 .43529 .33703 .42876 .32602 Mtetra
.557 .757 .971 r
.42876 .32602 .43529 .33703 .45838 .3367 .45202 .32574 Mtetra
.562 .762 .972 r
.45202 .32574 .45838 .3367 .48158 .33613 .47538 .3252 Mtetra
.566 .765 .972 r
.47538 .3252 .48158 .33613 .50488 .33536 .49885 .32445 Mtetra
.57 .768 .972 r
.49885 .32445 .50488 .33536 .52828 .3344 .52242 .32351 Mtetra
.573 .771 .973 r
.52242 .32351 .52828 .3344 .55179 .33329 .5461 .32241 Mtetra
.575 .773 .973 r
.5461 .32241 .55179 .33329 .57539 .33205 .56988 .32117 Mtetra
.578 .775 .973 r
.56988 .32117 .57539 .33205 .5991 .3307 .59376 .31981 Mtetra
.579 .777 .973 r
.59376 .31981 .5991 .3307 .6229 .32924 .61774 .31834 Mtetra
.581 .779 .973 r
.61774 .31834 .6229 .32924 .6468 .32768 .64182 .31677 Mtetra
.583 .78 .973 r
.64182 .31677 .6468 .32768 .6708 .32605 .666 .31512 Mtetra
.584 .781 .974 r
.666 .31512 .6708 .32605 .6949 .32434 .69028 .31339 Mtetra
.585 .782 .974 r
.69028 .31339 .6949 .32434 .71909 .32256 .71466 .3116 Mtetra
.586 .783 .974 r
.71466 .3116 .71909 .32256 .74338 .32072 .73914 .30973 Mtetra
.587 .784 .974 r
.73914 .30973 .74338 .32072 .76777 .31882 .76372 .30781 Mtetra
.588 .785 .974 r
.76372 .30781 .76777 .31882 .79226 .31688 .7884 .30584 Mtetra
.588 .786 .974 r
.7884 .30584 .79226 .31688 .81685 .31488 .81318 .30382 Mtetra
.589 .786 .974 r
.81318 .30382 .81685 .31488 .84153 .31284 .83806 .30175 Mtetra
.589 .787 .974 r
.83806 .30175 .84153 .31284 .86632 .31076 .86304 .29964 Mtetra
.59 .787 .974 r
.86304 .29964 .86632 .31076 .8912 .30864 .88812 .29749 Mtetra
.59 .788 .974 r
.88812 .29749 .8912 .30864 .91619 .30648 .9133 .2953 Mtetra
.591 .788 .974 r
.9133 .2953 .91619 .30648 .94127 .30429 .93859 .29307 Mtetra
.617 .786 .963 r
.13287 .24047 .14142 .25112 .16322 .24858 .15482 .2379 Mtetra
0 .343 .813 r
.15482 .2379 .16322 .24858 .18368 .2681 .17574 .25218 Mtetra
0 .281 .782 r
.17574 .25218 .18368 .2681 .20446 .28649 .19652 .27207 Mtetra
.187 .457 .881 r
.19652 .27207 .20446 .28649 .22581 .29889 .21794 .28544 Mtetra
.31 .56 .925 r
.21794 .28544 .22581 .29889 .24756 .30753 .23978 .29473 Mtetra
.387 .622 .946 r
.23978 .29473 .24756 .30753 .2696 .31366 .26193 .30132 Mtetra
.438 .663 .956 r
.26193 .30132 .2696 .31366 .29186 .31804 .28432 .30604 Mtetra
.472 .69 .962 r
.28432 .30604 .29186 .31804 .31432 .32115 .30691 .3094 Mtetra
.497 .71 .966 r
.30691 .3094 .31432 .32115 .33694 .32331 .32968 .31174 Mtetra
.515 .724 .968 r
.32968 .31174 .33694 .32331 .3597 .32474 .35259 .31331 Mtetra
.529 .735 .969 r
.35259 .31331 .3597 .32474 .3826 .32559 .37565 .31427 Mtetra
.54 .744 .97 r
.37565 .31427 .3826 .32559 .40562 .32599 .39883 .31475 Mtetra
.548 .751 .971 r
.39883 .31475 .40562 .32599 .42876 .32602 .42213 .31484 Mtetra
.555 .756 .971 r
.42213 .31484 .42876 .32602 .45202 .32574 .44555 .3146 Mtetra
.56 .761 .972 r
.44555 .3146 .45202 .32574 .47538 .3252 .46908 .3141 Mtetra
.565 .765 .972 r
.46908 .3141 .47538 .3252 .49885 .32445 .49272 .31337 Mtetra
.569 .768 .972 r
.49272 .31337 .49885 .32445 .52242 .32351 .51647 .31244 Mtetra
.572 .771 .973 r
.51647 .31244 .52242 .32351 .5461 .32241 .54032 .31134 Mtetra
.575 .773 .973 r
.54032 .31134 .5461 .32241 .56988 .32117 .56428 .31011 Mtetra
.577 .775 .973 r
.56428 .31011 .56988 .32117 .59376 .31981 .58834 .30874 Mtetra
.579 .777 .973 r
.58834 .30874 .59376 .31981 .61774 .31834 .6125 .30726 Mtetra
.581 .778 .973 r
.6125 .30726 .61774 .31834 .64182 .31677 .63676 .30568 Mtetra
.582 .78 .973 r
.63676 .30568 .64182 .31677 .666 .31512 .66113 .30402 Mtetra
.583 .781 .974 r
.66113 .30402 .666 .31512 .69028 .31339 .68559 .30227 Mtetra
.585 .782 .974 r
.68559 .30227 .69028 .31339 .71466 .3116 .71016 .30045 Mtetra
.586 .783 .974 r
.71016 .30045 .71466 .3116 .73914 .30973 .73483 .29857 Mtetra
.586 .784 .974 r
.73483 .29857 .73914 .30973 .76372 .30781 .7596 .29662 Mtetra
.587 .785 .974 r
.7596 .29662 .76372 .30781 .7884 .30584 .78447 .29462 Mtetra
.588 .786 .974 r
.78447 .29462 .7884 .30584 .81318 .30382 .80945 .29257 Mtetra
.589 .786 .974 r
.80945 .29257 .81318 .30382 .83806 .30175 .83452 .29047 Mtetra
.589 .787 .974 r
.83452 .29047 .83806 .30175 .86304 .29964 .8597 .28833 Mtetra
.59 .787 .974 r
.8597 .28833 .86304 .29964 .88812 .29749 .88498 .28615 Mtetra
.59 .788 .974 r
.88498 .28615 .88812 .29749 .9133 .2953 .91037 .28392 Mtetra
.591 .788 .974 r
.91037 .28392 .9133 .2953 .93859 .29307 .93586 .28166 Mtetra
.617 .786 .963 r
.12419 .22967 .13287 .24047 .15482 .2379 .14629 .22705 Mtetra
.199 .543 .928 r
.14629 .22705 .15482 .2379 .17574 .25218 .16769 .23604 Mtetra
0 .235 .753 r
.16769 .23604 .17574 .25218 .19652 .27207 .18847 .25745 Mtetra
.149 .43 .868 r
.18847 .25745 .19652 .27207 .21794 .28544 .20995 .27179 Mtetra
.286 .544 .92 r
.20995 .27179 .21794 .28544 .23978 .29473 .23188 .28175 Mtetra
.371 .612 .944 r
.23188 .28175 .23978 .29473 .26193 .30132 .25414 .28881 Mtetra
.427 .656 .955 r
.25414 .28881 .26193 .30132 .28432 .30604 .27666 .29386 Mtetra
.465 .685 .962 r
.27666 .29386 .28432 .30604 .30691 .3094 .2994 .29746 Mtetra
.491 .706 .966 r
.2994 .29746 .30691 .3094 .32968 .31174 .32231 .3 Mtetra
.511 .722 .968 r
.32231 .3 .32968 .31174 .35259 .31331 .34537 .30171 Mtetra
.526 .733 .969 r
.34537 .30171 .35259 .31331 .37565 .31427 .36858 .30278 Mtetra
.537 .742 .97 r
.36858 .30278 .37565 .31427 .39883 .31475 .39193 .30334 Mtetra
.546 .749 .971 r
.39193 .30334 .39883 .31475 .42213 .31484 .41539 .30348 Mtetra
.553 .755 .971 r
.41539 .30348 .42213 .31484 .44555 .3146 .43898 .30329 Mtetra
.559 .76 .972 r
.43898 .30329 .44555 .3146 .46908 .3141 .46268 .30282 Mtetra
.564 .764 .972 r
.46268 .30282 .46908 .3141 .49272 .31337 .4865 .30211 Mtetra
.568 .767 .972 r
.4865 .30211 .49272 .31337 .51647 .31244 .51042 .30119 Mtetra
.571 .77 .973 r
.51042 .30119 .51647 .31244 .54032 .31134 .53445 .30011 Mtetra
.574 .773 .973 r
.53445 .30011 .54032 .31134 .56428 .31011 .55858 .29887 Mtetra
.576 .775 .973 r
.55858 .29887 .56428 .31011 .58834 .30874 .58283 .2975 Mtetra
.578 .776 .973 r
.58283 .2975 .58834 .30874 .6125 .30726 .60717 .29601 Mtetra
.58 .778 .973 r
.60717 .29601 .6125 .30726 .63676 .30568 .63162 .29442 Mtetra
.582 .78 .973 r
.63162 .29442 .63676 .30568 .66113 .30402 .65617 .29274 Mtetra
.583 .781 .974 r
.65617 .29274 .66113 .30402 .68559 .30227 .68083 .29097 Mtetra
.584 .782 .974 r
.68083 .29097 .68559 .30227 .71016 .30045 .70559 .28913 Mtetra
.585 .783 .974 r
.70559 .28913 .71016 .30045 .73483 .29857 .73045 .28722 Mtetra
.586 .784 .974 r
.73045 .28722 .73483 .29857 .7596 .29662 .75541 .28525 Mtetra
.587 .785 .974 r
.75541 .28525 .7596 .29662 .78447 .29462 .78048 .28322 Mtetra
.588 .785 .974 r
.78048 .28322 .78447 .29462 .80945 .29257 .80566 .28114 Mtetra
.588 .786 .974 r
.80566 .28114 .80945 .29257 .83452 .29047 .83093 .27901 Mtetra
.589 .787 .974 r
.83093 .27901 .83452 .29047 .8597 .28833 .85631 .27684 Mtetra
.59 .787 .974 r
.85631 .27684 .8597 .28833 .88498 .28615 .8818 .27462 Mtetra
.59 .788 .974 r
.8818 .27462 .88498 .28615 .91037 .28392 .90738 .27236 Mtetra
.591 .788 .974 r
.90738 .27236 .91037 .28392 .93586 .28166 .93308 .27007 Mtetra
.617 .786 .963 r
.11538 .21869 .12419 .22967 .14629 .22705 .13763 .21604 Mtetra
.427 .688 .973 r
.13763 .21604 .14629 .22705 .16769 .23604 .15953 .21968 Mtetra
0 .188 .721 r
.15953 .21968 .16769 .23604 .18847 .25745 .18031 .24262 Mtetra
.11 .402 .854 r
.18031 .24262 .18847 .25745 .20995 .27179 .20184 .25795 Mtetra
.262 .527 .914 r
.20184 .25795 .20995 .27179 .23188 .28175 .22386 .26857 Mtetra
.355 .602 .941 r
.22386 .26857 .23188 .28175 .25414 .28881 .24624 .2761 Mtetra
.416 .649 .954 r
.24624 .2761 .25414 .28881 .27666 .29386 .26889 .28149 Mtetra
.457 .681 .961 r
.26889 .28149 .27666 .29386 .2994 .29746 .29176 .28535 Mtetra
.485 .703 .965 r
.29176 .28535 .2994 .29746 .32231 .3 .31482 .28807 Mtetra
.506 .719 .968 r
.31482 .28807 .32231 .3 .34537 .30171 .33804 .28992 Mtetra
.522 .731 .969 r
.33804 .28992 .34537 .30171 .36858 .30278 .36141 .2911 Mtetra
.534 .741 .97 r
.36141 .2911 .36858 .30278 .39193 .30334 .38492 .29174 Mtetra
.544 .748 .971 r
.38492 .29174 .39193 .30334 .41539 .30348 .40855 .29195 Mtetra
.551 .754 .972 r
.40855 .29195 .41539 .30348 .43898 .30329 .43231 .2918 Mtetra
.557 .759 .972 r
.43231 .2918 .43898 .30329 .46268 .30282 .45618 .29136 Mtetra
.562 .763 .972 r
.45618 .29136 .46268 .30282 .4865 .30211 .48017 .29067 Mtetra
.567 .767 .973 r
.48017 .29067 .4865 .30211 .51042 .30119 .50427 .28977 Mtetra
.57 .77 .973 r
.50427 .28977 .51042 .30119 .53445 .30011 .52848 .28869 Mtetra
.573 .772 .973 r
.52848 .28869 .53445 .30011 .55858 .29887 .5528 .28745 Mtetra
.576 .774 .973 r
.5528 .28745 .55858 .29887 .58283 .2975 .57723 .28607 Mtetra
.578 .776 .973 r
.57723 .28607 .58283 .2975 .60717 .29601 .60176 .28457 Mtetra
.58 .778 .973 r
.60176 .28457 .60717 .29601 .63162 .29442 .6264 .28297 Mtetra
.581 .779 .973 r
.6264 .28297 .63162 .29442 .65617 .29274 .65114 .28127 Mtetra
.583 .781 .974 r
.65114 .28127 .65617 .29274 .68083 .29097 .67599 .27948 Mtetra
.584 .782 .974 r
.67599 .27948 .68083 .29097 .70559 .28913 .70094 .27762 Mtetra
.585 .783 .974 r
.70094 .27762 .70559 .28913 .73045 .28722 .726 .27569 Mtetra
.586 .784 .974 r
.726 .27569 .73045 .28722 .75541 .28525 .75116 .27369 Mtetra
.587 .784 .974 r
.75116 .27369 .75541 .28525 .78048 .28322 .77643 .27163 Mtetra
.588 .785 .974 r
.77643 .27163 .78048 .28322 .80566 .28114 .8018 .26952 Mtetra
.588 .786 .974 r
.8018 .26952 .80566 .28114 .83093 .27901 .82728 .26736 Mtetra
.589 .787 .974 r
.82728 .26736 .83093 .27901 .85631 .27684 .85286 .26515 Mtetra
.85286 .26515 .85631 .27684 .8818 .27462 .87855 .2629 Mtetra
.59 .788 .974 r
.87855 .2629 .8818 .27462 .90738 .27236 .90435 .26061 Mtetra
.90435 .26061 .90738 .27236 .93308 .27007 .93026 .25828 Mtetra
.617 .786 .963 r
.10642 .20755 .11538 .21869 .13763 .21604 .12883 .20485 Mtetra
.593 .775 .967 r
.12883 .20485 .13763 .21604 .15953 .21968 .15126 .20309 Mtetra
0 .141 .686 r
.15126 .20309 .15953 .21968 .18031 .24262 .17203 .22758 Mtetra
.071 .373 .839 r
.17203 .22758 .18031 .24262 .20184 .25795 .19361 .2439 Mtetra
.237 .51 .907 r
.19361 .2439 .20184 .25795 .22386 .26857 .21572 .2552 Mtetra
.339 .591 .938 r
.21572 .2552 .22386 .26857 .24624 .2761 .23822 .2632 Mtetra
.405 .642 .953 r
.23822 .2632 .24624 .2761 .26889 .28149 .261 .26893 Mtetra
.449 .676 .961 r
.261 .26893 .26889 .28149 .29176 .28535 .28401 .27305 Mtetra
.48 .699 .965 r
.28401 .27305 .29176 .28535 .31482 .28807 .30721 .27595 Mtetra
.502 .716 .968 r
.30721 .27595 .31482 .28807 .33804 .28992 .33059 .27795 Mtetra
.519 .729 .969 r
.33059 .27795 .33804 .28992 .36141 .2911 .35412 .27923 Mtetra
.531 .739 .97 r
.35412 .27923 .36141 .2911 .38492 .29174 .37779 .27996 Mtetra
.541 .747 .971 r
.37779 .27996 .38492 .29174 .40855 .29195 .4016 .28023 Mtetra
.549 .753 .972 r
.4016 .28023 .40855 .29195 .43231 .2918 .42553 .28013 Mtetra
.556 .758 .972 r
.42553 .28013 .43231 .2918 .45618 .29136 .44958 .27971 Mtetra
.561 .762 .972 r
.44958 .27971 .45618 .29136 .48017 .29067 .47374 .27905 Mtetra
.565 .766 .973 r
.47374 .27905 .48017 .29067 .50427 .28977 .49802 .27816 Mtetra
.569 .769 .973 r
.49802 .27816 .50427 .28977 .52848 .28869 .52242 .27708 Mtetra
.572 .772 .973 r
.52242 .27708 .52848 .28869 .5528 .28745 .54692 .27584 Mtetra
.575 .774 .973 r
.54692 .27584 .5528 .28745 .57723 .28607 .57153 .27445 Mtetra
.577 .776 .973 r
.57153 .27445 .57723 .28607 .60176 .28457 .59625 .27295 Mtetra
.579 .777 .973 r
.59625 .27295 .60176 .28457 .6264 .28297 .62108 .27133 Mtetra
.581 .779 .974 r
.62108 .27133 .6264 .28297 .65114 .28127 .64602 .26961 Mtetra
.582 .78 .974 r
.64602 .26961 .65114 .28127 .67599 .27948 .67106 .2678 Mtetra
.583 .781 .974 r
.67106 .2678 .67599 .27948 .70094 .27762 .69621 .26592 Mtetra
.585 .782 .974 r
.69621 .26592 .70094 .27762 .726 .27569 .72147 .26396 Mtetra
.586 .783 .974 r
.72147 .26396 .726 .27569 .75116 .27369 .74683 .26193 Mtetra
.586 .784 .974 r
.74683 .26193 .75116 .27369 .77643 .27163 .7723 .25985 Mtetra
.587 .785 .974 r
.7723 .25985 .77643 .27163 .8018 .26952 .79788 .2577 Mtetra
.588 .786 .974 r
.79788 .2577 .8018 .26952 .82728 .26736 .82357 .25551 Mtetra
.589 .786 .974 r
.82357 .25551 .82728 .26736 .85286 .26515 .84936 .25327 Mtetra
.589 .787 .974 r
.84936 .25327 .85286 .26515 .87855 .2629 .87526 .25098 Mtetra
.59 .788 .974 r
.87526 .25098 .87855 .2629 .90435 .26061 .90127 .24865 Mtetra
.90127 .24865 .90435 .26061 .93026 .25828 .92739 .24628 Mtetra
.617 .786 .963 r
.09733 .19623 .10642 .20755 .12883 .20485 .1199 .19349 Mtetra
.1199 .19349 .12883 .20485 .15126 .20309 .14255 .19074 Mtetra
0 .107 .64 r
.14255 .19074 .15126 .20309 .17203 .22758 .16363 .21231 Mtetra
.032 .343 .822 r
.16363 .21231 .17203 .22758 .19361 .2439 .18526 .22964 Mtetra
.211 .493 .9 r
.18526 .22964 .19361 .2439 .21572 .2552 .20746 .24162 Mtetra
.322 .581 .935 r
.20746 .24162 .21572 .2552 .23822 .2632 .23007 .2501 Mtetra
.393 .635 .952 r
.23007 .2501 .23822 .2632 .261 .26893 .25298 .25618 Mtetra
.441 .671 .96 r
.25298 .25618 .261 .26893 .28401 .27305 .27613 .26055 Mtetra
.474 .696 .965 r
.27613 .26055 .28401 .27305 .30721 .27595 .29949 .26365 Mtetra
.497 .714 .968 r
.29949 .26365 .30721 .27595 .33059 .27795 .32302 .26579 Mtetra
.515 .727 .969 r
.32302 .26579 .33059 .27795 .35412 .27923 .34672 .26718 Mtetra
.529 .737 .971 r
.34672 .26718 .35412 .27923 .37779 .27996 .37056 .26799 Mtetra
.539 .746 .971 r
.37056 .26799 .37779 .27996 .4016 .28023 .39453 .26832 Mtetra
.548 .752 .972 r
.39453 .26832 .4016 .28023 .42553 .28013 .41864 .26826 Mtetra
.554 .757 .972 r
.41864 .26826 .42553 .28013 .44958 .27971 .44286 .26788 Mtetra
.56 .762 .972 r
.44286 .26788 .44958 .27971 .47374 .27905 .46721 .26723 Mtetra
.564 .765 .973 r
.46721 .26723 .47374 .27905 .49802 .27816 .49168 .26635 Mtetra
.568 .768 .973 r
.49168 .26635 .49802 .27816 .52242 .27708 .51625 .26528 Mtetra
.571 .771 .973 r
.51625 .26528 .52242 .27708 .54692 .27584 .54095 .26404 Mtetra
.574 .773 .973 r
.54095 .26404 .54692 .27584 .57153 .27445 .56575 .26265 Mtetra
.576 .775 .973 r
.56575 .26265 .57153 .27445 .59625 .27295 .59066 .26113 Mtetra
.578 .777 .973 r
.59066 .26113 .59625 .27295 .62108 .27133 .61568 .25949 Mtetra
.58 .779 .974 r
.61568 .25949 .62108 .27133 .64602 .26961 .64082 .25776 Mtetra
.582 .78 .974 r
.64082 .25776 .64602 .26961 .67106 .2678 .66606 .25593 Mtetra
.583 .781 .974 r
.66606 .25593 .67106 .2678 .69621 .26592 .69141 .25402 Mtetra
.584 .782 .974 r
.69141 .25402 .69621 .26592 .72147 .26396 .71687 .25203 Mtetra
.585 .783 .974 r
.71687 .25203 .72147 .26396 .74683 .26193 .74243 .24998 Mtetra
.586 .784 .974 r
.74243 .24998 .74683 .26193 .7723 .25985 .76811 .24786 Mtetra
.587 .785 .974 r
.76811 .24786 .7723 .25985 .79788 .2577 .79389 .24569 Mtetra
.588 .786 .974 r
.79389 .24569 .79788 .2577 .82357 .25551 .81979 .24346 Mtetra
.81979 .24346 .82357 .25551 .84936 .25327 .84579 .24118 Mtetra
.589 .787 .974 r
.84579 .24118 .84936 .25327 .87526 .25098 .87191 .23886 Mtetra
.59 .787 .974 r
.87191 .23886 .87526 .25098 .90127 .24865 .89813 .23649 Mtetra
.59 .788 .974 r
.89813 .23649 .90127 .24865 .92739 .24628 .92447 .23409 Mtetra
.617 .786 .963 r
.0881 .18473 .09733 .19623 .1199 .19349 .11082 .18195 Mtetra
.11082 .18195 .1199 .19349 .14255 .19074 .13364 .17915 Mtetra
0 .227 .73 r
.13364 .17915 .14255 .19074 .16363 .21231 .15511 .19683 Mtetra
0 .313 .804 r
.15511 .19683 .16363 .21231 .18526 .22964 .17679 .21517 Mtetra
.185 .474 .892 r
.17679 .21517 .18526 .22964 .20746 .24162 .19908 .22783 Mtetra
.305 .569 .932 r
.19908 .22783 .20746 .24162 .23007 .2501 .2218 .2368 Mtetra
.382 .628 .95 r
.2218 .2368 .23007 .2501 .25298 .25618 .24484 .24323 Mtetra
.432 .666 .96 r
.24484 .24323 .25298 .25618 .27613 .26055 .26813 .24785 Mtetra
.468 .692 .965 r
.26813 .24785 .27613 .26055 .29949 .26365 .29164 .25115 Mtetra
.493 .711 .968 r
.29164 .25115 .29949 .26365 .32302 .26579 .31533 .25343 Mtetra
.512 .725 .97 r
.31533 .25343 .32302 .26579 .34672 .26718 .33919 .25493 Mtetra
.526 .736 .971 r
.33919 .25493 .34672 .26718 .37056 .26799 .3632 .25582 Mtetra
.537 .744 .971 r
.3632 .25582 .37056 .26799 .39453 .26832 .38735 .25621 Mtetra
.546 .751 .972 r
.38735 .25621 .39453 .26832 .41864 .26826 .41163 .2562 Mtetra
.553 .756 .972 r
.41163 .2562 .41864 .26826 .44286 .26788 .43604 .25585 Mtetra
.559 .761 .973 r
.43604 .25585 .44286 .26788 .46721 .26723 .46057 .25522 Mtetra
.563 .765 .973 r
.46057 .25522 .46721 .26723 .49168 .26635 .48522 .25436 Mtetra
.567 .768 .973 r
.48522 .25436 .49168 .26635 .51625 .26528 .50999 .25329 Mtetra
.571 .771 .973 r
.50999 .25329 .51625 .26528 .54095 .26404 .53487 .25204 Mtetra
.573 .773 .973 r
.53487 .25204 .54095 .26404 .56575 .26265 .55987 .25065 Mtetra
.576 .775 .973 r
.55987 .25065 .56575 .26265 .59066 .26113 .58497 .24911 Mtetra
.578 .777 .973 r
.58497 .24911 .59066 .26113 .61568 .25949 .61019 .24746 Mtetra
.58 .778 .974 r
.61019 .24746 .61568 .25949 .64082 .25776 .63552 .24571 Mtetra
.581 .78 .974 r
.63552 .24571 .64082 .25776 .66606 .25593 .66097 .24386 Mtetra
.583 .781 .974 r
.66097 .24386 .66606 .25593 .69141 .25402 .68652 .24192 Mtetra
.584 .782 .974 r
.68652 .24192 .69141 .25402 .71687 .25203 .71218 .23991 Mtetra
.585 .783 .974 r
.71218 .23991 .71687 .25203 .74243 .24998 .73796 .23782 Mtetra
.586 .784 .974 r
.73796 .23782 .74243 .24998 .76811 .24786 .76384 .23568 Mtetra
.587 .785 .974 r
.76384 .23568 .76811 .24786 .79389 .24569 .78984 .23347 Mtetra
.588 .785 .974 r
.78984 .23347 .79389 .24569 .81979 .24346 .81595 .23121 Mtetra
.588 .786 .974 r
.81595 .23121 .81979 .24346 .84579 .24118 .84217 .22889 Mtetra
.589 .787 .974 r
.84217 .22889 .84579 .24118 .87191 .23886 .8685 .22653 Mtetra
.8685 .22653 .87191 .23886 .89813 .23649 .89494 .22413 Mtetra
.59 .788 .974 r
.89494 .22413 .89813 .23649 .92447 .23409 .9215 .22168 Mtetra
.617 .786 .963 r
.07871 .17305 .0881 .18473 .11082 .18195 .1016 .17022 Mtetra
.1016 .17022 .11082 .18195 .13364 .17915 .12458 .16738 Mtetra
0 .384 .842 r
.12458 .16738 .13364 .17915 .15511 .19683 .14646 .18112 Mtetra
0 .282 .784 r
.14646 .18112 .15511 .19683 .17679 .21517 .16819 .20048 Mtetra
.159 .455 .883 r
.16819 .20048 .17679 .21517 .19908 .22783 .19056 .21384 Mtetra
.288 .558 .928 r
.19056 .21384 .19908 .22783 .2218 .2368 .21339 .22329 Mtetra
.37 .62 .949 r
.21339 .22329 .2218 .2368 .24484 .24323 .23656 .23007 Mtetra
.424 .661 .959 r
.23656 .23007 .24484 .24323 .26813 .24785 .26 .23496 Mtetra
.461 .689 .965 r
.26 .23496 .26813 .24785 .29164 .25115 .28367 .23844 Mtetra
.488 .708 .968 r
.28367 .23844 .29164 .25115 .31533 .25343 .30752 .24087 Mtetra
.508 .723 .97 r
.30752 .24087 .31533 .25343 .33919 .25493 .33155 .24249 Mtetra
.523 .734 .971 r
.33155 .24249 .33919 .25493 .3632 .25582 .35573 .24346 Mtetra
.535 .743 .971 r
.35573 .24346 .3632 .25582 .38735 .25621 .38005 .24391 Mtetra
.544 .75 .972 r
.38005 .24391 .38735 .25621 .41163 .2562 .40451 .24394 Mtetra
.551 .756 .972 r
.40451 .24394 .41163 .2562 .43604 .25585 .4291 .24363 Mtetra
.557 .76 .973 r
.4291 .24363 .43604 .25585 .46057 .25522 .45382 .24302 Mtetra
.562 .764 .973 r
.45382 .24302 .46057 .25522 .48522 .25436 .47866 .24216 Mtetra
.566 .767 .973 r
.47866 .24216 .48522 .25436 .50999 .25329 .50362 .2411 Mtetra
.57 .77 .973 r
.50362 .2411 .50999 .25329 .53487 .25204 .52869 .23985 Mtetra
.573 .773 .973 r
.52869 .23985 .53487 .25204 .55987 .25065 .55388 .23844 Mtetra
.575 .775 .973 r
.55388 .23844 .55987 .25065 .58497 .24911 .57919 .2369 Mtetra
.577 .776 .974 r
.57919 .2369 .58497 .24911 .61019 .24746 .60461 .23523 Mtetra
.579 .778 .974 r
.60461 .23523 .61019 .24746 .63552 .24571 .63014 .23345 Mtetra
.581 .779 .974 r
.63014 .23345 .63552 .24571 .66097 .24386 .65579 .23158 Mtetra
.582 .781 .974 r
.65579 .23158 .66097 .24386 .68652 .24192 .68155 .22962 Mtetra
.584 .782 .974 r
.68155 .22962 .68652 .24192 .71218 .23991 .70742 .22757 Mtetra
.585 .783 .974 r
.70742 .22757 .71218 .23991 .73796 .23782 .73341 .22546 Mtetra
.586 .784 .974 r
.73341 .22546 .73796 .23782 .76384 .23568 .7595 .22328 Mtetra
.587 .785 .974 r
.7595 .22328 .76384 .23568 .78984 .23347 .78572 .22104 Mtetra
.78572 .22104 .78984 .23347 .81595 .23121 .81204 .21874 Mtetra
.588 .786 .974 r
.81204 .21874 .81595 .23121 .84217 .22889 .83848 .21639 Mtetra
.589 .787 .974 r
.83848 .21639 .84217 .22889 .8685 .22653 .86503 .21399 Mtetra
.86503 .21399 .8685 .22653 .89494 .22413 .8917 .21154 Mtetra
.59 .788 .974 r
.8917 .21154 .89494 .22413 .9215 .22168 .91848 .20906 Mtetra
.617 .786 .963 r
.06918 .16119 .07871 .17305 .1016 .17022 .09223 .15831 Mtetra
.09223 .15831 .1016 .17022 .12458 .16738 .11538 .15542 Mtetra
.178 .526 .921 r
.11538 .15542 .12458 .16738 .14646 .18112 .13769 .16518 Mtetra
0 .251 .763 r
.13769 .16518 .14646 .18112 .16819 .20048 .15945 .18557 Mtetra
.132 .436 .874 r
.15945 .18557 .16819 .20048 .19056 .21384 .18192 .19962 Mtetra
.271 .546 .924 r
.18192 .19962 .19056 .21384 .21339 .22329 .20486 .20957 Mtetra
.358 .613 .947 r
.20486 .20957 .21339 .22329 .23656 .23007 .22816 .21671 Mtetra
.416 .656 .958 r
.22816 .21671 .23656 .23007 .26 .23496 .25175 .22185 Mtetra
.455 .685 .964 r
.25175 .22185 .26 .23496 .28367 .23844 .27556 .22553 Mtetra
.484 .706 .968 r
.27556 .22553 .28367 .23844 .30752 .24087 .29958 .22811 Mtetra
.504 .721 .97 r
.29958 .22811 .30752 .24087 .33155 .24249 .32378 .22984 Mtetra
.52 .733 .971 r
.32378 .22984 .33155 .24249 .35573 .24346 .34813 .23089 Mtetra
.532 .742 .972 r
.34813 .23089 .35573 .24346 .38005 .24391 .37263 .2314 Mtetra
.542 .749 .972 r
.37263 .2314 .38005 .24391 .40451 .24394 .39728 .23148 Mtetra
.55 .755 .972 r
.39728 .23148 .40451 .24394 .4291 .24363 .42205 .23119 Mtetra
.556 .759 .973 r
.42205 .23119 .4291 .24363 .45382 .24302 .44696 .23061 Mtetra
.561 .763 .973 r
.44696 .23061 .45382 .24302 .47866 .24216 .47199 .22976 Mtetra
.565 .767 .973 r
.47199 .22976 .47866 .24216 .50362 .2411 .49714 .2287 Mtetra
.569 .77 .973 r
.49714 .2287 .50362 .2411 .52869 .23985 .52241 .22745 Mtetra
.572 .772 .973 r
.52241 .22745 .52869 .23985 .55388 .23844 .5478 .22603 Mtetra
.575 .774 .973 r
.5478 .22603 .55388 .23844 .57919 .2369 .57331 .22447 Mtetra
.577 .776 .974 r
.57331 .22447 .57919 .2369 .60461 .23523 .59893 .22279 Mtetra
.579 .778 .974 r
.59893 .22279 .60461 .23523 .63014 .23345 .62467 .22099 Mtetra
.58 .779 .974 r
.62467 .22099 .63014 .23345 .65579 .23158 .65053 .21909 Mtetra
.582 .781 .974 r
.65053 .21909 .65579 .23158 .68155 .22962 .67649 .2171 Mtetra
.583 .782 .974 r
.67649 .2171 .68155 .22962 .70742 .22757 .70258 .21503 Mtetra
.584 .783 .974 r
.70258 .21503 .70742 .22757 .73341 .22546 .72878 .21288 Mtetra
.585 .784 .974 r
.72878 .21288 .73341 .22546 .7595 .22328 .75509 .21067 Mtetra
.586 .784 .974 r
.75509 .21067 .7595 .22328 .78572 .22104 .78152 .20839 Mtetra
.587 .785 .974 r
.78152 .20839 .78572 .22104 .81204 .21874 .80806 .20606 Mtetra
.588 .786 .974 r
.80806 .20606 .81204 .21874 .83848 .21639 .83472 .20367 Mtetra
.589 .787 .974 r
.83472 .20367 .83848 .21639 .86503 .21399 .8615 .20123 Mtetra
.8615 .20123 .86503 .21399 .8917 .21154 .88839 .19874 Mtetra
.59 .788 .974 r
.88839 .19874 .8917 .21154 .91848 .20906 .9154 .19621 Mtetra
.617 .786 .963 r
.05949 .14913 .06918 .16119 .09223 .15831 .08271 .1462 Mtetra
.08271 .1462 .09223 .15831 .11538 .15542 .10603 .14327 Mtetra
.35 .641 .963 r
.10603 .14327 .11538 .15542 .13769 .16518 .12878 .149 Mtetra
0 .219 .742 r
.12878 .149 .13769 .16518 .15945 .18557 .15059 .17043 Mtetra
.106 .416 .864 r
.15059 .17043 .15945 .18557 .18192 .19962 .17313 .18519 Mtetra
.253 .534 .919 r
.17313 .18519 .18192 .19962 .20486 .20957 .19619 .19563 Mtetra
.346 .605 .945 r
.19619 .19563 .20486 .20957 .22816 .21671 .21962 .20313 Mtetra
.407 .65 .957 r
.21962 .20313 .22816 .21671 .25175 .22185 .24336 .20854 Mtetra
.449 .681 .964 r
.24336 .20854 .25175 .22185 .27556 .22553 .26733 .21241 Mtetra
.479 .703 .967 r
.26733 .21241 .27556 .22553 .29958 .22811 .29151 .21514 Mtetra
.501 .719 .97 r
.29151 .21514 .29958 .22811 .32378 .22984 .31588 .21698 Mtetra
.517 .731 .971 r
.31588 .21698 .32378 .22984 .34813 .23089 .34041 .21811 Mtetra
.53 .74 .972 r
.34041 .21811 .34813 .23089 .37263 .2314 .36509 .21869 Mtetra
.54 .748 .972 r
.36509 .21869 .37263 .2314 .39728 .23148 .38992 .21881 Mtetra
.548 .754 .972 r
.38992 .21881 .39728 .23148 .42205 .23119 .41488 .21855 Mtetra
.555 .759 .973 r
.41488 .21855 .42205 .23119 .44696 .23061 .43998 .21798 Mtetra
.56 .763 .973 r
.43998 .21798 .44696 .23061 .47199 .22976 .4652 .21715 Mtetra
.564 .766 .973 r
.4652 .21715 .47199 .22976 .49714 .2287 .49055 .21609 Mtetra
.568 .769 .973 r
.49055 .21609 .49714 .2287 .52241 .22745 .51602 .21483 Mtetra
.571 .772 .973 r
.51602 .21483 .52241 .22745 .5478 .22603 .54162 .21341 Mtetra
.574 .774 .974 r
.54162 .21341 .5478 .22603 .57331 .22447 .56733 .21183 Mtetra
.576 .776 .974 r
.56733 .21183 .57331 .22447 .59893 .22279 .59316 .21013 Mtetra
.578 .778 .974 r
.59316 .21013 .59893 .22279 .62467 .22099 .6191 .20831 Mtetra
.58 .779 .974 r
.6191 .20831 .62467 .22099 .65053 .21909 .64517 .20638 Mtetra
.582 .78 .974 r
.64517 .20638 .65053 .21909 .67649 .2171 .67135 .20437 Mtetra
.583 .781 .974 r
.67135 .20437 .67649 .2171 .70258 .21503 .69765 .20227 Mtetra
.584 .783 .974 r
.69765 .20227 .70258 .21503 .72878 .21288 .72407 .20009 Mtetra
.585 .783 .974 r
.72407 .20009 .72878 .21288 .75509 .21067 .7506 .19784 Mtetra
.586 .784 .974 r
.7506 .19784 .75509 .21067 .78152 .20839 .77725 .19552 Mtetra
.587 .785 .974 r
.77725 .19552 .78152 .20839 .80806 .20606 .80402 .19315 Mtetra
.588 .786 .974 r
.80402 .19315 .80806 .20606 .83472 .20367 .83091 .19072 Mtetra
.83091 .19072 .83472 .20367 .8615 .20123 .85791 .18824 Mtetra
.589 .787 .974 r
.85791 .18824 .8615 .20123 .88839 .19874 .88503 .18571 Mtetra
.589 .788 .974 r
.88503 .18571 .88839 .19874 .9154 .19621 .91227 .18314 Mtetra
.617 .786 .963 r
.04964 .13687 .05949 .14913 .08271 .1462 .07304 .1339 Mtetra
.07304 .1339 .08271 .1462 .10603 .14327 .09653 .13092 Mtetra
.492 .724 .974 r
.09653 .13092 .10603 .14327 .12878 .149 .11975 .13258 Mtetra
0 .187 .719 r
.11975 .13258 .12878 .149 .15059 .17043 .14159 .15505 Mtetra
.078 .396 .853 r
.14159 .15505 .15059 .17043 .17313 .18519 .16421 .17052 Mtetra
.235 .521 .914 r
.16421 .17052 .17313 .18519 .19619 .19563 .18738 .18147 Mtetra
.334 .597 .943 r
.18738 .18147 .19619 .19563 .21962 .20313 .21095 .18933 Mtetra
.399 .645 .956 r
.21095 .18933 .21962 .20313 .24336 .20854 .23483 .195 Mtetra
.443 .677 .963 r
.23483 .195 .24336 .20854 .26733 .21241 .25896 .19908 Mtetra
.474 .7 .967 r
.25896 .19908 .26733 .21241 .29151 .21514 .28331 .20195 Mtetra
.497 .717 .969 r
.28331 .20195 .29151 .21514 .31588 .21698 .30784 .2039 Mtetra
.514 .729 .971 r
.30784 .2039 .31588 .21698 .34041 .21811 .33255 .20512 Mtetra
.528 .739 .972 r
.33255 .20512 .34041 .21811 .36509 .21869 .35742 .20576 Mtetra
.538 .747 .972 r
.35742 .20576 .36509 .21869 .38992 .21881 .38244 .20593 Mtetra
.547 .753 .973 r
.38244 .20593 .38992 .21881 .41488 .21855 .40759 .2057 Mtetra
.553 .758 .973 r
.40759 .2057 .41488 .21855 .43998 .21798 .43288 .20515 Mtetra
.559 .762 .973 r
.43288 .20515 .43998 .21798 .4652 .21715 .4583 .20432 Mtetra
.563 .766 .973 r
.4583 .20432 .4652 .21715 .49055 .21609 .48385 .20326 Mtetra
.567 .769 .973 r
.48385 .20326 .49055 .21609 .51602 .21483 .50952 .202 Mtetra
.571 .771 .973 r
.50952 .202 .51602 .21483 .54162 .21341 .53532 .20057 Mtetra
.573 .774 .974 r
.53532 .20057 .54162 .21341 .56733 .21183 .56124 .19898 Mtetra
.576 .776 .974 r
.56124 .19898 .56733 .21183 .59316 .21013 .58728 .19725 Mtetra
.578 .777 .974 r
.58728 .19725 .59316 .21013 .6191 .20831 .61344 .19541 Mtetra
.58 .779 .974 r
.61344 .19541 .6191 .20831 .64517 .20638 .63972 .19346 Mtetra
.581 .78 .974 r
.63972 .19346 .64517 .20638 .67135 .20437 .66612 .19141 Mtetra
.583 .781 .974 r
.66612 .19141 .67135 .20437 .69765 .20227 .69264 .18928 Mtetra
.584 .782 .974 r
.69264 .18928 .69765 .20227 .72407 .20009 .71927 .18707 Mtetra
.585 .783 .974 r
.71927 .18707 .72407 .20009 .7506 .19784 .74603 .18478 Mtetra
.586 .784 .974 r
.74603 .18478 .7506 .19784 .77725 .19552 .77291 .18243 Mtetra
.587 .785 .974 r
.77291 .18243 .77725 .19552 .80402 .19315 .7999 .18002 Mtetra
.587 .786 .974 r
.7999 .18002 .80402 .19315 .83091 .19072 .82702 .17755 Mtetra
.588 .786 .974 r
.82702 .17755 .83091 .19072 .85791 .18824 .85425 .17502 Mtetra
.589 .787 .974 r
.85425 .17502 .85791 .18824 .88503 .18571 .88161 .17245 Mtetra
.88161 .17245 .88503 .18571 .91227 .18314 .90909 .16983 Mtetra
.617 .786 .963 r
.03963 .12441 .04964 .13687 .07304 .1339 .0632 .12139 Mtetra
.0632 .12139 .07304 .1339 .09653 .13092 .08686 .11836 Mtetra
.603 .78 .965 r
.08686 .11836 .09653 .13092 .11975 .13258 .11057 .11592 Mtetra
0 .156 .695 r
.11057 .11592 .11975 .13258 .14159 .15505 .13244 .13944 Mtetra
.051 .376 .842 r
.13244 .13944 .14159 .15505 .16421 .17052 .15515 .15563 Mtetra
.216 .508 .909 r
.15515 .15563 .16421 .17052 .18738 .18147 .17843 .16708 Mtetra
.321 .589 .94 r
.17843 .16708 .18738 .18147 .21095 .18933 .20213 .1753 Mtetra
.39 .64 .955 r
.20213 .1753 .21095 .18933 .23483 .195 .22616 .18125 Mtetra
.437 .674 .963 r
.22616 .18125 .23483 .195 .25896 .19908 .25045 .18552 Mtetra
.469 .697 .967 r
.25045 .18552 .25896 .19908 .28331 .20195 .27497 .18855 Mtetra
.493 .715 .969 r
.27497 .18855 .28331 .20195 .30784 .2039 .29968 .19061 Mtetra
.512 .728 .971 r
.29968 .19061 .30784 .2039 .33255 .20512 .32457 .19191 Mtetra
.525 .738 .972 r
.32457 .19191 .33255 .20512 .35742 .20576 .34962 .19261 Mtetra
.536 .746 .972 r
.34962 .19261 .35742 .20576 .38244 .20593 .37483 .19282 Mtetra
.545 .752 .973 r
.37483 .19282 .38244 .20593 .40759 .2057 .40017 .19263 Mtetra
.552 .757 .973 r
.40017 .19263 .40759 .2057 .43288 .20515 .42566 .19209 Mtetra
.558 .762 .973 r
.42566 .19209 .43288 .20515 .4583 .20432 .45128 .19128 Mtetra
.563 .765 .973 r
.45128 .19128 .4583 .20432 .48385 .20326 .47703 .19022 Mtetra
.567 .768 .973 r
.47703 .19022 .48385 .20326 .50952 .202 .50291 .18895 Mtetra
.57 .771 .973 r
.50291 .18895 .50952 .202 .53532 .20057 .52892 .1875 Mtetra
.573 .773 .974 r
.52892 .1875 .53532 .20057 .56124 .19898 .55505 .1859 Mtetra
.575 .775 .974 r
.55505 .1859 .56124 .19898 .58728 .19725 .5813 .18415 Mtetra
.577 .777 .974 r
.5813 .18415 .58728 .19725 .61344 .19541 .60768 .18228 Mtetra
.579 .778 .974 r
.60768 .18228 .61344 .19541 .63972 .19346 .63418 .18031 Mtetra
.581 .78 .974 r
.63418 .18031 .63972 .19346 .66612 .19141 .66079 .17823 Mtetra
.582 .781 .974 r
.66079 .17823 .66612 .19141 .69264 .18928 .68753 .17606 Mtetra
.584 .782 .974 r
.68753 .17606 .69264 .18928 .71927 .18707 .7144 .17381 Mtetra
.585 .783 .974 r
.7144 .17381 .71927 .18707 .74603 .18478 .74138 .17149 Mtetra
.586 .784 .974 r
.74138 .17149 .74603 .18478 .77291 .18243 .76849 .1691 Mtetra
.586 .785 .974 r
.76849 .1691 .77291 .18243 .7999 .18002 .79571 .16665 Mtetra
.587 .785 .974 r
.79571 .16665 .7999 .18002 .82702 .17755 .82306 .16413 Mtetra
.588 .786 .974 r
.82306 .16413 .82702 .17755 .85425 .17502 .85053 .16157 Mtetra
.589 .787 .974 r
.85053 .16157 .85425 .17502 .88161 .17245 .87813 .15895 Mtetra
.87813 .15895 .88161 .17245 .90909 .16983 .90585 .15629 Mtetra
.617 .786 .963 r
.02946 .11175 .03963 .12441 .0632 .12139 .0532 .10868 Mtetra
.0532 .10868 .0632 .12139 .08686 .11836 .07704 .10559 Mtetra
.07704 .10559 .08686 .11836 .11057 .11592 .10098 .1025 Mtetra
0 .147 .672 r
.10098 .1025 .11057 .11592 .13244 .13944 .12316 .12358 Mtetra
.023 .355 .829 r
.12316 .12358 .13244 .13944 .15515 .15563 .14594 .1405 Mtetra
.198 .495 .904 r
.14594 .1405 .15515 .15563 .17843 .16708 .16934 .15245 Mtetra
.309 .58 .938 r
.16934 .15245 .17843 .16708 .20213 .1753 .19317 .16105 Mtetra
.381 .634 .954 r
.19317 .16105 .20213 .1753 .22616 .18125 .21734 .16726 Mtetra
.43 .67 .962 r
.21734 .16726 .22616 .18125 .25045 .18552 .2418 .17174 Mtetra
.465 .694 .967 r
.2418 .17174 .25045 .18552 .27497 .18855 .26648 .17492 Mtetra
.49 .712 .969 r
.26648 .17492 .27497 .18855 .29968 .19061 .29137 .17709 Mtetra
.509 .726 .971 r
.29137 .17709 .29968 .19061 .32457 .19191 .31645 .17848 Mtetra
.523 .736 .972 r
.31645 .17848 .32457 .19191 .34962 .19261 .34169 .17924 Mtetra
.534 .744 .972 r
.34169 .17924 .34962 .19261 .37483 .19282 .36708 .17949 Mtetra
.543 .751 .973 r
.36708 .17949 .37483 .19282 .40017 .19263 .39263 .17933 Mtetra
.551 .756 .973 r
.39263 .17933 .40017 .19263 .42566 .19209 .41832 .17881 Mtetra
.557 .761 .973 r
.41832 .17881 .42566 .19209 .45128 .19128 .44414 .178 Mtetra
.562 .765 .973 r
.44414 .178 .45128 .19128 .47703 .19022 .4701 .17694 Mtetra
.566 .768 .973 r
.4701 .17694 .47703 .19022 .50291 .18895 .49619 .17567 Mtetra
.569 .771 .974 r
.49619 .17567 .50291 .18895 .52892 .1875 .5224 .17421 Mtetra
.572 .773 .974 r
.5224 .17421 .52892 .1875 .55505 .1859 .54875 .17259 Mtetra
.575 .775 .974 r
.54875 .17259 .55505 .1859 .5813 .18415 .57522 .17082 Mtetra
.577 .777 .974 r
.57522 .17082 .5813 .18415 .60768 .18228 .60181 .16893 Mtetra
.579 .778 .974 r
.60181 .16893 .60768 .18228 .63418 .18031 .62853 .16692 Mtetra
.58 .78 .974 r
.62853 .16692 .63418 .18031 .66079 .17823 .65537 .16481 Mtetra
.582 .781 .974 r
.65537 .16481 .66079 .17823 .68753 .17606 .68234 .16261 Mtetra
.583 .782 .974 r
.68234 .16261 .68753 .17606 .7144 .17381 .70943 .16032 Mtetra
.584 .783 .974 r
.70943 .16032 .7144 .17381 .74138 .17149 .73665 .15796 Mtetra
.585 .784 .974 r
.73665 .15796 .74138 .17149 .76849 .1691 .76398 .15553 Mtetra
.586 .785 .974 r
.76398 .15553 .76849 .1691 .79571 .16665 .79145 .15304 Mtetra
.587 .785 .974 r
.79145 .15304 .79571 .16665 .82306 .16413 .81903 .15048 Mtetra
.588 .786 .974 r
.81903 .15048 .82306 .16413 .85053 .16157 .84675 .14787 Mtetra
.588 .787 .974 r
.84675 .14787 .85053 .16157 .87813 .15895 .87458 .1452 Mtetra
.589 .787 .974 r
.87458 .1452 .87813 .15895 .90585 .15629 .90254 .14249 Mtetra
0 g
.89362 0 m
.98022 .38351 L
s
.98022 .38351 m
1 .65325 L
s
1 .65325 m
.91448 .33294 L
s
.91448 .33294 m
.89362 0 L
s
.02946 .11175 m
0 .4272 L
s
0 .4272 m
.91448 .33294 L
s
.91448 .33294 m
.89362 0 L
s
.89362 0 m
.02946 .11175 L
s
.02946 .11175 m
.89362 0 L
s
gsave
.44797 -0.02478 -65.9056 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(u) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
0 .4272 m
.29069 .70824 L
s
gsave
.15892 .66839 -66.3192 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(p) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{261.563, 185.125},
  ImageMargins->{{29.5, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.095767,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000450000^A000`40O003h00Oogoo1Woo003oOol6
Ool00?moo`Ioo`00ogoo1Woo003oOol6Ool00?moo`Ioo`00PWoo1000Ogoo0021Ool01000Oomoo`00
P7oo0021Ool01000Oomoo`00P7oo0020Ool200000goo00000020Ool00?moo`Ioo`00ogoo1Woo003o
Ool6Ool00?moo`Ioo`00ogoo1Woo003oOol6Ool00?moo`Ioo`00ogoo1Woo003oOol6Ool00?moo`Io
o`00g7oo10009Goo003DOol80003Ool00`00Oomoo`0SOol00<eoo`L000]oo`03001oogoo02=oo`00
aGoo20004Woo0P0097oo002nOol7000JOol2000TOol00;Ioo`P0025oo`8002Aoo`00[goo1`00:Goo
0P0097oo002XOol7000`Ool00`00Ool0000SOol00:1oo`P003Moo`03001oo`0002=oo`00VGoo1`00
@7oo0P008goo002AOol80017Ool2000SOol008Yoo`L004moo`8002=oo`00PWoo2000EWoo00<007oo
00008Woo001kOol7001NOol00`00Ool0000ROol007=oo`P006Eoo`03001oo`00029oo`00K7oo1`00
KGoo00<007oo00008Woo001TOol8001dOol01000Oomoo`008Goo001MOol7001lOol01000Oomoo`00
8Goo001FOol70023Ool01000Oomoo`008Goo001>Ool8002:Ool01000Oomoo`008Goo0017Ool7002B
Ool01@00Oomoogoo000087oo000oOol8002IOol01@00Oomoogoo000087oo000hOol7002QOol01@00
Oomoogoo000087oo000`Ool80002Cah00d/NCaioo`2SOol01@00Oomoogoo000087oo000/Ool40000
3DlnBae?7T/MCci;7DlNBae??T/MCai;7Dln0:=oo`05001oogooOol0000POol002aoo`05001?7TlN
Cai;7P03Cah014/NCai?7TlN1T/N00<0U7ooOol0Wgoo00<007ooOol00Woo00<007ooOol07Goo000/
Ool05000Ool004/MCai;7DlnBae?7T/MCci;7DlNB_e?7T/NCai:o@2F07BQOol01@00Oomoogoo0000
7goo000/Ool01000Ool007oo0TlN00E;7TlNCai?7T/N009?7PI;7P0309D0U7oo09moo`05001oogoo
Ool0000OOol002aoo`0F001oogoo001??T/MCai;7DlnBae?7T/MCci;7DlNB_e?7T/NCah0M@2F0EVO
Ool01@00Oomoogoo00007goo000/Ool01@00Oomoogoo00000dlN00E;7TlNCai?7T/N009?7P03?]hj
gSkN008ngP80U@031ET5FWoo09aoo`03001oogoo009oo`03001oogoo01aoo`00:goo00<007ooOol0
0goo01@004lnBae?7T/MCci;7DlNBae??T/M?]hjgSko>]h0]P1e09H1F@EjW7oo00<007ooOol00Woo
00<007ooOol077oo000[Ool00`00Oomoo`04Ool01@00Cai?7TlNBah00dlN00];7TlNCahZWRYn:YhZ
OP2f09D5NPEI008Eo9Aoo`I;7P03001oogoo009oo`03001oogoo01aoo`00:goo00<007ooOol01Goo
01H004lnBae?7T/MCci;7DlNBae??RYm:YhZOBjN:Wd0]P1e1GX1FAWl5M/Io8Moo`0BBcm77T/NAai;
?dLNBai77T/oAai;7TLNBcm77T/NAai;?`0017oo00<007ooOol077oo000[Ool00`00Oomoo`05Ool0
0`00Bai?7P02Cah034/NCai?7TlNBai?7RYn:YhZORZN0=L0]P85NP@Eo0039Seoogoo07Mooae;7P03
001oogoo009oo`03001oogoo01aoo`00:goo00<007ooOol01Woo01<004/MCci;7DlNBae??T/MCai;
7Dln4O`ZWRYm;Yh0]PVK1GT5NP026O`01AGK9UdV?BIM8Sd0Jgoo02U77T/OAai;7TLNBam77T/NAai;
7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/oAai;7TLNBcm77T/NAai;?dLNBai77T/oAai;
7P0000Eoo`03001oogoo01]oo`00:goo00<007ooOol01goo00<004/NCah00TlN00e;7TlNCai?7T/N
CahF71HM4Q`0e`2f2IX5NP046O`022IM9SdVGBHm;Wh^OBin;WeKOol01DLNBai77T/NAah00d/N00E7
7T/NBai;7TLN00=;7P05Aai;7T/NBai77P0NBah00`00Oomoo`03Ool00`00Oomoo`0KOol002]oo`03
001oogoo00Qoo`0R001;7DlnBae?7T/MCci;7DlNBae??Q7l5QdAo03G1GX9V`Ej6Q`Io1XL5O`ZGBHm
9Ud^OC:N;Wd^WRim=[hbWCJn<Ye5Ool0ADKnBai6oT/OA_i;7TKnBam77T/NA_i;7dLNBai6oT/OAai;
7TKnBam77T/NA_i;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/NAai;
7dLNBai77T/OAai;7TLNBcm77T/NAai;?dLNBai77T/oAai;7TLNBcl00005Ool00`00Oomoo`0KOol0
02]oo`03001oogoo00Uoo`03001;7TlN009?7P05Bai?7TlNCai;7P020GX01aHM0?L0e`FJ2IX5NQhL
008Io0@VG@04;Wd^ORim;Wh3=Yh00cJn=Yhj_P03>[heOol2Aah00dKnAai77P04Aah01D/NAai77TLN
Bah00dLN019;7TLNBai77T/NAai;7TLNBai77T/NAai;7TLNBai77T/NAah3Bah01DLNBai;7T/NAah0
94/N00<004/NOol00goo00<007ooOol06goo000[Ool00`00Oomoo`09Ool09000Cai;7DlnBae?7T/M
Cci;7DlNBad1VP5j0IX0m`fk2IX9VaWl7QdIo1hL9SdZGBHm:Ud^OC:N;WdbWS:M=[hbWCJn=[djgP8j
_P05=[dngSZn?]hj_P02?]h02D;N?]i2oSkN@_hngT;n?]i2oP0;Ool0JdKn@_i77d;nA_i2oTLO@_i7
7T;nAam6oTLN@_i77dKnAai6oTLOA_i77TKnBam6oTLNA_i;7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;
7dKnBai6oT/OA_i;7TKnBam77T/NA_i;7dLNBai6oT/OAai;7TKnBam77T/NAai;7dLNBai77T/OAai;
7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/NAai;?dLNBai77T/oAai;7TLNBcm77T/NAai;
?dLNBai77T/oAai;7P00Bcl01Goo00<007ooOol06Woo000[Ool00`00Oomoo`0:Ool00`00Cai;7P03
Cah01D/NCai?7TlNBah00P5j00T1603g2I/9V`fK6O`N71XL7Q`00bIM00TbWRim;Wh^OC:N=Yhf_SJN
=[h01CZn0ckN00<jgSkN?]h013kN00A2oSkN@_i2gPQ2oP06A_i2oT;n@_i6oT;n2TKn00Y77TKnA_i6
oTLNA_i77TKnAai6oP=77P05A_i77TLNAai6oP02Aah01D/NAai77TLNBah00dLN01I;7TLNAai77T/N
Aai;7TLNBai77T/NAai;7TLNBai77T/NAai;7TLNBai77P=;7P05Aai;7T/NBai77P0RBah00`00Baio
o`04Ool00`00Oomoo`0JOol002]oo`03001oogoo00]oo`2[001?7T/MCci;7DlNBae??T/MCai;7@3g
0GX1603g3K/9VPfk7Q`N7AWl:UdVGBYN9UdbWRim<Yh^OCJn<Ydf_SJM=[hj_C[N>[hjgSZm?]hjgSkN
>[i2oSkN@]hngT;n?]i2oSkN@_hngT;n@]i2oT;N@_i2gTKo@_i6oT;nA_m2oTKn@_i77d;nAai2oTLO
@_i77T;nAam6oTLN@_i77dKnAai6oTLOA_i77TKnBam6oTLNA_i;7dKnBai6oT/OA_i;7TKnBam6oT/N
A_i;7dKnBai6oT/OAai;7TKnBam77T/NA_i;7dLNBai6oT/OAai;7TKnBam77T/NAai;7dLNBai77T/O
Aai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/NAai;?dLNBai77T/oAai;7TLNBcm77T/N
Aai;?dLNBai77T/o001;7TLN00Aoo`03001oogoo01Yoo`00:Woo00<007ooOol03Goo0TlN00E;7TlN
Cai?7T/N00=?7P04Bah0eP4H0AP23K/00`VK7QdN70027Q`032YM9UdZGBYM<YhbOC:N<Ydf_SJN=[hf
WPDj_PLngP08@]hngSkN@]i2oT;N@_i2gPQ2oP03A_i2oT;n0096oP04@_i6oTKnAah3A_h03TLNA_i6
oTKnAai6oTLNA_i77TKnAai6oTLNA_h3Aah01DKnAai77TLNA_h00TLN00E;7TLNAai77T/N00=77P0>
Bai77T/NAai;7TLNBai77T/NAai;7TLNBai77P=;7P05Aai;7T/NBai77P03Bah01DLNBai;7T/NAah0
84/N00<004/NBah017oo00<007ooOol06Woo000ZOol00`00Oomoo`0>Ool034/MCai;7DlnBae?7T/M
Cci;7DlNBad0m`81600K3IXA^`fk7QdN71hM7Q`ZOBYM:WhZGC:N;WdbWRim=[hfWCZn=YdjgSZm>]hj
_S[N>[hngS[N008ngP0>@_hngT;n?]i2oSkN@_hngT;n?]i2oT;NA_i2gP92oP1YA_m2oTKn@_i77d;n
A_i2oTLO@_i77T;nAam2oTLNA_i77dKnAai6oT/OA_i77TKnBam6oTLNA_i;7dKnAai6oT/OA_i;7TKn
Bam6oT/NA_i;7dKnBai6oT/OA_i;7TKnBam77T/NA_i;7dLNBai6oT/OAai;7TKnBam77T/NA_i;7dLN
Bai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/NAai;?dLNBai77T/oAai;7TLN
Bcm77T/NAai;?dLNBai77T/o009;7P03001;?d/N00Aoo`03001oogoo01Yoo`00:Woo00<007ooOol0
3Woo00@004lNCai;7P9?7PE;7P0407D1>@4H0AP33K/00b8m7Q`N7005:Ud00c:N<WdbWP02=[h013JN
=[hf_S[N0cZn00<jgSkN?]h01CkN00I2gSkN@_i2gT;n@]h6@_h01TKn@_i2oT;nA_i2oP=6oP04@_i6
oTKnAah3A_h02TLNA_i6oTKnAai6oTLNA_i77TKn0dLN00=6oTLNAah024LN00E;7TLNAai77T/N00=7
7P0>Bai77T/NAai;7TLNBai77T/NAai;7TLNBai77P=;7P05Aai;7T/NBai77P03Bah00dLNBai;7P0P
Bah00`00Bai;7P05Ool00`00Oomoo`0IOol002Yoo`03001oogoo00moo`0?001;7DlNBae??T/MBai6
oD/NB_i;7P1C0CT1>17L008A^`0G7Q`R?AhL8SdZGBYm:UdZOS9m<YhbOC:N=Ydf_SJM>[hfWC[N>[dn
gSZn?]hj_P04?]h024;n?]i2oSkN@_i2gT;n?]h3@_h0LD;NA_i2oTKn@_i6od;nA_i2oTLO@_i77T;n
Aam6oTLN@_i77dKnAai6oTLOA_i77TKnBam6oTLNA_i;7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dKn
Bai6oT/OA_i;7TKnBam6oT/NA_i;7dLNBai6oT/OAai;7TKnBam77T/NA_i;7dLNBai6oT/OAai;7TLN
Bam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/oAai;7TLNBcm77T/NAai;?dLN
Bai77T/oAai;7TLNBcm;7P00Aah01Goo00<007ooOol06Goo000ZOol00`00Oomoo`0@Ool3Cah00d/N
Cai?7P04Bah04`2E05<1>@4i4M/A^a7K8Q`R?AhL:WdZGBim:UdZOC:M<YhbWC:N00@f_P03>[hjgSZn
008j_PPngP92gP=2oP03@]i2oT;n00A2oP06A_i2oTKn@_i6oT;n0dKn00A2oTKnA_i77P=6oP0:Aai6
oTLNA_i77TKnAai6oTLNA_h3Aah00dKnAai77P08Aah01D/NAai77TLNBah00dLN00Y;7TLNBai77T/N
Aai;7TLNBai77P=;7P05Aai;7T/NBai77P03Bah01DLNBai;7T/NAah08D/N00<004/NBah017oo00<0
07ooOol06Goo000ZOol00`00Oomoo`0AOol084lnBae?7T/MCci;7CJn<[hf_`1e09D5>@4i0CPAg16k
9SdR728m7Q`^ORYM;WhZGCJN<YdfWS9m>[hfWCZn=Yd2>[h00ckN>[dngP05?]h02d;n?]i2oSkN@_hn
gT;n@]i2oSkNA_h00T;n06Y2gTKn@_i6oT;nA_m2oTLN@_i77d;nAai2oTLOA_i77T;nAam6oTLNA_i7
7dKnAai6oT/OA_i77TKnBam6oT/NA_i;7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dLNBai6oT/OAai;
7TKnBam77T/NA_i;7dLNBai6oT/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/NAai;
7dLNBai77T/OAai;7TLNBcm77T/NAai;?dLNBai77T/oAai;7TLNBcm77T/NAai;?`9;7P04Aah004/N
Bah4Ool00`00Oomoo`0IOol002Yoo`03001oogoo019oo`=?7P08Bai?7TlN=[hb_SJn07D0M085F@03
5M/Eg16k00<R?@05:UdZOBYM;WdZG@03<Yh01C:M>[hf_SZn=[h00SZn00<jgSZn>[h01CkN00I2oSkN
@]hngT;n@]h3@_h00d;N@_i2oP04@_h014Kn@_i6oT;n24Kn00i77TKnA_i6oTLNA_i77TKnAai6oTLN
A_i77TKn0dLN00=6oTLNAah014LN01I;7TLNAai77T/NAai;7TLNBai77T/NAai;7TLNBai77T/NAai;
7TLNBai77P=;7P05Aai;7T/NBai77P03Bah01DLNBai;7T/NAah07d/N00<004/NBah01Goo00<007oo
Ool067oo000ZOol00`00Oomoo`0COol094lnBae?7T/MCchF71Xm<[h0]P1e1EX5>@EJ5M/Eg28L9SdR
728m:Ud^ORYM;WhbOCJN<YdfWSJM>[hf_CZn=YdngSZn?]hj_@HngP1k@_hngT;n?]i2oSkN@_i2gT;n
@]i6oT;nA_i2gTLN@_i6oT;nAai2oTLN@_i77d;nAai2oTLOA_i77T;nAam6oTLNA_i77dKnAai6oT/O
A_i;7TKnBam6oT/NA_i;7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dLNBai6oT/OAai;7TKnBam77T/N
A_i;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/O
Aai;7TLNBcm77T/NAai;?dLNBai77T/oAai;7TLNBcm77T/NAai;?d/N00177T/o00Eoo`03001oogoo
01Qoo`00:Woo00<007ooOol04goo00/004lNCai?7T/NCahF7AHm5Q`0]P1e0085F@8Io0035M`V?BHm
008V?@@^O@07<YdfWS:N=Yhf_SZn=[h00SZn00@jgSZn?]hj_PDngP03@]i2oSkN0092gP03@_i2gT;n
00M2oP04A_i2oTKn@_h6A_h02TLNA_i6oTKnAai6oTLNA_i77TKn0dLN00E6oTLNAai77TKn00=77P04
A_i77TLNBah3Aah05T/NAai77TLNBai77T/NAai;7TLNBai77T/NAai;7TLNBai77T/NAai;7TLN0d/N
00E77T/NBai;7TLN02E;7P03001;7T/N00Eoo`03001oogoo01Qoo`00:Woo00<007ooOol057oo02H0
04lnBae?7T/M6SdF71Xm5Q`0]PEi2GX5>AWl5M/Io28l9UdR?2Hm;Wd^ORYM=YhbWCJn<YdfWSJm>[hf
_SZn>[dngSZn?]hj_D;N0ckN0752oSkN@_hngT;n@]i2oT;N@_i2gTKn@]i6oT;nA_i2oTLN@_i6oT;n
Aai2oTLN@_i77d;nAai2oTLOA_i77TKnAam6oTLNA_i;7dKnAai6oT/OA_i;7TKnBam6oT/NA_i;7dKn
Bai6oT/OA_i;7TKnBam77T/NA_i;7dLNBai6oT/OAai;7TKnBam77T/NA_i;7dLNBai77T/OAai;7TLN
Bam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBcm77T/NAai;?dLN
Bai77T/o009;7P06Aai;?d/NBai77P000T/N00=77WooOol00Woo00<007ooOol067oo000ZOol00`00
Oomoo`0EOol01@00Cai?7TlNBah00QHM00<F?@3G0;H00PEj11Wl0bHm00P^ORim;Wd^OCJN<YdfWS:N
1SZn00@ngS[N?]hj_P@ngP92gP03@_hngT;N0092oP03@]i2oT;n00I2oP04A_i2oTKn@_h6A_h02TLN
A_i6oTKnAai6oTLNA_i77TKn0dLN00E6oTLNAai77TKn00I77P05Bai77TLNAai;7P03Aah03T/NAai;
7TLNBai77T/NAai;7TLNBai77T/NAah3Bah01DLNBai;7T/NAah00d/N00=77T/NBah08D/N00@004/N
Bai;7PAoo`03001oogoo01Qoo`00:Goo00<007ooOol05goo00`004lnBae?7T/M0ETF71Xm0;H=V`Ei
2GX26O`05AGK:UdV?2YM9Sd^ORim<Wh^OCJn<Ydf_S:M>[hf_CZn=[hj_SZm?]hj_P02?]h0MD;n?]i2
gSkN@_hngT;n?]i2oT;N@_i2gT;n@]i6oT;NA_i2oTKn@_i77T;nA_i2oTLO@_i77T;nAam6oTLN@_i7
7dKnAai6oTLOA_i77TKnBam6oTLNA_i;7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dKnBai6oT/OAai;
7TKnBam77T/NA_i;7dLNBai6oT/OAai;7TKnBam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/NAai;
7dLNBai77T/OAai;7TLNBcm77T/NAai;?dLNBai77T/oAai;7TLNBcm77T/NAai;?`02Bah01dLNBcm;
7P00Aai;?d/N00Eoo`03001oogoo01Moo`00:Goo00<007ooOol067oo00E;7TlNCai?7T/N0081F@0B
0?L0]PfJ2IXMo1Wl7O`Io2IM9SdVGBHm<Wh^OC9m;WdfWSJM0SJN13Zn2SkN0T;N00=2oSkN@_h01D;n
00I6oT;n@_i2oTKn@_h:A_h02TLNA_i6oTKnAai6oTLNA_i77TKn0dLN00E6oTLNAai77TKn00977P05
Bai77TLNAai;7P03Aah03T/NAai;7TLNBai77T/NAai;7TLNBai77T/NAah3Bah01DLNBai;7T/NAah0
0d/N00=77T/NBah08d/N00<004/NBah00T/N17oo00<007ooOol05goo000DOol3000BOol00`00Oomo
o`0HOol06`00Bae??T/MCai;7@5I0AP0m`Uj3I/9NQhL6O`N71Wl:UdV?2YM;WdbWRim<YhfWCJn=Ydf
_P02>[h01cJm>]hj_SkN>[dngSZn008ngP1e@_hngT;N?]i2oSkN@_hngTKn@]i2oT;NA_i2oTKn@_i6
oT;nA_i2oTLN@_i6oT;nAam6oTLN@_i77dKnAai6oTLOA_i77TKnBam6oTLNA_i;7dKnBai6oT/OA_i;
7TKnBam6oT/NA_i;7dKnBai6oT/OA_i;7TKnBam77T/NA_i;7dLNBai6oT/OAai;7TKnBam77T/NA_i;
7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/NAai;?dLNBai77T/oAai;
7TLNBcm77T/NAai;?dLNBai77T/o009;7P06Aah004/NBai77T/o17oo00<007ooOol05goo000EOol0
0`00Oomoo`0AOol00`00Oomoo`0IOol00dlNBai?7P02Cah02P1e0ET1603g2IX=VPVJ8Q`Io1gl12YM
00P^OC9n;WdbOCJN=[hfWCJN13Zn1CkN00Q2gSkN?]hngT;n@]i2oT;N24;n00=6oT;n@_h00TKn00=2
oTKnA_h024Kn00Y77TKnA_i6oTLNA_i77TKnAai6oP=77P05A_i77TLNAai6oP02Aah01D/NAai77TLN
Bah00dLN00i;7TLNBai77T/NAai;7TLNBai77T/NAai;7TLN0d/N00E77T/NBai;7TLN00=;7P03Aai;
7T/N025;7P03001;7T/N009;7PAoo`03001oogoo01Moo`004goo0`004goo00<007ooOol06Woo00I?
7T/MCci;7DlN07@20AP0Sa6k3IX=Vagl8Q`Mo28M9UdZGBHm<YhbOC:N;Wdf_SJM=[hfWCkN>[hjgSZm
?]hn_SkN>[dngSjn@_hngT;n?]i2oSkN@_hngT;n@]i6oT;N@_i2gTKn@_i6oT;nA_i2oTKn@_i77T;n
Aai2oTLOA_i77TKnAam6oTLNA_i;7dKnAai6oT/OA_i;7TKnBam6oT/NA_i;7dKnBai6oT/OA_i;7TKn
Bam6oT/NA_i;7dKnBai6oT/OAai;7TKnBam77T/NA_i;7dLNBai6oT/OAai;7TLNBam77T/NAai;7dLN
Bai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/oAai;7TLNBcm77T/NAai;?dLNBai77T/oAai;7TLN
Bcl00T/N00I77T/oBah004LNBcl2Bah5Ool00`00Oomoo`0FOol0019oo`04001oogoo000COol00`00
Oomoo`0KOol01TlNBai?7TlN09D0L`8160<A^`037Q`R71hL00@ZG@04<YdbOC:N<Wd3=[h00cJN>[hj
_P02>[h6?]h024;N?]hngSkN@_i2gT;n@]h6@_h014Kn@_i6oT;n0dKn00A2oTKnA_i77P=6oP0:Aai6
oTKnA_i77TKnAai6oTLNA_h3Aah01DKnAai77TLNA_h01TLN00E;7TLNAai77T/N00=77P0:Bai77T/N
Aai;7TLNBai77T/NAah3Bah01DLNBai;7T/NAah0:D/N00<004/NBah00T/N1Goo00<007ooOol05Woo
000BOol01000Oomoo`004goo00<007ooOol077oo00Hf_S:n=[lb_P2E1CP20AP00a6k3IXV?@028Q`0
0agl;WdZG@02;Wd043:N<WdbWSJM>[hfWCZn=YdngSZn?]hj_CkN?[hngSZm0SkN00a2oSkN@_hngT;n
?]i2oT;N@_i2gTKn@]h2@_h0GDKn@_i6oT;nAai2oTKn@_i77TKnAai2oTLNA_i77TKnAam6oTLNA_i;
7dKnAai6oT/OA_i;7TKnBam6oT/NA_i;7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dKnBai6oT/OAai;
7TKnBam77T/NA_i;7dLNBai6oT/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/NAai;
7dLNBai77T/oAai;7TLNBcm77T/NAai;?`02Bah01TLNBcm;7T/NAai;?`9;7P07Aah004/NBai77T/o
Bah017oo00<007ooOol05Woo000COol4000BOol00`00Oomoo`0MOol01CJn<[hf_P2f09D00PDi00<E
^aGK4K/00R8L00<R?BYM:Ud00RYM00DbWC:N<YdbWSJN00<f_P03=Yhj_SZn008j_PHngP03@]hngT;N
0092oP03@]i2oT;n00I2oP04A_i2oTKn@_h6A_h03TLNA_i6oTKnAai6oTLNA_i77TKnAai6oTLNA_h3
Aah014KnAai77T/N0dLN019;7TLNAai77T/NAai;7TLNBai77T/NAai;7TLNBai77T/NAah3Bah01DLN
Bai;7T/NAah00d/N00=77T/NBah09D/N00<004/NBah00d/N17oo00<007ooOol05Woo000YOol00`00
Oomoo`0MOol07`002M`b_SJo0;H0U@Dh1ETE^aGK8Q`V?B8L8SdZGBin:Ud^OC9m=YhbOCJN=Ydj_SJM
>[hj_CkN>[hngSjm00<ngP09?[e2oSkN@_hngT;n@]i2oSkN0092oP1SA_i2gTKn@_i6oT;nA_i2oTKn
@_i77T;nAai2oTLNA_i77T;nAai6oTLNA_i77dKnAai6oT/OA_i77TKnBam6oT/NA_i;7dKnBai6oT/O
A_i;7TKnBam6oT/NA_i;7dLNBai6oT/OAai;7TKnBam77T/NA_i;7dLNBai77T/OAai;7TLNBam77T/N
Aai;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBcm77T/NAai;?dLNBai77T/o
009;7P0:Aai;?d/NBai77T/oBah004LNBcl2Bah00dLNOomoo`03Ool00`00Oomoo`0EOol002Uoo`03
001oogoo01ioo`0I1K/5f`Fk0=H0]PUj1CTIg1WK5M/V?2Hm9S`V?BiM;Wd^GCJN<YdfWSJM=Yhf_SZn
=[h00SZn00<n_SZn?]h01CkN0T;N00=2oSkN@_h00T;n00=2gT;n@_h014;n00A6oT;nA_i2oPQ6oP0:
Aai6oTKnA_i77TKnAai6oTLNA_h3Aah01DKnAai77TLNA_h00TLN00E;7TLNAai77T/N00=77P0:Bai7
7T/NAai;7TLNBai77T/NAah3Bah01DLNBai;7T/NAah00d/N00E77T/NBai;7TLN02I;7P03001;7T/N
009;7PEoo`03001oogoo01Eoo`00:7oo00<007ooOol087oo0205^`WL1K/0e`2f3GX5>1gl6M/Io28L
9SdV?2Hm;Ud^ORYM=YhbOCJN<Ydj_SJM>[hj_CkN>[dngSZn?]hngD;N0ckN00Q2oSkN@_hngT;n@]i2
oT;N0T;n06=6oT;NA_i2oTKn@_i77T;nA_i2oTLN@_i77T;nAai6oTLN@_i77TKnAai6oT/OA_i77TKn
Bam6oTLNA_i;7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dKnBai6oT/OAai;7TKnBam77T/NA_i;7dLN
Bai6oT/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/oAai;7TLN
Bcm77T/NAai;?dLNBai77T/oAai;7TLNBcl00T/N00Y77T/oBai;7TLNBcl004/NAai;?`9;7PAoo`03
001oogoo01Eoo`00:7oo00<007ooOol08Goo00h5^`GK1AP0eQ6J2GXIfaWL6M/Io2Hl9SdV?39m0Rim
00DfWCJN<YdfWSJM00@j_P04?]hj_SkN?[h6?]h2@]h00d;n?]i2oP02@_h014;N@_i2oTKn0T;n0TKn
00=2oTKnA_h024Kn00I77TKnAai6oTLNA_h3Aah01DKnAai77TLNA_h01TLN00E;7TLNAai77T/N00=7
7P0:Bai77T/NAai;7TLNBai77T/NAah3Bah01DLNBai;7T/NAah0;4/N00<004/NBah00d/N17oo00<0
07ooOol05Goo000XOol00`00Oomoo`0QOol0S@Cg07<9g02f0=LAVPej7O/Mo1WK:UdV?2YM9S`bORiM
<WhfWCJN=Ydf_SZm>[hfWCZn>[dngSZm?]hj_T;N?]e2gSkN@]hngT;n?]i2oSkNA_i2gT;n@]i6oT;n
A_i2gTKn@_i6oT;nAai6oTLN@_i77TKnAai6oTLNA_i77TKnBai6oTLNA_i;7TKnBai6oT/OA_i;7TKn
Bam6oT/NA_i;7dKnBai6oT/OA_i;7TKnBam77T/NA_i;7dLNBai6oT/OAai;7TKnBam77T/NA_i;7dLN
Bai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/NAai;?dLNBai77T/oAai;7TLN
Bcm77T/NAai;?`02Bah01TLNBcm;7T/NAai;?`9;7P06001;?d/NBai77T/o17oo00<007ooOol05Goo
000XOol00`00Oomoo`0ROol010CF07@5602f0Q6J11gl00<ZGBHl:Sd0139m00@fWCJN=YdfWP@j_P8n
gP03?[hngSkN00@ngP06@_i2gT;N@]i2oT;N1T;n00=6oT;nA_h00TKn00=2oTKnA_h014Kn00Y77TKn
A_i6oTLNA_i77TKnAai6oP=77P05A_i77TLNAai6oP02Aah05T/NAai77TLNBai77T/NAai;7TLNBai7
7T/NAai;7TLNBai77T/NAai;7TLN0d/N00E77T/NBai;7TLN02Y;7P03001;7T/N00=;7PEoo`03001o
ogoo01Aoo`00:7oo00<007ooOol08Woo01d4eP2D2ET5616J4K/AVR8L7O/R72YL;UdV?2YM;WdbORim
<YhfWCZn=Ydj_SZm>[hj_CZn?[hngSZm008ngP1[@]hngD;n?]i2oSkN@_i2gTKn@]i6oT;NA_i2gTKn
@_i6oT;NAai2oTKn@_i77TKnAai2oTLNA_i77TKnAai6oTLNA_i;7TKnAai6oT/OA_i;7TKnBam6oT/N
A_i;7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dLNBai6oT/OAai;7TKnBam77T/NA_i;7dLNBai77T/O
Aai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/NAai;?dLNBai77T/oAai;7TLNBcm77T/N
Aai;?`02Bah01TLNBcm;7T/NAai;?`9;7P06Aai;?`00Bai77T/o0T/N1Goo00<007ooOol057oo000X
Ool00`00Oomoo`0ROol21=H0101d3ET561Vk0Q6J00HV71gl7O`ZGBiM:Ud4<Wd013JN=Ydf_SJM13Zn
0ckN00@n_SkN?]i2gP8ngP05@]i2oT;N@_i2gP06@_h014Kn@_i6oT;n2TKn00Y77TKnA_i6oTLNA_i7
7TKnAai6oP=77P05A_i77TLNBai6oP02Aah03T/NAai77TLNBai77T/NAai;7TLNBai77T/NAah3Bah0
1DLNBai;7T/NAah00d/N00E77T/NBai;7TLN02Q;7P03001;7T/N00A;7PAoo`03001oogoo01Aoo`00
:7oo00<007ooOol08Woo08PE>0Cg1=H=F@UI6M/E^QWK8Q`V727l;UdZG2iM:S`fWS9m=YhbOCZn=Ydj
_SJM?]hj_Cjn>[dngSjn?]hn_D;n?]i2oSkM@_i2gT;n?]i2oT;NA_i2gTKn@]i6oT;nA_i2oTKn@_i7
7T;nA_i2oTLNA_i77T;nAai6oTLNA_i77TKnAai6oT/NA_i77TKnBam6oT/NA_i;7dKnBai6oT/OA_i;
7TKnBam6oT/NA_i;7dKnBai6oT/OAai;7TKnBam77T/NA_i;7dLNBai6oT/OAai;7TLNBam77T/NAai;
7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/oAai;7TLNBcm77T/NAai;?`9;7P06Aai;?d/N
Bai77T/o0T/N00I77T/oBai;7P00Bcl2Bah00dLNBcm;7P04Ool00`00Oomoo`0DOol002Qoo`03001o
ogoo02=oo`035EP4ePCF008=F@066M/I^aVk9S`V728L12iM00HbWC9m<YdbOCZn>Yh6>[h4?]h3@]h0
1CkN@]i2gT;n@]h01T;n00A6oT;nA_i2oPQ6oP05Aai6oTKnA_i77P03A_h01TLNA_i77TKnAai6oP=7
7P05A_i77TLNBai6oP02Aah03T/NAai77TLNBai77T/NAai;7TLNBai77T/NAah3Bah01DLNBai;7T/N
Aah00d/N00=77T/NBah094/N1@001d/N17oo00<007ooOol04goo000XOol00`00Oomoo`0SOol0QaEH
5CP4maEi3ETMfb7l5KXZ?BHL:SdV72im;Ud^OC9m=YhbOCJN=Ydj_SJM>[hj_CkN>[dngSjm@]hngT;N
?]e2oSkN@_hngD;n@]i2oT;N@_i2gTKn@]i6oT;NA_i2oTKn@_i6oT;nAai2oTKn@_i77TKnAai2oTLN
A_i77TKnAai6oTLNA_i;7TKnBai6oT/NA_i;7TKnBam6oT/NA_i;7dKnBai6oT/OAai;7TKnBam77T/N
A_i;7dLNBai6oT/OAai;7TKnBam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/O
Aai;7TLNBam77T/NAai;?dLNBai77T/oAai;7P0:0002Bah01TLNBcl004/NAai;?`9;7P03Aai;?goo
00=oo`03001oogoo01=oo`00:7oo00<007ooOol097oo0QEH00H4eQFJ3ETMfb7k7M/29S`00bXl<Udb
O@02;Ud3=Yd00cJN>[dj_P03>[h00cjn>[hn_P04?]h5@]h3@_h014;N@_i2oTKn0d;n00=6oT;nA_h0
2DKn00i77TKnAai6oTLNA_i77TKnAai6oTLNA_i77TKn0TLN00E;7TLNAai77T/N00=77P0>Bai77T/N
Aai;7TLNBai77T/NAai;7TLNBai77P=;7P05Aai;7T/NBai77P0EBah9000?Bah00`00Bai;7P04Bah4
Ool00`00Oomoo`0COol002Qoo`03001oogoo02Aoo`1c4CLEF1Dh6IXENB7l7M/Qo2Xl;UdV72Xm;Udb
OBiM=YhbOCJN<Wdj_SZM>[hjWCZn>[dngSZm@]hn_D;N?]i2gSkM@_hngT;n?]e6oT;N@_i2gTKn@_i6
oT;NA_i2oTKn@_i6oT;nAai2oTLNA_i77TKnAai6oTLNA_i;7TKnAai6oT/NA_i;7TKnBai6oT/NA_i;
7TKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dLNBai6oT/OAai;7TKnBam77T/NA_i;7dLNBai77T/OAai;
7TLNBam77T/NAai;7dLNBai77T/OAah02P0000E;?dLNBai77T/o009;7P06Aai;?d/NBai77T/o0T/N
00I77T/oBai;7TLNBcl2Bah01TLN001;7T/NAai;?`9;7PAoo`03001oogoo01=oo`009goo00<007oo
Ool09Goo00hU^ADh5EPQfQVJ5IXV71gK8O/Z?2hm:S`bOC9M0S9m00HfWSJM=YdfWCZn>[d2>[h01CkN
?[hn_Sjn@]h00ckN14;N00=2oT;N@_h00T;n00E2gTKn@_i6oT;n00Y6oP0:Aai6oTKnA_i77TKnAai6
oTLNA_h3Aah01DKnAai77T/NA_h00TLN019;7TLNAai77T/NAai;7TLNBai77T/NAai;7TLNBai77T/N
Aah3Bah01DLNBai;7T/NAah00d/N00=77P0000001`008T/N00<004/NBah01D/N0goo00<007ooOol0
4goo000WOol00`00Oomoo`0VOol0H2Fi8ITEF26j8M/UnbXL9O/^GBXl;UdZ?3Im<WdfWC9m>YhfWCZN
=Ydn_SZM?[hj_CkN?[dngSjm@]hngD;N?]i2oSkM@_i2gT;n@]i6oT;N@_i2gTKn@_i6oT;NAai2oTKn
@_i77TKnAai2oTLNA_i77TKnAai6oTLNA_i;7TKnAai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/O
A_i;7TKnBam6oT/NA_i;7dLNBai6oT/OAai;7TKnBam77PT0000JAai;7dLNBai77T/OAai;7TLNBam7
7T/NAai;7dLNBai77T/oAai;7TLNBcm77T/NAai;?`9;7P06Aai;?d/NBai77T/o0T/N00Y77T/oBai;
7TLNBcm;7P00Aai;?`9;7P03Aai;?d/N00Aoo`03001oogoo019oo`009goo00<007ooOol09Woo00<U
VBFi9IT00R7J00TQfbGk9Q`V739M:S`^?C9m=Wd00S9m00@jWCZN=YdjW@8j_P05>[dj_SkN?]hn_P02
?]h01D;N?]i2gT;N@_h00d;N00=2oT;N@_h00d;n00=6oT;nA_h02dKn00Y77TKnA_i6oTLNA_i77TKn
Aai6oP=77P05A_i77TLNBai6oP02Aah02D/NAai77TLNBai77T/NAai;7P0:0002Bah01DLNBai;7T/N
Aah0;T/N00<004/NBah014/N17oo00<007ooOol04Woo000WOol00`00Oomoo`0VOol042Fi9ITU^BWj
9M/Q^Rhl:Q/Z72iL<Ud^G39M<WdfOC9m0SJM00Xj_SJM>[hj_Cjn>[dngSjm?]hn_@8ngP0_@]hngD;n
@]i2oT;M@_i2gTKn@]i6oT;NA_i2gTKn@_i6oT;nAai2oTKn@_i77TKnAai2oTLNA_i77TKnAai6oTLN
A_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7`090000;d/NA_i;7dLNBai6oT/OAai;7TKnBam77T/N
A_i;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/NAai;?dLNBai77T/o
Aai;7TLNBcl00T/N00I77T/oBai;7TLNBcl2Bah02TLNBcm;7T/NAai;?`00Bai77T/o0T/N00=77Woo
Ool00Woo00<007ooOol04Woo000WOol00`00Oomoo`0VOol04C7i9KTUVBFi:O/]nb7J;S`Z72hl;Udb
GBiL;UdfOCJM=Wd00SZM00<jWSJM?[h00Sjn00<j_Cjn?]h00ckN1D;N00E2oT;N@]i2oTKn00=2oP03
A_i2oTKn00e6oP08Aai6oTKnA_i77TKnAai6oPX0000@Bai77T/NAai;7TLNBai77T/NAai;7TLNBai7
7T/NAah3Bah01DLNBai;7T/NAah0<4/N00<004/NBah014/N17oo00<007ooOol04Woo000WOol00`00
Oomoo`0WOol0<S7I=OXUVBhK:OX^6bXL;S`Z6bhl<U`fOC9L=YhfOCJM=Wdn_SZM>[hjWCkN>[dn_SZm
@]hn_D;N?[e2oSkN@]hngD;n@]i2oT;MA_i2gTKn@]e6oT;NA_i2oTKn@_i6oT;nAah3A_h014LNA_i7
7TKn2@0003a6oT/NA_i;7TKnBai6oT/NA_i;7TKnBam6oT/NA_i;7dKnBai6oT/OAai;7TKnBam77T/N
A_i;7dLNBai6oT/OAai;7TKnBam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/o
Aai;7TLNBcl2Bah01TLNBcm;7T/NAai;?`9;7P06Aai;?d/NBai77T/o0T/N00I77T/oBai;7P00Bcl2
Bah014LNBcm;7T/N17oo00<007ooOol04Goo000WOol00`00Oomoo`0WOol03SGj<OTanRWk;Q/Ynbgk
<S`bG38l<WdbGCIm<Ud3>Yd01CJM>[djWCZn>Yd00cjn00Dn_D;N?]i2gSkN00A2gP04@_i2gT;n@]h2
@_h00dKn@_i2oP02A_h00d;nA_h000090003A_h01TLNA_i77TKnAai6oP977P05Bai6oTLNAai;7P03
Aah03T/NAai;7TLNBai77T/NAai;7TLNBai77T/NAah3Bah01DLNBai;7T/NAah0<d/N00<004/NBah0
14/N17oo00<007ooOol04Goo000WOol00`00Oomoo`0XOol033Gj<MTenS8K;Q/YnS9L<S`bG38l>Ydb
G08fO@0G>YhfWCZM>Ydn_SZM?[hj_CkN?[dngSZm@]hngD;N?[e2oT;N@_hngDKn@]i6oP090000DDKn
@_i77T;nAai6oTLNA_i77TKnAai6oT/NA_i77TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/N
A_i;7TKnBai6oT/OA_i;7TKnBam77T/NA_i;7dLNBai6oT/OAai;7TLNBam77T/NAai;7dLNBai77T/O
Aai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBcm77T/NAai;?`02Bah01TLNBcm;7T/NAai;?`9;
7P06Aai;?d/NBai77T/o0T/N00I77T/oBah004LNBcl2Bah00dLNBcl00004000COol002Moo`03001o
ogoo02Qoo`03<OXenS7i00<f>`04<S/bG38l<U`4=Wd03CJM>YdjWCZM>[dn_CZm?[hn_CkN?[hngT;N
00X00006@_i2gTKn@_i6oT;n2TKn00i77TKnA_i6oTLNA_i77TKnAai6oTLNA_i77TKn0TLN00E;7TKn
Aai77T/N00=77P0:Bai77T/NAai;7TLNBai77T/NAah3Bah01DLNBai;7T/NAah00d/N00=77T/NBah0
;d/N00<004/NBah014/N17oo00<007ooOol04Goo000WOol00`00Oomoo`0XOol04T8j?QY2>ShI=S`b
6cHk=U`jOCIL>W`fO3ZM=W`jOCZM?[hjW@T0000A?]e2gSkM@]i2gDKn@]i2oT;MA_i2gTKn@]e6oT;n
A_i2g@03A_h0BT;nAai6oTLNA_i77TKnAai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKn
Bai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBam77T/NA_i;7dLNBai6oT/OAai;7TKnBam77T/NAai;7dLN
Bai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/oAai;7TLNBcl2Bah01TLNBcm;7T/NAai;?`9;7P06
Aai;?d/NBai77T/o0T/N00I77T/oBai;7TLNBcl2Bah01TLN001;7T/NAai;?`9;7P05AaioogooOol0
000COol002Moo`03001oogoo02Uoo`<n>P04>U/nFcHk=S/:00000cZM?[hn_@02?[d013jn?[e2gSkN
14;N00I2oT;N@]i2gT;n@]h2@_h00dKn@_i6oP02A_h00d;nA_i6oP08A_h02TLNA_i6oTKnAai6oTLN
A_i77TKn0dLN01E6oTLNAai;7TKnBai77T/NAai;7TLNBai77T/NAai;7TLNBai77T/NAah00d/N00E7
7T/NBai;7TLN03A;7P03001;7T/N00A;7P=oo`03001oogoo015oo`009Woo00<007ooOol0:7oo2@00
02LjO3IL>WdfG3ZM>W`nWCYl?[djWCjn>Ydn_Sjm?[hn_D;N?[e2gSjm@]hngD;n@]e6oT;MA_i2gTKn
@]e6oT;NA_i2gDKn@_i6oT;MAah00TKn04Y2oTLNA_i77TKnAai6oTLNA_i;7TKnBai6oT/NA_i;7TKn
Bai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TLNBai6oT/OAai;7TKnBam77T/NA_i;7dLN
Bai6oT/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/NAai;?dLNBai77T/o0T/N00I7
7T/oBai;7TLNBcl2Bah01TLNBcm;7T/NAai;?`9;7P06Aai;?d/NBai77T/o0T/N00L004/oBai;7TLN
Bcm;7P03Ool00`00Oomoo`0AOol002Ioo`03001oogoo01moo`T0009oo`@n>P07?U/jFciK>U/nO3Yl
?W`00SZM00DjOCZM?[dn_CjM008n_@03@[hn_Cjm0092gP03@]e2gT;N00A2gP08@_i2gT;n@]i6oT;n
A_i2oQ16oP06Aai6oTKnA_i77TKn0TLN00I;7TKnAai77T/NA_h2Aah02T/NA_i;7TLNBai77T/NAai;
7TLN0d/N00E77T/NBai;7TLN00=;7P03Aai;7T/N03A;7P03001;7T/N00A;7P=oo`03001oogoo015o
o`009Woo00<007ooOol05Goo2P0037oo02Y:NTIIBWXjFciL>S/nG3Yl?WdjO3jM?Y`nWCjL?[djWCjm
>Ydn_Sjm@]hn_D;N?]e2gSjm@]i2gD;n@]e6oT;MA_i2gDKn@]e6oT;MA_i2gTKn@_d4A_h0ADLNA_i6
oTKnBai6oTLNA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;
7TKnBai6oT/OAai;7TKnBam77T/NA_i;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;
7TLNBam77T/NAai;7`02Bah01TLNBcm;7T/NAai;?`9;7P06Aai;?d/NBai77T/o0T/N00I77T/oBai;
7TLNBcl2Bah03DLNBcm;7T/NAai;?d/N00177T/oBai;?TLN00=oo`03001oogoo015oo`009Woo00<0
07ooOol037oo2@005Woo00A:FTYjBUY:FPA2N`8nO003>W`nO3jM00<nW@07?[e2_Cjm@]e2_D;N@[d0
0d;N00=2gD;N@]h014;N00I6oT;N@_i2gTKn@_h>A_h02TLNA_i6oTKnAai6oTLNA_i77TKn0TLN00i;
7TKnAai77T/NAai;7TLNBai77T/NAai;7TLN0d/N00E77T/NBai;7TLN00=;7P03Aai;7T/N03M;7P03
001;7T/N00=;7PAoo`03001oogoo011oo`009Woo00<007ooOol00Woo2P0087oo07A6FDYjAUU6O49k
AWa2NdIl?Wa2WCil@[dnW4:m?Ya2_Sjm@[dnWD;N?[e2gSjmA]i2gD;N@]e6gT;MA_i2gDKn@]e6oT;M
A_i2gDKn@]e6oT;nA_i2oDLNA_i77TKmAai6oTLNA_i;7TKnAai6oT/NA_i;7TKnBai6oT/NA_i;7TKn
Bai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NAai;7TKnBai77T/NA_i;7dLNBai6oT/OAai;7TLN
Bam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/o0T/N00I77T/oBai;7TLNBcl2
Bah01TLNBcm;7T/NAai;?`9;7P06Aai;?d/NBai77T/o0T/N00a77T/oBai;7TLN001;7T/nAai;?d/N
Bch3Ool00`00Oomoo`0@Ool002Ioo`D002Yoo`9:FP03BWY:FT9k00=2N`A2W0=2_@03@Ye2_D:m0092
_@04@]e2_D;N@[d3@]h01D;M@]i2gTKn@]h00dKn00=2gTKnA_h034Kn00i77TKnA_i6oTLNA_i77TKn
Aai6oTLNA_i;7TKn0TLN00i;7TKnBai77T/NAai;7TLNBai77T/NAai;7TLN0d/N00E77T/NBai;7TLN
00=;7P03Aai;7T/N03E;7P03001;7T/N00A;7P=oo`03001oogoo011oo`009goo00<007ooOol0:goo
02E>NE:JCWUBVTIkBYa6VdZK@Ya6_D:LA[`nW4:m?Ya2_CjL@]i2_D;M@[e6gT:m@]i2_DKn@]e6gT;M
A_i2gDKn@]e6oT;MA_i2g@03A_h0BT;MA_i6oTKnA_e77TKnAai6oD/NA_i;7TKnBai6oT/NA_i;7TKn
Bai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai77T/NA_i;7TLNBai6oT/NAai;7TKn
Bam77T/NA_i;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBcl2Bah01TLNBcm;
7T/NAai;?`9;7P06Aai;?d/NBai77T/o0T/N00I77T/oBai;7TLNBcl2Bah01TLNBcm;7T/NAai;?`9;
7P06001;?d/NBci77T/o0goo00<007ooOol047oo000XOol00`00Oomoo`0[Ool014iiDYYBNE:J14ZK
0dJL00U6_4:mA[e2_DJm@[e6gD:mA]d00d;M00Y2gT;M@]i2gDKN@]i6oTKNA_i2gQ96oP0:Aai6oTKn
A_i;7TKnAai6oT/NA_h2Aah02T/NA_i;7TLNBai77T/NAai;7TLN0d/N00E77T/NBai;7TLN00=;7P03
Aai;7T/N03a;7P03001;7T/N00A;7P9oo`03001oogoo011oo`00:Goo00<007ooOol0:Woo02IBVTii
DYY>NDZKAW]:W4JKA[a2W4Jm@Ya6_D:lA[e2_4Jm@[e6gT:mA]e2_DKN@]e6gT;MA_i2gDKn@]e6oT;M
A_i2gDKnA]e6oT;M0dKn04I6oD/NA_i6oTKmBai6oT/NA_e;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;
7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NAai;7TKnBai77T/NA_i;7TLNBai6oT/OAai;
7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/NAai;7`9;7P06Aai;?d/NBai77T/o0T/N00I7
7T/oBai;7TLNBcl2Bah01TLNBcm;7T/NAai;?`9;7P06Aai;?d/NBai77T/o0T/N00U77T/o001;?TLN
Bcm;7T/nAah00Woo00<007ooOol047oo000ZOol00`00Oomoo`0YOol01eJIE[UFVEJiEYU>^djK009>
^`A:_00@A[e2_DJm@[e6gD:mA]e2_DKN@]e6gD;MA]i2gDKNA]d2A]h00dKnA]i6oP0?A_h01DLNA_i6
oTKnAah00dKn00I;7TKnAai77T/NA_h2Aah01T/NAai;7TLNBai77P=;7P05Aai;7T/NBai77P03Bah0
0dLNBai;7P0nBah00`00Bai;7P04Bah2Ool00`00Oomoo`0@Ool002]oo`03001oogoo02Qoo`0YF[YF
VEZjEYUJ^TjKC[]>VdjkA[a:_4JLB[a6_4KMA[a:gDJlA]e2_DKNA[e6gT;MA_i6gDKn@]e6oTKMA_i6
gDKnA]e6oTKMB_i6oDKnA_e;7P02A_h0@TKmBai6oT/NA_e;7TKnBai6oD/NA_i;7TKnBai6oT/NA_i;
7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai77T/NA_i;7TLNBai6oT/NAai;
7TLNBai77T/NAai;7dLNBai77T/OAai;7TLNBam77T/NAai;7`9;7P06Aai;?d/NBai77T/o0T/N00I7
7T/oBai;7TLNBcl2Bah01TLNBcm;7T/NAai;?`9;7P06Aai;?d/NBai77T/o0T/N00]77T/oBai;?TLN
001;7T/nAai;?d/N009oo`03001oogoo011oo`00;7oo00<007ooOol0:7oo00EF^EJIE[UFVEJi009>
^`03CY]>^dZl00=:_004A[e6gDJmA[d5A]d02TKNA]e6gDKMA_i6gDKNA]e6oTKM4TKn00i77TKnAai6
oT/NA_i77TKnBai6oT/NAai;7TKn0d/N00E77T/NBai;7TLN00=;7P03Aai;7T/N04E;7P03001;7T/N
00A;7P03Ool007oo015oo`00;Goo00<007ooOol09goo06IFVEZjEYUJ^UJIE]]B^U;KD[Y>g4ZlC]a:
^dkLB[a:gDJlB]e6gD[MA]e:gDKMB_i6gD[nA]e6oTKMB_i6gDKnA]e:oTKMB_i6oD[nA_e:oTKmBai6
oT[nA_e;7TKnBai6oD/NA_i;7TKmBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6
oT/NA_i;7TKnBai77T/NA_i;7TLNBai6oT/NAai;7TKnBai77T/NAai;7dLNBai77T/OAai;7TLNBal2
Bah01TLNBam;7T/NAai;?`9;7P06Aai;?d/NBai77T/o0T/N00I77T/oBai;7TLNBcl2Bah01TLNBcm;
7T/NAai;?`9;7P06Aai;?d/NBai77T/o0T/N00a77T/oBah004LNBcm;7T/nAai;?goo000BOol002io
o`03001oogoo02Ioo`05G[UJ^EjiF[UN^@05D[/2C[`00dkLB[a:g@02B]d014[LB]e6gD[M1dKM00=6
oTKMA_h00TKn00=6oDKnA_h024Kn00E:oTKnA_i6oT/N00=6oP0:Bai6oTLNA_i;7TKnBai77T/NA_h3
Bah01DKnBai;7T/NAah00d/N00=77T/NBah0B4/N00<004/NBah00d/N00=oo`00Ool04Goo000_Ool0
0`00Oomoo`0UOol0I5ZiG[UJ^5kIF[UN^E:jE]]B^U;KC[]Bg4kKD]a>^dkMB]a>gD[LB_e:gD[mA]e:
oTKMB_i6gD[nA]e:oTKMB_i6oD[nA]e:oTKmB_i6oD/NA_e;7TKmBai6oD/NA_e;7TKnBai6oD/NA_i;
7TKmBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NAai;7TKnBai77T/NA_i;
7TLNBai6oT/NAai;7TLNBai77T/NAai;7dLNBai77T/O0T/N00I77T/OBai;7TLNBal2Bah01TLNBcm;
7T/NAai;?`9;7P06Aai;?d/NBai77T/o0T/N00I77T/oBai;7TLNBcl2Bah05TLNBcm;7T/NAai;?d/N
Bci77T/oBai;?TLNBcl004/nAai;?d/NBcioo`004Woo000`Ool00`00Oomoo`0UOol04eZiG[UJ^Eji
F[UFfeKJE]]FfUKKC]aBg4kLD]a:g4kMB]a>gD[L00A:g@08B_e6gD[mA]e6oTKmB_i6o@96oP05B_i6
oDKnA_i:oP03A_h01D[nA_i6oTKnBah00dKn00i;7TKnBai6oT/NA_i;7TKnBai6oT/NAai;7TLN0d/N
00E77T/NBai;7TLN04a;7P03001;7T/N00A;7P03001oogoo011oo`00<Goo00<007ooOol097oo065N
fEZiG[UJ^6;IE[YFfeJjF]]F^U;LC[]Bg4kKD]a:g4kMB]a>gDKMB_e:gD[mA]e:oTKMB_i6gD[nA_e:
oTKMB_i6oD[nA_e:oTKmB_i6oD/NA_e;7TKmBai6oT/NA_e;7TKnBai6oD/NA_i;7TKmBai6oT/NA_i;
7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TLNBai6oT/NAai;7TKnBai77T/NA_i;7TLNBai77T/NAai;
7TLNBai77T/NAai;7`02Bah01TLNBam;7T/NAai;?`9;7P06Aai;?d/NBai77T/o0T/N00I77T/oBai;
7TLNBcl2Bah01TLNBcm;7T/NAai;?`9;7P06Aai;?d/NBai77T/o0T/N01177T/oBai;?TLNBcm;7T/n
001;?d/NBci;7T/oBah0019oo`00<Woo00<007ooOol097oo00aN^F;HH]UNf6;IE]YFfeKJE]]FfU;L
D]/3D]`02DkLC]e>g4kmB]e:oD[MC_e:g@04B_d014[nB_e:oT[m0d[n01E6oD[nA_i:oTKnB_i6oT[n
A_i:oTKnBai6oT[nA_i;7TKnBai77T/NA_h00d/N00=6oT/NBah0ED/N00<004/NBah00d/N00=oo`00
Ool047oo000cOol00`00Oomoo`0SOol0FEjhH]UN^6;IG[QNne[JF_]JfUkkF]YFo5;KE_aBfdkmC]a>
oDkLC_e:g4kmB]e:oTKMB_i:gD[nB_e:oT[mB_i:oD/NA_e:oTKmBai6oD/NA_e;7TKmBai6oD/NA_i;
7TKmBai6oT/NA_e;7TKnBai6oD/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai77T/NA_i;
7TLNBai6oT/NAai;7TKnBai77T/NAah00d/N00I77T/NBai;7TLNBal2Bah01TLNBam;7T/NAai;?`9;
7P06Aai;?d/NBai77T/o0T/N00I77T/oBai;7TLNBcl2Bah01TLNBcm;7T/NAai;?`9;7P06Aai;?d/N
Bai77T/o0T/N00m77T/oBai;?T/NBcm;7P00Bai;?d/NBci;7Woo00004Goo000dOol00`00Oomoo`0R
Ool01V;IG]QRfF;HI]QRf0EJfP07E_]Fo5KKE_]Bo5;mC]`00U;l14km24[m00A:oT[mB_i:o@E:oP0=
A_i:oT[nBai6oT/NB_i;7TKnBai:oT/NA_h00d/N00=:oT/NBah0Ed/N00<004/NBah00d/N00=oo`00
Ool047oo000eOol2000SOol0DV;IG[QVn6;HI]QJfUkkF]YNnU[JE_aFfeKlD]]Fo4kLD_e>g5;mC]a>
oD[LC_e:gDknB]e>oT[mC_i:oDlNB_e>oT[mBai:oD/NA_e;7T[mBai6oD/NA_e;7TKmBai6oT/NA_e;
7TKnBai6oD/NA_i;7TKmBai6oT/NA_i;7TKnBai6oT/NAai;7TKnBai77T/NA_i;7TLNBai6oT/NAai;
7TLN0d/N00E77T/NBai;7TLN00=;7P05Aai;7T/NBai77P03Bah01TLNBam;7T/NAai;?`9;7P06Aai;
?d/NBai77T/o0T/N00I77T/oBai;7TLNBcl2Bah01TLNBcm;7T/NAai;?`9;7P0EAai;?d/NBci77T/o
Bai;?T/NBcm;7T/nBah004/NBci;7T/oBai;?P00015oo`00=goo00<007ooOol087oo00]Rf6KHH]QV
f6;HI]QNfUkjG]YNnUkJ009Fn`03E_aFfe;l00EBo0E>o@04B_e>oD[mB_h3B_d01T[nB_e:oT[mB_i:
o@I:oP06Bai:oT/NB_i;7T[n0d/N00E:oT/NBai;7T[n05Q;7P03001;7T/N00=;7P03001oogoo00mo
o`00>7oo00<007ooOol07goo015Vn6;HI]QRf6KhI]MNnU[JG_YNfUkjE]]Jo5KkF_aFfeKm009Bo00a
D]aFoDklC_e>g5;mB_e>oD[mC_i:oDlNB_e?7T[mBai:oDlNB_e;7T[mBai:oD/NA_e;7T[mBai6oD/N
B_i;7TKmBai6oT/NA_e;7TKnBai6oD/NA_i;7TKnBai:oT/NA_h00d/N00E6oT/NBai;7TKn00=;7P05
A_i;7T/NBai77P03Bah01DLNBai;7T/NAah00d/N00I77T/NBai;7TLNBcl2Bah01TLNBcm;7T/NAai;
?`9;7P06Aai;?d/NBai77T/o0T/N00I77T/oBai;7TLNBcl2Bah01TLNBcm;7T/NAai;?`=;7P04Bcm;
7T/nBah7Ool00`00Oomoo`03Ool00`00Oomoo`0?Ool003Uoo`03001oogoo01ioo`0AH]QVf6;HI]QV
efKhI]QNnUkJH_YNnV;jE_]JneKkF_]Fn`03E_`01U;lE_a>oE;mC_eBo@A>o@03B_e>oT[m009:o@06
B_i:oD[nB_e;7T[m0T[n00I;7T[nBai:oT/NB_h3Bah00d[nBai;7P17BahEOol00`00Oomoo`03Ool0
0`00Oomoo`0?Ool003Yoo`03001oogoo01ioo`0>H]QVn6KGI_QVef[hG_URnUkIH_YNnF;jF_]O6`=J
n`0`EaaBo5KlD_aC7DklD_e>o5<MC_e?7DkmDae:oDlNB_e?7T[mCai:oDlNB_e;7T[mCai:oD/NB_e;
7T[mBai6oD/NB_e;7TKmBai:oT/NA_e;7T[nBai6oD/NB_i;7TKm0d/N00E6oT/NBai;7TKn00=;7P05
A_i;7T/NBai77P03Bah01DLNBai;7T/NAah00d/N00E77T/NBai;7TLN00=;7P06Aai;?d/NBai77T/o
0T/N00A77T/oBai;7R9oo`03001oogoo00=oo`03001oogoo00moo`00>goo00<007ooOol07Goo00aV
f6KGI_QVf6KhJ_MRnUkjH_YNnF;jH_T5F_/3E_`00eLLD_aBo@02D_d00e;lC_e>o@04C_d01TlMB_e>
oD[mCai:o@9:oP03Bai:oD/N009;7P05B_i;7T/NBai:oP0aBah`Ool00`00Oomoo`02Ool00`00Oomo
o`0?Ool003aoo`03001oogoo01aoo`0=I]MVn6KGJ_QVef[hI]MRnUkiH_YRnFLJH_T00U[k031O6e[j
EaaFneLLE_aG74klDaeBo5<MC_eC7DkmDae>oDlNC_e?7T[mCai:oDlNB_e?7T[mCai:oDlNB_e;7T[m
Cai:oD/NB_e;7T[nBai:oD/NB_i;7T[mBai:oT/NA_d3Bah01DKnBai;7T/NA_h00d/N00E6oT/NBai;
7TLN00=;7T5oo`03001oogoo009oo`03001oogoo00moo`00?Goo00<007ooOol077oo00=Vf6KhI]L0
0f[g0f;i00IRnV;iH_UNnelKF_/2G_/05ULLE_aFo5KlDaeBo5<MD_aC7DkmDae>oE<MC_e?7DkmCae>
oDlNB_e?7T[m0T/N00=?7T[mBah00T/N00E:oT/NBai;7T[n00i;7U5oo`03001oogoo009oo`03001o
ogoo00moo`00?Woo00<007ooOol06goo03AZn6KGJ_QVef[hJ_M^mf;iIaYRnF;jH_UO6e[jGa]JnUlK
E_]K75KkFaaFneLMD_aG7E;lEae>o5<MC_eC7DklDai>oDlNC_e?7T[mCai:oDlNB_e?7T[mCai:oDlN
B_e?7T[mBai:oEmoo`05001oogooOol0000AOol003moo`03001oogoo01]oo`03I_QZmf[g00=Zm`06
H_YRnFKiI_UW6F;i0Ukk00YO6ekjGa]Fo5/LE_aK75KlEaeBo09G7003EaeBoE<M009C7@04C_e?7Dkm
Cae_Ool01@00Oomoogoo00004Goo0010Ool00`00Oomoo`0JOol06fKGJ_QVefkgJ_I^mf[gIaURnFLI
H_UW6EkjHa]NnUlKG_YK75[kFaaFne/LF_]G7E;lEaeBo01gOol01@00Oomoogoo00004Goo0011Ool0
0`00Oomoo`0IOol6J_L01FkgI_UW6F;iI_T00VLI00ENnUlKHaYS6elJ00=K7003Fa]K77oo07Yoo`03
001oogoo009oo`03001oogoo00ioo`00@Woo00<007ooOol06Goo019Zn6[fK_MZmfkgJ_I_5f;iIaUV
n6/II_QS6ekjHa]NnV<KG_Z0Ool01@00Oomoogoo000047oo0013Ool00`00Oomoo`0HOol4J_L2K_L0
2FkfIaUW6FLII_U[6FLHHa]O6P02HaZ1Ool01@00Oomoogoo000047oo0014Ool00`00Oomoo`0GOol0
3fkgJ_M^mf[fKaMZmVlGI_Q[6FKhJaUVn6/IG_YS6`23Ool01@00Oomoogoo000047oo0015Ool00`00
Oomoo`0FOol3J_L02fkgK_I^mfkfKaIVnF/IIaQ[6FLHJaT0Q7oo00D007ooOomoo`00011oo`00AWoo
00<007ooOol05Woo00aZmVlGJ_I_5f[fLaM^mV/II_Q[6FKhJaV6Ool01000Oomoo`0047oo0017Ool0
0`00Oomoo`0EOol01F[gK_I^mfkgKaH00Vkf00AW66/IIaQ[6HMoo`04001oogoo000@Ool004Qoo`03
001oogoo01Aoo`09J_I_5f[fKaM^mVlGK_Ic5VKh08Uoo`04001oogoo000@Ool004Uoo`03001oogoo
01Aoo`9^m`=^mP03LaI^mWoo08Yoo`03001oo`00011oo`00BWoo00<007ooOol04goo00M_5f[fKaM^
mW<FK_Ic5P2;Ool00`00Ool0000@Ool004]oo`03001oogoo01=oo`9^mP03KaI^mVlF08aoo`03001o
o`00011oo`00C7oo00<007ooOol04Woo00E^mW<GK_Ic5Vkf08aoo`03001oo`00011oo`00CGoo00<0
07ooOol04Woo00=^mVlFK_H0SWoo0P0047oo001>Ool00`00Oomoo`0AOol00g<FK_Ic5P2>Ool2000@
Ool004moo`03001oogoo011oo`03K_Ic5Vkf08ioo`03001oo`0000moo`00D7oo00<007ooOol03goo
00=c5VkfOol0SWoo00<007oo00003goo001AOol00`00Oomoo`0?Ool00flFOomoo`2>Ool2000?Ool0
059oo`03001oogoo00ioo`03001oogoo08ioo`8000moo`00Dgoo0P003Woo00<007ooOol0SWoo0P00
3goo001EOol00`00Oomoo`0;Ool00`00Oomoo`2>Ool2000?Ool005Ioo`03001oogoo00Yoo`03001o
ogoo08moo`03001oogoo00eoo`00Egoo00<007ooOol02Goo00<007ooOol0RGoo1`003goo001HOol0
0`00Oomoo`08Ool00`00Oomoo`1kOol>000FOol005Uoo`03001oogoo00Moo`03001oogoo06ioo`d0
02Aoo`00FWoo00<007ooOol01Goo00<007ooOol0HWoo3@00<Goo001KOol00`00Oomoo`04Ool00`00
Oomoo`1DOol>000nOol005aoo`03001oogoo00=oo`03001oogoo04Moo`d004aoo`00A7oo0`005Woo
00<007ooOol00Woo00<007ooOol0>Woo3@00FGoo0015Ool00`00Oomoo`0FOol01@00Oomoogoo0000
;Woo3P00IWoo0015Ool3000GOol01000Oomoo`008Goo3@00M7oo0015Ool01000Oomoo`005goo00<0
07oo000057oo3@00PGoo0015Ool01000Oomoo`0067oo0P001Woo3P00SWoo0014Ool4000JOol7002L
Ool00?moo`Ioo`00ogoo1Woo003oOol6Ool00?moo`Ioo`00ogoo1Woo003oOol6Ool00?moo`Ioo`00
O7oo0P0000=oo`0000000Woo10000goo0P0017oo0P0017oo0P0017oo0P00Igoo001mOol00`00Ool0
0009Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo001VOol007ioo`03001oogoo009o
o`@0009oo`04001oogoo0008Ool01000Oomoo`001Goo00<007ooOol0I7oo001lOol200000goo0000
0008Ool01000Oomoo`0027oo00@007ooOol000=oo`8006Moo`00RGoo00@007ooOol000Qoo`04001o
ogoo0003Ool00`00Oomoo`1VOol008Yoo`8000Yoo`8000Aoo`<006Ioo`00ogoo1Woo003oOol6Ool0
0?moo`Ioo`00ogoo1Woo0000\
\>"],
  ImageRangeCache->{{{0, 260.563}, {184.125, 0}} -> {-0.170508, 0.0461608, \
0.00439067, 0.00439067}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .70824 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1.10169 -0.148196 1.10169 [
[.5 .72074 -20 0 ]
[.5 .72074 20 15 ]
[.44797 -0.02478 -4.90556 -15 ]
[.44797 -0.02478 5.09444 0 ]
[.15892 .66839 -5.31917 0 ]
[.15892 .66839 4.68083 15 ]
[-0.06694 .27471 -10 -6.62571 ]
[-0.06694 .27471 0 8.37429 ]
[ 0 0 0 0 ]
[ 1 .70824 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .72074 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.437500 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(=) show
75.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.06) show
99.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math1Mono
%%DocumentNeededResources: + font Courier
%%DocumentNeededFonts: Math1Mono
%%DocumentNeededFont: + Courier
%%DocumentFonts: font Math1Mono
%%DocumentFonts: + font Courier
grestore
.25 Mabswid
.02946 .11175 m
.89362 0 L
s
gsave
.44797 -0.02478 -65.9056 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(u) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
0 .4272 m
.29069 .70824 L
s
gsave
.15892 .66839 -66.3192 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(p) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.02946 .11175 m
0 .4272 L
s
gsave
-0.06694 .27471 -71 -10.6257 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(q) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.02946 .11175 m
0 .4272 L
s
0 .4272 m
.29069 .70824 L
s
.29069 .70824 m
.30155 .45044 L
s
.30155 .45044 m
.02946 .11175 L
s
.89362 0 m
.98022 .38351 L
s
.98022 .38351 m
1 .65325 L
s
1 .65325 m
.91448 .33294 L
s
.91448 .33294 m
.89362 0 L
s
.02946 .11175 m
0 .4272 L
s
0 .4272 m
.91448 .33294 L
s
.91448 .33294 m
.89362 0 L
s
.89362 0 m
.02946 .11175 L
s
.30155 .45044 m
.98022 .38351 L
s
.98022 .38351 m
1 .65325 L
s
1 .65325 m
.29069 .70824 L
s
.29069 .70824 m
.30155 .45044 L
s
0 0 m
1 0 L
1 .70824 L
0 .70824 L
closepath
clip
newpath
.899 .771 .711 r
.2865 .64532 .29257 .66372 .31416 .61108 .30807 .59687 Mtetra
.848 .781 .787 r
.30807 .59687 .31416 .61108 .33452 .58565 .32846 .57361 Mtetra
.791 .785 .848 r
.32846 .57361 .33452 .58565 .35441 .57165 .34843 .56087 Mtetra
.739 .784 .889 r
.34843 .56087 .35441 .57165 .37413 .56315 .36824 .55316 Mtetra
.699 .782 .916 r
.36824 .55316 .37413 .56315 .39379 .55754 .388 .54809 Mtetra
.669 .78 .933 r
.388 .54809 .39379 .55754 .41345 .55356 .40777 .54449 Mtetra
.647 .779 .944 r
.40777 .54449 .41345 .55356 .43314 .55054 .42757 .54174 Mtetra
.632 .778 .951 r
.42757 .54174 .43314 .55054 .45287 .54811 .44742 .53951 Mtetra
.621 .778 .956 r
.44742 .53951 .45287 .54811 .47266 .54604 .46733 .53759 Mtetra
.614 .779 .96 r
.46733 .53759 .47266 .54604 .49251 .5442 .4873 .53587 Mtetra
.608 .779 .963 r
.4873 .53587 .49251 .5442 .51242 .54251 .50733 .53427 Mtetra
.605 .78 .965 r
.50733 .53427 .51242 .54251 .53239 .54092 .52743 .53274 Mtetra
.602 .781 .966 r
.52743 .53274 .53239 .54092 .55244 .53938 .5476 .53126 Mtetra
.6 .782 .968 r
.5476 .53126 .55244 .53938 .57254 .53787 .56783 .52979 Mtetra
.598 .783 .969 r
.56783 .52979 .57254 .53787 .59272 .53638 .58813 .52833 Mtetra
.597 .784 .969 r
.58813 .52833 .59272 .53638 .61296 .5349 .60851 .52687 Mtetra
.596 .784 .97 r
.60851 .52687 .61296 .5349 .63327 .53341 .62895 .5254 Mtetra
.596 .785 .971 r
.62895 .5254 .63327 .53341 .65365 .53192 .64946 .52392 Mtetra
.595 .786 .971 r
.64946 .52392 .65365 .53192 .6741 .53042 .67004 .52243 Mtetra
.595 .786 .972 r
.67004 .52243 .6741 .53042 .69461 .52891 .69069 .52092 Mtetra
.595 .787 .972 r
.69069 .52092 .69461 .52891 .7152 .52738 .71141 .51939 Mtetra
.71141 .51939 .7152 .52738 .73585 .52584 .7322 .51784 Mtetra
.595 .788 .973 r
.7322 .51784 .73585 .52584 .75658 .52428 .75306 .51628 Mtetra
.75306 .51628 .75658 .52428 .77737 .52271 .77399 .5147 Mtetra
.595 .789 .973 r
.77399 .5147 .77737 .52271 .79824 .52112 .79499 .5131 Mtetra
.79499 .5131 .79824 .52112 .81917 .51951 .81606 .51148 Mtetra
.595 .79 .974 r
.81606 .51148 .81917 .51951 .84018 .51789 .83721 .50985 Mtetra
.83721 .50985 .84018 .51789 .86125 .51626 .85843 .5082 Mtetra
.85843 .5082 .86125 .51626 .8824 .51461 .87972 .50653 Mtetra
.595 .791 .974 r
.87972 .50653 .8824 .51461 .90362 .51294 .90108 .50485 Mtetra
.90108 .50485 .90362 .51294 .92491 .51126 .92251 .50316 Mtetra
.92251 .50316 .92491 .51126 .94627 .50957 .94402 .50145 Mtetra
.595 .792 .974 r
.94402 .50145 .94627 .50957 .9677 .50786 .9656 .49972 Mtetra
.9656 .49972 .9677 .50786 .98921 .50614 .98726 .49798 Mtetra
.89 .768 .72 r
.28038 .62673 .2865 .64532 .30807 .59687 .3019 .58251 Mtetra
.836 .777 .796 r
.3019 .58251 .30807 .59687 .32846 .57361 .32234 .56142 Mtetra
.778 .78 .854 r
.32234 .56142 .32846 .57361 .34843 .56087 .34238 .54996 Mtetra
.728 .78 .894 r
.34238 .54996 .34843 .56087 .36824 .55316 .36228 .54306 Mtetra
.689 .778 .919 r
.36228 .54306 .36824 .55316 .388 .54809 .38215 .53853 Mtetra
.66 .776 .935 r
.38215 .53853 .388 .54809 .40777 .54449 .40202 .5353 Mtetra
.64 .775 .945 r
.40202 .5353 .40777 .54449 .42757 .54174 .42194 .53283 Mtetra
.627 .775 .952 r
.42194 .53283 .42757 .54174 .44742 .53951 .4419 .5308 Mtetra
.617 .776 .957 r
.4419 .5308 .44742 .53951 .46733 .53759 .46193 .52903 Mtetra
.61 .777 .96 r
.46193 .52903 .46733 .53759 .4873 .53587 .48202 .52743 Mtetra
.606 .778 .963 r
.48202 .52743 .4873 .53587 .50733 .53427 .50218 .52592 Mtetra
.602 .779 .965 r
.50218 .52592 .50733 .53427 .52743 .53274 .5224 .52446 Mtetra
.6 .78 .967 r
.5224 .52446 .52743 .53274 .5476 .53126 .54269 .52302 Mtetra
.598 .781 .968 r
.54269 .52302 .5476 .53126 .56783 .52979 .56306 .5216 Mtetra
.597 .782 .969 r
.56306 .5216 .56783 .52979 .58813 .52833 .58349 .52017 Mtetra
.596 .783 .97 r
.58349 .52017 .58813 .52833 .60851 .52687 .60399 .51873 Mtetra
.595 .784 .97 r
.60399 .51873 .60851 .52687 .62895 .5254 .62456 .51728 Mtetra
.595 .785 .971 r
.62456 .51728 .62895 .5254 .64946 .52392 .64521 .51581 Mtetra
.64521 .51581 .64946 .52392 .67004 .52243 .66592 .51432 Mtetra
.595 .786 .972 r
.66592 .51432 .67004 .52243 .69069 .52092 .6867 .51281 Mtetra
.594 .787 .972 r
.6867 .51281 .69069 .52092 .71141 .51939 .70756 .51128 Mtetra
.70756 .51128 .71141 .51939 .7322 .51784 .72849 .50973 Mtetra
.594 .788 .973 r
.72849 .50973 .7322 .51784 .75306 .51628 .74949 .50817 Mtetra
.74949 .50817 .75306 .51628 .77399 .5147 .77056 .50658 Mtetra
.594 .789 .973 r
.77056 .50658 .77399 .5147 .79499 .5131 .7917 .50497 Mtetra
.7917 .50497 .79499 .5131 .81606 .51148 .81291 .50334 Mtetra
.594 .79 .974 r
.81291 .50334 .81606 .51148 .83721 .50985 .8342 .50169 Mtetra
.8342 .50169 .83721 .50985 .85843 .5082 .85556 .50003 Mtetra
.85556 .50003 .85843 .5082 .87972 .50653 .877 .49835 Mtetra
.595 .791 .974 r
.877 .49835 .87972 .50653 .90108 .50485 .8985 .49665 Mtetra
.8985 .49665 .90108 .50485 .92251 .50316 .92008 .49494 Mtetra
.92008 .49494 .92251 .50316 .94402 .50145 .94174 .49321 Mtetra
.94174 .49321 .94402 .50145 .9656 .49972 .96347 .49146 Mtetra
.595 .792 .974 r
.96347 .49146 .9656 .49972 .98726 .49798 .98527 .4897 Mtetra
.881 .764 .729 r
.2742 .60796 .28038 .62673 .3019 .58251 .29568 .56798 Mtetra
.824 .772 .804 r
.29568 .56798 .3019 .58251 .32234 .56142 .31615 .54909 Mtetra
.765 .775 .861 r
.31615 .54909 .32234 .56142 .34238 .54996 .33626 .53891 Mtetra
.715 .774 .899 r
.33626 .53891 .34238 .54996 .36228 .54306 .35625 .53282 Mtetra
.678 .773 .922 r
.35625 .53282 .36228 .54306 .38215 .53853 .37621 .52884 Mtetra
.652 .772 .937 r
.37621 .52884 .38215 .53853 .40202 .5353 .3962 .526 Mtetra
.634 .772 .947 r
.3962 .526 .40202 .5353 .42194 .53283 .41623 .5238 Mtetra
.621 .773 .953 r
.41623 .5238 .42194 .53283 .4419 .5308 .43631 .52197 Mtetra
.613 .774 .958 r
.43631 .52197 .4419 .5308 .46193 .52903 .45646 .52036 Mtetra
.607 .775 .961 r
.45646 .52036 .46193 .52903 .48202 .52743 .47667 .51887 Mtetra
.603 .776 .963 r
.47667 .51887 .48202 .52743 .50218 .52592 .49695 .51745 Mtetra
.6 .778 .965 r
.49695 .51745 .50218 .52592 .5224 .52446 .5173 .51606 Mtetra
.598 .779 .967 r
.5173 .51606 .5224 .52446 .54269 .52302 .53773 .51468 Mtetra
.596 .78 .968 r
.53773 .51468 .54269 .52302 .56306 .5216 .55822 .5133 Mtetra
.596 .781 .969 r
.55822 .5133 .56306 .5216 .58349 .52017 .57878 .5119 Mtetra
.595 .782 .97 r
.57878 .5119 .58349 .52017 .60399 .51873 .59941 .51048 Mtetra
.594 .783 .97 r
.59941 .51048 .60399 .51873 .62456 .51728 .62012 .50905 Mtetra
.594 .784 .971 r
.62012 .50905 .62456 .51728 .64521 .51581 .6409 .50759 Mtetra
.594 .785 .971 r
.6409 .50759 .64521 .51581 .66592 .51432 .66175 .50611 Mtetra
.594 .786 .972 r
.66175 .50611 .66592 .51432 .6867 .51281 .68267 .5046 Mtetra
.68267 .5046 .6867 .51281 .70756 .51128 .70366 .50307 Mtetra
.594 .787 .972 r
.70366 .50307 .70756 .51128 .72849 .50973 .72473 .50152 Mtetra
.594 .787 .973 r
.72473 .50152 .72849 .50973 .74949 .50817 .74587 .49994 Mtetra
.594 .788 .973 r
.74587 .49994 .74949 .50817 .77056 .50658 .76708 .49834 Mtetra
.76708 .49834 .77056 .50658 .7917 .50497 .78836 .49672 Mtetra
.594 .789 .973 r
.78836 .49672 .7917 .50497 .81291 .50334 .80972 .49508 Mtetra
.594 .789 .974 r
.80972 .49508 .81291 .50334 .8342 .50169 .83115 .49342 Mtetra
.594 .79 .974 r
.83115 .49342 .8342 .50169 .85556 .50003 .85266 .49175 Mtetra
.85266 .49175 .85556 .50003 .877 .49835 .87424 .49005 Mtetra
.87424 .49005 .877 .49835 .8985 .49665 .89589 .48833 Mtetra
.594 .791 .974 r
.89589 .48833 .8985 .49665 .92008 .49494 .91762 .4866 Mtetra
.595 .791 .974 r
.91762 .4866 .92008 .49494 .94174 .49321 .93942 .48485 Mtetra
.93942 .48485 .94174 .49321 .96347 .49146 .9613 .48309 Mtetra
.595 .792 .974 r
.9613 .48309 .96347 .49146 .98527 .4897 .98326 .48131 Mtetra
.869 .76 .739 r
.26795 .58901 .2742 .60796 .29568 .56798 .28938 .5533 Mtetra
.809 .767 .814 r
.28938 .5533 .29568 .56798 .31615 .54909 .30988 .53661 Mtetra
.75 .769 .868 r
.30988 .53661 .31615 .54909 .33626 .53891 .33006 .52772 Mtetra
.702 .768 .903 r
.33006 .52772 .33626 .53891 .35625 .53282 .35014 .52246 Mtetra
.667 .768 .925 r
.35014 .52246 .35625 .53282 .37621 .52884 .37021 .51902 Mtetra
.643 .768 .939 r
.37021 .51902 .37621 .52884 .3962 .526 .3903 .51657 Mtetra
.627 .769 .948 r
.3903 .51657 .3962 .526 .41623 .5238 .41044 .51465 Mtetra
.616 .77 .954 r
.41044 .51465 .41623 .5238 .43631 .52197 .43065 .51303 Mtetra
.608 .772 .958 r
.43065 .51303 .43631 .52197 .45646 .52036 .45091 .51157 Mtetra
.603 .773 .962 r
.45091 .51157 .45646 .52036 .47667 .51887 .47125 .5102 Mtetra
.6 .775 .964 r
.47125 .5102 .47667 .51887 .49695 .51745 .49166 .50887 Mtetra
.597 .776 .966 r
.49166 .50887 .49695 .51745 .5173 .51606 .51214 .50755 Mtetra
.596 .778 .967 r
.51214 .50755 .5173 .51606 .53773 .51468 .53269 .50622 Mtetra
.595 .779 .968 r
.53269 .50622 .53773 .51468 .55822 .5133 .55331 .50488 Mtetra
.594 .78 .969 r
.55331 .50488 .55822 .5133 .57878 .5119 .57401 .50352 Mtetra
.594 .782 .97 r
.57401 .50352 .57878 .5119 .59941 .51048 .59477 .50212 Mtetra
.593 .783 .971 r
.59477 .50212 .59941 .51048 .62012 .50905 .61561 .5007 Mtetra
.593 .784 .971 r
.61561 .5007 .62012 .50905 .6409 .50759 .63653 .49925 Mtetra
.593 .784 .972 r
.63653 .49925 .6409 .50759 .66175 .50611 .65751 .49778 Mtetra
.593 .785 .972 r
.65751 .49778 .66175 .50611 .68267 .5046 .67857 .49627 Mtetra
.593 .786 .972 r
.67857 .49627 .68267 .5046 .70366 .50307 .69971 .49474 Mtetra
.593 .787 .973 r
.69971 .49474 .70366 .50307 .72473 .50152 .72091 .49318 Mtetra
.72091 .49318 .72473 .50152 .74587 .49994 .74219 .4916 Mtetra
.593 .788 .973 r
.74219 .4916 .74587 .49994 .76708 .49834 .76355 .48999 Mtetra
.594 .788 .973 r
.76355 .48999 .76708 .49834 .78836 .49672 .78498 .48836 Mtetra
.594 .789 .973 r
.78498 .48836 .78836 .49672 .80972 .49508 .80648 .48671 Mtetra
.594 .789 .974 r
.80648 .48671 .80972 .49508 .83115 .49342 .82806 .48504 Mtetra
.594 .79 .974 r
.82806 .48504 .83115 .49342 .85266 .49175 .84971 .48334 Mtetra
.84971 .48334 .85266 .49175 .87424 .49005 .87144 .48163 Mtetra
.87144 .48163 .87424 .49005 .89589 .48833 .89324 .4799 Mtetra
.594 .791 .974 r
.89324 .4799 .89589 .48833 .91762 .4866 .91512 .47815 Mtetra
.91512 .47815 .91762 .4866 .93942 .48485 .93708 .47638 Mtetra
.93708 .47638 .93942 .48485 .9613 .48309 .95911 .47459 Mtetra
.595 .791 .974 r
.95911 .47459 .9613 .48309 .98326 .48131 .98122 .47279 Mtetra
.856 .754 .75 r
.26165 .56988 .26795 .58901 .28938 .5533 .28301 .53844 Mtetra
.793 .76 .823 r
.28301 .53844 .28938 .5533 .30988 .53661 .30354 .52399 Mtetra
.734 .762 .875 r
.30354 .52399 .30988 .53661 .33006 .52772 .32378 .5164 Mtetra
.688 .762 .908 r
.32378 .5164 .33006 .52772 .35014 .52246 .34395 .51196 Mtetra
.656 .762 .928 r
.34395 .51196 .35014 .52246 .37021 .51902 .36412 .50908 Mtetra
.634 .763 .941 r
.36412 .50908 .37021 .51902 .3903 .51657 .38432 .50701 Mtetra
.619 .765 .949 r
.38432 .50701 .3903 .51657 .41044 .51465 .40458 .50538 Mtetra
.61 .767 .955 r
.40458 .50538 .41044 .51465 .43065 .51303 .4249 .50396 Mtetra
.604 .769 .959 r
.4249 .50396 .43065 .51303 .45091 .51157 .44529 .50266 Mtetra
.6 .771 .962 r
.44529 .50266 .45091 .51157 .47125 .5102 .46576 .50141 Mtetra
.597 .773 .964 r
.46576 .50141 .47125 .5102 .49166 .50887 .48629 .50017 Mtetra
.595 .775 .966 r
.48629 .50017 .49166 .50887 .51214 .50755 .5069 .49892 Mtetra
.594 .777 .967 r
.5069 .49892 .51214 .50755 .53269 .50622 .52758 .49765 Mtetra
.593 .778 .968 r
.52758 .49765 .53269 .50622 .55331 .50488 .54834 .49635 Mtetra
.593 .78 .969 r
.54834 .49635 .55331 .50488 .57401 .50352 .56917 .49501 Mtetra
.592 .781 .97 r
.56917 .49501 .57401 .50352 .59477 .50212 .59007 .49365 Mtetra
.592 .782 .971 r
.59007 .49365 .59477 .50212 .61561 .5007 .61105 .49224 Mtetra
.592 .783 .971 r
.61105 .49224 .61561 .5007 .63653 .49925 .6321 .4908 Mtetra
.592 .784 .972 r
.6321 .4908 .63653 .49925 .65751 .49778 .65322 .48933 Mtetra
.593 .785 .972 r
.65322 .48933 .65751 .49778 .67857 .49627 .67442 .48783 Mtetra
.593 .786 .972 r
.67442 .48783 .67857 .49627 .69971 .49474 .6957 .48629 Mtetra
.593 .786 .973 r
.6957 .48629 .69971 .49474 .72091 .49318 .71705 .48473 Mtetra
.593 .787 .973 r
.71705 .48473 .72091 .49318 .74219 .4916 .73847 .48314 Mtetra
.73847 .48314 .74219 .4916 .76355 .48999 .75997 .48153 Mtetra
.593 .788 .973 r
.75997 .48153 .76355 .48999 .78498 .48836 .78155 .47988 Mtetra
.593 .789 .973 r
.78155 .47988 .78498 .48836 .80648 .48671 .8032 .47822 Mtetra
.594 .789 .974 r
.8032 .47822 .80648 .48671 .82806 .48504 .82492 .47653 Mtetra
.82492 .47653 .82806 .48504 .84971 .48334 .84672 .47482 Mtetra
.594 .79 .974 r
.84672 .47482 .84971 .48334 .87144 .48163 .8686 .47309 Mtetra
.8686 .47309 .87144 .48163 .89324 .4799 .89056 .47134 Mtetra
.89056 .47134 .89324 .4799 .91512 .47815 .91259 .46957 Mtetra
.594 .791 .974 r
.91259 .46957 .91512 .47815 .93708 .47638 .9347 .46778 Mtetra
.9347 .46778 .93708 .47638 .95911 .47459 .95688 .46598 Mtetra
.95688 .46598 .95911 .47459 .98122 .47279 .97915 .46416 Mtetra
.84 .747 .761 r
.25528 .55055 .26165 .56988 .28301 .53844 .27657 .52342 Mtetra
.775 .752 .832 r
.27657 .52342 .28301 .53844 .30354 .52399 .29711 .51121 Mtetra
.717 .754 .882 r
.29711 .51121 .30354 .52399 .32378 .5164 .31743 .50493 Mtetra
.673 .755 .912 r
.31743 .50493 .32378 .5164 .34395 .51196 .33768 .50133 Mtetra
.644 .757 .931 r
.33768 .50133 .34395 .51196 .36412 .50908 .35795 .49901 Mtetra
.625 .759 .943 r
.35795 .49901 .36412 .50908 .38432 .50701 .37827 .49734 Mtetra
.612 .761 .951 r
.37827 .49734 .38432 .50701 .40458 .50538 .39864 .49598 Mtetra
.604 .764 .956 r
.39864 .49598 .40458 .50538 .4249 .50396 .41908 .49478 Mtetra
.599 .767 .96 r
.41908 .49478 .4249 .50396 .44529 .50266 .4396 .49364 Mtetra
.596 .769 .963 r
.4396 .49364 .44529 .50266 .46576 .50141 .46019 .4925 Mtetra
.594 .772 .965 r
.46019 .4925 .46576 .50141 .48629 .50017 .48085 .49136 Mtetra
.593 .774 .966 r
.48085 .49136 .48629 .50017 .5069 .49892 .50159 .49018 Mtetra
.592 .776 .968 r
.50159 .49018 .5069 .49892 .52758 .49765 .52241 .48896 Mtetra
.591 .777 .969 r
.52241 .48896 .52758 .49765 .54834 .49635 .5433 .4877 Mtetra
.591 .779 .969 r
.5433 .4877 .54834 .49635 .56917 .49501 .56426 .4864 Mtetra
.591 .78 .97 r
.56426 .4864 .56917 .49501 .59007 .49365 .5853 .48505 Mtetra
.591 .781 .971 r
.5853 .48505 .59007 .49365 .61105 .49224 .60642 .48366 Mtetra
.591 .783 .971 r
.60642 .48366 .61105 .49224 .6321 .4908 .62761 .48223 Mtetra
.592 .784 .972 r
.62761 .48223 .6321 .4908 .65322 .48933 .64887 .48077 Mtetra
.64887 .48077 .65322 .48933 .67442 .48783 .67022 .47926 Mtetra
.592 .785 .972 r
.67022 .47926 .67442 .48783 .6957 .48629 .69163 .47773 Mtetra
.592 .786 .973 r
.69163 .47773 .6957 .48629 .71705 .48473 .71313 .47616 Mtetra
.592 .787 .973 r
.71313 .47616 .71705 .48473 .73847 .48314 .7347 .47456 Mtetra
.593 .787 .973 r
.7347 .47456 .73847 .48314 .75997 .48153 .75634 .47294 Mtetra
.593 .788 .973 r
.75634 .47294 .75997 .48153 .78155 .47988 .77806 .47129 Mtetra
.77806 .47129 .78155 .47988 .8032 .47822 .79986 .46961 Mtetra
.593 .789 .974 r
.79986 .46961 .8032 .47822 .82492 .47653 .82174 .4679 Mtetra
.82174 .4679 .82492 .47653 .84672 .47482 .84369 .46618 Mtetra
.594 .79 .974 r
.84369 .46618 .84672 .47482 .8686 .47309 .86572 .46443 Mtetra
.86572 .46443 .8686 .47309 .89056 .47134 .88783 .46266 Mtetra
.88783 .46266 .89056 .47134 .91259 .46957 .91002 .46087 Mtetra
.594 .791 .974 r
.91002 .46087 .91259 .46957 .9347 .46778 .93228 .45906 Mtetra
.93228 .45906 .9347 .46778 .95688 .46598 .95463 .45724 Mtetra
.95463 .45724 .95688 .46598 .97915 .46416 .97705 .45539 Mtetra
.822 .738 .772 r
.24885 .53103 .25528 .55055 .27657 .52342 .27005 .50823 Mtetra
.754 .743 .842 r
.27005 .50823 .27657 .52342 .29711 .51121 .29062 .49827 Mtetra
.698 .745 .888 r
.29062 .49827 .29711 .51121 .31743 .50493 .31099 .49332 Mtetra
.658 .748 .916 r
.31099 .49332 .31743 .50493 .33768 .50133 .33133 .49056 Mtetra
.631 .751 .934 r
.33133 .49056 .33768 .50133 .35795 .49901 .3517 .48881 Mtetra
.615 .754 .944 r
.3517 .48881 .35795 .49901 .37827 .49734 .37213 .48753 Mtetra
.605 .758 .952 r
.37213 .48753 .37827 .49734 .39864 .49598 .39262 .48646 Mtetra
.598 .761 .957 r
.39262 .48646 .39864 .49598 .41908 .49478 .41318 .48547 Mtetra
.594 .764 .96 r
.41318 .48547 .41908 .49478 .4396 .49364 .43383 .48448 Mtetra
.592 .767 .963 r
.43383 .48448 .4396 .49364 .46019 .4925 .45454 .48347 Mtetra
.591 .77 .965 r
.45454 .48347 .46019 .4925 .48085 .49136 .47534 .48242 Mtetra
.59 .772 .967 r
.47534 .48242 .48085 .49136 .50159 .49018 .49621 .48131 Mtetra
.59 .775 .968 r
.49621 .48131 .50159 .49018 .52241 .48896 .51716 .48015 Mtetra
.59 .776 .969 r
.51716 .48015 .52241 .48896 .5433 .4877 .53818 .47893 Mtetra
.59 .778 .97 r
.53818 .47893 .5433 .4877 .56426 .4864 .55928 .47766 Mtetra
.59 .78 .97 r
.55928 .47766 .56426 .4864 .5853 .48505 .58046 .47633 Mtetra
.59 .781 .971 r
.58046 .47633 .5853 .48505 .60642 .48366 .60172 .47496 Mtetra
.591 .782 .971 r
.60172 .47496 .60642 .48366 .62761 .48223 .62305 .47354 Mtetra
.591 .783 .972 r
.62305 .47354 .62761 .48223 .64887 .48077 .64446 .47208 Mtetra
.591 .784 .972 r
.64446 .47208 .64887 .48077 .67022 .47926 .66595 .47058 Mtetra
.591 .785 .972 r
.66595 .47058 .67022 .47926 .69163 .47773 .68751 .46904 Mtetra
.592 .786 .973 r
.68751 .46904 .69163 .47773 .71313 .47616 .70915 .46747 Mtetra
.70915 .46747 .71313 .47616 .7347 .47456 .73087 .46586 Mtetra
.592 .787 .973 r
.73087 .46586 .7347 .47456 .75634 .47294 .75266 .46423 Mtetra
.592 .788 .973 r
.75266 .46423 .75634 .47294 .77806 .47129 .77453 .46256 Mtetra
.593 .788 .973 r
.77453 .46256 .77806 .47129 .79986 .46961 .79648 .46087 Mtetra
.593 .789 .974 r
.79648 .46087 .79986 .46961 .82174 .4679 .81851 .45915 Mtetra
.81851 .45915 .82174 .4679 .84369 .46618 .84062 .45741 Mtetra
.84062 .45741 .84369 .46618 .86572 .46443 .8628 .45564 Mtetra
.593 .79 .974 r
.8628 .45564 .86572 .46443 .88783 .46266 .88507 .45386 Mtetra
.594 .79 .974 r
.88507 .45386 .88783 .46266 .91002 .46087 .90741 .45205 Mtetra
.594 .791 .974 r
.90741 .45205 .91002 .46087 .93228 .45906 .92983 .45022 Mtetra
.92983 .45022 .93228 .45906 .95463 .45724 .95233 .44837 Mtetra
.95233 .44837 .95463 .45724 .97705 .45539 .97492 .4465 Mtetra
.799 .728 .785 r
.24236 .51132 .24885 .53103 .27005 .50823 .26346 .49287 Mtetra
.731 .732 .851 r
.26346 .49287 .27005 .50823 .29062 .49827 .28404 .48518 Mtetra
.677 .735 .894 r
.28404 .48518 .29062 .49827 .31099 .49332 .30447 .48156 Mtetra
.641 .739 .92 r
.30447 .48156 .31099 .49332 .33133 .49056 .3249 .47965 Mtetra
.619 .744 .936 r
.3249 .47965 .33133 .49056 .3517 .48881 .34537 .47847 Mtetra
.605 .749 .946 r
.34537 .47847 .3517 .48881 .37213 .48753 .36591 .47759 Mtetra
.597 .754 .953 r
.36591 .47759 .37213 .48753 .39262 .48646 .38652 .47681 Mtetra
.592 .758 .958 r
.38652 .47681 .39262 .48646 .41318 .48547 .40721 .47603 Mtetra
.59 .762 .961 r
.40721 .47603 .41318 .48547 .43383 .48448 .42797 .47521 Mtetra
.588 .766 .963 r
.42797 .47521 .43383 .48448 .45454 .48347 .44882 .47432 Mtetra
.588 .769 .965 r
.44882 .47432 .45454 .48347 .47534 .48242 .46974 .47336 Mtetra
.588 .771 .967 r
.46974 .47336 .47534 .48242 .49621 .48131 .49075 .47232 Mtetra
.588 .773 .968 r
.49075 .47232 .49621 .48131 .51716 .48015 .51183 .47121 Mtetra
.588 .776 .969 r
.51183 .47121 .51716 .48015 .53818 .47893 .533 .47004 Mtetra
.588 .777 .97 r
.533 .47004 .53818 .47893 .55928 .47766 .55424 .46879 Mtetra
.589 .779 .97 r
.55424 .46879 .55928 .47766 .58046 .47633 .57556 .46749 Mtetra
.589 .78 .971 r
.57556 .46749 .58046 .47633 .60172 .47496 .59696 .46614 Mtetra
.59 .782 .971 r
.59696 .46614 .60172 .47496 .62305 .47354 .61843 .46473 Mtetra
.59 .783 .972 r
.61843 .46473 .62305 .47354 .64446 .47208 .63999 .46327 Mtetra
.59 .784 .972 r
.63999 .46327 .64446 .47208 .66595 .47058 .66162 .46177 Mtetra
.591 .785 .972 r
.66162 .46177 .66595 .47058 .68751 .46904 .68333 .46023 Mtetra
.591 .785 .973 r
.68333 .46023 .68751 .46904 .70915 .46747 .70512 .45865 Mtetra
.592 .786 .973 r
.70512 .45865 .70915 .46747 .73087 .46586 .72698 .45704 Mtetra
.592 .787 .973 r
.72698 .45704 .73087 .46586 .75266 .46423 .74893 .45539 Mtetra
.74893 .45539 .75266 .46423 .77453 .46256 .77095 .45371 Mtetra
.592 .788 .974 r
.77095 .45371 .77453 .46256 .79648 .46087 .79305 .45201 Mtetra
.593 .788 .974 r
.79305 .45201 .79648 .46087 .81851 .45915 .81524 .45027 Mtetra
.593 .789 .974 r
.81524 .45027 .81851 .45915 .84062 .45741 .8375 .44851 Mtetra
.8375 .44851 .84062 .45741 .8628 .45564 .85984 .44673 Mtetra
.593 .79 .974 r
.85984 .44673 .8628 .45564 .88507 .45386 .88226 .44492 Mtetra
.88226 .44492 .88507 .45386 .90741 .45205 .90476 .44309 Mtetra
.594 .79 .974 r
.90476 .44309 .90741 .45205 .92983 .45022 .92735 .44124 Mtetra
.594 .791 .974 r
.92735 .44124 .92983 .45022 .95233 .44837 .95001 .43937 Mtetra
.95001 .43937 .95233 .44837 .97492 .4465 .97276 .43748 Mtetra
.772 .714 .797 r
.2358 .49141 .24236 .51132 .26346 .49287 .2568 .47733 Mtetra
.704 .718 .86 r
.2568 .47733 .26346 .49287 .28404 .48518 .27738 .47192 Mtetra
.654 .724 .9 r
.27738 .47192 .28404 .48518 .30447 .48156 .29787 .46965 Mtetra
.623 .73 .924 r
.29787 .46965 .30447 .48156 .3249 .47965 .31838 .4686 Mtetra
.605 .737 .938 r
.31838 .4686 .3249 .47965 .34537 .47847 .33896 .46799 Mtetra
.595 .744 .948 r
.33896 .46799 .34537 .47847 .36591 .47759 .3596 .46751 Mtetra
.589 .75 .954 r
.3596 .46751 .36591 .47759 .38652 .47681 .38033 .46702 Mtetra
.586 .755 .958 r
.38033 .46702 .38652 .47681 .40721 .47603 .40114 .46646 Mtetra
.585 .76 .962 r
.40114 .46646 .40721 .47603 .42797 .47521 .42204 .4658 Mtetra
.585 .764 .964 r
.42204 .4658 .42797 .47521 .44882 .47432 .44302 .46504 Mtetra
.585 .767 .966 r
.44302 .46504 .44882 .47432 .46974 .47336 .46407 .46417 Mtetra
.585 .77 .967 r
.46407 .46417 .46974 .47336 .49075 .47232 .48522 .46321 Mtetra
.586 .772 .968 r
.48522 .46321 .49075 .47232 .51183 .47121 .50644 .46215 Mtetra
.586 .775 .969 r
.50644 .46215 .51183 .47121 .533 .47004 .52774 .46102 Mtetra
.587 .777 .97 r
.52774 .46102 .533 .47004 .55424 .46879 .54912 .45981 Mtetra
.588 .778 .971 r
.54912 .45981 .55424 .46879 .57556 .46749 .57058 .45853 Mtetra
.588 .78 .971 r
.57058 .45853 .57556 .46749 .59696 .46614 .59213 .45719 Mtetra
.589 .781 .972 r
.59213 .45719 .59696 .46614 .61843 .46473 .61375 .45579 Mtetra
.589 .782 .972 r
.61375 .45579 .61843 .46473 .63999 .46327 .63545 .45434 Mtetra
.59 .783 .972 r
.63545 .45434 .63999 .46327 .66162 .46177 .65723 .45284 Mtetra
.59 .784 .973 r
.65723 .45284 .66162 .46177 .68333 .46023 .67909 .45129 Mtetra
.591 .785 .973 r
.67909 .45129 .68333 .46023 .70512 .45865 .70102 .44971 Mtetra
.591 .786 .973 r
.70102 .44971 .70512 .45865 .72698 .45704 .72304 .44809 Mtetra
.72304 .44809 .72698 .45704 .74893 .45539 .74514 .44643 Mtetra
.592 .787 .973 r
.74514 .44643 .74893 .45539 .77095 .45371 .76732 .44474 Mtetra
.592 .788 .974 r
.76732 .44474 .77095 .45371 .79305 .45201 .78958 .44302 Mtetra
.78958 .44302 .79305 .45201 .81524 .45027 .81191 .44127 Mtetra
.593 .789 .974 r
.81191 .44127 .81524 .45027 .8375 .44851 .83433 .43949 Mtetra
.83433 .43949 .8375 .44851 .85984 .44673 .85683 .43768 Mtetra
.593 .79 .974 r
.85683 .43768 .85984 .44673 .88226 .44492 .87941 .43586 Mtetra
.87941 .43586 .88226 .44492 .90476 .44309 .90208 .43401 Mtetra
.90208 .43401 .90476 .44309 .92735 .44124 .92482 .43213 Mtetra
.594 .791 .974 r
.92482 .43213 .92735 .44124 .95001 .43937 .94765 .43024 Mtetra
.94765 .43024 .95001 .43937 .97276 .43748 .97056 .42832 Mtetra
.74 .696 .81 r
.22918 .4713 .2358 .49141 .2568 .47733 .25005 .46161 Mtetra
.673 .702 .869 r
.25005 .46161 .2568 .47733 .27738 .47192 .27064 .4585 Mtetra
.63 .711 .905 r
.27064 .4585 .27738 .47192 .29787 .46965 .29118 .45759 Mtetra
.605 .721 .927 r
.29118 .45759 .29787 .46965 .31838 .4686 .31178 .4574 Mtetra
.591 .73 .94 r
.31178 .4574 .31838 .4686 .33896 .46799 .33245 .45737 Mtetra
.584 .738 .949 r
.33245 .45737 .33896 .46799 .3596 .46751 .35321 .4573 Mtetra
.581 .746 .955 r
.35321 .4573 .3596 .46751 .38033 .46702 .37406 .45711 Mtetra
.58 .752 .959 r
.37406 .45711 .38033 .46702 .40114 .46646 .395 .45676 Mtetra
.58 .757 .962 r
.395 .45676 .40114 .46646 .42204 .4658 .41602 .45626 Mtetra
.581 .762 .964 r
.41602 .45626 .42204 .4658 .44302 .46504 .43713 .45562 Mtetra
.582 .765 .966 r
.43713 .45562 .44302 .46504 .46407 .46417 .45832 .45485 Mtetra
.583 .768 .967 r
.45832 .45485 .46407 .46417 .48522 .46321 .4796 .45396 Mtetra
.584 .771 .969 r
.4796 .45396 .48522 .46321 .50644 .46215 .50096 .45296 Mtetra
.585 .774 .969 r
.50096 .45296 .50644 .46215 .52774 .46102 .52241 .45187 Mtetra
.586 .776 .97 r
.52241 .45187 .52774 .46102 .54912 .45981 .54393 .45069 Mtetra
.586 .778 .971 r
.54393 .45069 .54912 .45981 .57058 .45853 .56554 .44943 Mtetra
.587 .779 .971 r
.56554 .44943 .57058 .45853 .59213 .45719 .58723 .44811 Mtetra
.588 .781 .972 r
.58723 .44811 .59213 .45719 .61375 .45579 .60899 .44672 Mtetra
.589 .782 .972 r
.60899 .44672 .61375 .45579 .63545 .45434 .63084 .44527 Mtetra
.589 .783 .972 r
.63084 .44527 .63545 .45434 .65723 .45284 .65277 .44377 Mtetra
.59 .784 .973 r
.65277 .44377 .65723 .45284 .67909 .45129 .67478 .44222 Mtetra
.59 .785 .973 r
.67478 .44222 .67909 .45129 .70102 .44971 .69687 .44063 Mtetra
.591 .786 .973 r
.69687 .44063 .70102 .44971 .72304 .44809 .71904 .439 Mtetra
.71904 .439 .72304 .44809 .74514 .44643 .7413 .43733 Mtetra
.591 .787 .973 r
.7413 .43733 .74514 .44643 .76732 .44474 .76363 .43563 Mtetra
.592 .788 .974 r
.76363 .43563 .76732 .44474 .78958 .44302 .78605 .43389 Mtetra
.78605 .43389 .78958 .44302 .81191 .44127 .80854 .43212 Mtetra
.592 .789 .974 r
.80854 .43212 .81191 .44127 .83433 .43949 .83112 .43033 Mtetra
.593 .789 .974 r
.83112 .43033 .83433 .43949 .85683 .43768 .85378 .4285 Mtetra
.85378 .4285 .85683 .43768 .87941 .43586 .87653 .42666 Mtetra
.593 .79 .974 r
.87653 .42666 .87941 .43586 .90208 .43401 .89935 .42478 Mtetra
.89935 .42478 .90208 .43401 .92482 .43213 .92226 .42289 Mtetra
.593 .791 .974 r
.92226 .42289 .92482 .43213 .94765 .43024 .94526 .42097 Mtetra
.594 .791 .974 r
.94526 .42097 .94765 .43024 .97056 .42832 .96833 .41903 Mtetra
.699 .674 .822 r
.22248 .45099 .22918 .4713 .25005 .46161 .24323 .4457 Mtetra
.638 .684 .876 r
.24323 .4457 .25005 .46161 .27064 .4585 .26381 .44492 Mtetra
.603 .697 .909 r
.26381 .44492 .27064 .4585 .29118 .45759 .28441 .44537 Mtetra
.585 .71 .929 r
.28441 .44537 .29118 .45759 .31178 .4574 .30509 .44605 Mtetra
.577 .722 .942 r
.30509 .44605 .31178 .4574 .33245 .45737 .32586 .44661 Mtetra
.574 .733 .95 r
.32586 .44661 .33245 .45737 .35321 .4573 .34674 .44695 Mtetra
.573 .741 .956 r
.34674 .44695 .35321 .4573 .37406 .45711 .3677 .44705 Mtetra
.574 .749 .96 r
.3677 .44705 .37406 .45711 .395 .45676 .38877 .44692 Mtetra
.575 .754 .963 r
.38877 .44692 .395 .45676 .41602 .45626 .40992 .44659 Mtetra
.577 .759 .965 r
.40992 .44659 .41602 .45626 .43713 .45562 .43116 .44608 Mtetra
.579 .764 .966 r
.43116 .44608 .43713 .45562 .45832 .45485 .45249 .4454 Mtetra
.58 .767 .968 r
.45249 .4454 .45832 .45485 .4796 .45396 .47391 .44458 Mtetra
.582 .77 .969 r
.47391 .44458 .4796 .45396 .50096 .45296 .49541 .44364 Mtetra
.583 .773 .97 r
.49541 .44364 .50096 .45296 .52241 .45187 .517 .44259 Mtetra
.584 .775 .97 r
.517 .44259 .52241 .45187 .54393 .45069 .53867 .44144 Mtetra
.585 .777 .971 r
.53867 .44144 .54393 .45069 .56554 .44943 .56042 .44021 Mtetra
.586 .779 .971 r
.56042 .44021 .56554 .44943 .58723 .44811 .58225 .4389 Mtetra
.587 .78 .972 r
.58225 .4389 .58723 .44811 .60899 .44672 .60417 .43752 Mtetra
.588 .781 .972 r
.60417 .43752 .60899 .44672 .63084 .44527 .62617 .43607 Mtetra
.588 .782 .972 r
.62617 .43607 .63084 .44527 .65277 .44377 .64825 .43457 Mtetra
.589 .783 .973 r
.64825 .43457 .65277 .44377 .67478 .44222 .67041 .43302 Mtetra
.59 .784 .973 r
.67041 .43302 .67478 .44222 .69687 .44063 .69266 .43142 Mtetra
.59 .785 .973 r
.69266 .43142 .69687 .44063 .71904 .439 .71499 .42978 Mtetra
.591 .786 .973 r
.71499 .42978 .71904 .439 .7413 .43733 .7374 .4281 Mtetra
.591 .787 .973 r
.7374 .4281 .7413 .43733 .76363 .43563 .75989 .42638 Mtetra
.591 .787 .974 r
.75989 .42638 .76363 .43563 .78605 .43389 .78246 .42463 Mtetra
.592 .788 .974 r
.78246 .42463 .78605 .43389 .80854 .43212 .80512 .42285 Mtetra
.80512 .42285 .80854 .43212 .83112 .43033 .82786 .42103 Mtetra
.592 .789 .974 r
.82786 .42103 .83112 .43033 .85378 .4285 .85069 .41919 Mtetra
.593 .789 .974 r
.85069 .41919 .85378 .4285 .87653 .42666 .87359 .41732 Mtetra
.593 .79 .974 r
.87359 .41732 .87653 .42666 .89935 .42478 .89659 .41542 Mtetra
.89659 .41542 .89935 .42478 .92226 .42289 .91966 .4135 Mtetra
.91966 .4135 .92226 .42289 .94526 .42097 .94283 .41156 Mtetra
.593 .791 .974 r
.94283 .41156 .94526 .42097 .96833 .41903 .96607 .4096 Mtetra
.65 .645 .832 r
.21572 .43047 .22248 .45099 .24323 .4457 .23633 .42961 Mtetra
.598 .661 .882 r
.23633 .42961 .24323 .4457 .26381 .44492 .2569 .43116 Mtetra
.574 .681 .913 r
.2569 .43116 .26381 .44492 .28441 .44537 .27755 .43299 Mtetra
.564 .699 .932 r
.27755 .43299 .28441 .44537 .30509 .44605 .29831 .43455 Mtetra
.562 .714 .943 r
.29831 .43455 .30509 .44605 .32586 .44661 .31918 .4357 Mtetra
.563 .727 .951 r
.31918 .4357 .32586 .44661 .34674 .44695 .34017 .43646 Mtetra
.565 .737 .957 r
.34017 .43646 .34674 .44695 .3677 .44705 .36126 .43686 Mtetra
.568 .745 .96 r
.36126 .43686 .3677 .44705 .38877 .44692 .38245 .43695 Mtetra
.571 .752 .963 r
.38245 .43695 .38877 .44692 .40992 .44659 .40373 .43678 Mtetra
.573 .757 .965 r
.40373 .43678 .40992 .44659 .43116 .44608 .42511 .43639 Mtetra
.576 .762 .967 r
.42511 .43639 .43116 .44608 .45249 .4454 .44658 .43581 Mtetra
.578 .766 .968 r
.44658 .43581 .45249 .4454 .47391 .44458 .46813 .43507 Mtetra
.58 .769 .969 r
.46813 .43507 .47391 .44458 .49541 .44364 .48978 .43418 Mtetra
.581 .772 .97 r
.48978 .43418 .49541 .44364 .517 .44259 .51151 .43318 Mtetra
.583 .774 .97 r
.51151 .43318 .517 .44259 .53867 .44144 .53333 .43206 Mtetra
.584 .776 .971 r
.53333 .43206 .53867 .44144 .56042 .44021 .55523 .43085 Mtetra
.585 .778 .971 r
.55523 .43085 .56042 .44021 .58225 .4389 .57721 .42955 Mtetra
.586 .779 .972 r
.57721 .42955 .58225 .4389 .60417 .43752 .59928 .42818 Mtetra
.587 .781 .972 r
.59928 .42818 .60417 .43752 .62617 .43607 .62143 .42674 Mtetra
.588 .782 .972 r
.62143 .42674 .62617 .43607 .64825 .43457 .64366 .42524 Mtetra
.588 .783 .973 r
.64366 .42524 .64825 .43457 .67041 .43302 .66598 .42369 Mtetra
.589 .784 .973 r
.66598 .42369 .67041 .43302 .69266 .43142 .68838 .42208 Mtetra
.59 .785 .973 r
.68838 .42208 .69266 .43142 .71499 .42978 .71087 .42043 Mtetra
.59 .786 .973 r
.71087 .42043 .71499 .42978 .7374 .4281 .73344 .41874 Mtetra
.591 .786 .973 r
.73344 .41874 .7374 .4281 .75989 .42638 .75609 .417 Mtetra
.591 .787 .974 r
.75609 .417 .75989 .42638 .78246 .42463 .77883 .41523 Mtetra
.591 .788 .974 r
.77883 .41523 .78246 .42463 .80512 .42285 .80165 .41343 Mtetra
.592 .788 .974 r
.80165 .41343 .80512 .42285 .82786 .42103 .82455 .4116 Mtetra
.592 .789 .974 r
.82455 .4116 .82786 .42103 .85069 .41919 .84754 .40973 Mtetra
.84754 .40973 .85069 .41919 .87359 .41732 .87062 .40784 Mtetra
.593 .79 .974 r
.87062 .40784 .87359 .41732 .89659 .41542 .89378 .40592 Mtetra
.89378 .40592 .89659 .41542 .91966 .4135 .91703 .40398 Mtetra
.91703 .40398 .91966 .4135 .94283 .41156 .94036 .40201 Mtetra
.593 .791 .974 r
.94036 .40201 .94283 .41156 .96607 .4096 .96378 .40002 Mtetra
.589 .608 .839 r
.2089 .40974 .21572 .43047 .23633 .42961 .22935 .41333 Mtetra
.553 .635 .886 r
.22935 .41333 .23633 .42961 .2569 .43116 .2499 .41723 Mtetra
.542 .663 .915 r
.2499 .41723 .2569 .43116 .27755 .43299 .2706 .42045 Mtetra
.542 .686 .933 r
.2706 .42045 .27755 .43299 .29831 .43455 .29144 .42289 Mtetra
.546 .706 .945 r
.29144 .42289 .29831 .43455 .31918 .4357 .31241 .42464 Mtetra
.551 .721 .952 r
.31241 .42464 .31918 .4357 .34017 .43646 .33351 .42582 Mtetra
.556 .732 .957 r
.33351 .42582 .34017 .43646 .36126 .43686 .35472 .42652 Mtetra
.561 .742 .961 r
.35472 .42652 .36126 .43686 .38245 .43695 .37604 .42684 Mtetra
.566 .749 .964 r
.37604 .42684 .38245 .43695 .40373 .43678 .39746 .42684 Mtetra
.569 .755 .966 r
.39746 .42684 .40373 .43678 .42511 .43639 .41897 .42657 Mtetra
.572 .76 .967 r
.41897 .42657 .42511 .43639 .44658 .43581 .44058 .42609 Mtetra
.575 .764 .968 r
.44058 .42609 .44658 .43581 .46813 .43507 .46228 .42542 Mtetra
.577 .768 .969 r
.46228 .42542 .46813 .43507 .48978 .43418 .48407 .42459 Mtetra
.579 .771 .97 r
.48407 .42459 .48978 .43418 .51151 .43318 .50594 .42362 Mtetra
.581 .773 .971 r
.50594 .42362 .51151 .43318 .53333 .43206 .52791 .42254 Mtetra
.583 .775 .971 r
.52791 .42254 .53333 .43206 .55523 .43085 .54996 .42135 Mtetra
.584 .777 .971 r
.54996 .42135 .55523 .43085 .57721 .42955 .57209 .42007 Mtetra
.585 .779 .972 r
.57209 .42007 .57721 .42955 .59928 .42818 .59431 .41871 Mtetra
.586 .78 .972 r
.59431 .41871 .59928 .42818 .62143 .42674 .61662 .41727 Mtetra
.587 .782 .972 r
.61662 .41727 .62143 .42674 .64366 .42524 .63901 .41577 Mtetra
.588 .783 .973 r
.63901 .41577 .64366 .42524 .66598 .42369 .66148 .41421 Mtetra
.589 .784 .973 r
.66148 .41421 .66598 .42369 .68838 .42208 .68405 .4126 Mtetra
.589 .785 .973 r
.68405 .4126 .68838 .42208 .71087 .42043 .70669 .41094 Mtetra
.59 .786 .973 r
.70669 .41094 .71087 .42043 .73344 .41874 .72942 .40923 Mtetra
.72942 .40923 .73344 .41874 .75609 .417 .75224 .40748 Mtetra
.591 .787 .974 r
.75224 .40748 .75609 .417 .77883 .41523 .77514 .4057 Mtetra
.77514 .4057 .77883 .41523 .80165 .41343 .79812 .40387 Mtetra
.592 .788 .974 r
.79812 .40387 .80165 .41343 .82455 .4116 .82119 .40202 Mtetra
.592 .789 .974 r
.82119 .40202 .82455 .4116 .84754 .40973 .84435 .40013 Mtetra
.84435 .40013 .84754 .40973 .87062 .40784 .8676 .39822 Mtetra
.8676 .39822 .87062 .40784 .89378 .40592 .89093 .39628 Mtetra
.593 .79 .974 r
.89093 .39628 .89378 .40592 .91703 .40398 .91435 .39431 Mtetra
.91435 .39431 .91703 .40398 .94036 .40201 .93785 .39232 Mtetra
.593 .791 .974 r
.93785 .39232 .94036 .40201 .96378 .40002 .96145 .3903 Mtetra
.513 .561 .841 r
.202 .38879 .2089 .40974 .22935 .41333 .22229 .39686 Mtetra
.501 .603 .887 r
.22229 .39686 .22935 .41333 .2499 .41723 .24281 .40312 Mtetra
.507 .642 .916 r
.24281 .40312 .2499 .41723 .2706 .42045 .26355 .40775 Mtetra
.518 .673 .934 r
.26355 .40775 .2706 .42045 .29144 .42289 .28447 .41108 Mtetra
.529 .696 .945 r
.28447 .41108 .29144 .42289 .31241 .42464 .30555 .41343 Mtetra
.539 .714 .953 r
.30555 .41343 .31241 .42464 .33351 .42582 .32676 .41503 Mtetra
.548 .728 .958 r
.32676 .41503 .33351 .42582 .35472 .42652 .34809 .41603 Mtetra
.555 .738 .961 r
.34809 .41603 .35472 .42652 .37604 .42684 .36954 .41658 Mtetra
.561 .746 .964 r
.36954 .41658 .37604 .42684 .39746 .42684 .39109 .41675 Mtetra
.565 .753 .966 r
.39109 .41675 .39746 .42684 .41897 .42657 .41274 .41661 Mtetra
.569 .759 .967 r
.41274 .41661 .41897 .42657 .44058 .42609 .43449 .41623 Mtetra
.573 .763 .968 r
.43449 .41623 .44058 .42609 .46228 .42542 .45633 .41563 Mtetra
.575 .767 .969 r
.45633 .41563 .46228 .42542 .48407 .42459 .47827 .41486 Mtetra
.578 .77 .97 r
.47827 .41486 .48407 .42459 .50594 .42362 .50029 .41393 Mtetra
.58 .772 .971 r
.50029 .41393 .50594 .42362 .52791 .42254 .52241 .41288 Mtetra
.581 .775 .971 r
.52241 .41288 .52791 .42254 .54996 .42135 .54461 .41171 Mtetra
.583 .777 .972 r
.54461 .41171 .54996 .42135 .57209 .42007 .5669 .41044 Mtetra
.584 .778 .972 r
.5669 .41044 .57209 .42007 .59431 .41871 .58927 .40909 Mtetra
.585 .78 .972 r
.58927 .40909 .59431 .41871 .61662 .41727 .61174 .40766 Mtetra
.586 .781 .973 r
.61174 .40766 .61662 .41727 .63901 .41577 .63428 .40616 Mtetra
.587 .782 .973 r
.63428 .40616 .63901 .41577 .66148 .41421 .65692 .40459 Mtetra
.588 .783 .973 r
.65692 .40459 .66148 .41421 .68405 .4126 .67964 .40297 Mtetra
.589 .784 .973 r
.67964 .40297 .68405 .4126 .70669 .41094 .70245 .4013 Mtetra
.589 .785 .973 r
.70245 .4013 .70669 .41094 .72942 .40923 .72534 .39958 Mtetra
.59 .786 .974 r
.72534 .39958 .72942 .40923 .75224 .40748 .74832 .39782 Mtetra
.59 .787 .974 r
.74832 .39782 .75224 .40748 .77514 .4057 .77139 .39601 Mtetra
.591 .787 .974 r
.77139 .39601 .77514 .4057 .79812 .40387 .79454 .39417 Mtetra
.591 .788 .974 r
.79454 .39417 .79812 .40387 .82119 .40202 .81779 .3923 Mtetra
.592 .788 .974 r
.81779 .3923 .82119 .40202 .84435 .40013 .84111 .39039 Mtetra
.592 .789 .974 r
.84111 .39039 .84435 .40013 .8676 .39822 .86453 .38845 Mtetra
.86453 .38845 .8676 .39822 .89093 .39628 .88804 .38648 Mtetra
.593 .79 .974 r
.88804 .38648 .89093 .39628 .91435 .39431 .91163 .38449 Mtetra
.91163 .38449 .91435 .39431 .93785 .39232 .93531 .38247 Mtetra
.93531 .38247 .93785 .39232 .96145 .3903 .95908 .38043 Mtetra
.422 .5 .835 r
.19503 .36764 .202 .38879 .22229 .39686 .21514 .38019 Mtetra
.442 .567 .885 r
.21514 .38019 .22229 .39686 .24281 .40312 .23563 .38884 Mtetra
.469 .62 .916 r
.23563 .38884 .24281 .40312 .26355 .40775 .25642 .39487 Mtetra
.493 .659 .934 r
.25642 .39487 .26355 .40775 .28447 .41108 .27741 .39911 Mtetra
.512 .687 .946 r
.27741 .39911 .28447 .41108 .30555 .41343 .29859 .40206 Mtetra
.527 .707 .953 r
.29859 .40206 .30555 .41343 .32676 .41503 .31991 .40409 Mtetra
.539 .723 .958 r
.31991 .40409 .32676 .41503 .34809 .41603 .34137 .4054 Mtetra
.548 .735 .962 r
.34137 .4054 .34809 .41603 .36954 .41658 .36294 .40617 Mtetra
.555 .744 .964 r
.36294 .40617 .36954 .41658 .39109 .41675 .38463 .40651 Mtetra
.561 .751 .966 r
.38463 .40651 .39109 .41675 .41274 .41661 .40642 .4065 Mtetra
.566 .757 .968 r
.40642 .4065 .41274 .41661 .43449 .41623 .42831 .40622 Mtetra
.57 .762 .969 r
.42831 .40622 .43449 .41623 .45633 .41563 .4503 .4057 Mtetra
.573 .766 .97 r
.4503 .4057 .45633 .41563 .47827 .41486 .47238 .40498 Mtetra
.576 .769 .97 r
.47238 .40498 .47827 .41486 .50029 .41393 .49456 .4041 Mtetra
.578 .772 .971 r
.49456 .4041 .50029 .41393 .52241 .41288 .51683 .40308 Mtetra
.58 .774 .971 r
.51683 .40308 .52241 .41288 .54461 .41171 .53918 .40193 Mtetra
.582 .776 .972 r
.53918 .40193 .54461 .41171 .5669 .41044 .56163 .40068 Mtetra
.583 .778 .972 r
.56163 .40068 .5669 .41044 .58927 .40909 .58416 .39933 Mtetra
.585 .78 .972 r
.58416 .39933 .58927 .40909 .61174 .40766 .60678 .3979 Mtetra
.586 .781 .973 r
.60678 .3979 .61174 .40766 .63428 .40616 .62949 .3964 Mtetra
.587 .782 .973 r
.62949 .3964 .63428 .40616 .65692 .40459 .65229 .39483 Mtetra
.588 .783 .973 r
.65229 .39483 .65692 .40459 .67964 .40297 .67517 .3932 Mtetra
.588 .784 .973 r
.67517 .3932 .67964 .40297 .70245 .4013 .69814 .39152 Mtetra
.589 .785 .973 r
.69814 .39152 .70245 .4013 .72534 .39958 .7212 .38978 Mtetra
.59 .786 .974 r
.7212 .38978 .72534 .39958 .74832 .39782 .74435 .388 Mtetra
.74435 .388 .74832 .39782 .77139 .39601 .76759 .38618 Mtetra
.591 .787 .974 r
.76759 .38618 .77139 .39601 .79454 .39417 .79091 .38432 Mtetra
.591 .788 .974 r
.79091 .38432 .79454 .39417 .81779 .3923 .81432 .38242 Mtetra
.81432 .38242 .81779 .3923 .84111 .39039 .83783 .38049 Mtetra
.592 .789 .974 r
.83783 .38049 .84111 .39039 .86453 .38845 .86142 .37853 Mtetra
.86142 .37853 .86453 .38845 .88804 .38648 .8851 .37654 Mtetra
.592 .79 .974 r
.8851 .37654 .88804 .38648 .91163 .38449 .90887 .37452 Mtetra
.593 .79 .974 r
.90887 .37452 .91163 .38449 .93531 .38247 .93273 .37248 Mtetra
.93273 .37248 .93531 .38247 .95908 .38043 .95668 .3704 Mtetra
.312 .425 .816 r
.18798 .34626 .19503 .36764 .21514 .38019 .2079 .36332 Mtetra
.377 .524 .877 r
.2079 .36332 .21514 .38019 .23563 .38884 .22836 .37436 Mtetra
.429 .595 .913 r
.22836 .37436 .23563 .38884 .25642 .39487 .24918 .38182 Mtetra
.467 .643 .934 r
.24918 .38182 .25642 .39487 .27741 .39911 .27026 .38697 Mtetra
.495 .677 .946 r
.27026 .38697 .27741 .39911 .29859 .40206 .29153 .39054 Mtetra
.515 .701 .954 r
.29153 .39054 .29859 .40206 .31991 .40409 .31297 .39299 Mtetra
.53 .718 .959 r
.31297 .39299 .31991 .40409 .34137 .4054 .33455 .39461 Mtetra
.541 .731 .962 r
.33455 .39461 .34137 .4054 .36294 .40617 .35626 .39561 Mtetra
.55 .741 .965 r
.35626 .39561 .36294 .40617 .38463 .40651 .37808 .39612 Mtetra
.557 .749 .967 r
.37808 .39612 .38463 .40651 .40642 .4065 .40001 .39625 Mtetra
.563 .755 .968 r
.40001 .39625 .40642 .4065 .42831 .40622 .42205 .39606 Mtetra
.567 .76 .969 r
.42205 .39606 .42831 .40622 .4503 .4057 .44418 .39562 Mtetra
.571 .764 .97 r
.44418 .39562 .4503 .4057 .47238 .40498 .46641 .39496 Mtetra
.574 .768 .97 r
.46641 .39496 .47238 .40498 .49456 .4041 .48874 .39412 Mtetra
.577 .771 .971 r
.48874 .39412 .49456 .4041 .51683 .40308 .51116 .39313 Mtetra
.579 .773 .971 r
.51116 .39313 .51683 .40308 .53918 .40193 .53367 .392 Mtetra
.581 .776 .972 r
.53367 .392 .53918 .40193 .56163 .40068 .55627 .39076 Mtetra
.582 .777 .972 r
.55627 .39076 .56163 .40068 .58416 .39933 .57897 .38943 Mtetra
.584 .779 .972 r
.57897 .38943 .58416 .39933 .60678 .3979 .60175 .388 Mtetra
.585 .78 .973 r
.60175 .388 .60678 .3979 .62949 .3964 .62462 .38649 Mtetra
.586 .782 .973 r
.62462 .38649 .62949 .3964 .65229 .39483 .64758 .38492 Mtetra
.587 .783 .973 r
.64758 .38492 .65229 .39483 .67517 .3932 .67063 .38328 Mtetra
.588 .784 .973 r
.67063 .38328 .67517 .3932 .69814 .39152 .69377 .38158 Mtetra
.589 .785 .973 r
.69377 .38158 .69814 .39152 .7212 .38978 .717 .37983 Mtetra
.589 .786 .974 r
.717 .37983 .7212 .38978 .74435 .388 .74032 .37804 Mtetra
.59 .786 .974 r
.74032 .37804 .74435 .388 .76759 .38618 .76372 .3762 Mtetra
.59 .787 .974 r
.76372 .3762 .76759 .38618 .79091 .38432 .78722 .37432 Mtetra
.591 .788 .974 r
.78722 .37432 .79091 .38432 .81432 .38242 .81081 .3724 Mtetra
.81081 .3724 .81432 .38242 .83783 .38049 .83449 .37045 Mtetra
.592 .789 .974 r
.83449 .37045 .83783 .38049 .86142 .37853 .85825 .36846 Mtetra
.85825 .36846 .86142 .37853 .8851 .37654 .88211 .36644 Mtetra
.88211 .36644 .8851 .37654 .90887 .37452 .90606 .3644 Mtetra
.592 .79 .974 r
.90606 .3644 .90887 .37452 .93273 .37248 .93011 .36232 Mtetra
.593 .79 .974 r
.93011 .36232 .93273 .37248 .95668 .3704 .95424 .36022 Mtetra
.184 .334 .782 r
.18087 .32465 .18798 .34626 .2079 .36332 .20058 .34624 Mtetra
.304 .475 .864 r
.20058 .34624 .2079 .36332 .22836 .37436 .221 .3597 Mtetra
.385 .567 .908 r
.221 .3597 .22836 .37436 .24918 .38182 .24185 .3686 Mtetra
.44 .627 .932 r
.24185 .3686 .24918 .38182 .27026 .38697 .263 .37466 Mtetra
.477 .666 .946 r
.263 .37466 .27026 .38697 .29153 .39054 .28437 .37885 Mtetra
.502 .693 .954 r
.28437 .37885 .29153 .39054 .31297 .39299 .30593 .38173 Mtetra
.521 .713 .959 r
.30593 .38173 .31297 .39299 .33455 .39461 .32763 .38367 Mtetra
.535 .727 .963 r
.32763 .38367 .33455 .39461 .35626 .39561 .34947 .3849 Mtetra
.545 .738 .965 r
.34947 .3849 .35626 .39561 .37808 .39612 .37143 .38559 Mtetra
.553 .747 .967 r
.37143 .38559 .37808 .39612 .40001 .39625 .39351 .38584 Mtetra
.56 .753 .968 r
.39351 .38584 .40001 .39625 .42205 .39606 .41569 .38575 Mtetra
.565 .759 .969 r
.41569 .38575 .42205 .39606 .44418 .39562 .43797 .38539 Mtetra
.569 .763 .97 r
.43797 .38539 .44418 .39562 .46641 .39496 .46036 .38478 Mtetra
.572 .767 .971 r
.46036 .38478 .46641 .39496 .48874 .39412 .48284 .38399 Mtetra
.575 .77 .971 r
.48284 .38399 .48874 .39412 .51116 .39313 .50541 .38303 Mtetra
.578 .773 .972 r
.50541 .38303 .51116 .39313 .53367 .392 .52808 .38193 Mtetra
.58 .775 .972 r
.52808 .38193 .53367 .392 .55627 .39076 .55084 .3807 Mtetra
.582 .777 .972 r
.55084 .3807 .55627 .39076 .57897 .38943 .5737 .37937 Mtetra
.583 .779 .972 r
.5737 .37937 .57897 .38943 .60175 .388 .59664 .37795 Mtetra
.584 .78 .973 r
.59664 .37795 .60175 .388 .62462 .38649 .61968 .37644 Mtetra
.585 .781 .973 r
.61968 .37644 .62462 .38649 .64758 .38492 .64281 .37486 Mtetra
.586 .783 .973 r
.64281 .37486 .64758 .38492 .67063 .38328 .66602 .37321 Mtetra
.587 .784 .973 r
.66602 .37321 .67063 .38328 .69377 .38158 .68933 .3715 Mtetra
.588 .784 .973 r
.68933 .3715 .69377 .38158 .717 .37983 .71273 .36973 Mtetra
.589 .785 .974 r
.71273 .36973 .717 .37983 .74032 .37804 .73622 .36792 Mtetra
.589 .786 .974 r
.73622 .36792 .74032 .37804 .76372 .3762 .7598 .36606 Mtetra
.59 .787 .974 r
.7598 .36606 .76372 .3762 .78722 .37432 .78348 .36416 Mtetra
.78348 .36416 .78722 .37432 .81081 .3724 .80724 .36222 Mtetra
.591 .788 .974 r
.80724 .36222 .81081 .3724 .83449 .37045 .83109 .36024 Mtetra
.83109 .36024 .83449 .37045 .85825 .36846 .85504 .35823 Mtetra
.592 .789 .974 r
.85504 .35823 .85825 .36846 .88211 .36644 .87908 .35619 Mtetra
.87908 .35619 .88211 .36644 .90606 .3644 .90322 .35411 Mtetra
.592 .79 .974 r
.90322 .35411 .90606 .3644 .93011 .36232 .92744 .35201 Mtetra
.593 .79 .974 r
.92744 .35201 .93011 .36232 .95424 .36022 .95176 .34988 Mtetra
.044 .23 .73 r
.17367 .30282 .18087 .32465 .20058 .34624 .19317 .32896 Mtetra
.224 .42 .844 r
.19317 .32896 .20058 .34624 .221 .3597 .21354 .34485 Mtetra
.339 .537 .901 r
.21354 .34485 .221 .3597 .24185 .3686 .23442 .35519 Mtetra
.411 .609 .93 r
.23442 .35519 .24185 .3686 .263 .37466 .25564 .36218 Mtetra
.458 .655 .945 r
.25564 .36218 .263 .37466 .28437 .37885 .27711 .36699 Mtetra
.489 .686 .954 r
.27711 .36699 .28437 .37885 .30593 .38173 .29878 .37032 Mtetra
.512 .707 .959 r
.29878 .37032 .30593 .38173 .32763 .38367 .32061 .37257 Mtetra
.528 .723 .963 r
.32061 .37257 .32763 .38367 .34947 .3849 .34258 .37403 Mtetra
.54 .735 .965 r
.34258 .37403 .34947 .3849 .37143 .38559 .36469 .37489 Mtetra
.549 .744 .967 r
.36469 .37489 .37143 .38559 .39351 .38584 .3869 .37528 Mtetra
.556 .752 .968 r
.3869 .37528 .39351 .38584 .41569 .38575 .40923 .37529 Mtetra
.562 .757 .969 r
.40923 .37529 .41569 .38575 .43797 .38539 .43167 .375 Mtetra
.567 .762 .97 r
.43167 .375 .43797 .38539 .46036 .38478 .4542 .37446 Mtetra
.571 .766 .971 r
.4542 .37446 .46036 .38478 .48284 .38399 .47684 .3737 Mtetra
.574 .769 .971 r
.47684 .3737 .48284 .38399 .50541 .38303 .49957 .37278 Mtetra
.576 .772 .972 r
.49957 .37278 .50541 .38303 .52808 .38193 .5224 .37169 Mtetra
.579 .774 .972 r
.5224 .37169 .52808 .38193 .55084 .3807 .54533 .37048 Mtetra
.581 .776 .972 r
.54533 .37048 .55084 .3807 .5737 .37937 .56835 .36916 Mtetra
.582 .778 .973 r
.56835 .36916 .5737 .37937 .59664 .37795 .59146 .36774 Mtetra
.584 .78 .973 r
.59146 .36774 .59664 .37795 .61968 .37644 .61466 .36623 Mtetra
.585 .781 .973 r
.61466 .36623 .61968 .37644 .64281 .37486 .63796 .36464 Mtetra
.586 .782 .973 r
.63796 .36464 .64281 .37486 .66602 .37321 .66134 .36298 Mtetra
.587 .783 .973 r
.66134 .36298 .66602 .37321 .68933 .3715 .68482 .36126 Mtetra
.588 .784 .974 r
.68482 .36126 .68933 .3715 .71273 .36973 .7084 .35948 Mtetra
.588 .785 .974 r
.7084 .35948 .71273 .36973 .73622 .36792 .73206 .35765 Mtetra
.589 .786 .974 r
.73206 .35765 .73622 .36792 .7598 .36606 .75582 .35577 Mtetra
.59 .787 .974 r
.75582 .35577 .7598 .36606 .78348 .36416 .77967 .35384 Mtetra
.77967 .35384 .78348 .36416 .80724 .36222 .80361 .35188 Mtetra
.591 .788 .974 r
.80361 .35188 .80724 .36222 .83109 .36024 .82765 .34988 Mtetra
.82765 .34988 .83109 .36024 .85504 .35823 .85178 .34784 Mtetra
.591 .789 .974 r
.85178 .34784 .85504 .35823 .87908 .35619 .876 .34577 Mtetra
.592 .789 .974 r
.876 .34577 .87908 .35619 .90322 .35411 .90032 .34366 Mtetra
.592 .79 .974 r
.90032 .34366 .90322 .35411 .92744 .35201 .92473 .34153 Mtetra
.92473 .34153 .92744 .35201 .95176 .34988 .94924 .33937 Mtetra
0 .119 .665 r
.16632 .28211 .17367 .30282 .19317 .32896 .18567 .31147 Mtetra
.139 .359 .817 r
.18567 .31147 .19317 .32896 .21354 .34485 .20598 .32981 Mtetra
.29 .504 .891 r
.20598 .32981 .21354 .34485 .23442 .35519 .22689 .3416 Mtetra
.381 .59 .926 r
.22689 .3416 .23442 .35519 .25564 .36218 .24818 .34952 Mtetra
.438 .643 .944 r
.24818 .34952 .25564 .36218 .27711 .36699 .26975 .35497 Mtetra
.476 .678 .954 r
.26975 .35497 .27711 .36699 .29878 .37032 .29153 .35873 Mtetra
.502 .702 .959 r
.29153 .35873 .29878 .37032 .32061 .37257 .31349 .36131 Mtetra
.521 .719 .963 r
.31349 .36131 .32061 .37257 .34258 .37403 .3356 .36301 Mtetra
.535 .732 .966 r
.3356 .36301 .34258 .37403 .36469 .37489 .35784 .36404 Mtetra
.545 .742 .967 r
.35784 .36404 .36469 .37489 .3869 .37528 .3802 .36456 Mtetra
.553 .75 .969 r
.3802 .36456 .3869 .37528 .40923 .37529 .40268 .36468 Mtetra
.56 .756 .97 r
.40268 .36468 .40923 .37529 .43167 .375 .42527 .36446 Mtetra
.565 .761 .97 r
.42527 .36446 .43167 .375 .4542 .37446 .44796 .36397 Mtetra
.569 .765 .971 r
.44796 .36397 .4542 .37446 .47684 .3737 .47075 .36326 Mtetra
.572 .768 .971 r
.47075 .36326 .47684 .3737 .49957 .37278 .49365 .36237 Mtetra
.575 .771 .972 r
.49365 .36237 .49957 .37278 .5224 .37169 .51664 .36131 Mtetra
.578 .774 .972 r
.51664 .36131 .5224 .37169 .54533 .37048 .53973 .36011 Mtetra
.58 .776 .972 r
.53973 .36011 .54533 .37048 .56835 .36916 .56291 .35879 Mtetra
.581 .778 .973 r
.56291 .35879 .56835 .36916 .59146 .36774 .58619 .35737 Mtetra
.583 .779 .973 r
.58619 .35737 .59146 .36774 .61466 .36623 .60956 .35586 Mtetra
.584 .781 .973 r
.60956 .35586 .61466 .36623 .63796 .36464 .63303 .35426 Mtetra
.585 .782 .973 r
.63303 .35426 .63796 .36464 .66134 .36298 .65659 .35259 Mtetra
.586 .783 .973 r
.65659 .35259 .66134 .36298 .68482 .36126 .68025 .35086 Mtetra
.587 .784 .974 r
.68025 .35086 .68482 .36126 .7084 .35948 .70399 .34906 Mtetra
.588 .785 .974 r
.70399 .34906 .7084 .35948 .73206 .35765 .72784 .34721 Mtetra
.589 .786 .974 r
.72784 .34721 .73206 .35765 .75582 .35577 .75177 .34531 Mtetra
.75177 .34531 .75582 .35577 .77967 .35384 .7758 .34336 Mtetra
.59 .787 .974 r
.7758 .34336 .77967 .35384 .80361 .35188 .79993 .34137 Mtetra
.59 .788 .974 r
.79993 .34137 .80361 .35188 .82765 .34988 .82415 .33935 Mtetra
.591 .788 .974 r
.82415 .33935 .82765 .34988 .85178 .34784 .84847 .33728 Mtetra
.591 .789 .974 r
.84847 .33728 .85178 .34784 .876 .34577 .87288 .33518 Mtetra
.592 .789 .974 r
.87288 .33518 .876 .34577 .90032 .34366 .89738 .33305 Mtetra
.592 .79 .974 r
.89738 .33305 .90032 .34366 .92473 .34153 .92198 .33089 Mtetra
.592 .79 .975 r
.92198 .33089 .92473 .34153 .94924 .33937 .94668 .3287 Mtetra
0 .01 .54 r
.15814 .27193 .16632 .28211 .18567 .31147 .17807 .29376 Mtetra
.049 .293 .783 r
.17807 .29376 .18567 .31147 .20598 .32981 .19832 .31457 Mtetra
.237 .468 .878 r
.19832 .31457 .20598 .32981 .22689 .3416 .21925 .32783 Mtetra
.349 .569 .921 r
.21925 .32783 .22689 .3416 .24818 .34952 .24062 .33669 Mtetra
.418 .631 .942 r
.24062 .33669 .24818 .34952 .26975 .35497 .26228 .34277 Mtetra
.462 .67 .953 r
.26228 .34277 .26975 .35497 .29153 .35873 .28418 .34698 Mtetra
.492 .696 .959 r
.28418 .34698 .29153 .35873 .31349 .36131 .30626 .34988 Mtetra
.514 .715 .963 r
.30626 .34988 .31349 .36131 .3356 .36301 .32851 .35181 Mtetra
.529 .729 .966 r
.32851 .35181 .3356 .36301 .35784 .36404 .35089 .35303 Mtetra
.541 .74 .968 r
.35089 .35303 .35784 .36404 .3802 .36456 .3734 .35368 Mtetra
.55 .748 .969 r
.3734 .35368 .3802 .36456 .40268 .36468 .39603 .3539 Mtetra
.557 .754 .97 r
.39603 .3539 .40268 .36468 .42527 .36446 .41877 .35376 Mtetra
.563 .76 .97 r
.41877 .35376 .42527 .36446 .44796 .36397 .44162 .35333 Mtetra
.567 .764 .971 r
.44162 .35333 .44796 .36397 .47075 .36326 .46458 .35266 Mtetra
.571 .768 .971 r
.46458 .35266 .47075 .36326 .49365 .36237 .48763 .3518 Mtetra
.574 .771 .972 r
.48763 .3518 .49365 .36237 .51664 .36131 .51079 .35076 Mtetra
.577 .773 .972 r
.51079 .35076 .51664 .36131 .53973 .36011 .53404 .34957 Mtetra
.579 .775 .972 r
.53404 .34957 .53973 .36011 .56291 .35879 .55739 .34826 Mtetra
.581 .777 .973 r
.55739 .34826 .56291 .35879 .58619 .35737 .58084 .34684 Mtetra
.582 .779 .973 r
.58084 .34684 .58619 .35737 .60956 .35586 .60439 .34533 Mtetra
.584 .78 .973 r
.60439 .34533 .60956 .35586 .63303 .35426 .62803 .34372 Mtetra
.585 .782 .973 r
.62803 .34372 .63303 .35426 .65659 .35259 .65176 .34204 Mtetra
.586 .783 .973 r
.65176 .34204 .65659 .35259 .68025 .35086 .6756 .34029 Mtetra
.587 .784 .974 r
.6756 .34029 .68025 .35086 .70399 .34906 .69952 .33848 Mtetra
.588 .785 .974 r
.69952 .33848 .70399 .34906 .72784 .34721 .72355 .33661 Mtetra
.72355 .33661 .72784 .34721 .75177 .34531 .74766 .33469 Mtetra
.589 .786 .974 r
.74766 .33469 .75177 .34531 .7758 .34336 .77188 .33272 Mtetra
.59 .787 .974 r
.77188 .33272 .7758 .34336 .79993 .34137 .79619 .3307 Mtetra
.79619 .3307 .79993 .34137 .82415 .33935 .82059 .32865 Mtetra
.591 .788 .974 r
.82059 .32865 .82415 .33935 .84847 .33728 .8451 .32656 Mtetra
.591 .789 .974 r
.8451 .32656 .84847 .33728 .87288 .33518 .8697 .32443 Mtetra
.8697 .32443 .87288 .33518 .89738 .33305 .8944 .32227 Mtetra
.592 .789 .974 r
.8944 .32227 .89738 .33305 .92198 .33089 .91919 .32007 Mtetra
.592 .79 .975 r
.91919 .32007 .92198 .33089 .94668 .3287 .94408 .31785 Mtetra
0 .332 .805 r
.14985 .2616 .15814 .27193 .17807 .29376 .17038 .27584 Mtetra
0 .223 .741 r
.17038 .27584 .17807 .29376 .19832 .31457 .19056 .29912 Mtetra
.183 .43 .862 r
.19056 .29912 .19832 .31457 .21925 .32783 .21151 .31386 Mtetra
.316 .548 .915 r
.21151 .31386 .21925 .32783 .24062 .33669 .23294 .32367 Mtetra
.397 .618 .94 r
.23294 .32367 .24062 .33669 .26228 .34277 .25471 .3304 Mtetra
.448 .661 .952 r
.25471 .3304 .26228 .34277 .28418 .34698 .27672 .33506 Mtetra
.482 .691 .959 r
.27672 .33506 .28418 .34698 .30626 .34988 .29893 .33828 Mtetra
.506 .711 .963 r
.29893 .33828 .30626 .34988 .32851 .35181 .32131 .34045 Mtetra
.524 .726 .966 r
.32131 .34045 .32851 .35181 .35089 .35303 .34383 .34185 Mtetra
.537 .737 .968 r
.34383 .34185 .35089 .35303 .3734 .35368 .36649 .34264 Mtetra
.547 .746 .969 r
.36649 .34264 .3734 .35368 .39603 .3539 .38928 .34295 Mtetra
.554 .753 .97 r
.38928 .34295 .39603 .3539 .41877 .35376 .41217 .34289 Mtetra
.56 .758 .971 r
.41217 .34289 .41877 .35376 .44162 .35333 .43518 .34252 Mtetra
.565 .763 .971 r
.43518 .34252 .44162 .35333 .46458 .35266 .4583 .3419 Mtetra
.569 .767 .972 r
.4583 .3419 .46458 .35266 .48763 .3518 .48152 .34106 Mtetra
.573 .77 .972 r
.48152 .34106 .48763 .3518 .51079 .35076 .50484 .34005 Mtetra
.576 .773 .972 r
.50484 .34005 .51079 .35076 .53404 .34957 .52827 .33887 Mtetra
.578 .775 .973 r
.52827 .33887 .53404 .34957 .55739 .34826 .55179 .33757 Mtetra
.58 .777 .973 r
.55179 .33757 .55739 .34826 .58084 .34684 .57541 .33615 Mtetra
.582 .778 .973 r
.57541 .33615 .58084 .34684 .60439 .34533 .59913 .33463 Mtetra
.583 .78 .973 r
.59913 .33463 .60439 .34533 .62803 .34372 .62295 .33301 Mtetra
.584 .781 .973 r
.62295 .33301 .62803 .34372 .65176 .34204 .64686 .33132 Mtetra
.585 .782 .973 r
.64686 .33132 .65176 .34204 .6756 .34029 .67087 .32956 Mtetra
.586 .783 .974 r
.67087 .32956 .6756 .34029 .69952 .33848 .69498 .32773 Mtetra
.587 .784 .974 r
.69498 .32773 .69952 .33848 .72355 .33661 .71919 .32584 Mtetra
.588 .785 .974 r
.71919 .32584 .72355 .33661 .74766 .33469 .74349 .32389 Mtetra
.589 .786 .974 r
.74349 .32389 .74766 .33469 .77188 .33272 .76789 .3219 Mtetra
.589 .787 .974 r
.76789 .3219 .77188 .33272 .79619 .3307 .79239 .31986 Mtetra
.59 .787 .974 r
.79239 .31986 .79619 .3307 .82059 .32865 .81698 .31778 Mtetra
.59 .788 .974 r
.81698 .31778 .82059 .32865 .8451 .32656 .84168 .31566 Mtetra
.591 .788 .974 r
.84168 .31566 .8451 .32656 .8697 .32443 .86647 .3135 Mtetra
.591 .789 .974 r
.86647 .3135 .8697 .32443 .8944 .32227 .89136 .31131 Mtetra
.592 .789 .974 r
.89136 .31131 .8944 .32227 .91919 .32007 .91635 .30908 Mtetra
.592 .79 .975 r
.91635 .30908 .91919 .32007 .94408 .31785 .94144 .30683 Mtetra
.304 .614 .956 r
.14142 .25112 .14985 .2616 .17038 .27584 .1626 .25769 Mtetra
0 .151 .693 r
.1626 .25769 .17038 .27584 .19056 .29912 .1827 .28347 Mtetra
.126 .389 .843 r
.1827 .28347 .19056 .29912 .21151 .31386 .20366 .2997 Mtetra
.282 .525 .908 r
.20366 .2997 .21151 .31386 .23294 .32367 .22516 .31047 Mtetra
.375 .604 .937 r
.22516 .31047 .23294 .32367 .25471 .3304 .24702 .31784 Mtetra
.434 .653 .951 r
.24702 .31784 .25471 .3304 .27672 .33506 .26915 .32296 Mtetra
.472 .685 .959 r
.26915 .32296 .27672 .33506 .29893 .33828 .29149 .3265 Mtetra
.499 .707 .963 r
.29149 .3265 .29893 .33828 .32131 .34045 .314 .32892 Mtetra
.518 .723 .966 r
.314 .32892 .32131 .34045 .34383 .34185 .33667 .33049 Mtetra
.532 .735 .968 r
.33667 .33049 .34383 .34185 .36649 .34264 .35948 .33142 Mtetra
.543 .744 .969 r
.35948 .33142 .36649 .34264 .38928 .34295 .38242 .33184 Mtetra
.552 .751 .97 r
.38242 .33184 .38928 .34295 .41217 .34289 .40548 .33186 Mtetra
.558 .757 .971 r
.40548 .33186 .41217 .34289 .43518 .34252 .42865 .33155 Mtetra
.564 .762 .971 r
.42865 .33155 .43518 .34252 .4583 .3419 .45193 .33097 Mtetra
.568 .766 .972 r
.45193 .33097 .4583 .3419 .48152 .34106 .47531 .33016 Mtetra
.571 .769 .972 r
.47531 .33016 .48152 .34106 .50484 .34005 .49881 .32917 Mtetra
.574 .772 .972 r
.49881 .32917 .50484 .34005 .52827 .33887 .5224 .32801 Mtetra
.577 .774 .973 r
.5224 .32801 .52827 .33887 .55179 .33757 .5461 .32671 Mtetra
.579 .776 .973 r
.5461 .32671 .55179 .33757 .57541 .33615 .56989 .32529 Mtetra
.581 .778 .973 r
.56989 .32529 .57541 .33615 .59913 .33463 .59379 .32376 Mtetra
.582 .78 .973 r
.59379 .32376 .59913 .33463 .62295 .33301 .61778 .32214 Mtetra
.584 .781 .973 r
.61778 .32214 .62295 .33301 .64686 .33132 .64188 .32043 Mtetra
.585 .782 .973 r
.64188 .32043 .64686 .33132 .67087 .32956 .66607 .31865 Mtetra
.586 .783 .974 r
.66607 .31865 .67087 .32956 .69498 .32773 .69036 .3168 Mtetra
.587 .784 .974 r
.69036 .3168 .69498 .32773 .71919 .32584 .71476 .31489 Mtetra
.588 .785 .974 r
.71476 .31489 .71919 .32584 .74349 .32389 .73925 .31293 Mtetra
.589 .786 .974 r
.73925 .31293 .74349 .32389 .76789 .3219 .76383 .31091 Mtetra
.589 .787 .974 r
.76383 .31091 .76789 .3219 .79239 .31986 .78852 .30884 Mtetra
.59 .787 .974 r
.78852 .30884 .79239 .31986 .81698 .31778 .81331 .30673 Mtetra
.59 .788 .974 r
.81331 .30673 .81698 .31778 .84168 .31566 .8382 .30458 Mtetra
.591 .788 .974 r
.8382 .30458 .84168 .31566 .86647 .3135 .86319 .30239 Mtetra
.591 .789 .974 r
.86319 .30239 .86647 .3135 .89136 .31131 .88828 .30017 Mtetra
.88828 .30017 .89136 .31131 .91635 .30908 .91347 .29791 Mtetra
.592 .79 .975 r
.91347 .29791 .91635 .30908 .94144 .30683 .93876 .29562 Mtetra
.58 .769 .969 r
.13287 .24047 .14142 .25112 .1626 .25769 .15472 .23931 Mtetra
0 .078 .64 r
.15472 .23931 .1626 .25769 .1827 .28347 .17473 .2676 Mtetra
.068 .346 .821 r
.17473 .2676 .1827 .28347 .20366 .2997 .1957 .28534 Mtetra
.247 .501 .899 r
.1957 .28534 .20366 .2997 .22516 .31047 .21726 .29708 Mtetra
.353 .59 .934 r
.21726 .29708 .22516 .31047 .24702 .31784 .23922 .3051 Mtetra
.419 .644 .95 r
.23922 .3051 .24702 .31784 .26915 .32296 .26146 .31067 Mtetra
.462 .679 .959 r
.26146 .31067 .26915 .32296 .29149 .3265 .28393 .31455 Mtetra
.492 .703 .963 r
.28393 .31455 .29149 .3265 .314 .32892 .30658 .31721 Mtetra
.513 .72 .966 r
.30658 .31721 .314 .32892 .33667 .33049 .3294 .31897 Mtetra
.528 .733 .968 r
.3294 .31897 .33667 .33049 .35948 .33142 .35236 .32003 Mtetra
.54 .742 .969 r
.35236 .32003 .35948 .33142 .38242 .33184 .37546 .32056 Mtetra
.549 .75 .97 r
.37546 .32056 .38242 .33184 .40548 .33186 .39867 .32065 Mtetra
.556 .756 .971 r
.39867 .32065 .40548 .33186 .42865 .33155 .42201 .3204 Mtetra
.562 .761 .971 r
.42201 .3204 .42865 .33155 .45193 .33097 .44545 .31986 Mtetra
.566 .765 .972 r
.44545 .31986 .45193 .33097 .47531 .33016 .46901 .31909 Mtetra
.57 .768 .972 r
.46901 .31909 .47531 .33016 .49881 .32917 .49267 .31811 Mtetra
.573 .771 .972 r
.49267 .31811 .49881 .32917 .5224 .32801 .51644 .31697 Mtetra
.576 .774 .973 r
.51644 .31697 .5224 .32801 .5461 .32671 .54031 .31567 Mtetra
.578 .776 .973 r
.54031 .31567 .5461 .32671 .56989 .32529 .56429 .31425 Mtetra
.58 .778 .973 r
.56429 .31425 .56989 .32529 .59379 .32376 .58836 .31272 Mtetra
.582 .779 .973 r
.58836 .31272 .59379 .32376 .61778 .32214 .61254 .31109 Mtetra
.583 .781 .973 r
.61254 .31109 .61778 .32214 .64188 .32043 .63682 .30937 Mtetra
.585 .782 .974 r
.63682 .30937 .64188 .32043 .66607 .31865 .6612 .30757 Mtetra
.586 .783 .974 r
.6612 .30757 .66607 .31865 .69036 .3168 .68567 .3057 Mtetra
.587 .784 .974 r
.68567 .3057 .69036 .3168 .71476 .31489 .71025 .30377 Mtetra
.587 .785 .974 r
.71025 .30377 .71476 .31489 .73925 .31293 .73493 .30178 Mtetra
.588 .786 .974 r
.73493 .30178 .73925 .31293 .76383 .31091 .75971 .29974 Mtetra
.589 .786 .974 r
.75971 .29974 .76383 .31091 .78852 .30884 .7846 .29764 Mtetra
.589 .787 .974 r
.7846 .29764 .78852 .30884 .81331 .30673 .80958 .2955 Mtetra
.59 .788 .974 r
.80958 .2955 .81331 .30673 .8382 .30458 .83466 .29332 Mtetra
.83466 .29332 .8382 .30458 .86319 .30239 .85985 .2911 Mtetra
.591 .789 .974 r
.85985 .2911 .86319 .30239 .88828 .30017 .88514 .28885 Mtetra
.88514 .28885 .88828 .30017 .91347 .29791 .91053 .28656 Mtetra
.592 .789 .975 r
.91053 .28656 .91347 .29791 .93876 .29562 .93603 .28423 Mtetra
.617 .786 .963 r
.12419 .22967 .13287 .24047 .15472 .23931 .14629 .22705 Mtetra
0 0 .545 r
.14629 .22705 .15472 .23931 .17473 .2676 .16665 .25152 Mtetra
.009 .302 .795 r
.16665 .25152 .17473 .2676 .1957 .28534 .18763 .27078 Mtetra
.21 .476 .889 r
.18763 .27078 .1957 .28534 .21726 .29708 .20925 .28349 Mtetra
.33 .575 .93 r
.20925 .28349 .21726 .29708 .23922 .3051 .2313 .29217 Mtetra
.404 .634 .949 r
.2313 .29217 .23922 .3051 .26146 .31067 .25366 .29821 Mtetra
.452 .672 .958 r
.25366 .29821 .26146 .31067 .28393 .31455 .27626 .30242 Mtetra
.484 .698 .963 r
.27626 .30242 .28393 .31455 .30658 .31721 .29905 .30533 Mtetra
.507 .717 .966 r
.29905 .30533 .30658 .31721 .3294 .31897 .32202 .30726 Mtetra
.524 .73 .968 r
.32202 .30726 .3294 .31897 .35236 .32003 .34513 .30847 Mtetra
.536 .74 .969 r
.34513 .30847 .35236 .32003 .37546 .32056 .36838 .3091 Mtetra
.546 .748 .97 r
.36838 .3091 .37546 .32056 .39867 .32065 .39176 .30927 Mtetra
.554 .755 .971 r
.39176 .30927 .39867 .32065 .42201 .3204 .41526 .30908 Mtetra
.56 .76 .972 r
.41526 .30908 .42201 .3204 .44545 .31986 .43888 .30858 Mtetra
.565 .764 .972 r
.43888 .30858 .44545 .31986 .46901 .31909 .46261 .30784 Mtetra
.569 .768 .972 r
.46261 .30784 .46901 .31909 .49267 .31811 .48644 .30688 Mtetra
.572 .771 .973 r
.48644 .30688 .49267 .31811 .51644 .31697 .51039 .30575 Mtetra
.575 .773 .973 r
.51039 .30575 .51644 .31697 .54031 .31567 .53444 .30446 Mtetra
.578 .775 .973 r
.53444 .30446 .54031 .31567 .56429 .31425 .55859 .30304 Mtetra
.58 .777 .973 r
.55859 .30304 .56429 .31425 .58836 .31272 .58285 .3015 Mtetra
.581 .779 .973 r
.58285 .3015 .58836 .31272 .61254 .31109 .60721 .29986 Mtetra
.583 .78 .973 r
.60721 .29986 .61254 .31109 .63682 .30937 .63167 .29812 Mtetra
.584 .782 .974 r
.63167 .29812 .63682 .30937 .6612 .30757 .65624 .29631 Mtetra
.585 .783 .974 r
.65624 .29631 .6612 .30757 .68567 .3057 .68091 .29442 Mtetra
.586 .784 .974 r
.68091 .29442 .68567 .3057 .71025 .30377 .70568 .29247 Mtetra
.587 .785 .974 r
.70568 .29247 .71025 .30377 .73493 .30178 .73055 .29045 Mtetra
.588 .785 .974 r
.73055 .29045 .73493 .30178 .75971 .29974 .75553 .28838 Mtetra
.589 .786 .974 r
.75553 .28838 .75971 .29974 .7846 .29764 .7806 .28626 Mtetra
.589 .787 .974 r
.7806 .28626 .7846 .29764 .80958 .2955 .80579 .28409 Mtetra
.59 .787 .974 r
.80579 .28409 .80958 .2955 .83466 .29332 .83107 .28188 Mtetra
.59 .788 .974 r
.83107 .28188 .83466 .29332 .85985 .2911 .85646 .27963 Mtetra
.591 .788 .974 r
.85646 .27963 .85985 .2911 .88514 .28885 .88195 .27734 Mtetra
.591 .789 .974 r
.88195 .27734 .88514 .28885 .91053 .28656 .90755 .27501 Mtetra
.592 .789 .975 r
.90755 .27501 .91053 .28656 .93603 .28423 .93325 .27265 Mtetra
.617 .786 .963 r
.11538 .21869 .12419 .22967 .14629 .22705 .13763 .21604 Mtetra
0 .146 .663 r
.13763 .21604 .14629 .22705 .16665 .25152 .15846 .23522 Mtetra
0 .256 .766 r
.15846 .23522 .16665 .25152 .18763 .27078 .17944 .25601 Mtetra
.173 .449 .878 r
.17944 .25601 .18763 .27078 .20925 .28349 .20112 .2697 Mtetra
.307 .559 .925 r
.20112 .2697 .20925 .28349 .2313 .29217 .22326 .27905 Mtetra
.389 .625 .947 r
.22326 .27905 .2313 .29217 .25366 .29821 .24574 .28555 Mtetra
.441 .666 .957 r
.24574 .28555 .25366 .29821 .27626 .30242 .26847 .2901 Mtetra
.476 .694 .963 r
.26847 .2901 .27626 .30242 .29905 .30533 .2914 .29325 Mtetra
.501 .713 .966 r
.2914 .29325 .29905 .30533 .32202 .30726 .31452 .29538 Mtetra
.519 .728 .968 r
.31452 .29538 .32202 .30726 .34513 .30847 .33779 .29672 Mtetra
.533 .738 .97 r
.33779 .29672 .34513 .30847 .36838 .3091 .3612 .29745 Mtetra
.543 .747 .97 r
.3612 .29745 .36838 .3091 .39176 .30927 .38474 .29771 Mtetra
.552 .754 .971 r
.38474 .29771 .39176 .30927 .41526 .30908 .40841 .29757 Mtetra
.558 .759 .972 r
.40841 .29757 .41526 .30908 .43888 .30858 .4322 .29712 Mtetra
.563 .763 .972 r
.4322 .29712 .43888 .30858 .46261 .30784 .4561 .29641 Mtetra
.568 .767 .972 r
.4561 .29641 .46261 .30784 .48644 .30688 .48011 .29547 Mtetra
.571 .77 .973 r
.48011 .29547 .48644 .30688 .51039 .30575 .50423 .29435 Mtetra
.574 .773 .973 r
.50423 .29435 .51039 .30575 .53444 .30446 .52846 .29307 Mtetra
.577 .775 .973 r
.52846 .29307 .53444 .30446 .55859 .30304 .5528 .29164 Mtetra
.579 .777 .973 r
.5528 .29164 .55859 .30304 .58285 .3015 .57724 .2901 Mtetra
.581 .779 .973 r
.57724 .2901 .58285 .3015 .60721 .29986 .60179 .28844 Mtetra
.582 .78 .973 r
.60179 .28844 .60721 .29986 .63167 .29812 .62644 .2867 Mtetra
.584 .781 .974 r
.62644 .2867 .63167 .29812 .65624 .29631 .6512 .28486 Mtetra
.585 .782 .974 r
.6512 .28486 .65624 .29631 .68091 .29442 .67606 .28296 Mtetra
.586 .784 .974 r
.67606 .28296 .68091 .29442 .70568 .29247 .70103 .28098 Mtetra
.587 .784 .974 r
.70103 .28098 .70568 .29247 .73055 .29045 .7261 .27894 Mtetra
.588 .785 .974 r
.7261 .27894 .73055 .29045 .75553 .28838 .75127 .27684 Mtetra
.588 .786 .974 r
.75127 .27684 .75553 .28838 .7806 .28626 .77655 .27469 Mtetra
.589 .787 .974 r
.77655 .27469 .7806 .28626 .80579 .28409 .80193 .27249 Mtetra
.59 .787 .974 r
.80193 .27249 .80579 .28409 .83107 .28188 .82742 .27025 Mtetra
.59 .788 .974 r
.82742 .27025 .83107 .28188 .85646 .27963 .85301 .26796 Mtetra
.591 .788 .974 r
.85301 .26796 .85646 .27963 .88195 .27734 .87871 .26563 Mtetra
.591 .789 .974 r
.87871 .26563 .88195 .27734 .90755 .27501 .90452 .26327 Mtetra
.591 .789 .975 r
.90452 .26327 .90755 .27501 .93325 .27265 .93043 .26087 Mtetra
.617 .786 .963 r
.10642 .20755 .11538 .21869 .13763 .21604 .12883 .20485 Mtetra
0 .367 .83 r
.12883 .20485 .13763 .21604 .15846 .23522 .15016 .2187 Mtetra
0 .209 .735 r
.15016 .2187 .15846 .23522 .17944 .25601 .17114 .24102 Mtetra
.135 .422 .865 r
.17114 .24102 .17944 .25601 .20112 .2697 .19287 .25571 Mtetra
.283 .543 .92 r
.19287 .25571 .20112 .2697 .22326 .27905 .21511 .26573 Mtetra
.373 .615 .945 r
.21511 .26573 .22326 .27905 .24574 .28555 .2377 .2727 Mtetra
.43 .659 .957 r
.2377 .2727 .24574 .28555 .26847 .2901 .26056 .27759 Mtetra
.469 .689 .963 r
.26056 .27759 .26847 .2901 .2914 .29325 .28364 .28099 Mtetra
.496 .71 .966 r
.28364 .28099 .2914 .29325 .31452 .29538 .3069 .2833 Mtetra
.515 .725 .968 r
.3069 .2833 .31452 .29538 .33779 .29672 .33033 .28479 Mtetra
.53 .737 .97 r
.33033 .28479 .33779 .29672 .3612 .29745 .3539 .28563 Mtetra
.541 .745 .971 r
.3539 .28563 .3612 .29745 .38474 .29771 .37761 .28596 Mtetra
.549 .752 .971 r
.37761 .28596 .38474 .29771 .40841 .29757 .40145 .28589 Mtetra
.556 .758 .972 r
.40145 .28589 .40841 .29757 .4322 .29712 .42541 .28548 Mtetra
.562 .762 .972 r
.42541 .28548 .4322 .29712 .4561 .29641 .44949 .28479 Mtetra
.566 .766 .972 r
.44949 .28479 .4561 .29641 .48011 .29547 .47368 .28388 Mtetra
.57 .769 .973 r
.47368 .28388 .48011 .29547 .50423 .29435 .49798 .28277 Mtetra
.573 .772 .973 r
.49798 .28277 .50423 .29435 .52846 .29307 .5224 .28149 Mtetra
.576 .774 .973 r
.5224 .28149 .52846 .29307 .5528 .29164 .54692 .28006 Mtetra
.578 .776 .973 r
.54692 .28006 .5528 .29164 .57724 .2901 .57155 .27851 Mtetra
.58 .778 .973 r
.57155 .27851 .57724 .2901 .60179 .28844 .59629 .27684 Mtetra
.582 .78 .974 r
.59629 .27684 .60179 .28844 .62644 .2867 .62113 .27508 Mtetra
.583 .781 .974 r
.62113 .27508 .62644 .2867 .6512 .28486 .64608 .27323 Mtetra
.584 .782 .974 r
.64608 .27323 .6512 .28486 .67606 .28296 .67114 .2713 Mtetra
.586 .783 .974 r
.67114 .2713 .67606 .28296 .70103 .28098 .6963 .2693 Mtetra
.586 .784 .974 r
.6963 .2693 .70103 .28098 .7261 .27894 .72157 .26723 Mtetra
.587 .785 .974 r
.72157 .26723 .7261 .27894 .75127 .27684 .74694 .2651 Mtetra
.588 .786 .974 r
.74694 .2651 .75127 .27684 .77655 .27469 .77242 .26292 Mtetra
.589 .787 .974 r
.77242 .26292 .77655 .27469 .80193 .27249 .79801 .26069 Mtetra
.79801 .26069 .80193 .27249 .82742 .27025 .8237 .25842 Mtetra
.59 .788 .974 r
.8237 .25842 .82742 .27025 .85301 .26796 .84951 .2561 Mtetra
.84951 .2561 .85301 .26796 .87871 .26563 .87541 .25373 Mtetra
.591 .789 .974 r
.87541 .25373 .87871 .26563 .90452 .26327 .90143 .25133 Mtetra
.591 .789 .975 r
.90143 .25133 .90452 .26327 .93043 .26087 .92756 .2489 Mtetra
.617 .786 .963 r
.09733 .19623 .10642 .20755 .12883 .20485 .1199 .19349 Mtetra
.227 .562 .937 r
.1199 .19349 .12883 .20485 .15016 .2187 .14174 .20195 Mtetra
0 .161 .701 r
.14174 .20195 .15016 .2187 .17114 .24102 .16271 .22582 Mtetra
.096 .393 .85 r
.16271 .22582 .17114 .24102 .19287 .25571 .1845 .24151 Mtetra
.258 .527 .914 r
.1845 .24151 .19287 .25571 .21511 .26573 .20683 .2522 Mtetra
.357 .604 .942 r
.20683 .2522 .21511 .26573 .2377 .2727 .22953 .25965 Mtetra
.419 .653 .956 r
.22953 .25965 .2377 .2727 .26056 .27759 .25253 .26489 Mtetra
.461 .685 .962 r
.25253 .26489 .26056 .27759 .28364 .28099 .27575 .26854 Mtetra
.49 .707 .966 r
.27575 .26854 .28364 .28099 .3069 .2833 .29916 .27104 Mtetra
.511 .723 .968 r
.29916 .27104 .3069 .2833 .33033 .28479 .32275 .27267 Mtetra
.526 .735 .97 r
.32275 .27267 .33033 .28479 .3539 .28563 .34649 .27361 Mtetra
.538 .744 .971 r
.34649 .27361 .3539 .28563 .37761 .28596 .37037 .27403 Mtetra
.547 .751 .971 r
.37037 .27403 .37761 .28596 .40145 .28589 .39438 .27401 Mtetra
.554 .757 .972 r
.39438 .27401 .40145 .28589 .42541 .28548 .41851 .27365 Mtetra
.56 .762 .972 r
.41851 .27365 .42541 .28548 .44949 .28479 .44277 .27299 Mtetra
.565 .766 .973 r
.44277 .27299 .44949 .28479 .47368 .28388 .46714 .27209 Mtetra
.569 .769 .973 r
.46714 .27209 .47368 .28388 .49798 .28277 .49163 .27099 Mtetra
.572 .772 .973 r
.49163 .27099 .49798 .28277 .5224 .28149 .51623 .26972 Mtetra
.575 .774 .973 r
.51623 .26972 .5224 .28149 .54692 .28006 .54094 .26829 Mtetra
.577 .776 .973 r
.54094 .26829 .54692 .28006 .57155 .27851 .56576 .26673 Mtetra
.579 .778 .973 r
.56576 .26673 .57155 .27851 .59629 .27684 .59069 .26505 Mtetra
.581 .779 .974 r
.59069 .26505 .59629 .27684 .62113 .27508 .61573 .26327 Mtetra
.583 .781 .974 r
.61573 .26327 .62113 .27508 .64608 .27323 .64087 .2614 Mtetra
.584 .782 .974 r
.64087 .2614 .64608 .27323 .67114 .2713 .66613 .25945 Mtetra
.585 .783 .974 r
.66613 .25945 .67114 .2713 .6963 .2693 .69149 .25742 Mtetra
.586 .784 .974 r
.69149 .25742 .6963 .2693 .72157 .26723 .71696 .25533 Mtetra
.587 .785 .974 r
.71696 .25533 .72157 .26723 .74694 .2651 .74254 .25317 Mtetra
.588 .786 .974 r
.74254 .25317 .74694 .2651 .77242 .26292 .76823 .25096 Mtetra
.589 .786 .974 r
.76823 .25096 .77242 .26292 .79801 .26069 .79402 .2487 Mtetra
.589 .787 .974 r
.79402 .2487 .79801 .26069 .8237 .25842 .81993 .24638 Mtetra
.59 .788 .974 r
.81993 .24638 .8237 .25842 .84951 .2561 .84594 .24403 Mtetra
.84594 .24403 .84951 .2561 .87541 .25373 .87206 .24163 Mtetra
.591 .789 .974 r
.87206 .24163 .87541 .25373 .90143 .25133 .8983 .23919 Mtetra
.591 .789 .975 r
.8983 .23919 .90143 .25133 .92756 .2489 .92464 .23672 Mtetra
.617 .786 .963 r
.0881 .18473 .09733 .19623 .1199 .19349 .11082 .18195 Mtetra
.449 .7 .974 r
.11082 .18195 .1199 .19349 .14174 .20195 .13321 .18496 Mtetra
0 .114 .666 r
.13321 .18496 .14174 .20195 .16271 .22582 .15416 .2104 Mtetra
.056 .364 .834 r
.15416 .2104 .16271 .22582 .1845 .24151 .176 .2271 Mtetra
.233 .509 .907 r
.176 .2271 .1845 .24151 .20683 .2522 .19842 .23847 Mtetra
.34 .594 .939 r
.19842 .23847 .20683 .2522 .22953 .25965 .22124 .2464 Mtetra
.408 .646 .954 r
.22124 .2464 .22953 .25965 .25253 .26489 .24437 .25198 Mtetra
.453 .68 .962 r
.24437 .25198 .25253 .26489 .27575 .26854 .26773 .25589 Mtetra
.484 .703 .966 r
.26773 .25589 .27575 .26854 .29916 .27104 .2913 .25858 Mtetra
.506 .72 .968 r
.2913 .25858 .29916 .27104 .32275 .27267 .31505 .26035 Mtetra
.523 .733 .97 r
.31505 .26035 .32275 .27267 .34649 .27361 .33895 .2614 Mtetra
.535 .742 .971 r
.33895 .2614 .34649 .27361 .37037 .27403 .363 .2619 Mtetra
.545 .75 .971 r
.363 .2619 .37037 .27403 .39438 .27401 .38719 .26194 Mtetra
.553 .756 .972 r
.38719 .26194 .39438 .27401 .41851 .27365 .4115 .26162 Mtetra
.559 .761 .972 r
.4115 .26162 .41851 .27365 .44277 .27299 .43594 .26099 Mtetra
.564 .765 .973 r
.43594 .26099 .44277 .27299 .46714 .27209 .46049 .26012 Mtetra
.568 .768 .973 r
.46049 .26012 .46714 .27209 .49163 .27099 .48517 .25903 Mtetra
.571 .771 .973 r
.48517 .25903 .49163 .27099 .51623 .26972 .50996 .25775 Mtetra
.574 .774 .973 r
.50996 .25775 .51623 .26972 .54094 .26829 .53486 .25632 Mtetra
.577 .776 .973 r
.53486 .25632 .54094 .26829 .56576 .26673 .55987 .25475 Mtetra
.579 .777 .973 r
.55987 .25475 .56576 .26673 .59069 .26505 .585 .25306 Mtetra
.581 .779 .974 r
.585 .25306 .59069 .26505 .61573 .26327 .61023 .25126 Mtetra
.582 .78 .974 r
.61023 .25126 .61573 .26327 .64087 .2614 .63558 .24937 Mtetra
.584 .782 .974 r
.63558 .24937 .64087 .2614 .66613 .25945 .66104 .2474 Mtetra
.585 .783 .974 r
.66104 .2474 .66613 .25945 .69149 .25742 .6866 .24534 Mtetra
.586 .784 .974 r
.6866 .24534 .69149 .25742 .71696 .25533 .71228 .24322 Mtetra
.587 .785 .974 r
.71228 .24322 .71696 .25533 .74254 .25317 .73806 .24104 Mtetra
.588 .786 .974 r
.73806 .24104 .74254 .25317 .76823 .25096 .76396 .23879 Mtetra
.76396 .23879 .76823 .25096 .79402 .2487 .78997 .2365 Mtetra
.589 .787 .974 r
.78997 .2365 .79402 .2487 .81993 .24638 .81608 .23415 Mtetra
.81608 .23415 .81993 .24638 .84594 .24403 .84231 .23176 Mtetra
.59 .788 .974 r
.84231 .23176 .84594 .24403 .87206 .24163 .86865 .22932 Mtetra
.59 .789 .975 r
.86865 .22932 .87206 .24163 .8983 .23919 .89511 .22684 Mtetra
.591 .789 .975 r
.89511 .22684 .8983 .23919 .92464 .23672 .92167 .22433 Mtetra
.617 .786 .963 r
.07871 .17305 .0881 .18473 .11082 .18195 .1016 .17022 Mtetra
.608 .782 .964 r
.1016 .17022 .11082 .18195 .13321 .18496 .12455 .16774 Mtetra
0 .068 .629 r
.12455 .16774 .13321 .18496 .15416 .2104 .14549 .19476 Mtetra
.017 .334 .816 r
.14549 .19476 .15416 .2104 .176 .2271 .16738 .21247 Mtetra
.207 .491 .9 r
.16738 .21247 .176 .2271 .19842 .23847 .18989 .22453 Mtetra
.324 .583 .936 r
.18989 .22453 .19842 .23847 .22124 .2464 .21282 .23295 Mtetra
.397 .639 .953 r
.21282 .23295 .22124 .2464 .24437 .25198 .23608 .23887 Mtetra
.445 .675 .961 r
.23608 .23887 .24437 .25198 .26773 .25589 .25959 .24304 Mtetra
.478 .7 .966 r
.25959 .24304 .26773 .25589 .2913 .25858 .28332 .24592 Mtetra
.502 .717 .968 r
.28332 .24592 .2913 .25858 .31505 .26035 .30723 .24783 Mtetra
.519 .731 .97 r
.30723 .24783 .31505 .26035 .33895 .2614 .3313 .24899 Mtetra
.532 .741 .971 r
.3313 .24899 .33895 .2614 .363 .2619 .35552 .24957 Mtetra
.543 .748 .972 r
.35552 .24957 .363 .2619 .38719 .26194 .37988 .24967 Mtetra
.551 .755 .972 r
.37988 .24967 .38719 .26194 .4115 .26162 .40437 .24939 Mtetra
.557 .76 .972 r
.40437 .24939 .4115 .26162 .43594 .26099 .42899 .2488 Mtetra
.563 .764 .973 r
.42899 .2488 .43594 .26099 .46049 .26012 .45374 .24794 Mtetra
.567 .768 .973 r
.45374 .24794 .46049 .26012 .48517 .25903 .4786 .24686 Mtetra
.57 .771 .973 r
.4786 .24686 .48517 .25903 .50996 .25775 .50358 .24559 Mtetra
.574 .773 .973 r
.50358 .24559 .50996 .25775 .53486 .25632 .52868 .24415 Mtetra
.576 .775 .973 r
.52868 .24415 .53486 .25632 .55987 .25475 .55389 .24257 Mtetra
.578 .777 .974 r
.55389 .24257 .55987 .25475 .585 .25306 .57921 .24087 Mtetra
.58 .779 .974 r
.57921 .24087 .585 .25306 .61023 .25126 .60465 .23905 Mtetra
.582 .78 .974 r
.60465 .23905 .61023 .25126 .63558 .24937 .6302 .23714 Mtetra
.583 .781 .974 r
.6302 .23714 .63558 .24937 .66104 .2474 .65586 .23514 Mtetra
.584 .783 .974 r
.65586 .23514 .66104 .2474 .6866 .24534 .68163 .23306 Mtetra
.585 .784 .974 r
.68163 .23306 .6866 .24534 .71228 .24322 .70751 .23091 Mtetra
.586 .785 .974 r
.70751 .23091 .71228 .24322 .73806 .24104 .73351 .22869 Mtetra
.587 .785 .974 r
.73351 .22869 .73806 .24104 .76396 .23879 .75962 .22642 Mtetra
.588 .786 .974 r
.75962 .22642 .76396 .23879 .78997 .2365 .78584 .22408 Mtetra
.589 .787 .974 r
.78584 .22408 .78997 .2365 .81608 .23415 .81218 .2217 Mtetra
.81218 .2217 .81608 .23415 .84231 .23176 .83862 .21927 Mtetra
.59 .788 .974 r
.83862 .21927 .84231 .23176 .86865 .22932 .86518 .21679 Mtetra
.59 .788 .975 r
.86518 .21679 .86865 .22932 .89511 .22684 .89186 .21428 Mtetra
.591 .789 .975 r
.89186 .21428 .89511 .22684 .92167 .22433 .91865 .21172 Mtetra
.617 .786 .963 r
.06918 .16119 .07871 .17305 .1016 .17022 .09223 .15831 Mtetra
.09223 .15831 .1016 .17022 .12455 .16774 .11538 .15542 Mtetra
0 .03 .566 r
.11538 .15542 .12455 .16774 .14549 .19476 .13668 .17888 Mtetra
0 .303 .797 r
.13668 .17888 .14549 .19476 .16738 .21247 .15862 .19761 Mtetra
.181 .473 .892 r
.15862 .19761 .16738 .21247 .18989 .22453 .18122 .21037 Mtetra
.307 .572 .933 r
.18122 .21037 .18989 .22453 .21282 .23295 .20427 .21928 Mtetra
.385 .631 .952 r
.20427 .21928 .21282 .23295 .23608 .23887 .22766 .22556 Mtetra
.437 .67 .961 r
.22766 .22556 .23608 .23887 .25959 .24304 .25132 .22998 Mtetra
.472 .696 .966 r
.25132 .22998 .25959 .24304 .28332 .24592 .2752 .23306 Mtetra
.497 .715 .968 r
.2752 .23306 .28332 .24592 .30723 .24783 .29927 .23511 Mtetra
.516 .729 .97 r
.29927 .23511 .30723 .24783 .3313 .24899 .32352 .23638 Mtetra
.53 .739 .971 r
.32352 .23638 .3313 .24899 .35552 .24957 .34791 .23704 Mtetra
.54 .747 .972 r
.34791 .23704 .35552 .24957 .37988 .24967 .37245 .2372 Mtetra
.549 .754 .972 r
.37245 .2372 .37988 .24967 .40437 .24939 .39713 .23697 Mtetra
.556 .759 .973 r
.39713 .23697 .40437 .24939 .42899 .2488 .42194 .2364 Mtetra
.561 .763 .973 r
.42194 .2364 .42899 .2488 .45374 .24794 .44687 .23556 Mtetra
.566 .767 .973 r
.44687 .23556 .45374 .24794 .4786 .24686 .47192 .23449 Mtetra
.57 .77 .973 r
.47192 .23449 .4786 .24686 .50358 .24559 .4971 .23322 Mtetra
.573 .773 .973 r
.4971 .23322 .50358 .24559 .52868 .24415 .52239 .23177 Mtetra
.575 .775 .973 r
.52239 .23177 .52868 .24415 .55389 .24257 .5478 .23019 Mtetra
.578 .777 .974 r
.5478 .23019 .55389 .24257 .57921 .24087 .57332 .22847 Mtetra
.58 .778 .974 r
.57332 .22847 .57921 .24087 .60465 .23905 .59896 .22663 Mtetra
.581 .78 .974 r
.59896 .22663 .60465 .23905 .6302 .23714 .62472 .2247 Mtetra
.583 .781 .974 r
.62472 .2247 .6302 .23714 .65586 .23514 .65059 .22267 Mtetra
.584 .782 .974 r
.65059 .22267 .65586 .23514 .68163 .23306 .67657 .22057 Mtetra
.585 .783 .974 r
.67657 .22057 .68163 .23306 .70751 .23091 .70267 .21838 Mtetra
.586 .784 .974 r
.70267 .21838 .70751 .23091 .73351 .22869 .72888 .21614 Mtetra
.587 .785 .974 r
.72888 .21614 .73351 .22869 .75962 .22642 .7552 .21382 Mtetra
.588 .786 .974 r
.7552 .21382 .75962 .22642 .78584 .22408 .78164 .21146 Mtetra
.588 .787 .974 r
.78164 .21146 .78584 .22408 .81218 .2217 .8082 .20904 Mtetra
.589 .787 .974 r
.8082 .20904 .81218 .2217 .83862 .21927 .83487 .20657 Mtetra
.59 .788 .974 r
.83487 .20657 .83862 .21927 .86518 .21679 .86166 .20405 Mtetra
.59 .788 .975 r
.86166 .20405 .86518 .21679 .89186 .21428 .88856 .20149 Mtetra
.591 .789 .975 r
.88856 .20149 .89186 .21428 .91865 .21172 .91557 .19889 Mtetra
.617 .786 .963 r
.05949 .14913 .06918 .16119 .09223 .15831 .08271 .1462 Mtetra
.08271 .1462 .09223 .15831 .11538 .15542 .10603 .14327 Mtetra
0 .166 .682 r
.10603 .14327 .11538 .15542 .13668 .17888 .12775 .16276 Mtetra
0 .271 .777 r
.12775 .16276 .13668 .17888 .15862 .19761 .14973 .18253 Mtetra
.155 .454 .883 r
.14973 .18253 .15862 .19761 .18122 .21037 .17241 .196 Mtetra
.289 .56 .929 r
.17241 .196 .18122 .21037 .20427 .21928 .19558 .20539 Mtetra
.373 .624 .95 r
.19558 .20539 .20427 .21928 .22766 .22556 .2191 .21203 Mtetra
.428 .665 .96 r
.2191 .21203 .22766 .22556 .25132 .22998 .24291 .21671 Mtetra
.466 .693 .965 r
.24291 .21671 .25132 .22998 .2752 .23306 .26695 .21998 Mtetra
.493 .712 .968 r
.26695 .21998 .2752 .23306 .29927 .23511 .29119 .22218 Mtetra
.512 .726 .97 r
.29119 .22218 .29927 .23511 .32352 .23638 .3156 .22356 Mtetra
.527 .737 .971 r
.3156 .22356 .32352 .23638 .34791 .23704 .34018 .2243 Mtetra
.538 .746 .972 r
.34018 .2243 .34791 .23704 .37245 .2372 .3649 .22452 Mtetra
.547 .753 .972 r
.3649 .22452 .37245 .2372 .39713 .23697 .38976 .22433 Mtetra
.554 .758 .973 r
.38976 .22433 .39713 .23697 .42194 .2364 .41476 .22379 Mtetra
.56 .763 .973 r
.41476 .22379 .42194 .2364 .44687 .23556 .43988 .22297 Mtetra
.565 .766 .973 r
.43988 .22297 .44687 .23556 .47192 .23449 .46513 .2219 Mtetra
.569 .769 .973 r
.46513 .2219 .47192 .23449 .4971 .23322 .4905 .22063 Mtetra
.572 .772 .973 r
.4905 .22063 .4971 .23322 .52239 .23177 .516 .21919 Mtetra
.575 .774 .973 r
.516 .21919 .52239 .23177 .5478 .23019 .54161 .21759 Mtetra
.577 .776 .974 r
.54161 .21759 .5478 .23019 .57332 .22847 .56734 .21585 Mtetra
.579 .778 .974 r
.56734 .21585 .57332 .22847 .59896 .22663 .59319 .214 Mtetra
.581 .78 .974 r
.59319 .214 .59896 .22663 .62472 .2247 .61915 .21204 Mtetra
.582 .781 .974 r
.61915 .21204 .62472 .2247 .65059 .22267 .64523 .20999 Mtetra
.584 .782 .974 r
.64523 .20999 .65059 .22267 .67657 .22057 .67143 .20786 Mtetra
.585 .783 .974 r
.67143 .20786 .67657 .22057 .70267 .21838 .69774 .20564 Mtetra
.586 .784 .974 r
.69774 .20564 .70267 .21838 .72888 .21614 .72417 .20336 Mtetra
.587 .785 .974 r
.72417 .20336 .72888 .21614 .7552 .21382 .75071 .20101 Mtetra
.588 .786 .974 r
.75071 .20101 .7552 .21382 .78164 .21146 .77737 .19861 Mtetra
.77737 .19861 .78164 .21146 .8082 .20904 .80415 .19615 Mtetra
.589 .787 .974 r
.80415 .19615 .8082 .20904 .83487 .20657 .83105 .19364 Mtetra
.589 .788 .974 r
.83105 .19364 .83487 .20657 .86166 .20405 .85806 .19108 Mtetra
.59 .788 .975 r
.85806 .19108 .86166 .20405 .88856 .20149 .8852 .18848 Mtetra
.59 .789 .975 r
.8852 .18848 .88856 .20149 .91557 .19889 .91245 .18584 Mtetra
.617 .786 .963 r
.04964 .13687 .05949 .14913 .08271 .1462 .07304 .1339 Mtetra
.07304 .1339 .08271 .1462 .10603 .14327 .09653 .13092 Mtetra
0 .324 .801 r
.09653 .13092 .10603 .14327 .12775 .16276 .11868 .1464 Mtetra
0 .24 .756 r
.11868 .1464 .12775 .16276 .14973 .18253 .1407 .16722 Mtetra
.128 .434 .873 r
.1407 .16722 .14973 .18253 .17241 .196 .16347 .18139 Mtetra
.272 .548 .925 r
.16347 .18139 .17241 .196 .19558 .20539 .18675 .19128 Mtetra
.362 .616 .948 r
.18675 .19128 .19558 .20539 .2191 .21203 .21041 .19828 Mtetra
.42 .66 .959 r
.21041 .19828 .2191 .21203 .24291 .21671 .23437 .20323 Mtetra
.46 .689 .965 r
.23437 .20323 .24291 .21671 .26695 .21998 .25857 .20669 Mtetra
.488 .709 .968 r
.25857 .20669 .26695 .21998 .29119 .22218 .28297 .20904 Mtetra
.508 .724 .97 r
.28297 .20904 .29119 .22218 .3156 .22356 .30756 .21053 Mtetra
.524 .736 .971 r
.30756 .21053 .3156 .22356 .34018 .2243 .33231 .21135 Mtetra
.536 .745 .972 r
.33231 .21135 .34018 .2243 .3649 .22452 .35722 .21163 Mtetra
.545 .752 .972 r
.35722 .21163 .3649 .22452 .38976 .22433 .38227 .21148 Mtetra
.553 .757 .973 r
.38227 .21148 .38976 .22433 .41476 .22379 .40746 .21097 Mtetra
.559 .762 .973 r
.40746 .21097 .41476 .22379 .43988 .22297 .43278 .21016 Mtetra
.564 .766 .973 r
.43278 .21016 .43988 .22297 .46513 .2219 .45822 .20911 Mtetra
.568 .769 .973 r
.45822 .20911 .46513 .2219 .4905 .22063 .4838 .20784 Mtetra
.571 .772 .973 r
.4838 .20784 .4905 .22063 .516 .21919 .50949 .20639 Mtetra
.574 .774 .974 r
.50949 .20639 .516 .21919 .54161 .21759 .53531 .20477 Mtetra
.576 .776 .974 r
.53531 .20477 .54161 .21759 .56734 .21585 .56125 .20302 Mtetra
.579 .778 .974 r
.56125 .20302 .56734 .21585 .59319 .214 .58731 .20115 Mtetra
.58 .779 .974 r
.58731 .20115 .59319 .214 .61915 .21204 .61348 .19917 Mtetra
.582 .781 .974 r
.61348 .19917 .61915 .21204 .64523 .20999 .63978 .19709 Mtetra
.583 .782 .974 r
.63978 .19709 .64523 .20999 .67143 .20786 .66619 .19492 Mtetra
.584 .783 .974 r
.66619 .19492 .67143 .20786 .69774 .20564 .69272 .19268 Mtetra
.586 .784 .974 r
.69272 .19268 .69774 .20564 .72417 .20336 .71937 .19036 Mtetra
.586 .785 .974 r
.71937 .19036 .72417 .20336 .75071 .20101 .74614 .18798 Mtetra
.587 .786 .974 r
.74614 .18798 .75071 .20101 .77737 .19861 .77303 .18553 Mtetra
.588 .786 .974 r
.77303 .18553 .77737 .19861 .80415 .19615 .80004 .18303 Mtetra
.589 .787 .974 r
.80004 .18303 .80415 .19615 .83105 .19364 .82716 .18048 Mtetra
.589 .788 .974 r
.82716 .18048 .83105 .19364 .85806 .19108 .85441 .17788 Mtetra
.59 .788 .975 r
.85441 .17788 .85806 .19108 .8852 .18848 .88177 .17524 Mtetra
.59 .789 .975 r
.88177 .17524 .8852 .18848 .91245 .18584 .90926 .17255 Mtetra
.617 .786 .963 r
.03963 .12441 .04964 .13687 .07304 .1339 .0632 .12139 Mtetra
.0632 .12139 .07304 .1339 .09653 .13092 .08686 .11836 Mtetra
.104 .474 .894 r
.08686 .11836 .09653 .13092 .11868 .1464 .10948 .1298 Mtetra
0 .208 .733 r
.10948 .1298 .11868 .1464 .1407 .16722 .13153 .15167 Mtetra
.101 .415 .863 r
.13153 .15167 .1407 .16722 .16347 .18139 .15438 .16655 Mtetra
.254 .536 .92 r
.15438 .16655 .16347 .18139 .18675 .19128 .17778 .17695 Mtetra
.349 .609 .946 r
.17778 .17695 .18675 .19128 .21041 .19828 .20158 .1843 Mtetra
.412 .654 .959 r
.20158 .1843 .21041 .19828 .23437 .20323 .22568 .18952 Mtetra
.454 .685 .965 r
.22568 .18952 .23437 .20323 .25857 .20669 .25004 .19318 Mtetra
.483 .707 .968 r
.25004 .19318 .25857 .20669 .28297 .20904 .27462 .19567 Mtetra
.505 .722 .97 r
.27462 .19567 .28297 .20904 .30756 .21053 .29938 .19728 Mtetra
.521 .734 .971 r
.29938 .19728 .30756 .21053 .33231 .21135 .32432 .19818 Mtetra
.534 .743 .972 r
.32432 .19818 .33231 .21135 .35722 .21163 .34941 .19852 Mtetra
.543 .751 .972 r
.34941 .19852 .35722 .21163 .38227 .21148 .37465 .19841 Mtetra
.551 .756 .973 r
.37465 .19841 .38227 .21148 .40746 .21097 .40003 .19793 Mtetra
.557 .761 .973 r
.40003 .19793 .40746 .21097 .43278 .21016 .42555 .19714 Mtetra
.562 .765 .973 r
.42555 .19714 .43278 .21016 .45822 .20911 .4512 .19609 Mtetra
.567 .768 .973 r
.4512 .19609 .45822 .20911 .4838 .20784 .47697 .19482 Mtetra
.57 .771 .973 r
.47697 .19482 .4838 .20784 .50949 .20639 .50288 .19336 Mtetra
.573 .774 .974 r
.50288 .19336 .50949 .20639 .53531 .20477 .5289 .19174 Mtetra
.576 .776 .974 r
.5289 .19174 .53531 .20477 .56125 .20302 .55505 .18997 Mtetra
.578 .777 .974 r
.55505 .18997 .56125 .20302 .58731 .20115 .58132 .18807 Mtetra
.58 .779 .974 r
.58132 .18807 .58731 .20115 .61348 .19917 .60772 .18607 Mtetra
.581 .78 .974 r
.60772 .18607 .61348 .19917 .63978 .19709 .63423 .18396 Mtetra
.583 .782 .974 r
.63423 .18396 .63978 .19709 .66619 .19492 .66086 .18176 Mtetra
.584 .783 .974 r
.66086 .18176 .66619 .19492 .69272 .19268 .68762 .17948 Mtetra
.585 .784 .974 r
.68762 .17948 .69272 .19268 .71937 .19036 .71449 .17713 Mtetra
.586 .785 .974 r
.71449 .17713 .71937 .19036 .74614 .18798 .74149 .17471 Mtetra
.587 .785 .974 r
.74149 .17471 .74614 .18798 .77303 .18553 .76861 .17223 Mtetra
.588 .786 .974 r
.76861 .17223 .77303 .18553 .80004 .18303 .79584 .16969 Mtetra
.589 .787 .974 r
.79584 .16969 .80004 .18303 .82716 .18048 .8232 .16709 Mtetra
.8232 .16709 .82716 .18048 .85441 .17788 .85069 .16445 Mtetra
.59 .788 .975 r
.85069 .16445 .85441 .17788 .88177 .17524 .87829 .16176 Mtetra
.87829 .16176 .88177 .17524 .90926 .17255 .90602 .15902 Mtetra
.617 .786 .963 r
.02946 .11175 .03963 .12441 .0632 .12139 .0532 .10868 Mtetra
.0532 .10868 .0632 .12139 .08686 .11836 .07704 .10559 Mtetra
.286 .6 .951 r
.07704 .10559 .08686 .11836 .10948 .1298 .10013 .11294 Mtetra
0 .176 .71 r
.10013 .11294 .10948 .1298 .13153 .15167 .12222 .13587 Mtetra
.073 .394 .852 r
.12222 .13587 .13153 .15167 .15438 .16655 .14515 .15148 Mtetra
.236 .523 .916 r
.14515 .15148 .15438 .16655 .17778 .17695 .16866 .16238 Mtetra
.337 .601 .944 r
.16866 .16238 .17778 .17695 .20158 .1843 .19259 .1701 Mtetra
.403 .649 .958 r
.19259 .1701 .20158 .1843 .22568 .18952 .21685 .17558 Mtetra
.447 .681 .964 r
.21685 .17558 .22568 .18952 .25004 .19318 .24138 .17944 Mtetra
.479 .704 .968 r
.24138 .17944 .25004 .19318 .27462 .19567 .26612 .18209 Mtetra
.501 .72 .97 r
.26612 .18209 .27462 .19567 .29938 .19728 .29107 .1838 Mtetra
.518 .732 .971 r
.29107 .1838 .29938 .19728 .32432 .19818 .31619 .18478 Mtetra
.531 .742 .972 r
.31619 .18478 .32432 .19818 .34941 .19852 .34147 .18518 Mtetra
.541 .749 .973 r
.34147 .18518 .34941 .19852 .37465 .19841 .3669 .18511 Mtetra
.55 .755 .973 r
.3669 .18511 .37465 .19841 .40003 .19793 .39248 .18466 Mtetra
.556 .76 .973 r
.39248 .18466 .40003 .19793 .42555 .19714 .4182 .18389 Mtetra
.561 .764 .973 r
.4182 .18389 .42555 .19714 .4512 .19609 .44405 .18285 Mtetra
.566 .768 .973 r
.44405 .18285 .4512 .19609 .47697 .19482 .47003 .18158 Mtetra
.569 .771 .974 r
.47003 .18158 .47697 .19482 .50288 .19336 .49614 .18011 Mtetra
.573 .773 .974 r
.49614 .18011 .50288 .19336 .5289 .19174 .52238 .17847 Mtetra
.575 .775 .974 r
.52238 .17847 .5289 .19174 .55505 .18997 .54875 .17668 Mtetra
.577 .777 .974 r
.54875 .17668 .55505 .18997 .58132 .18807 .57523 .17477 Mtetra
.579 .779 .974 r
.57523 .17477 .58132 .18807 .60772 .18607 .60185 .17273 Mtetra
.581 .78 .974 r
.60185 .17273 .60772 .18607 .63423 .18396 .62858 .1706 Mtetra
.583 .781 .974 r
.62858 .1706 .63423 .18396 .66086 .18176 .65544 .16837 Mtetra
.584 .783 .974 r
.65544 .16837 .66086 .18176 .68762 .17948 .68242 .16605 Mtetra
.585 .784 .974 r
.68242 .16605 .68762 .17948 .71449 .17713 .70953 .16366 Mtetra
.586 .784 .974 r
.70953 .16366 .71449 .17713 .74149 .17471 .73675 .1612 Mtetra
.587 .785 .974 r
.73675 .1612 .74149 .17471 .76861 .17223 .7641 .15868 Mtetra
.588 .786 .974 r
.7641 .15868 .76861 .17223 .79584 .16969 .79158 .1561 Mtetra
.588 .787 .974 r
.79158 .1561 .79584 .16969 .8232 .16709 .81918 .15346 Mtetra
.589 .787 .975 r
.81918 .15346 .8232 .16709 .85069 .16445 .8469 .15077 Mtetra
.589 .788 .975 r
.8469 .15077 .85069 .16445 .87829 .16176 .87474 .14803 Mtetra
.59 .788 .975 r
.87474 .14803 .87829 .16176 .90602 .15902 .90272 .14525 Mtetra
0 g
.89362 0 m
.98022 .38351 L
s
.98022 .38351 m
1 .65325 L
s
1 .65325 m
.91448 .33294 L
s
.91448 .33294 m
.89362 0 L
s
.02946 .11175 m
0 .4272 L
s
0 .4272 m
.91448 .33294 L
s
.91448 .33294 m
.89362 0 L
s
.89362 0 m
.02946 .11175 L
s
.02946 .11175 m
.89362 0 L
s
gsave
.44797 -0.02478 -65.9056 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(u) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
0 .4272 m
.29069 .70824 L
s
gsave
.15892 .66839 -66.3192 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(p) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{261.5, 185},
  ImageMargins->{{29.5, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.095767,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000450000^A000`40O003h00Oogoo1Woo003oOol6
Ool00?moo`Ioo`00ogoo1Woo003oOol6Ool00?moo`Ioo`00PWoo1000Ogoo0021Ool01000Oomoo`00
P7oo0021Ool01000Oomoo`00P7oo0020Ool200000goo00000020Ool00?moo`Ioo`00ogoo1Woo003o
Ool6Ool00?moo`Ioo`00ogoo1Woo003oOol6Ool00?moo`Ioo`00ogoo1Woo003oOol6Ool00?moo`Io
o`00ogoo1Woo003LOol4000UOol00=Aoo`P000=oo`03001oogoo02=oo`00c7oo20002goo00<007oo
Ool08goo0034Ool8000COol2000TOol00;aoo`P001]oo`8002Aoo`00]Goo1`008goo0P0097oo002]
Ool8000ZOol2000TOol00:Eoo`P0039oo`03001oo`0002=oo`00WGoo2000>Woo00<007oo00008goo
002FOol70013Ool2000SOol008ioo`P004Yoo`8002=oo`00QWoo2000DWoo00<007oo00008Woo001n
Ool8001JOol00`00Ool0000ROol007Ioo`P0069oo`03001oo`00029oo`00Kgoo1`00JWoo00<007oo
00008Woo001WOol8001aOol00`00Ool0000ROol005moo`P007Uoo`04001oogoo000QOol005Moo`P0
085oo`04001oogoo000QOol0051oo`L008Uoo`04001oogoo000QOol004Qoo`P0091oo`04001oogoo
000QOol0041oo`P009Qoo`05001oogooOol0000POol003Qoo`P00:1oo`05001oogooOol0000POol0
031oo`P00:Qoo`05001oogooOol0000POol002aoo`@0000;Cci;7DlNBae??T/MCahRGBIn8UdRGP2U
Ool01@00Oomoogoo000087oo000/Ool01@00Cai?7TlNBah00dlN00A;7TlNCai?7P<RG@038Uioogoo
0:9oo`05001oogooOol0000POol002aoo`0A001oo`00Bae?7T/MCci;7DlNBae??T/MCah9fbIn8Ud0
]P2SOol00`00Oomoo`02Ool00`00Oomoo`0MOol002aoo`04001oo`00Ool2Cah01D/NCai?7TlNBah0
0TlN00D9g0WK2M`9f`2f0:=oo`05001oogooOol0000OOol002aoo`0C001oogoo001??T/MCai;7Dln
Bae?7T/MCci;7@gL2M/=o0WK0;H0XWoo00D007ooOomoo`0001moo`00;7oo00D007ooOomoo`0000=?
7P05Bai?7TlNCai;7P02Cah01@WL2M/9g03F0;H0XGoo00D007ooOomoo`0001moo`00:goo00<007oo
Ool00goo00h004lnBae?7T/MCci;7DlNBae??T/M0ET9f`gl0P2fX7oo00<007ooOol00Woo00<007oo
Ool077oo000[Ool00`00Oomoo`04Ool01@00Cai?7TlNBah00dlN00E;7TlNCah1>@4h0080eP031IX5
NWoo09eoo`03001oogoo009oo`03001oogoo01aoo`00:goo00<007ooOol01Goo014004lnBae?7T/M
Cci;7DlNBae??P2D0ET1>03G0;H9V`Ej095oo`08Aai;7TLNBcm77T/NAai;?`9;7P03Aai;?`0000Ao
o`03001oogoo01aoo`00:goo00<007ooOol01Goo00<004/NCah00TlN00I;7TlNCai?7T/NCah209D0
1P3G0=H9VPFJ1GXN78AooaM;7P03001oogoo009oo`03001oogoo01aoo`00:goo00<007ooOol01Woo
00d004/MCci;7DlNBae??T/MCai;7Dln09@0]@020=L01PVJ2K/Io1hM6O`N7GIoo`0PAai;7TLNBam7
7T/NAai;?dLNBai77T/oAai;7TLNBcm77T/NAai;?dLNBai77T/oAai;7TLNBcm77T/NAai;?`9;7P03
001oogoo00=oo`03001oogoo01]oo`00:goo00<007ooOol01goo00<004/NCah00TlN00I;7TlNCai?
7T/NCah209D02@3G2I/9VPVK6O`N71XL7Q`ZG@1XOol3Bah00dLNBai;7P0XBah00`00Oomoo`03Ool0
0`00Oomoo`0KOol002]oo`03001oogoo00Qoo`0H001;7DlnBae?7T/MCai;7DlNBae?7P2D0AP0e`fk
2IX9^ahL7QdIo2YM9UdZORIMFWoo035;7dLNBai6oT/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;
7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBcm77T/NAai;?dLNBai77T/oAai;7TLNBcm77T/NAai;
?`02Bah01dLNBcm;7T/NAai;?`0000Eoo`03001oogoo01]oo`00:goo00<007ooOol02Goo00<004/N
Cah00TlN0d/N00E?7T/N0340U@4H008=^`032IXN7AhL008N70@ZG@04<YhbWC:N<Yi:Ool034/NAai;
7TLNBai77T/NAai;7TLNBai77P=;7P05Aai;7T/NBai77P03Bah01DLNBai;7T/NAah0:4/N00<007oo
Ool00goo00<007ooOol06goo000[Ool00`00Oomoo`09Ool03`00Cai;7DlnBae?7T/MCai;7DlNBad0
<@3g0AP=VP023K/041hM7Q`R?AhL:WhVGBYn<WdbWRim<YhbOCZn=Ydj_SJM=Goo04Y6oT/OA_i;7TKn
Bam6oT/NA_i;7dKnBai6oT/OA_i;7TKnBam77T/NA_i;7dLNBai6oT/OAai;7TKnBam77T/NA_i;7dLN
Bai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/NAai;?dLNBai77T/oAai;7TLN
Bcm77T/NAai;?dLNBai77T/o0T/N00I77T/oBai;7TLNBcl2Bah00`00Bcmoo`03Ool00`00Oomoo`0K
Ool002]oo`03001oogoo00Yoo`03001?7T/N00=?7P<f_P03=]h0<`4i008160<=^`058SdN71hL:UdZ
O@02:Ud2<Yh00c:M<Yhf_P04=[h01C[N>[hjgSZn>]h01CkN6Woo00Y77TKnA_i6oTLNA_i77TKnAai6
oP=77P05A_i77TLNAai6oP03Aah014KnAai77T/N0dLN019;7TLNAai77T/NAai;7TLNBai77T/NAai;
7TLNBai77T/NAah3Bah01DLNBai;7T/NAah00d/N00E77T/NBai;7TLN02I;7P03001;7Woo00Aoo`03
001oogoo01Yoo`00:goo00<007ooOol02goo00h004lNBae??T/M>]hf_S[O=[hjgP0A0CT1617L0Pfk
00lN728m7Q`R?BYM:WhZGBin<YdbWS9m=YhfWCZn=Yd00SZn00@ngSZm?]hj_PHngP1e@_hngT;n?]i2
oT;N@_hngT;n@]i6oT;NA_m2oTKn@_i77d;nA_i2oTLO@_i77T;nAam2oTLN@_i77dKnAai6oTLOA_i7
7TKnBam6oTLNA_i;7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dKnBai6oT/OA_i;7TKnBam77T/NA_i;
7dLNBai6oT/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;
7TLNBcm77T/NAai;?dLNBai77T/oAai;7TLNBcm77T/NAai;?dLNBai77T/o009;7P08Aai;?d/NBai7
7T/o001;7PEoo`03001oogoo01Yoo`00:Woo00<007ooOol03Goo0TlN00A;7TlNCahfgP<f_P0;07@1
604i0CPAfa6k4M/R728m7Q`R?@02:Wd02BYM<YhbWS:N<YdbWSJn>[hf_P02>[h013[N>[hjgSZn1SkN
00A2gSkN@_hngP=2oP03@]i2oT;n00A2oP04A_i2oTKn@_h8A_h02TLNA_i6oTKnAai6oTLNA_i77TKn
0dLN00=6oTLNAah024LN00E;7TLNAai77T/N00=77P0>Bai77T/NAai;7TLNBai77T/NAai;7TLNBai7
7P=;7P05Aai;7T/NBai77P0/Bah00`00Bai;7P04Ool00`00Oomoo`0JOol002Yoo`03001oogoo00io
o`0OBae?7T/MCci;7Ahm6Q`N?AXm03<1604i0APAg0fk4M`R?28m7Q`^ORYM;WhZGCJN<YdbWS9m>[hf
_SZn=Yd00SZn00@ngSZm?]hj_P8ngP0<@]hngSkN?]i2oSkN@_hngT;n@]i2oSkN0T;n06]6oT;NA_m2
oTKn@_i77d;nA_i2oTLO@_i77T;nAam6oTLN@_i77dKnAai6oT/OA_i77TKnBam6oTLNA_i;7dKnBai6
oT/OA_i;7TKnBam6oT/NA_i;7dKnBai6oT/OA_i;7TKnBam77T/NA_i;7dLNBai6oT/OAai;7TLNBam7
7T/NAai;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/oAai;7TLNBcm77T/NAai;?dLNBai7
7T/oAai;7TLNBcm77T/NAai;?dLNBai77T/o009;7P07Aai;?d/NBah004/oBah017oo00<007ooOol0
6Woo000ZOol00`00Oomoo`0>Ool01000Cai?7T/N0TlN0aXm00L0U@EI0AP1>AGK5M`A^`038Sd01B8l
;WdZOBim:Ud00S:N00HfWS:M>[hf_SZn=[h2>[h00ckN>[hjgP05?]h014;n?]i2gT;N24;n00I6oT;n
@_i2oTKn@_h:A_h02TLNA_i6oTKnAai6oTLNA_i77TKn0dLN00=6oTLNAah014LN01I;7TLNAai77T/N
Aai;7TLNBai77T/NAai;7TLNBai77T/NAai;7TLNBai77P=;7P05Aai;7T/NBai77P03Bah00dLNBai;
7P0XBah00`00Bai;7P05Ool00`00Oomoo`0IOol002Yoo`03001oogoo00moo`0;001;7DlNBae??T/M
7SdJ71hm09D5F@020CT04a7K5M`AfbHm8S`R?B8L;Wh^OBin:UdfWS:M=YhbWCZn=[hj_SJm008j_P03
?]hj_CkN00<ngP1a@]hngT;n?]i2oSkN@_i2gT;n@]i2oT;NA_i2oTKn@_i6oT;nA_i2oTLO@_i6oT;n
Aam2oTLN@_i77dKnAai2oTLOA_i77TKnBam6oT/NA_i;7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dKn
Bai6oT/OAai;7TKnBam77T/NA_i;7dLNBai6oT/OAai;7TKnBam77T/NAai;7dLNBai77T/OAai;7TLN
Bam77T/NAai;7dLNBai77T/OAai;7TLNBcm77T/NAai;?dLNBai77T/oAai;7TLNBcm77T/NAai;?`02
Bah01TLNBcm;7T/NAai;?`9;7P05Aai;?d/N00177P05Ool00`00Oomoo`0IOol002Yoo`03001oogoo
011oo`=?7P0>Bai?7TlN0GXJ?@2E07@5F@4i5M`EfaGL5M/V?@8R?@<^O@03;WhbWCJN008fWP09<Ydj
_SZn>[hf_SkN>]hngSZn00HngP04@_i2gT;n@]h8@_h00dKn@_i2oP02A_h014;nA_i6oTLN0dKn00i7
7TKnAai6oTLNA_i77TKnAai6oTLNA_i77TKn0dLN00=6oTLNAah014LN01I;7TLNAai77T/NAai;7TLN
Bai77T/NAai;7TLNBai77T/NAai;7TLNBai77P=;7P05Aai;7T/NBai77P0]Bah00`00Baioo`04Ool0
0`00Oomoo`0IOol002Yoo`03001oogoo015oo`09Cci;7DlNBae??T/M0GX0U@2f0085F@0B0CTIo17K
5M`R?2IM8S`VGBYM;Wh^OBin<Ydf_S:M=[hf_C[N0SZn01<f_CkN>[hngSZm@_hngT;N?]i2oSkN@_hn
gT;n?]i2oT;NA_i2gP02@_h0IDKn@_i6oT;nAam2oTKn@_i77d;nAai2oTLOA_i77TKnAam6oTLNA_i;
7dKnAai6oT/OA_i;7TKnBam6oT/NA_i;7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dLNBai6oT/OAai;
7TKnBam77T/NA_i;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/NAai;
7dLNBai77T/oAai;7TLNBcm77T/NAai;?dLNBai77T/oAai;7TLNBcl00T/N00I77T/oBai;7TLNBcl2
Bah014LN001;7T/N17oo00<007ooOol06Goo000ZOol00`00Oomoo`0BOol3Cah014/NCah0U05j0P2E
0PEj00@Eg1Wl5O`Io0<V?@06;Wh^OBim;WdfWS:M0cJN13Zn2SkN00E2gT;n@]i2oT;N00Q2oP03A_i2
oTKn0096oP04@_i6oTKnAah3A_h02TLNA_i77TKnAai6oTLNA_i77TKn0dLN00=6oTLNAah014LN00E;
7TLNAai77T/N00=77P0BBai77T/NAai;7TLNBai77T/NAai;7TLNBai77T/NAai;7TLN0d/N00E77T/N
Bai;7TLN02];7P03001;7T/N00Aoo`03001oogoo01Uoo`00:Woo00<007ooOol04goo01e??T/MCai;
7Dln07@0e`2E0;H5F@Ej5M/Io1GK:UdV?2IM8S`bORim<Yh^OCJn<Ydf_SJM>[hf_C[N008j_P1f>[dn
gSZn?]hj_D;n?]i2gSkN@_hngT;n?]i2oT;N@_i2gTKn@]i6oT;nA_i2oTKn@_i77d;nAai2oTLOA_i7
7T;nAam6oTLNA_i77dKnAai6oT/OA_i77TKnBam6oT/NA_i;7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;
7dLNBai6oT/OAai;7TKnBam77T/NA_i;7dLNBai6oT/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;
7TLNBam77T/NAai;7dLNBai77T/oAai;7TLNBcm77T/NAai;?dLNBai77T/oAai;7TLNBcl2Bah01TLN
Bcm;7T/NAai;?`9;7P06Aai;?d/N00177T/o1Goo00<007ooOol067oo000ZOol00`00Oomoo`0COol0
3000Cai?7TlNBai?7P2D0=L0]PVJ1GXMo08Io0065O`VGBHm9Ud^OBin0Rim00<fWSJn=Yh00SJN13Zn
23kN00I2gSkN@_i2gT;n@]h6@_h01TKn@_i6oT;nA_i2oP=6oP04@_i6oTKnAah3A_h02TLNA_i77TKn
Aai6oTLNA_i77TKn0dLN00A6oTLNAai;7P=77P05Bai77TLNAai;7P03Aah02T/NAai;7TLNBai77T/N
Aai;7TLN0d/N00E77T/NBai;7TLN00=;7P05Aai;7T/NBai77P0YBah00`00Bai;7P05Ool00`00Oomo
o`0HOol002Yoo`03001oogoo01Aoo`0Q001??T/MCai;7@0A07@0e`2f2I/5FAhL6O`N72Hm:UdV?2YM
;WdbWRim<YhfWCJn<Ydf_SZn>]hj_C[N>[hngSZm00@ngP1a@_hngT;n?]i2oT;N@_hngTKn@]i2oT;N
A_i2oTKn@_i6oT;nAai2oTLO@_i77T;nAam6oTLN@_i77dKnAai6oTLOA_i77TKnBam6oTLNA_i;7dKn
Bai6oT/OA_i;7TKnBam6oT/NA_i;7dKnBai6oT/OAai;7TKnBam77T/NA_i;7dLNBai6oT/OAai;7TKn
Bam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBcm77T/NAai;?dLN
Bai77T/oAai;7TLNBcm77T/NAai;?`02Bah01TLNBcm;7T/NAai;?`9;7P04Aah004/NBah5Ool00`00
Oomoo`0HOol002Yoo`03001oogoo01Eoo`0<001;7TKnBai6oP2D0?L0e`fJ2IXIo1gl0QWl00<ZGBIM
9Sd00S9m00LbWRim<WdfWSJn=Yhf_P05>[h4?]h014;N?]i2gSkN0T;N0d;n00=2gT;n@_h014;n00A6
oT;nA_i2oPQ6oP0:Aai6oTKnA_i77TKnAai6oTLNA_h3Aah01DKnAai77TLNA_h00TLN00E;7TLNAai7
7T/N00=77P0>Bai77T/NAai;7TLNBai77T/NAai;7TLNBai77P=;7P05Aai;7T/NBai77P03Bah00dLN
Bai;7P0YBah01000Bai;7T/N17oo00<007ooOol067oo000YOol00`00Oomoo`0GOol03@00Bai6oT/N
0100U@2f0=L=VQ6k7O`N71Wl00<ZG@099UdbWRim<Yh^OCZn=Ydf_SJM008j_P06?]hj_CkN>[hngSjm
0SkN06]2oSkN@_hngT;n?]i2oT;N@_hngTKn@_i6oT;NA_i2oTKn@_i77T;nAai2oTLO@_i77T;nAam6
oTLN@_i77dKnAai6oTLOA_i77TKnBam6oTLNA_i;7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dKnBai6
oT/OAai;7TKnBam77T/NA_i;7dLNBai6oT/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBam7
7T/NAai;?dLNBai77T/oAai;7TLNBcm77T/NAai;?dLNBai77T/o009;7P06Aai;?d/NBai77T/o0T/N
00]77T/oBai;7TLNBcm;7P00Aai;?d/N00Eoo`03001oogoo01Moo`00:Goo00<007ooOol067oo00XR
GBInA_i;7P0@0?P0ePfk3IX=^`<N70@ZG@0;<YhbWC:N<Wdf_SJN=[hfWSJn>[hjgP02>[h5?]h01T;n
?]i2gSkN@_i2gPI2oP03A_i2oTKn0096oP03@_i6oTKn00A6oP0:Aai6oTKnA_i77TKnAai6oTLNA_h3
Aah01DKnAai77TLNA_h00dLN00A6oTLNAai;7P=77P0>Bai77TLNAai;7TLNBai77T/NAai;7TLNBai7
7P=;7P05Aai;7T/NBai77P03Bah00dLNBai;7P0[Bah01000Bai;7T/N1Goo00<007ooOol05goo000D
Ool3000BOol00`00Oomoo`0HOol01@008UdVOR9M05@00P4H01L=VQ6k3IXA^agl8Q`Mo2in:Ud^OBYM
<YhbOC:N<Wdj_SJM>[hfWCkN>[hngSZm00<ngP1^?[dngSkN@_hngT;n?]i2oT;N@_i2gT;n@]i6oT;n
A_i2gTLN@_i6oT;nAai2oTLN@_i77T;nAai6oTLOA_i77TKnBam6oTLNA_i;7dKnAai6oT/OA_i;7TKn
Bam6oT/NA_i;7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dLNBai6oT/OAai;7TKnBam77T/NAai;7dLN
Bai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBcm77T/NAai;?dLNBai77T/oAai;7TLN
Bcm77T/NAai;?`9;7P06Aai;?d/NBai77T/o0T/N00I77T/oBai;7TLN0002Bah00dLNBcmoo`03Ool0
0`00Oomoo`0GOol001Eoo`03001oogoo015oo`03001oogoo01Uoo`0:9WhRGBIn9Wd04@4H0?PA^`fk
3IX28Q`02QhL:UdZGBYM;UdbWC:N<YdfWS:M0SJn00Hj_SJn>[hj_SkN>[h5?]h014;N@_hngT;N0T;n
00A2gT;n@_i6oP=2oP03A_i2oTKn0096oP03@_i6oTKn00A6oP0:Aai6oTKnA_i77TKnAai6oTLNA_h3
Aah00dKnAai77P08Aah04T/NAai;7TLNBai77T/NAai;7TLNBai77T/NAai;7TLNBai77P=;7P05Aai;
7T/NBai77P0_Bah00`00Bai;7P02Bah4Ool00`00Oomoo`0GOol001=oo`<001=oo`03001oogoo01Yo
o`0O9WhRGBIn07D5>@4H5M/A^aGK4K/R?B8L8SdZGBin:Ud^OC9m=YhbWCJN=Ydj_SJm>[hj_CkN>[hn
gSZm@]h00SkN06XngD;n?]i2oSkN@_i2gT;n@]i2oT;NA_i2gTKn@_i6oT;nAai2oTKn@_i77TKnAai2
oTLNA_i77TKnAam6oTLNA_i;7dKnAai6oT/OA_i;7TKnBam6oT/NA_i;7dKnBai6oT/OA_i;7TKnBam7
7T/NA_i;7dLNBai6oT/OAai;7TKnBam77T/NA_i;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai7
7T/OAai;7TLNBam77T/NAai;?dLNBai77T/oAai;7TLNBcm77T/NAai;?`9;7P06Aai;?d/NBai77T/o
0T/N00Y77T/oBai;7TLNBcm;7P00Aai;?`9;7PEoo`03001oogoo01Ioo`004Woo00@007ooOol001=o
o`03001oogoo01]oo`0>0ETRGBIn03<1>@4H5K/A^aFk4K/V?B8L8Sd^G@8^O@05=YhbWC:N<YdfWP05
>[h00ckN?[hngP05?]h2@]h00d;n?]i2gP02@_h014;N@_i2oTKn0d;n00=6oT;nA_h00TKn00=2oTKn
A_h014Kn00Y77TKnA_i6oTLNA_i77TKnAai6oP=77P04A_i77TLNBah3Aah04T/NAai77TLNBai77T/N
Aai;7TLNBai77T/NAai;7TLNBai77P=;7P05Aai;7T/NBai77P0aBah00`00Bai;7P02Bah5Ool00`00
Oomoo`0FOol0019oo`04001oogoo000COol00`00Oomoo`0LOol0Q`5I0CP0UPEI1CT161Wl4K/Efb8L
9SdR?2Hm:Ud^ORiM=YhbWCJN<Ydj_SJM>[hf_CkN>[dngSZn?]hngD;n?]i2gSkM@_hngT;n?]i6oT;N
@_i2gTKn@_i6oT;nA_i2oTKn@_i77T;nA_i2oTLNA_i77T;nAai6oTLNA_i77dKnAai6oT/OA_i77TKn
Bam6oT/NA_i;7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dLNBai6oT/OAai;7TKnBam77T/NA_i;7dLN
Bai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/NAai;?dLNBai77T/oAai;7TLN
Bcm77T/NAai;?`02Bah01TLNBcm;7T/NAai;?`9;7P06Aai;?d/NBai77T/o0T/N00M77P00Bai;7TLN
Bcm;7P04Ool00`00Oomoo`0FOol001=oo`@0019oo`03001oogoo01eoo`030ET0eP2E0085F@085M/I
faWK6M`V?2Hm9S`bO@8^O@05=YdfWSJM=YhfW@04>[h013kN>[hngSjn1SkN00A2oT;N@_i2gPI2oP06
A_i2oTKn@_i6oT;n1TKn00i77TKnAai6oTLNA_i77TKnAai6oTLNA_i77TKn1TLN00E;7TLNAai77T/N
00=77P0:Bai77T/NAai;7TLNBai77T/NAah3Bah01DLNBai;7T/NAah0<d/N00<004/NBah00d/N17oo
00<007ooOol05Woo000YOol00`00Oomoo`0MOol0Q01D0ET0eP2F1ET5FQGK6O`EfbYM9S`V?B8l<Wh^
GC9n<YdfWS:M=Yhj_CZn>[dj_SZm?]hj_CkN>[i2gSkM@_hngT;N?]i2oT;N@_i2gTKn@]i2oT;NA_i2
oTKn@_i6oT;nA_i2oTLN@_i77T;nAai6oTLN@_i77TKnAai6oTLNA_i77TKnBam6oT/NA_i;7dKnBai6
oT/OA_i;7TKnBam6oT/NA_i;7dLNBai6oT/OAai;7TKnBam77T/NA_i;7dLNBai6oT/OAai;7TLNBam7
7T/NAai;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/oAai;7TLNBcm77T/NAai;?`9;7P06
Aai;?d/NBai77T/o0T/N00I77T/oBai;7TLNBcl2Bah01TLNBcm;7P00Aai;?`9;7P03Aaioogoo009o
o`03001oogoo01Ioo`00:Goo00<007ooOol07Woo00D0403G0=H=NPEI008Mo08If`05:UdV?BXm;Wdb
O@02;Wd013JM=YhfWCJN1CZn00DngSjn?]hngT;N00<ngP92gP03@_i2gT;n00E2oP04A_i2oTKn@_h6
A_h04TLNA_i6oTKnAai6oTLNA_i77TKnAai6oTLNA_i77TKnAai6oPI77P05Bai77TLNAai;7P03Aah0
2T/NAai;7TLNBai77T/NAai;7TLN0d/N00E77T/NBai;7TLN039;7P03001;7T/N009;7PEoo`03001o
ogoo01Eoo`00:7oo00<007ooOol07goo01`0M@0@0=L0ePfJ1ETMo1Wk7O`V?2YM9S`ZGC9m<Yh^OC:N
=Ydf_SJM=[hj_CZn>[dngSjn?]hn_@8ngP1W@]hngD;n?]i2oSkN@_i2gT;n@]i6oT;NA_i2gTKn@_i6
oT;nA_i2oTLN@_i77T;nAai2oTLNA_i77TKnAai6oTLNA_i;7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;
7dKnBai6oT/OA_i;7TKnBam77T/NA_i;7dLNBai6oT/OAai;7TKnBam77T/NA_i;7dLNBai77T/OAai;
7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/NAai;?dLNBai77T/oAai;7TLNBcl00T/N00I7
7T/oBai;7TLNBcl2Bah01TLNBcm;7T/NAai;?`9;7P07Aai;?`00Bai77T/oBah01Goo00<007ooOol0
5Goo000XOol00`00Oomoo`0OOol207@010DH0=LE^Pej11gl0RYM00<V?C9m<Wd00S9m00@f_SJN>[hf
W@Dj_PDngP08@]hngT;N?]i2oT;N@_i2gPA2oP03A_i2oTKn0096oP03@_i6oTKn00A6oP0:Aai6oTKn
A_i77TKnAai6oTLNA_h3Aah01DKnAai77TLNA_h00TLN00i;7TLNAai77T/NAai;7TLNBai77T/NAai;
7TLN0d/N00E77T/NBai;7TLN00=;7P05Aai;7T/NBai77P0`Bah00`00Bai;7P03Bah4Ool00`00Oomo
o`0EOol002Qoo`03001oogoo01moo`0N1?L0E00a0=H0ea6J5K/Qo1gl6O/^GBYM;UdZ?3:N<WdbWRim
>[hfWCZn=YdngSZm?]hj_CkN?[hngSjm0SkN06M2oSkM@_hngT;n@]i2oT;NA_i2gTKn@_i6oT;nAai2
oTKn@_i77T;nAai2oTLNA_i77TKnAai6oTLNA_i;7TKnAai6oT/OA_i;7TKnBam6oT/NA_i;7dKnBai6
oT/OA_i;7TKnBam6oT/NA_i;7dLNBai6oT/OAai;7TKnBam77T/NAai;7dLNBai77T/OAai;7TLNBam7
7T/NAai;7dLNBai77T/OAai;7TLNBcm77T/NAai;?dLNBai77T/oAai;7TLNBcm77T/NAai;?`02Bah0
1TLNBcm;7T/NAai;?`9;7P06Aai;?d/NBai77T/o0T/N00H004/oBai;?TLNBcl4Ool00`00Oomoo`0E
Ool002Qoo`03001oogoo021oo`80M0051AP0eaFk5KXE^`038Q`4:Ud01S:M<WdfWSJM=[hfWP@j_P03
?[hj_SkN00<ngPE2gP92oP04@]i2oT;nA_h3@_h00dKn@_i6oP02A_h00d;nA_i6oP04A_h02TLNA_i6
oTKnAai6oTLNA_i77TKn0dLN00E6oTLNAai;7TKn00977P0>Bai77TLNAai;7TLNBai77T/NAai;7TLN
Bai77P=;7P05Aai;7T/NBai77P0fBah00`00Bai;7P03Bah5Ool00`00Oomoo`0DOol002Qoo`03001o
ogoo021oo`0L1=H0M@eI1CPAVQFk4IXE^bHL8Q`Qo2im;Ud^OC9m=YhbOCJN=Ydj_SJM>[hj_CkN>[dn
gSZm@]h2?]h0HSjm@_hngT;n?]e2oT;N@_i2gTKn@_i6oT;NA_i2oTKn@_i77T;nA_i2oTLNA_i77T;n
Aai6oTLNA_i77TKnAai6oT/NA_i;7TKnBam6oT/NA_i;7dKnBai6oT/OA_i;7TKnBam77T/NA_i;7dLN
Bai6oT/OAai;7TKnBam77T/NA_i;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLN
Bam77T/NAai;?dLNBai77T/oAai;7TLNBcl2Bah01TLNBcm;7T/NAai;?`9;7P06Aai;?d/NBai77T/o
0T/N00a77T/oBai;7TLNBcl004/nAai;?d/NBch5Ool00`00Oomoo`0DOol002Qoo`03001oogoo025o
o`0;1=H0M0eI1APIfaFk5KXV?2HL9S`V7003;Ud3=Yd00cJN>Ydj_P03>[h2?[h4?]h6@]h3@_h014;N
@_i2oTKn0d;n00=6oT;nA_h02DKn00I77TKnAai6oTLNA_h3Aah00dKnAai77P04Aah01D/NAai77TLN
Bah00dLN00Y;7TLNBai77T/NAai;7TLNBai77P=;7P05Aai;7T/NBai77P0dBah00`00Bai;7P03Bah5
Ool00`00Oomoo`0DOol002Qoo`03001oogoo025oo`211?L0E15i3ETMfaWK7M/I^bHm9Q`V?BiM<Wd^
GCJN<WdfWSJM=YhjWCZn>[dj_SZm?]hj_CkN?]e2gSkN@]hngD;n@]i2oSkMA_i2gTKn@]i6oT;nA_i2
gTKn@_i6oT;nAai2oTKn@_i77TKnAai6oTLNA_i77TKnBai6oTLNA_i;7TKnBai6oT/NA_i;7TKnBam6
oT/NA_i;7dKnBai6oT/OAai;7TKnBam77T/NA_i;7dLNBai6oT/OAai;7TKnBam77T/NAai;7dLNBai7
7T/OAai;7TLNBam77T/NAai;7dLNBai77T/oAai;7TLNBcm77T/NAai;?dLNBai77T/o009;7P06Aai;
?d/NBai77T/o0T/N00I77T/oBai;7TLNBcl2Bah02dLNBcm;7T/N001;?d/NBci77T/oBah017oo00<0
07ooOol057oo000XOol00`00Oomoo`0QOol021Dh1=H=FA5i3ETMfaWK7M/2:S`00bHL9S`^O@02<Wd0
1SJN=YdfWCJM>[hj_@<j_P04?[hngSjn@]h3?]h4@]h00d;n@]i2oP02@_h01D;NA_i2oTKn@_h03TKn
00I77TKnAai6oTLNA_h3Aah014KnAai77T/N0dLN019;7TLNBai77T/NAai;7TLNBai77T/NAai;7TLN
Bai77T/NAah3Bah01DLNBai;7T/NAah0;T/N1@001T/N17oo00<007ooOol057oo000XOol00`00Oomo
o`0ROol0NQ4h1?L=FA5i8O/V71WK7M/Z?2iM:S`bOBiM<Wd^GCZN=Ydj_SJM>[hjWCZn>[dngSZm?]hn
_D;N?]e2oSkN@]i2gD;n@]i2oT;MA_i2gTKn@]i6oT;nA_i2oTKn@_i6oT;nAai2oTLNA_i77TKnAai6
oT/NA_i77TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBam6oT/NA_i;7dKnBai6oT/OAai;7TKnBam7
7T/NA_i;7dLNBai6oT/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai7
7T/oAai;7TLNBcl2Bah01TLNBcm;7T/NAai;?`9;7P04Aai;?d/NBah:00002d/NBci77T/o001;?TLN
Bcm;7T/nAah01Goo00<007ooOol04goo000XOol00`00Oomoo`0ROol02AEH5CPIVQVJ4GTQnb7l8O/Z
?@03:S`01CIm<WdbOC9m=Yh00cJM00@n_SZm>[hj_P@ngP08@]hngT;N?]i2oT;N@_i2gPA2oP03A_i2
oTKn0096oP03@_i6oTKn00A6oP0>Aai6oTKnA_i77TKnAai6oTLNA_i77TKnAai6oP=77P04A_i77TLN
Bah3Aah02T/NAai;7TLNBai77T/NAai;7TLN0d/N00E77T/NBai;7TLN00=;7P03Aai;7T/N01];7PT0
00m;7P03001;7T/N00=;7PEoo`03001oogoo01=oo`00:7oo00<007ooOol08Woo07DE>1EH4CPM^QVJ
9O`QnbHL8O/^GBXl;UdbOCIm<WdfWSJM>[hfWCZn>[dn_SZm?[hn_CkN?[e2gSjm@]hngD;n?]i2oT;M
A_i2gT;n@]i6oT;NA_i2oTKn@_i6oT;nAai6oTLN@_i77TKnAai6oTLNA_i77TKnBai6oTLNA_i;7TKn
Bai6oT/NA_i;7TKnBai6oT/NA_i;7dKnBai6oT/OA_i;7TKnBam77T/NA_i;7dLNBai6oT/OAai;7TLN
Bam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/OAah02P0000E;?d/NBai77T/o
009;7P06Aai;?d/NBai77T/o0T/N01177T/oBai;7TLNBcm;7T/nAah004/NBci77T/oBai;?PAoo`03
001oogoo01=oo`009goo00<007ooOol08goo00@U^AEH5EPQfP8IVP03:Q`Qnb7l008^G@04;U`^GC9m
=Wd2<Wd013ZM>[hjWCZM0Sjn00<j_Cjn?]h00ckN1D;N00Y2oT;N@_i2gTKn@_i6oT;nA_i2oP=6oP03
@_i6oTKn00A6oP0:Aai6oTKnA_i77TKnAai6oTLNA_h3Aah01DKnAai77T/NA_h00TLN00i;7TLNAai7
7T/NAai;7TLNBai77T/NAai;7TLN0d/N00E77T/NBai;7TLN00a;7PT0029;7P03001;7T/N00A;7PAo
o`03001oogoo01=oo`009goo00<007ooOol097oo01`U^ADh5EPQfRGk9Q/Z72HK:S`^G2iM;S`bGCIm
=YdfOCZn=Ydj_SJM?]hj_CkN>[dngSkM@]hn_@92gP14@_hngD;n@]i2oT;MA_i2gTKn@]i6oT;NA_i2
oTKn@_i6oT;nAai6oTLN@_i;7TKnAai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6
oT/NA_i;7TKnBai6oT/OAai;7TKnBam77T/NA_i;7dLNBai77T/OAai;7TLNBam77PT0000>Aai;7dLN
Bai77T/oAai;7TLNBcm77T/NAai;?`9;7P06Aai;?d/NBai77T/o0T/N00I77T/oBai;7TLNBcl2Bah0
1TLNBcm;7T/NAai;?`9;7P0:Aai;?d/N00177T/oBai;?TLNBcl5Ool00`00Oomoo`0BOol002Moo`03
001oogoo02Aoo`069ITU^AEH9M/QfRGK0bXL0S9M00XbOC9M=YdfOCJM=Wdj_SZm>[hjW@<n_P05>[dn
gSkN@]hngP05@]h2@_h01d;N@_i2oTKn@_i6oT;n00a6oP06Aai6oTLNA_i77TKn0dLN00E6oTLNAai;
7TKn00977P0:Bai77T/NAai;7TLNBai77T/NAah3Bah014LNBai;7T/N2P00=D/N00<004/NBah00d/N
1Goo00<007ooOol04Woo000WOol00`00Oomoo`0UOol0CR6I9KTQfRGK8MXUnbhl:Q`V6cIm<U`bOC9L
>YhfWCZM=Wdn_SZM>[hjWCkN?[dngSjm@]hngD;N?]e2oT;N@_hngDKn@]i6oT;MA_i2oTKn@]i6oT;n
A_i2oTLN@_i77TKnAai6oTLNA_i;7TKnAai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKn
Bai6oT/NA_i;7`T0000OBai6oT/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/NAai;
7dLNBai77T/oAai;7TLNBcl00T/N00I77T/oBai;7TLNBcl2Bah01TLNBcm;7T/NAai;?`9;7P06Aai;
?d/NBai77T/o0T/N00e77T/oBai;?TLNBcl004/nAai;?d/NBci77P04Ool00`00Oomoo`0BOol002Mo
o`03001oogoo02Eoo`069KTUVBFi;Q/Ufb7J0bhl0c9M00<bOCJM>Yd00SZM00Dj_Cjn?[dn_Sjm008n
_P8ngP=2gP05?]i2gT;N@_i2gP02@_h00dKn@]i2oP02A_h00d;nA_i6oP0<A_h01TLNA_i77TKnAai6
oP977P04Bai6oTLNAah:000014/NAai;7TLN0d/N00E77T/NBai;7TLN03a;7P03001;7T/N00A;7PAo
o`03001oogoo019oo`009goo00<007ooOol09Goo00danCGj8IT^6bgk;Q/]nc9L;S`b?3Il=WdfO002
=Wd073ZN=YdjWCZM?[hj_Cjn?[e2gSjm@]hngD;N?]e2gT;M@_i2gT;n@]e6oT;NA_i2gDKn@_i6oT;N
0dKn00e2oTLNA_i77TKnAai6oTLNA_i;7TKnAai6oP090000=4KnBai6oT/NA_i;7TKnBai6oT/NA_i;
7dLNBai6oT/OAai;7TKnBam77T/NA_i;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;
7TLNBam77T/NAai;?dLNBai77T/o0T/N00I77T/oBai;7TLNBcl2Bah01TLNBcm;7T/NAai;?`9;7P06
Aai;?d/NBai77T/o0T/N00]77T/oBai;?P00Bcm;7T/nAai;?d/N00Eoo`03001oogoo015oo`009goo
00<007ooOol09Woo00<anSGj<OT00bhK00@bG3IL=U`fG0<fO@@jW@08?[hj_Cjn?[dn_Sjm?]hn_PI2
gP08@_i2gT;n@]i6oT;nA_i2oPU6oPX00005A_i77TKnAai6oP02Aah04T/NA_i;7TLNBai77T/NAai;
7TLNBai77T/NAai;7TLNBai77P=;7P05Aai;7T/NBai77P0kBah00`00Bai;7P03Bah5Ool00`00Oomo
o`0AOol002Moo`03001oogoo02Ioo`0W=OXanCGj=S/jG2gk;Q/bG3IM<U`jWCIl=WdfO3jn>Ydn_SZM
?[hn_CkN?[e2gSjm@]hn_D;N?]e2oT;M@]i2gDKn@]i6oT;MA_i2gTKn00T00011Aai6oTLNA_i;7TKn
Bai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NAai;7TKn
Bam77T/NA_i;7dLNBai6oT/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBcm77T/NAai;?`02
Bah01TLNBcm;7T/NAai;?`9;7P06Aai;?d/NBai77T/o0T/N00I77T/oBai;7TLNBcl2Bah04TLNBcm;
7T/nAai;?d/NBci77T/oBah004LNBcm;7T/nAai;?`D001=oo`009goo00<007ooOol09Woo00@anCGj
<OXenP<f>`06=U`bG3IL=U`jWCYm1SZM00Hn_Sjm?[hn_D;N?]d4@]h:00000dKn@_i6oP09A_h02TLN
A_i6oTKnAai6oTLNA_i;7TKn0TLN00i;7TKnAai77T/NAai;7TLNBai77T/NAai;7TLN0d/N00E77T/N
Bai;7TLN045;7P03001;7T/N00A;7PAoo`03001oogoo015oo`009goo00<007ooOol09goo00Tn6CGj
<OTf?3Hk>U`f>cYm>U`00SYm00PjWCIl>YdjWCjn>Ydn_Sjm2@0000e2gD;n@]e6oT;MA_i2gTKn@]e6
oT;nA_i2o@03A_h0@T;mAai6oTLNA_i;7TKnAai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;
7TKnBai6oT/NA_i;7TKnBai6oT/NAai;7TKnBai77T/NA_i;7dLNBai77T/OAai;7TLNBam77T/NAai;
7dLNBai77T/OAai;7TLNBam77T/NAai;?`9;7P06Aai;?d/NBai77T/o0T/N00I77T/oBai;7TLNBcl2
Bah01TLNBcm;7T/NAai;?`9;7P0DAai;?d/NBai77T/oBai;?TLNBcm;7T/nAah004/NBci77T/oBai;
?PAoo`03001oogoo015oo`009goo00<007ooOol09goo00=2>Shj?SX013Hk0SYl2P0000@n_D;N?[dn
_P92gP04@]e2gT;N@_h2@]h01D;nA_i2gTKn@_h044Kn00I77TKnA_i6oTLNA_h2Aah04T/NA_i77TLN
Bai6oT/NAai;7TLNBai77T/NAai;7TLNBai77P=;7P03Aai;7T/N049;7P03001;7T/N00=;7PAoo`03
001oogoo015oo`009Woo00<007ooOol0:7oo2@0002<jOCYL?YdjWCjM>Ya2_Sjm@[hnWD;N?[e2gSjm
@]i2gD;N?[e2gT;MA_i2gDKn@]i6oT;MA_i2oTKn@]e6oT;nA_i6oDLN00=6oP0mBai6oTLNA_i;7TKn
Bai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TLNBai6oT/NAai;7TKn
Bai77T/NA_i;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBal00T/N00I77T/o
Bai;7TLNBcl2Bah01TLNBcm;7T/NAai;?`9;7P06Aai;?d/NBai77T/o0T/N00I77T/oBai;7TLNBcl2
Bah03dLNBcm;7T/nAai;?d/NBch004/oBai;?TLNBcm;7P03Ool00`00Oomoo`0AOol002Ioo`03001o
ogoo01moo`T00004Ooln>T8j?SX2?U/01SiL?U/nW3il?Y`nO0@nW@8n_@06@[dn_D;M@[e2gT:m0d;N
00U2gDKn@]i6oT;NA_i2oTKn@]h02TKn00i77TKnA_i6oTLNA_i77TKnAai6oTLNA_i;7TKn0TLN00i;
7TKnAai77T/NAai;7TLNBai77T/NAai;7TLN0d/N00E77T/NBai;7TLN049;7P03001;7T/N00A;7P=o
o`03001oogoo015oo`009Woo00<007ooOol05Goo2P002Woo02A:NTIIBWY6FCil?U/nO3iK@YdnO3jM
?Wa2_CjM@[dnWD:n?[e2_Sjm@]hn_D;N?[e6oT;M@]i2gDKn@]e6oT;MA_i2gDKn@]d3A_h0@T;mA_i6
oTKnA_e77TKnAai6oT/NA_i77TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6
oT/NA_i;7TKnBai77T/NA_i;7TLNBai6oT/OAai;7TKnBam77T/NAai;7dLNBai77T/OAai;7TLNBam7
7T/NAai;?`9;7P06Aai;?d/NBai77T/o0T/N00I77T/oBai;7TLNBcl2Bah01TLNBcm;7T/NAai;?`9;
7P0IAai;?d/NBai77T/oBai;?TLNBcm;7T/nAai;?d/NBci77T/oBah004LNBcm;7T/nAah00goo00<0
07ooOol04Goo000VOol00`00Oomoo`0<Ool9000DOol3BUX00dYj@W]6N`02AW/01cil?Y`nO3jL?Ye2
_CjM00E2_@=2g@0:@]i2gDKN@]i6gT;NA_i2gTKn@]h>A_h02TLNA_i6oTKnAai6oTLNA_i;7TKn0TLN
00Y;7TKnBai77T/NA_i;7TLNBai77P=;7P05Aai;7T/NBai77P03Bah00dLNBai;7P13Bah00`00Bai;
7P03Bah4Ool00`00Oomoo`0@Ool002Ioo`03001oogoo009oo`X001ioo`0UAUU:NTIIBWY2NdJL@W]6
WD:LA[e2W4JM@Ya6_D:lA[dn_D;N@[e2gD:mA]i2_D;N@]e6oT;MA_i2gDKn@]e6oT;MA_i6gDKn@]d0
0dKn03Y6oDKnA_i77TKmBai6oT/NA_e;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;
7TKnBai6oT/NA_i;7TKnBai6oT/NAai;7TKnBai77T/NAai;7TLNBai77T/OAai;7TLNBam77T/NAai;
7`9;7P06Aai;7d/NBai77T/o0T/N00I77T/oBai;7TLNBcl2Bah01TLNBcm;7T/NAai;?`9;7P06Aai;
?d/NBai77T/o0T/N01Q77T/oBai;7TLNBcm;7T/nAai;?d/NBci77T/oBai;?TLN001;7T/nBai;?d/N
Bch3Ool00`00Oomoo`0@Ool002Ioo`D002Qoo`06BWY:FTYJBUY6Nd9k0TIk14:L1T:m00A2gD:mA]i2
g@96g@04A]i2gDKN@]h2A]h00dKnA]i6oP0?A_h04T/NA_i6oTKnBai6oTLNA_i;7TKnBai77T/NA_i;
7TLNBai77P=;7P05Aai;7T/NBai77P03Bah00dLNBai;7P15Bah00`00Bai;7P04Bah3Ool00`00Oomo
o`0@Ool002Moo`03001oogoo02Uoo`05CWUBVTiiDYY>N@02BY/08Djl@Ya6WD:LA[e2W4Jm@Ya6_D:l
A]e2_DKN@[e6gT;MA]i2gDKn@]e6oT;MA_i2gDKnA]e6oTKMA_i6oDKnA_e;7P02A_h0>TKmBai6oT/N
A_e;7TKnBai6oD/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TLNBai6oT/N
Aai;7TKnBai77T/NA_i;7TLNBai77T/NAai;7TLNBam77T/NAai;7dLNBai77T/O0T/N00I77T/OBai;
7TLNBcl2Bah01TLNBcm;7T/NAai;?`9;7P06Aai;?d/NBai77T/o0T/N00I77T/oBai;7TLNBcl2Bah0
5TLNBcm;7T/nAai;?d/NBci77T/oBai;?T/NBcm;7T/n001;?d/NBci;7T/o0goo00<007ooOol047oo
000XOol00`00Oomoo`0XOol01E:JDYUBVU9iDYX014ZK14Jl14Jm1DKM00Y6gT;MA]e6gDKnA]e6gTKM
A_i6gQ16oP0@Aai6oT/NA_i77TKnBai6oT/NA_i;7TKnBai77T/NAah3Bah01DLNBai;7T/NAah00d/N
00=77T/NBah0B4/N00<004/NBah00d/N0goo00<007ooOol047oo000YOol00`00Oomoo`0XOol01E:J
CWUBVTiiDYX00dZK05U:_DJLB[a6W4ZmA[a6gDJlA]e6_DKM@[e6gTKMA_i6gDKnA]e6oTKMA_i6gDKn
A]e:oTKMB_i6oD[nA_e:oTKmBai6oT[nA_e;7TKnBai6oD/NA_i;7TKmBai6oT/NA_i;7TKnBai6oT/N
A_i;7TKnBai6oT/NA_i;7TKnBai6oT/NAai;7TKnBai77T/NA_i;7TLNBai6oT/NAai;7TLNBai77T/N
Aai;7dLNBai77T/O009;7P06Aai;?d/NBai77T/o0T/N00I77T/oBai;7TLNBcl2Bah01TLNBcm;7T/N
Aai;?`9;7P06Aai;?d/NBai77T/o0T/N01U77T/oBai;?TLNBcm;7T/nAai;?d/NBci77T/oBai;?T/N
Bcl004/nBai;?d/NBci;7P02Ool00`00Oomoo`0@Ool002Yoo`03001oogoo02Moo`05DWUBVU:IDYYB
N@04BY/4A[`4A[d6A]d01TKNA]e6gDKMA_i6g@=6oP03A_e6oTKn00Q6oP0>Bai6oTKnA_i;7TKnBai6
oT/NA_i;7TLNBai6oP=;7P05A_i;7T/NBai77P03Bah00dLNBai;7P1>Bah00`00Bai;7P04Bah2Ool0
0`00Oomoo`0@Ool002]oo`03001oogoo02Ioo`1KF[YFVEZjEYUJ^TjKD[]>^e:kCY]>g4ZlC]a:_4[M
A[a:gDJlB]i6gD[MA]e:gTKMB_i6gD[nA]e:oTKMB_i6oD[nA]e:oTKmB_i6oD/NA_e;7TKmBai6oT/N
A_e;7TKnBai6oD/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai77T/NA_i;7TLNBai6oT/N
Aai;7TKnBai77T/NAai;7TLNBai77T/NAai;7TLNBal00T/N00I77T/OBai;7TLNBal2Bah01TLNBcm;
7T/NAai;?`9;7P06Aai;?d/NBai77T/o0T/N00I77T/oBai;7TLNBcl2Bah01TLNBcm;7T/NAai;?`9;
7P0GAai;?d/NBci77T/oBai;?TLNBcm;7T/nBai;?d/NBci;7P00Bai;?T/NBcm;7P02Ool00`00Oomo
o`0@Ool002aoo`03001oogoo02Ioo`05E[UFVEJiEYUF^@03C[/00e:kB[a:_003B[`3B]d014JlA]e6
gD[M0dKM00I6oTKMA_i6oDKnA]d3A_h014KmA_i6oT[n0dKn00i:oTKnA_i6oT/NA_i:oTKnBai6oT/N
B_i;7TKn0d/N00E6oT/NBai;7TLN05M;7P03001;7T/N00=;7P9oo`03001oogoo011oo`00;Goo00<0
07ooOol09Goo05MFVEZjEYUJ^UJIE]]B^UKKD[YFfdjkD]a>_4kLB]a>gD[LC]e:g4[mB]e:oDKMB_i6
gD[nA]e:oTKMB_i6gD[nA_e:oTKmB_i6oD[nA_e;7TKmBai6oD/NA_e;7TKmBai6oT/NA_e;7TKnBai6
oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NAai;7TKnBai77T/NA_i;7TLNBai6oT/NAai;7TLNBai7
7T/NAah00d/N00I77T/OBai;7TLNBal2Bah01TLNBam;7T/NAai;?`9;7P06Aai;?d/NBai77T/o0T/N
00I77T/oBai;7TLNBcl2Bah01TLNBcm;7T/NAai;?`9;7P0LAai;?d/NBci77T/oBai;?T/NBcm;7T/n
Bai;?d/NBci;7T/oBah004/NBcm;7T/nBai;?goo000BOol002ioo`03001oogoo02Eoo`09EYUF^EZi
G[UB^eKKD[]F^e:k00E>g003B]a:gD[M00E:g@0EA]e:oD[MB_e6gD[nA_e:oTKmB_i6oT[nA_e:oTKn
B_i6oT[nA_i;7TKn009:oP06Bai6oT/NB_i;7TKn0d/N00=:oT/NBah0G4/N00<004/NBah00d/N00=o
o`00Ool04Goo000_Ool00`00Oomoo`0TOol0C5kIF[UNfEZhG]UB^UKKD[YFfe:jC]a>^e;LC[a>oD[L
C_e>g4kmB]e>oD[MC_e:gD[nB]e:oT[MB_i6oD[nA]e;7TKmB_i6oD/NA_e;7TKmBai6oD/NA_e;7TKn
Bai6oD/NA_i;7TKmBai6oT/NA_e;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TLNBai6oT/NAai;7TKn
0d/N00E77T/NBai;7TLN00=;7P05Aai;7T/NBai77P03Bah01TLNBcm;7T/NAai;?`9;7P06Aai;?d/N
Bai77T/o0T/N00I77T/oBai;7TLNBcl2Bah01TLNBcm;7T/NAai;?`=;7P0MBcm;7T/nBai;?d/NBci;
7T/oBai;?T/NBcm;7T/nBai;?d/NBci;7T/o001;?T/NBcm;7T/nOol0000BOol0031oo`03001oogoo
02=oo`0:F[UN^EjiG[UJ^E[KE]YJfeKJF]/5D]`024kMC]a>gDkLB_e:gD[mB]d6B_d014[nB_e:oT[m
0d[n00E6oT[nB_i:oTKn009:oP06Bai6oT/NB_i;7T[n0d/N00E:oT/NBai;7T[n05a;7P03001;7T/N
00=;7P03Ool007oo015oo`00<Goo00<007ooOol08goo045J^5kIF[URfEjhF]]FfU[KE[YJfe;KD]a>
fe;lC]a>oD[LC_e:gDkmB]a>oD[MC_i:gDknB_e>oT[mBai:oD[nA_e;7T[mBai6oD/NB_e;7TKmBai6
oD/NA_e;7TKnBai6oD/NA_i;7TKmBai6oT/NA_e;7TKnBai6oT/NA_i;7TKn00=;7P05A_i;7T/NBai6
oP03Bah01DKnBai;7T/NAah00d/N00E77T/NBai;7TLN00=;7P06Aai;7T/NBai77T/o0T/N00I77T/o
Bai;7TLNBcl2Bah01TLNBcm;7T/NAai;?`9;7P03Aai;?d/N009;7P0SBcm;7T/NBai;?d/NBci;7T/o
Bai;?T/NBcm;7T/nBai;?d/NBci;7T/oBai;?T/NBcm;7T/n001;?d/NBci;7T/oOol0000BOol0039o
o`03001oogoo029oo`0CG[UNf6;IH]QRfEKJF]]FfU[KE]YFo5KKE_aBfeKlC_aBoDkLD_`01Dkm14[m
00I:oT[mB_e:oD[nB_d6B_h01T/NB_i;7T[nBai:oP=;7P05B_i;7T/NBai:oP1OBah00`00Bai;7P03
Bah00goo001oo`0@Ool003=oo`03001oogoo025oo`13G[QRfEjhH]UN^6;IF]YNne[JG_YBfeKlD]]F
o5;KD_e>g5;mC]aBoD[MC_e:g4kmB_e>oD[mCai:oDlNB_e?7T[mBai:oDlNB_e;7T[mBai:oD/NA_e;
7T[mBai6oD/NB_i;7TKmBai:oT/NA_e;7T[nBai6oD/NB_i;7TKnBai:oT/NA_h00d/N00E6oT/NBai;
7TKn00=;7P05Aai;7T/NBai77P03Bah01DLNBai;7T/NAah00d/N00I77T/nBai;7TLNBcl2Bah01TLN
Bcm;7T/NAai;?`=;7P05Bcm;7T/NBai;?`03Bah09T/oBai;7T/NBcm;7T/nBai;?d/NBci;7T/oBai;
?T/NBcm;7T/nBai;?d/NBci;7T/oBai;?T/NBcm;7P00Bai;?d/NBci;7Woo000AOol003Aoo`03001o
ogoo021oo`07H]URf6;IG]QRfF;HG_X00e[J00INnU;KE_aFfeKlD]/5D_`6C_d014[mC_e>oD[n0d[m
00I:oT[mB_i:oD/NB_d2B_h01T/NB_i;7T[nBai:oP=;7P03B_i;7T/N05m;7P03001;7T/N00=;7P03
Ool007oo011oo`00=Goo0P008Goo01ERfEjhH]URf6KhH]QNnU[JG_]JfU[lE]]Jo5KKF_aFfe;mD_aB
oE;LD_d00Tkm02E>o4lNC_e?7D[mCai>oDlNB_e?7T[mCai:oDlNB_e;7T[mCai:oD/NB_e;7T[mBai:
oD/NB_i;7TKmBai:oT/NB_e;7T[nBai:o@03Bah01DKmBai;7T/NA_h00d/N00E6oT/NBai;7TLN00=;
7P05Aai;7T/NBai77P03Bah01TLNBai;7T/NAai;?P9;7P06Aai;?d/NBai77T/o0T/N00I77T/oBai;
7TLNBcl3Bah01D/oBai;7T/NBcl00d/N02A;?d/NBai;7T/oBai;?T/NBcm;7T/nBai;?d/NBci;7T/o
Bai;?T/NBcm;7T/nBai;?d/NBci;7P00Bai;?T/NBcm;7T/n000AOol003Moo`03001oogoo01ioo`07
G]QVf6;HI]QRf6KHF]X015kj00eFo5KkE_]FneKlD_aFo5;lE_aBo5;mC_eBo@06C_d01d[mC_i:oDkm
B_e;7T[m009:oP06Bai:oD/NB_i;7T[n0d/N00=:oT/NBah0HT/N00<004/NBah00d/N00<007ooOol0
3goo000hOol00`00Oomoo`0MOol03fKhH]QVn6;HI_QRf6;jG]YNnUkIH_YNfU[kE_]K7002F_/0:E;l
EaeBo5KlC_aC7DklD_e>o5<MC_eC7DkmDae:oDlNB_e?7T[mCai:oDlNB_e?7T[mCai:oD/NB_e?7T[m
Bai:oD/NB_e;7T[mBai:oT/NB_d00d/N00E:oD/NBai;7T[m00=;7P03B_i;7T/N00E;7P03Aai;7T/N
00Y;7P05Bci;7T/NBai;?P03Bah01D/nBai;7T/NBcl00d/N00E;?d/NBai;7T/o00=;7P0TBcm;7T/N
Bai;?d/NBci;7T/oBai;?T/NBcm;7T/nBai;?d/NBci;7T/oBai;?T/NBcm;7T/nBai;?d/NBci;7T/o
Bai;?P001Goo00<007ooOol03goo000iOol00`00Oomoo`0MOol01VKHH]QVf6;HI_QVe`ANnP03H_YJ
ne[k00=Jn`06EaaFo5KlE_aG75;l0U;m00EC7E;lC_e>oDlM00=>o@06Cae>oDlNB_e?7T[m0T/N00=?
7T[mBah00T/N00=:oT/NBah0F4/N37oo00<007ooOol00goo00<007ooOol03goo000jOol00`00Oomo
o`0LOol036;HI_QRf6[hI]MZn5kIH_YNnF;jG_URnP9Jn`0VF_YO6e[kEaaFo5LLE_aC7DklDaeBo5<M
C_eC7DkmDae>oDlNC_e?7TkmCai:oDlNB_e?7T[mCai:oDlNB_e?7T[mCai:oD/NB_e?7P9;7P06B_e?
7T/NBai:oDlN0T/N00E:oD/NBai;7T[n01Q;7P05Bci;7T/NBai;?P03Bah01D/nBai;7T/NBcl00d/N
00E;?d/NBai;7T/o00=;7P08Bcm;7T/NBai;?d/NBci;7QUoo`03001oogoo00=oo`03001oogoo00mo
o`00>goo00<007ooOol077oo00]Rf6KhI]MVn6KHI_QRnF;jH_URnV;i009Jn`05Ga]Jne[kE_aG7003
E_`03U<MD_aC7E;lDae>oE<MC_eC7DkmCae>oDlMC_d2Cad02DlNC_e?7D/NCai;7DlNBai?7P0oBahW
Ool00`00Oomoo`02Ool00`00Oomoo`0?Ool003aoo`03001oogoo01]oo`0iJ_QVef[hI]MZn6[gH_YN
nF;jG_UW6V;iGa]JnelKF_YO6eKlFaaFne/LE_aG7E;lEaeBo5<MC_aC7DkmDae>oE<NC_eC7T[mCai:
oDlNB_e?7T[mCai:oDlNB_e?7T[mCai;7DlNB_e?7T/NCai:oDlN009;7P06B_e?7T/NBai:oDlN4d/N
00E;?T/NBai;7T/n00=;7P04Bci;7T/NBahdOol00`00Oomoo`02Ool00`00Oomoo`0?Ool003eoo`03
001oogoo01Yoo`04I]MVn6KHI_P3J_L03V;jH_URnF;iI_UNnelKG_]O6ekkGa]Fo5/LE_`2Ea`01ULM
D_aG7ELLDaeBo@9C7@03Cae>oDlM00E?7@0:Cai?7DlNCae?7T/MCai;7TlNBad2Bah00dlNBai;7P0I
Bai5Ool00`00Oomoo`02Ool00`00Oomoo`0?Ool003ioo`03001oogoo01Yoo`0nI]MZn6[gJ_QVef[h
H_UW6V;iIaYVnFLIF_YO6ekjGa]JnU/LF_]K75KkFaaBo5LMD_aG7E;mDaeBo5<MD_eC7DkmDai>oE<M
C_e?7TkmCai:oDlNB_e?7T[mCai;7DlNB_e?7T/MCai:oDlNBai?7T[mCai;7TlNB_e?7P9;7P03Bae?
7Woo055oo`05001oogooOol0000AOol003moo`03001oogoo01Uoo`03I_QZmf[g00=Zm`9Rn@9Vn@08
IaUVnElKG_]O6elJHa]O6PAK709G7003EaeG75LL00IC7@=?7@0:Cai?7DlMCae?7TlMCai?7DlNBad3
Cah3Bah00dlNOomoo`1MOol01@00Oomoogoo00004Goo0010Ool00`00Oomoo`0HOol0:F[gJ_QVef[h
J_M^mf[fIaYVnFLIH_UW6FKiHa]NnV<KG_YS6e[kGaaK6elLF_]G7ELLEaeFo5LMDaaG7E;lEaeC75<M
C_eC7TlMCai>oE<NCad0Jgoo00D007ooOomoo`00015oo`00@Goo00<007ooOol05goo1V[g00]^mfKi
IaUVnFLII_UW6ElJHa]O6UlK009S6P04Fa]K75/KFa`6Ea`015<MEaeC7E<MLgoo00<007ooOol00Woo
00<007ooOol03Woo0012Ool00`00Oomoo`0GOol076[hJ_M^mf[fKaMZmVLIH_UW6FKiJaUVn6/IG_YS
6ekjHa]S6UlLFa]O75/KGaaG75/MEaaK7ELLN7oo00D007ooOomoo`00011oo`00@goo00<007ooOol0
5Woo0f[g00I^mf[gK_M^mfLII_P3IaT00fKhHaYS6P04HaX01ElLFa]O6elKGa`0O7oo00D007ooOomo
o`00011oo`00A7oo00<007ooOol05Goo01I^mf[fKaMZmflGJ_I_5fKhJaUVn6/II_Q[6FKhHa]S6VLJ
HaYW6e/KGaaK6gioo`05001oogooOol0000@Ool004Eoo`03001oogoo01Eoo`03K_MZmf[g009^m`9^
mP9W6@04I_Q[66/HJaT6HaZ0Ool01@00Oomoogoo000047oo0016Ool00`00Oomoo`0DOol04V[gK_MZ
mVlGJ_I_5fkfJaUVn6/II_Q[6F/HIaYS6VLKHaYW6X9oo`04001oogoo000@Ool004Moo`03001oogoo
01Aoo`07J_M^mfkfK_M^mVlFK_H00V/H00A[6F/HJaQ[609S6XAoo`04001oogoo000@Ool004Qoo`03
001oogoo01=oo`0=KaMZmVlGK_Ic5fkfLaIVn6/II_Q[66[hKaT0QWoo00@007ooOol0011oo`00BGoo
00<007ooOol04Woo00A^mVkgK_M_5P=^mP03LaI[66/H009[68Qoo`03001oo`00011oo`00BWoo00<0
07ooOol04Woo00YZmW<GK_I_5fkfLaI^mV/HJ_Q_6HUoo`03001oo`00011oo`00Bgoo00<007ooOol0
4Goo00M^mfkfK_I^mW<FK_I_5P03JaR9Ool00`00Ool0000@Ool004aoo`03001oogoo011oo`09K_I_
5fkfLaI^mW<FK_Ec5V/H08Yoo`03001oo`00011oo`00CGoo00<007ooOol03goo0Vkf00I_5VkfKaI^
mW<FL_J<Ool2000@Ool004ioo`03001oogoo00moo`07LaM^mW<FK_Ic5VkeLaH0S7oo0P0047oo001?
Ool00`00Oomoo`0>Ool01VkfKaI^mW<FL_Ic5Xeoo`03001oo`0000moo`00D7oo00<007ooOol03Goo
00Ic5VkfLaI^mW<FK_F=Ool00`00Ool0000?Ool0055oo`03001oogoo00eoo`03LaI^mW<F009c5Xio
o`8000moo`00DWoo00<007ooOol037oo00A^mW<FK_Ec5Xmoo`8000moo`00Dgoo0P003Goo0W<F00=b
mWooOol0SGoo0P003goo001EOol00`00Oomoo`0:Ool00g<FK_Eoo`2?Ool2000?Ool005Ioo`03001o
ogoo00Uoo`03L_Ic5Woo091oo`03001oogoo00eoo`00Egoo00<007ooOol02Goo00=^mGooOol0RGoo
1`003goo001HOol00`00Oomoo`08Ool00`00Oomoo`1kOol>000FOol005Uoo`03001oogoo00Moo`03
001oogoo06ioo`d002Aoo`00FWoo00<007ooOol01Goo00<007ooOol0HWoo3@00<Goo001KOol00`00
Oomoo`04Ool00`00Oomoo`1DOol>000nOol005aoo`03001oogoo00=oo`03001oogoo04Moo`d004ao
o`00A7oo0`005Woo00<007ooOol00Woo00<007ooOol0>Woo3@00FGoo0015Ool00`00Oomoo`0FOol0
1@00Oomoogoo0000;Woo3P00IWoo0015Ool3000GOol01000Oomoo`008Goo3@00M7oo0015Ool01000
Oomoo`005goo00<007oo000057oo3@00PGoo0015Ool01000Oomoo`0067oo0P001Woo3P00SWoo0014
Ool4000JOol7002LOol00?moo`Ioo`00ogoo1Woo003oOol6Ool00?moo`Ioo`00ogoo1Woo003oOol6
Ool00?moo`Ioo`00O7oo0P0000=oo`0000000Woo10000goo0P0017oo0P0017oo0P000goo0`00Igoo
001mOol00`00Ool00009Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo001VOol007io
o`03001oogoo009oo`@0009oo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol006Ioo`00
O7oo0P0000=oo`00000027oo00@007ooOol000Qoo`04001oogoo0002Ool3001WOol008Uoo`04001o
ogoo0008Ool01000Oomoo`000goo00<007ooOol0IWoo002:Ool2000:Ool20004Ool3001VOol00?mo
o`Ioo`00ogoo1Woo003oOol6Ool00?moo`Ioo`00\
\>"],
  ImageRangeCache->{{{0, 260.5}, {184, 0}} -> {-0.170853, 0.0461073, \
0.00439424, 0.00439424}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .70824 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1.10169 -0.148196 1.10169 [
[.5 .72074 -20 0 ]
[.5 .72074 20 15 ]
[.44797 -0.02478 -4.90556 -15 ]
[.44797 -0.02478 5.09444 0 ]
[.15892 .66839 -5.31917 0 ]
[.15892 .66839 4.68083 15 ]
[-0.06694 .27471 -10 -6.62571 ]
[-0.06694 .27471 0 8.37429 ]
[ 0 0 0 0 ]
[ 1 .70824 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .72074 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.437500 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(=) show
75.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.07) show
99.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math1Mono
%%DocumentNeededResources: + font Courier
%%DocumentNeededFonts: Math1Mono
%%DocumentNeededFont: + Courier
%%DocumentFonts: font Math1Mono
%%DocumentFonts: + font Courier
grestore
.25 Mabswid
.02946 .11175 m
.89362 0 L
s
gsave
.44797 -0.02478 -65.9056 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(u) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
0 .4272 m
.29069 .70824 L
s
gsave
.15892 .66839 -66.3192 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(p) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.02946 .11175 m
0 .4272 L
s
gsave
-0.06694 .27471 -71 -10.6257 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(q) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.02946 .11175 m
0 .4272 L
s
0 .4272 m
.29069 .70824 L
s
.29069 .70824 m
.30155 .45044 L
s
.30155 .45044 m
.02946 .11175 L
s
.89362 0 m
.98022 .38351 L
s
.98022 .38351 m
1 .65325 L
s
1 .65325 m
.91448 .33294 L
s
.91448 .33294 m
.89362 0 L
s
.02946 .11175 m
0 .4272 L
s
0 .4272 m
.91448 .33294 L
s
.91448 .33294 m
.89362 0 L
s
.89362 0 m
.02946 .11175 L
s
.30155 .45044 m
.98022 .38351 L
s
.98022 .38351 m
1 .65325 L
s
1 .65325 m
.29069 .70824 L
s
.29069 .70824 m
.30155 .45044 L
s
0 0 m
1 0 L
1 .70824 L
0 .70824 L
closepath
clip
newpath
.905 .773 .705 r
.28582 .66117 .2919 .67955 .31368 .62339 .30757 .60923 Mtetra
.858 .785 .779 r
.30757 .60923 .31368 .62339 .33415 .59576 .32809 .58376 Mtetra
.804 .791 .84 r
.32809 .58376 .33415 .59576 .35413 .58025 .34814 .5695 Mtetra
.754 .791 .883 r
.34814 .5695 .35413 .58025 .37391 .57063 .36801 .56068 Mtetra
.712 .789 .912 r
.36801 .56068 .37391 .57063 .39361 .56417 .38782 .55475 Mtetra
.681 .787 .93 r
.38782 .55475 .39361 .56417 .41331 .55951 .40763 .55047 Mtetra
.658 .785 .941 r
.40763 .55047 .41331 .55951 .43303 .55595 .42746 .54717 Mtetra
.642 .784 .949 r
.42746 .54717 .43303 .55595 .45279 .55306 .44734 .54449 Mtetra
.63 .783 .955 r
.44734 .54449 .45279 .55306 .4726 .55061 .46727 .54219 Mtetra
.621 .783 .959 r
.46727 .54219 .4726 .55061 .49247 .54845 .48725 .54014 Mtetra
.615 .783 .962 r
.48725 .54014 .49247 .54845 .51239 .54648 .5073 .53825 Mtetra
.61 .784 .964 r
.5073 .53825 .51239 .54648 .53238 .54463 .52742 .53648 Mtetra
.607 .784 .966 r
.52742 .53648 .53238 .54463 .55244 .54288 .5476 .53477 Mtetra
.604 .785 .967 r
.5476 .53477 .55244 .54288 .57255 .54118 .56784 .53311 Mtetra
.602 .785 .968 r
.56784 .53311 .57255 .54118 .59274 .53952 .58815 .53148 Mtetra
.601 .786 .969 r
.58815 .53148 .59274 .53952 .61299 .53788 .60853 .52987 Mtetra
.6 .787 .97 r
.60853 .52987 .61299 .53788 .63331 .53625 .62898 .52826 Mtetra
.599 .787 .971 r
.62898 .52826 .63331 .53625 .6537 .53464 .6495 .52665 Mtetra
.598 .788 .971 r
.6495 .52665 .6537 .53464 .67415 .53302 .67009 .52504 Mtetra
.598 .788 .972 r
.67009 .52504 .67415 .53302 .69467 .5314 .69074 .52342 Mtetra
.597 .789 .972 r
.69074 .52342 .69467 .5314 .71526 .52978 .71147 .5218 Mtetra
.71147 .5218 .71526 .52978 .73592 .52814 .73227 .52016 Mtetra
.596 .789 .973 r
.73227 .52016 .73592 .52814 .75665 .5265 .75313 .51851 Mtetra
.596 .79 .973 r
.75313 .51851 .75665 .5265 .77745 .52485 .77407 .51685 Mtetra
.77407 .51685 .77745 .52485 .79832 .52319 .79508 .51518 Mtetra
.596 .791 .973 r
.79508 .51518 .79832 .52319 .81926 .52152 .81615 .5135 Mtetra
.596 .791 .974 r
.81615 .5135 .81926 .52152 .84027 .51984 .8373 .5118 Mtetra
.8373 .5118 .84027 .51984 .86135 .51814 .85852 .5101 Mtetra
.85852 .5101 .86135 .51814 .8825 .51644 .87982 .50838 Mtetra
.596 .792 .974 r
.87982 .50838 .8825 .51644 .90372 .51472 .90118 .50664 Mtetra
.90118 .50664 .90372 .51472 .92502 .51299 .92262 .5049 Mtetra
.92262 .5049 .92502 .51299 .94638 .51126 .94413 .50314 Mtetra
.94413 .50314 .94638 .51126 .96782 .5095 .96572 .50137 Mtetra
.596 .793 .974 r
.96572 .50137 .96782 .5095 .98933 .50774 .98737 .49959 Mtetra
.897 .771 .713 r
.27967 .64261 .28582 .66117 .30757 .60923 .3014 .5949 Mtetra
.847 .782 .788 r
.3014 .5949 .30757 .60923 .32809 .58376 .32196 .57161 Mtetra
.792 .787 .847 r
.32196 .57161 .32809 .58376 .34814 .5695 .34208 .55863 Mtetra
.743 .787 .888 r
.34208 .55863 .34814 .5695 .36801 .56068 .36205 .55061 Mtetra
.703 .785 .915 r
.36205 .55061 .36801 .56068 .38782 .55475 .38196 .54522 Mtetra
.673 .783 .932 r
.38196 .54522 .38782 .55475 .40763 .55047 .40187 .54131 Mtetra
.652 .782 .943 r
.40187 .54131 .40763 .55047 .42746 .54717 .42182 .53829 Mtetra
.637 .781 .951 r
.42182 .53829 .42746 .54717 .44734 .54449 .44181 .5358 Mtetra
.626 .781 .956 r
.44181 .5358 .44734 .54449 .46727 .54219 .46186 .53365 Mtetra
.618 .781 .96 r
.46186 .53365 .46727 .54219 .48725 .54014 .48197 .53172 Mtetra
.612 .782 .962 r
.48197 .53172 .48725 .54014 .5073 .53825 .50214 .52992 Mtetra
.608 .783 .965 r
.50214 .52992 .5073 .53825 .52742 .53648 .52238 .52821 Mtetra
.605 .783 .966 r
.52238 .52821 .52742 .53648 .5476 .53477 .54269 .52656 Mtetra
.603 .784 .968 r
.54269 .52656 .5476 .53477 .56784 .53311 .56306 .52494 Mtetra
.601 .785 .969 r
.56306 .52494 .56784 .53311 .58815 .53148 .58351 .52334 Mtetra
.6 .785 .969 r
.58351 .52334 .58815 .53148 .60853 .52987 .60402 .52175 Mtetra
.599 .786 .97 r
.60402 .52175 .60853 .52987 .62898 .52826 .6246 .52015 Mtetra
.598 .787 .971 r
.6246 .52015 .62898 .52826 .6495 .52665 .64525 .51855 Mtetra
.597 .787 .971 r
.64525 .51855 .6495 .52665 .67009 .52504 .66597 .51695 Mtetra
.597 .788 .972 r
.66597 .51695 .67009 .52504 .69074 .52342 .68676 .51533 Mtetra
.68676 .51533 .69074 .52342 .71147 .5218 .70762 .51371 Mtetra
.596 .789 .972 r
.70762 .51371 .71147 .5218 .73227 .52016 .72856 .51207 Mtetra
.596 .789 .973 r
.72856 .51207 .73227 .52016 .75313 .51851 .74956 .51041 Mtetra
.596 .79 .973 r
.74956 .51041 .75313 .51851 .77407 .51685 .77064 .50875 Mtetra
.77064 .50875 .77407 .51685 .79508 .51518 .79178 .50706 Mtetra
.79178 .50706 .79508 .51518 .81615 .5135 .813 .50537 Mtetra
.596 .791 .974 r
.813 .50537 .81615 .5135 .8373 .5118 .83429 .50366 Mtetra
.83429 .50366 .8373 .5118 .85852 .5101 .85566 .50194 Mtetra
.85566 .50194 .85852 .5101 .87982 .50838 .8771 .5002 Mtetra
.596 .792 .974 r
.8771 .5002 .87982 .50838 .90118 .50664 .89861 .49845 Mtetra
.89861 .49845 .90118 .50664 .92262 .5049 .92019 .49669 Mtetra
.595 .792 .974 r
.92019 .49669 .92262 .5049 .94413 .50314 .94185 .49491 Mtetra
.596 .792 .974 r
.94185 .49491 .94413 .50314 .96572 .50137 .96358 .49312 Mtetra
.96358 .49312 .96572 .50137 .98737 .49959 .98539 .49132 Mtetra
.889 .768 .722 r
.27347 .62387 .27967 .64261 .3014 .5949 .29515 .58041 Mtetra
.836 .778 .796 r
.29515 .58041 .3014 .5949 .32196 .57161 .31575 .55932 Mtetra
.78 .782 .854 r
.31575 .55932 .32196 .57161 .34208 .55863 .33595 .54762 Mtetra
.731 .782 .893 r
.33595 .54762 .34208 .55863 .36205 .55061 .356 .54041 Mtetra
.693 .78 .918 r
.356 .54041 .36205 .55061 .38196 .54522 .37602 .53556 Mtetra
.665 .779 .934 r
.37602 .53556 .38196 .54522 .40187 .54131 .39604 .53204 Mtetra
.645 .779 .945 r
.39604 .53204 .40187 .54131 .42182 .53829 .4161 .52928 Mtetra
.631 .779 .952 r
.4161 .52928 .42182 .53829 .44181 .5358 .43622 .527 Mtetra
.622 .779 .957 r
.43622 .527 .44181 .5358 .46186 .53365 .45639 .525 Mtetra
.614 .78 .96 r
.45639 .525 .46186 .53365 .48197 .53172 .47662 .52318 Mtetra
.609 .78 .963 r
.47662 .52318 .48197 .53172 .50214 .52992 .49692 .52148 Mtetra
.606 .781 .965 r
.49692 .52148 .50214 .52992 .52238 .52821 .51728 .51984 Mtetra
.603 .782 .966 r
.51728 .51984 .52238 .52821 .54269 .52656 .53772 .51824 Mtetra
.601 .783 .968 r
.53772 .51824 .54269 .52656 .56306 .52494 .55822 .51666 Mtetra
.6 .784 .969 r
.55822 .51666 .56306 .52494 .58351 .52334 .57879 .51508 Mtetra
.598 .785 .97 r
.57879 .51508 .58351 .52334 .60402 .52175 .59944 .51351 Mtetra
.59944 .51351 .60402 .52175 .6246 .52015 .62015 .51194 Mtetra
.597 .786 .971 r
.62015 .51194 .6246 .52015 .64525 .51855 .64094 .51035 Mtetra
.597 .787 .971 r
.64094 .51035 .64525 .51855 .66597 .51695 .66179 .50875 Mtetra
.596 .787 .972 r
.66179 .50875 .66597 .51695 .68676 .51533 .68272 .50713 Mtetra
.596 .788 .972 r
.68272 .50713 .68676 .51533 .70762 .51371 .70372 .5055 Mtetra
.596 .788 .973 r
.70372 .5055 .70762 .51371 .72856 .51207 .72479 .50386 Mtetra
.596 .789 .973 r
.72479 .50386 .72856 .51207 .74956 .51041 .74594 .5022 Mtetra
.595 .789 .973 r
.74594 .5022 .74956 .51041 .77064 .50875 .76716 .50052 Mtetra
.595 .79 .973 r
.76716 .50052 .77064 .50875 .79178 .50706 .78845 .49883 Mtetra
.78845 .49883 .79178 .50706 .813 .50537 .80981 .49712 Mtetra
.595 .79 .974 r
.80981 .49712 .813 .50537 .83429 .50366 .83124 .4954 Mtetra
.595 .791 .974 r
.83124 .4954 .83429 .50366 .85566 .50194 .85275 .49366 Mtetra
.85275 .49366 .85566 .50194 .8771 .5002 .87434 .49191 Mtetra
.87434 .49191 .8771 .5002 .89861 .49845 .896 .49014 Mtetra
.595 .792 .974 r
.896 .49014 .89861 .49845 .92019 .49669 .91773 .48836 Mtetra
.91773 .48836 .92019 .49669 .94185 .49491 .93954 .48657 Mtetra
.93954 .48657 .94185 .49491 .96358 .49312 .96142 .48476 Mtetra
.96142 .48476 .96358 .49312 .98539 .49132 .98338 .48294 Mtetra
.879 .764 .731 r
.26721 .60495 .27347 .62387 .29515 .58041 .28884 .56577 Mtetra
.823 .773 .805 r
.28884 .56577 .29515 .58041 .31575 .55932 .30947 .54689 Mtetra
.767 .777 .861 r
.30947 .54689 .31575 .55932 .33595 .54762 .32974 .53647 Mtetra
.719 .777 .898 r
.32974 .53647 .33595 .54762 .356 .54041 .34988 .53008 Mtetra
.683 .776 .921 r
.34988 .53008 .356 .54041 .37602 .53556 .37 .52578 Mtetra
.657 .775 .936 r
.37 .52578 .37602 .53556 .39604 .53204 .39014 .52264 Mtetra
.639 .775 .946 r
.39014 .52264 .39604 .53204 .4161 .52928 .41031 .52016 Mtetra
.626 .776 .953 r
.41031 .52016 .4161 .52928 .43622 .527 .43054 .51808 Mtetra
.617 .777 .957 r
.43054 .51808 .43622 .527 .45639 .525 .45084 .51624 Mtetra
.611 .778 .961 r
.45084 .51624 .45639 .525 .47662 .52318 .47119 .51453 Mtetra
.607 .779 .963 r
.47119 .51453 .47662 .52318 .49692 .52148 .49162 .51292 Mtetra
.603 .78 .965 r
.49162 .51292 .49692 .52148 .51728 .51984 .51211 .51135 Mtetra
.601 .781 .967 r
.51211 .51135 .51728 .51984 .53772 .51824 .53268 .5098 Mtetra
.599 .782 .968 r
.53268 .5098 .53772 .51824 .55822 .51666 .55331 .50826 Mtetra
.598 .783 .969 r
.55331 .50826 .55822 .51666 .57879 .51508 .57402 .50672 Mtetra
.597 .784 .97 r
.57402 .50672 .57879 .51508 .59944 .51351 .5948 .50517 Mtetra
.597 .785 .97 r
.5948 .50517 .59944 .51351 .62015 .51194 .61565 .50361 Mtetra
.596 .786 .971 r
.61565 .50361 .62015 .51194 .64094 .51035 .63657 .50203 Mtetra
.63657 .50203 .64094 .51035 .66179 .50875 .65756 .50043 Mtetra
.596 .787 .972 r
.65756 .50043 .66179 .50875 .68272 .50713 .67863 .49882 Mtetra
.595 .788 .972 r
.67863 .49882 .68272 .50713 .70372 .5055 .69977 .49719 Mtetra
.595 .788 .973 r
.69977 .49719 .70372 .5055 .72479 .50386 .72098 .49554 Mtetra
.595 .789 .973 r
.72098 .49554 .72479 .50386 .74594 .5022 .74227 .49387 Mtetra
.74227 .49387 .74594 .5022 .76716 .50052 .76363 .49219 Mtetra
.595 .79 .973 r
.76363 .49219 .76716 .50052 .78845 .49883 .78506 .49048 Mtetra
.78506 .49048 .78845 .49883 .80981 .49712 .80657 .48876 Mtetra
.595 .79 .974 r
.80657 .48876 .80981 .49712 .83124 .4954 .82815 .48703 Mtetra
.595 .791 .974 r
.82815 .48703 .83124 .4954 .85275 .49366 .84981 .48527 Mtetra
.84981 .48527 .85275 .49366 .87434 .49191 .87154 .4835 Mtetra
.87154 .4835 .87434 .49191 .896 .49014 .89335 .48172 Mtetra
.595 .792 .974 r
.89335 .48172 .896 .49014 .91773 .48836 .91523 .47992 Mtetra
.91523 .47992 .91773 .48836 .93954 .48657 .93719 .4781 Mtetra
.93719 .4781 .93954 .48657 .96142 .48476 .95923 .47627 Mtetra
.595 .792 .975 r
.95923 .47627 .96142 .48476 .98338 .48294 .98134 .47443 Mtetra
.867 .759 .742 r
.26089 .58584 .26721 .60495 .28884 .56577 .28245 .55095 Mtetra
.809 .767 .815 r
.28245 .55095 .28884 .56577 .30947 .54689 .30311 .5343 Mtetra
.752 .77 .868 r
.30311 .5343 .30947 .54689 .32974 .53647 .32345 .52518 Mtetra
.706 .771 .903 r
.32345 .52518 .32974 .53647 .34988 .53008 .34369 .51962 Mtetra
.672 .771 .925 r
.34369 .51962 .34988 .53008 .37 .52578 .36391 .51587 Mtetra
.648 .771 .938 r
.36391 .51587 .37 .52578 .39014 .52264 .38415 .51312 Mtetra
.632 .772 .947 r
.38415 .51312 .39014 .52264 .41031 .52016 .40444 .51092 Mtetra
.621 .773 .954 r
.40444 .51092 .41031 .52016 .43054 .51808 .4248 .50904 Mtetra
.613 .775 .958 r
.4248 .50904 .43054 .51808 .45084 .51624 .44521 .50735 Mtetra
.607 .776 .961 r
.44521 .50735 .45084 .51624 .47119 .51453 .4657 .50577 Mtetra
.604 .778 .964 r
.4657 .50577 .47119 .51453 .49162 .51292 .48625 .50424 Mtetra
.601 .779 .966 r
.48625 .50424 .49162 .51292 .51211 .51135 .50687 .50274 Mtetra
.599 .78 .967 r
.50687 .50274 .51211 .51135 .53268 .5098 .52757 .50124 Mtetra
.598 .781 .968 r
.52757 .50124 .53268 .5098 .55331 .50826 .54834 .49975 Mtetra
.597 .782 .969 r
.54834 .49975 .55331 .50826 .57402 .50672 .56918 .49823 Mtetra
.596 .783 .97 r
.56918 .49823 .57402 .50672 .5948 .50517 .59009 .49671 Mtetra
.596 .784 .971 r
.59009 .49671 .5948 .50517 .61565 .50361 .61108 .49516 Mtetra
.595 .785 .971 r
.61108 .49516 .61565 .50361 .63657 .50203 .63214 .49359 Mtetra
.595 .786 .972 r
.63214 .49359 .63657 .50203 .65756 .50043 .65327 .492 Mtetra
.595 .787 .972 r
.65327 .492 .65756 .50043 .67863 .49882 .67448 .49039 Mtetra
.67448 .49039 .67863 .49882 .69977 .49719 .69576 .48876 Mtetra
.595 .788 .973 r
.69576 .48876 .69977 .49719 .72098 .49554 .71711 .4871 Mtetra
.71711 .4871 .72098 .49554 .74227 .49387 .73854 .48543 Mtetra
.595 .789 .973 r
.73854 .48543 .74227 .49387 .76363 .49219 .76005 .48373 Mtetra
.76005 .48373 .76363 .49219 .78506 .49048 .78163 .48202 Mtetra
.595 .79 .974 r
.78163 .48202 .78506 .49048 .80657 .48876 .80328 .48028 Mtetra
.80328 .48028 .80657 .48876 .82815 .48703 .82501 .47853 Mtetra
.82501 .47853 .82815 .48703 .84981 .48527 .84682 .47676 Mtetra
.595 .791 .974 r
.84682 .47676 .84981 .48527 .87154 .4835 .8687 .47498 Mtetra
.8687 .47498 .87154 .4835 .89335 .48172 .89066 .47317 Mtetra
.89066 .47317 .89335 .48172 .91523 .47992 .9127 .47135 Mtetra
.595 .792 .974 r
.9127 .47135 .91523 .47992 .93719 .4781 .93481 .46952 Mtetra
.93481 .46952 .93719 .4781 .95923 .47627 .957 .46767 Mtetra
.595 .792 .975 r
.957 .46767 .95923 .47627 .98134 .47443 .97927 .4658 Mtetra
.853 .753 .752 r
.2545 .56654 .26089 .58584 .28245 .55095 .27599 .53597 Mtetra
.792 .761 .824 r
.27599 .53597 .28245 .55095 .30311 .5343 .29668 .52156 Mtetra
.736 .764 .875 r
.29668 .52156 .30311 .5343 .32345 .52518 .31708 .51376 Mtetra
.692 .765 .907 r
.31708 .51376 .32345 .52518 .34369 .51962 .33741 .50902 Mtetra
.661 .766 .928 r
.33741 .50902 .34369 .51962 .36391 .51587 .35773 .50583 Mtetra
.639 .767 .94 r
.35773 .50583 .36391 .51587 .38415 .51312 .37809 .50347 Mtetra
.625 .769 .949 r
.37809 .50347 .38415 .51312 .40444 .51092 .3985 .50155 Mtetra
.615 .77 .955 r
.3985 .50155 .40444 .51092 .4248 .50904 .41897 .49988 Mtetra
.608 .772 .959 r
.41897 .49988 .4248 .50904 .44521 .50735 .43951 .49835 Mtetra
.604 .774 .962 r
.43951 .49835 .44521 .50735 .4657 .50577 .46012 .49688 Mtetra
.601 .776 .964 r
.46012 .49688 .4657 .50577 .48625 .50424 .4808 .49545 Mtetra
.599 .778 .966 r
.4808 .49545 .48625 .50424 .50687 .50274 .50156 .49401 Mtetra
.597 .779 .967 r
.50156 .49401 .50687 .50274 .52757 .50124 .52239 .49257 Mtetra
.596 .78 .968 r
.52239 .49257 .52757 .50124 .54834 .49975 .54329 .49111 Mtetra
.595 .782 .969 r
.54329 .49111 .54834 .49975 .56918 .49823 .56427 .48963 Mtetra
.595 .783 .97 r
.56427 .48963 .56918 .49823 .59009 .49671 .58532 .48813 Mtetra
.595 .784 .971 r
.58532 .48813 .59009 .49671 .61108 .49516 .60644 .4866 Mtetra
.594 .785 .971 r
.60644 .4866 .61108 .49516 .63214 .49359 .62764 .48504 Mtetra
.594 .785 .972 r
.62764 .48504 .63214 .49359 .65327 .492 .64892 .48345 Mtetra
.594 .786 .972 r
.64892 .48345 .65327 .492 .67448 .49039 .67027 .48184 Mtetra
.594 .787 .972 r
.67027 .48184 .67448 .49039 .69576 .48876 .69169 .48021 Mtetra
.594 .788 .973 r
.69169 .48021 .69576 .48876 .71711 .4871 .71319 .47855 Mtetra
.71319 .47855 .71711 .4871 .73854 .48543 .73477 .47686 Mtetra
.594 .789 .973 r
.73477 .47686 .73854 .48543 .76005 .48373 .75642 .47516 Mtetra
.75642 .47516 .76005 .48373 .78163 .48202 .77815 .47343 Mtetra
.594 .79 .974 r
.77815 .47343 .78163 .48202 .80328 .48028 .79995 .47168 Mtetra
.79995 .47168 .80328 .48028 .82501 .47853 .82183 .46992 Mtetra
.595 .79 .974 r
.82183 .46992 .82501 .47853 .84682 .47676 .84379 .46813 Mtetra
.595 .791 .974 r
.84379 .46813 .84682 .47676 .8687 .47498 .86582 .46632 Mtetra
.86582 .46632 .8687 .47498 .89066 .47317 .88794 .4645 Mtetra
.88794 .4645 .89066 .47317 .9127 .47135 .91013 .46266 Mtetra
.595 .792 .974 r
.91013 .46266 .9127 .47135 .93481 .46952 .93239 .46081 Mtetra
.93239 .46081 .93481 .46952 .957 .46767 .95474 .45894 Mtetra
.595 .792 .975 r
.95474 .45894 .957 .46767 .97927 .4658 .97717 .45705 Mtetra
.837 .746 .764 r
.24805 .54705 .2545 .56654 .27599 .53597 .26946 .52082 Mtetra
.774 .752 .834 r
.26946 .52082 .27599 .53597 .29668 .52156 .29016 .50866 Mtetra
.719 .756 .882 r
.29016 .50866 .29668 .52156 .31708 .51376 .31063 .50218 Mtetra
.677 .758 .912 r
.31063 .50218 .31708 .51376 .33741 .50902 .33105 .49829 Mtetra
.649 .76 .93 r
.33105 .49829 .33741 .50902 .35773 .50583 .35147 .49566 Mtetra
.63 .762 .942 r
.35147 .49566 .35773 .50583 .37809 .50347 .37194 .49369 Mtetra
.617 .765 .95 r
.37194 .49369 .37809 .50347 .3985 .50155 .39247 .49206 Mtetra
.609 .768 .956 r
.39247 .49206 .3985 .50155 .41897 .49988 .41307 .4906 Mtetra
.604 .77 .959 r
.41307 .4906 .41897 .49988 .43951 .49835 .43373 .48922 Mtetra
.6 .772 .962 r
.43373 .48922 .43951 .49835 .46012 .49688 .45447 .48788 Mtetra
.598 .774 .965 r
.45447 .48788 .46012 .49688 .4808 .49545 .47528 .48653 Mtetra
.596 .776 .966 r
.47528 .48653 .4808 .49545 .50156 .49401 .49617 .48517 Mtetra
.595 .778 .968 r
.49617 .48517 .50156 .49401 .52239 .49257 .51714 .48378 Mtetra
.594 .78 .969 r
.51714 .48378 .52239 .49257 .54329 .49111 .53818 .48236 Mtetra
.594 .781 .969 r
.53818 .48236 .54329 .49111 .56427 .48963 .55929 .48091 Mtetra
.594 .782 .97 r
.55929 .48091 .56427 .48963 .58532 .48813 .58048 .47943 Mtetra
.594 .783 .971 r
.58048 .47943 .58532 .48813 .60644 .4866 .60174 .47791 Mtetra
.593 .784 .971 r
.60174 .47791 .60644 .4866 .62764 .48504 .62309 .47636 Mtetra
.593 .785 .972 r
.62309 .47636 .62764 .48504 .64892 .48345 .6445 .47478 Mtetra
.593 .786 .972 r
.6445 .47478 .64892 .48345 .67027 .48184 .666 .47317 Mtetra
.594 .787 .972 r
.666 .47317 .67027 .48184 .69169 .48021 .68757 .47153 Mtetra
.594 .787 .973 r
.68757 .47153 .69169 .48021 .71319 .47855 .70921 .46987 Mtetra
.594 .788 .973 r
.70921 .46987 .71319 .47855 .73477 .47686 .73094 .46818 Mtetra
.73094 .46818 .73477 .47686 .75642 .47516 .75274 .46646 Mtetra
.594 .789 .973 r
.75274 .46646 .75642 .47516 .77815 .47343 .77461 .46472 Mtetra
.594 .789 .974 r
.77461 .46472 .77815 .47343 .79995 .47168 .79657 .46296 Mtetra
.594 .79 .974 r
.79657 .46296 .79995 .47168 .82183 .46992 .8186 .46118 Mtetra
.8186 .46118 .82183 .46992 .84379 .46813 .84071 .45937 Mtetra
.594 .791 .974 r
.84071 .45937 .84379 .46813 .86582 .46632 .8629 .45755 Mtetra
.8629 .45755 .86582 .46632 .88794 .4645 .88517 .45571 Mtetra
.595 .791 .974 r
.88517 .45571 .88794 .4645 .91013 .46266 .90752 .45385 Mtetra
.90752 .45385 .91013 .46266 .93239 .46081 .92994 .45197 Mtetra
.595 .792 .974 r
.92994 .45197 .93239 .46081 .95474 .45894 .95245 .45008 Mtetra
.595 .792 .975 r
.95245 .45008 .95474 .45894 .97717 .45705 .97504 .44817 Mtetra
.817 .737 .776 r
.24153 .52737 .24805 .54705 .26946 .52082 .26285 .5055 Mtetra
.753 .743 .843 r
.26285 .5055 .26946 .52082 .29016 .50866 .28357 .49561 Mtetra
.7 .747 .888 r
.28357 .49561 .29016 .50866 .31063 .50218 .3041 .49046 Mtetra
.662 .751 .916 r
.3041 .49046 .31063 .50218 .33105 .49829 .32461 .48741 Mtetra
.637 .754 .933 r
.32461 .48741 .33105 .49829 .35147 .49566 .34513 .48536 Mtetra
.62 .758 .944 r
.34513 .48536 .35147 .49566 .37194 .49369 .36571 .48378 Mtetra
.61 .761 .951 r
.36571 .48378 .37194 .49369 .39247 .49206 .38636 .48244 Mtetra
.603 .765 .957 r
.38636 .48244 .39247 .49206 .41307 .4906 .40708 .48119 Mtetra
.599 .768 .96 r
.40708 .48119 .41307 .4906 .43373 .48922 .42787 .47997 Mtetra
.596 .77 .963 r
.42787 .47997 .43373 .48922 .45447 .48788 .44874 .47874 Mtetra
.595 .773 .965 r
.44874 .47874 .45447 .48788 .47528 .48653 .46969 .47749 Mtetra
.594 .775 .967 r
.46969 .47749 .47528 .48653 .49617 .48517 .49071 .4762 Mtetra
.593 .777 .968 r
.49071 .4762 .49617 .48517 .51714 .48378 .51181 .47487 Mtetra
.593 .779 .969 r
.51181 .47487 .51714 .48378 .53818 .48236 .53299 .47349 Mtetra
.593 .78 .97 r
.53299 .47349 .53818 .48236 .55929 .48091 .55424 .47207 Mtetra
.592 .781 .97 r
.55424 .47207 .55929 .48091 .58048 .47943 .57557 .47061 Mtetra
.592 .783 .971 r
.57557 .47061 .58048 .47943 .60174 .47791 .59698 .4691 Mtetra
.593 .784 .971 r
.59698 .4691 .60174 .47791 .62309 .47636 .61846 .46756 Mtetra
.593 .785 .972 r
.61846 .46756 .62309 .47636 .6445 .47478 .64003 .46599 Mtetra
.64003 .46599 .6445 .47478 .666 .47317 .66167 .46438 Mtetra
.593 .786 .972 r
.66167 .46438 .666 .47317 .68757 .47153 .68338 .46274 Mtetra
.593 .787 .973 r
.68338 .46274 .68757 .47153 .70921 .46987 .70518 .46106 Mtetra
.593 .788 .973 r
.70518 .46106 .70921 .46987 .73094 .46818 .72705 .45936 Mtetra
.72705 .45936 .73094 .46818 .75274 .46646 .749 .45764 Mtetra
.594 .789 .973 r
.749 .45764 .75274 .46646 .77461 .46472 .77103 .45588 Mtetra
.594 .789 .974 r
.77103 .45588 .77461 .46472 .79657 .46296 .79314 .45411 Mtetra
.594 .79 .974 r
.79314 .45411 .79657 .46296 .8186 .46118 .81533 .45231 Mtetra
.81533 .45231 .8186 .46118 .84071 .45937 .83759 .45049 Mtetra
.83759 .45049 .84071 .45937 .8629 .45755 .85994 .44865 Mtetra
.594 .791 .974 r
.85994 .44865 .8629 .45755 .88517 .45571 .88237 .44678 Mtetra
.88237 .44678 .88517 .45571 .90752 .45385 .90487 .4449 Mtetra
.90487 .4449 .90752 .45385 .92994 .45197 .92746 .443 Mtetra
.595 .792 .974 r
.92746 .443 .92994 .45197 .95245 .45008 .95013 .44109 Mtetra
.595 .792 .975 r
.95013 .44109 .95245 .45008 .97504 .44817 .97287 .43915 Mtetra
.794 .725 .788 r
.23495 .50749 .24153 .52737 .26285 .5055 .25617 .49 Mtetra
.729 .732 .853 r
.25617 .49 .26285 .5055 .28357 .49561 .2769 .4824 Mtetra
.679 .737 .894 r
.2769 .4824 .28357 .49561 .3041 .49046 .29749 .47859 Mtetra
.645 .742 .92 r
.29749 .47859 .3041 .49046 .32461 .48741 .31808 .4764 Mtetra
.624 .748 .936 r
.31808 .4764 .32461 .48741 .34513 .48536 .33871 .47491 Mtetra
.611 .753 .946 r
.33871 .47491 .34513 .48536 .36571 .48378 .3594 .47374 Mtetra
.603 .758 .953 r
.3594 .47374 .36571 .48378 .38636 .48244 .38017 .47268 Mtetra
.598 .762 .957 r
.38017 .47268 .38636 .48244 .40708 .48119 .40101 .47165 Mtetra
.595 .765 .961 r
.40101 .47165 .40708 .48119 .42787 .47997 .42193 .47059 Mtetra
.593 .769 .963 r
.42193 .47059 .42787 .47997 .44874 .47874 .44293 .46949 Mtetra
.592 .771 .965 r
.44293 .46949 .44874 .47874 .46969 .47749 .46401 .46832 Mtetra
.591 .774 .967 r
.46401 .46832 .46969 .47749 .49071 .4762 .48517 .4671 Mtetra
.591 .776 .968 r
.48517 .4671 .49071 .4762 .51181 .47487 .50641 .46582 Mtetra
.591 .778 .969 r
.50641 .46582 .51181 .47487 .53299 .47349 .52773 .46449 Mtetra
.591 .779 .97 r
.52773 .46449 .53299 .47349 .55424 .47207 .54912 .4631 Mtetra
.591 .781 .97 r
.54912 .4631 .55424 .47207 .57557 .47061 .57059 .46166 Mtetra
.591 .782 .971 r
.57059 .46166 .57557 .47061 .59698 .4691 .59215 .46017 Mtetra
.592 .783 .971 r
.59215 .46017 .59698 .4691 .61846 .46756 .61378 .45864 Mtetra
.592 .784 .972 r
.61378 .45864 .61846 .46756 .64003 .46599 .63549 .45707 Mtetra
.592 .785 .972 r
.63549 .45707 .64003 .46599 .66167 .46438 .65727 .45546 Mtetra
.592 .786 .973 r
.65727 .45546 .66167 .46438 .68338 .46274 .67914 .45381 Mtetra
.593 .787 .973 r
.67914 .45381 .68338 .46274 .70518 .46106 .70109 .45213 Mtetra
.70109 .45213 .70518 .46106 .72705 .45936 .72311 .45042 Mtetra
.593 .788 .973 r
.72311 .45042 .72705 .45936 .749 .45764 .74521 .44868 Mtetra
.74521 .44868 .749 .45764 .77103 .45588 .7674 .44692 Mtetra
.593 .789 .974 r
.7674 .44692 .77103 .45588 .79314 .45411 .78966 .44513 Mtetra
.594 .789 .974 r
.78966 .44513 .79314 .45411 .81533 .45231 .812 .44331 Mtetra
.594 .79 .974 r
.812 .44331 .81533 .45231 .83759 .45049 .83443 .44147 Mtetra
.83443 .44147 .83759 .45049 .85994 .44865 .85693 .43961 Mtetra
.594 .791 .974 r
.85693 .43961 .85994 .44865 .88237 .44678 .87952 .43773 Mtetra
.87952 .43773 .88237 .44678 .90487 .4449 .90219 .43583 Mtetra
.90219 .43583 .90487 .4449 .92746 .443 .92494 .43391 Mtetra
.92494 .43391 .92746 .443 .95013 .44109 .94777 .43197 Mtetra
.594 .792 .975 r
.94777 .43197 .95013 .44109 .97287 .43915 .97068 .43001 Mtetra
.765 .711 .801 r
.2283 .4874 .23495 .50749 .25617 .49 .24941 .47431 Mtetra
.702 .718 .862 r
.24941 .47431 .25617 .49 .2769 .4824 .27014 .46902 Mtetra
.657 .726 .9 r
.27014 .46902 .2769 .4824 .29749 .47859 .29079 .46657 Mtetra
.628 .734 .923 r
.29079 .46657 .29749 .47859 .31808 .4764 .31147 .46523 Mtetra
.611 .741 .938 r
.31147 .46523 .31808 .4764 .33871 .47491 .3322 .46433 Mtetra
.601 .748 .947 r
.3322 .46433 .33871 .47491 .3594 .47374 .353 .46356 Mtetra
.595 .754 .954 r
.353 .46356 .3594 .47374 .38017 .47268 .37389 .46279 Mtetra
.592 .759 .958 r
.37389 .46279 .38017 .47268 .40101 .47165 .39486 .46198 Mtetra
.59 .763 .961 r
.39486 .46198 .40101 .47165 .42193 .47059 .41591 .46108 Mtetra
.589 .767 .964 r
.41591 .46108 .42193 .47059 .44293 .46949 .43704 .4601 Mtetra
.589 .77 .966 r
.43704 .4601 .44293 .46949 .46401 .46832 .45826 .45903 Mtetra
.589 .772 .967 r
.45826 .45903 .46401 .46832 .48517 .4671 .47956 .45788 Mtetra
.589 .775 .968 r
.47956 .45788 .48517 .4671 .50641 .46582 .50093 .45665 Mtetra
.589 .777 .969 r
.50093 .45665 .50641 .46582 .52773 .46449 .52239 .45536 Mtetra
.59 .779 .97 r
.52239 .45536 .52773 .46449 .54912 .4631 .54393 .454 Mtetra
.59 .78 .971 r
.54393 .454 .54912 .4631 .57059 .46166 .56555 .45258 Mtetra
.59 .781 .971 r
.56555 .45258 .57059 .46166 .59215 .46017 .58724 .45111 Mtetra
.591 .783 .972 r
.58724 .45111 .59215 .46017 .61378 .45864 .60902 .44959 Mtetra
.591 .784 .972 r
.60902 .44959 .61378 .45864 .63549 .45707 .63088 .44802 Mtetra
.591 .785 .972 r
.63088 .44802 .63549 .45707 .65727 .45546 .65282 .44641 Mtetra
.592 .786 .973 r
.65282 .44641 .65727 .45546 .67914 .45381 .67483 .44476 Mtetra
.67483 .44476 .67914 .45381 .70109 .45213 .69693 .44307 Mtetra
.592 .787 .973 r
.69693 .44307 .70109 .45213 .72311 .45042 .71911 .44135 Mtetra
.593 .788 .973 r
.71911 .44135 .72311 .45042 .74521 .44868 .74137 .4396 Mtetra
.74137 .4396 .74521 .44868 .7674 .44692 .76371 .43782 Mtetra
.593 .789 .974 r
.76371 .43782 .7674 .44692 .78966 .44513 .78613 .43602 Mtetra
.78613 .43602 .78966 .44513 .812 .44331 .80863 .43418 Mtetra
.593 .79 .974 r
.80863 .43418 .812 .44331 .83443 .44147 .83122 .43232 Mtetra
.594 .79 .974 r
.83122 .43232 .83443 .44147 .85693 .43961 .85388 .43044 Mtetra
.85388 .43044 .85693 .43961 .87952 .43773 .87663 .42854 Mtetra
.594 .791 .974 r
.87663 .42854 .87952 .43773 .90219 .43583 .89946 .42662 Mtetra
.89946 .42662 .90219 .43583 .92494 .43391 .92238 .42467 Mtetra
.92238 .42467 .92494 .43391 .94777 .43197 .94537 .42271 Mtetra
.594 .792 .975 r
.94537 .42271 .94777 .43197 .97068 .43001 .96845 .42073 Mtetra
.731 .692 .814 r
.22159 .46712 .2283 .4874 .24941 .47431 .24257 .45845 Mtetra
.671 .702 .87 r
.24257 .45845 .24941 .47431 .27014 .46902 .2633 .45547 Mtetra
.632 .713 .905 r
.2633 .45547 .27014 .46902 .29079 .46657 .284 .45439 Mtetra
.609 .724 .927 r
.284 .45439 .29079 .46657 .31147 .46523 .30476 .45392 Mtetra
.597 .734 .94 r
.30476 .45392 .31147 .46523 .3322 .46433 .3256 .4536 Mtetra
.59 .742 .949 r
.3256 .4536 .3322 .46433 .353 .46356 .34652 .45324 Mtetra
.587 .75 .955 r
.34652 .45324 .353 .46356 .37389 .46279 .36753 .45277 Mtetra
.586 .755 .959 r
.36753 .45277 .37389 .46279 .39486 .46198 .38862 .45217 Mtetra
.585 .76 .962 r
.38862 .45217 .39486 .46198 .41591 .46108 .4098 .45143 Mtetra
.585 .765 .964 r
.4098 .45143 .41591 .46108 .43704 .4601 .43107 .45057 Mtetra
.586 .768 .966 r
.43107 .45057 .43704 .4601 .45826 .45903 .45242 .4496 Mtetra
.586 .771 .967 r
.45242 .4496 .45826 .45903 .47956 .45788 .47386 .44852 Mtetra
.587 .774 .968 r
.47386 .44852 .47956 .45788 .50093 .45665 .49538 .44735 Mtetra
.588 .776 .969 r
.49538 .44735 .50093 .45665 .52239 .45536 .51698 .4461 Mtetra
.588 .778 .97 r
.51698 .4461 .52239 .45536 .54393 .454 .53866 .44477 Mtetra
.589 .779 .971 r
.53866 .44477 .54393 .454 .56555 .45258 .56042 .44337 Mtetra
.589 .781 .971 r
.56042 .44337 .56555 .45258 .58724 .45111 .58227 .44191 Mtetra
.59 .782 .972 r
.58227 .44191 .58724 .45111 .60902 .44959 .6042 .4404 Mtetra
.59 .783 .972 r
.6042 .4404 .60902 .44959 .63088 .44802 .6262 .43884 Mtetra
.591 .784 .972 r
.6262 .43884 .63088 .44802 .65282 .44641 .64829 .43722 Mtetra
.591 .785 .973 r
.64829 .43722 .65282 .44641 .67483 .44476 .67047 .43557 Mtetra
.592 .786 .973 r
.67047 .43557 .67483 .44476 .69693 .44307 .69272 .43388 Mtetra
.592 .787 .973 r
.69272 .43388 .69693 .44307 .71911 .44135 .71505 .43215 Mtetra
.71505 .43215 .71911 .44135 .74137 .4396 .73747 .43039 Mtetra
.592 .788 .974 r
.73747 .43039 .74137 .4396 .76371 .43782 .75997 .42859 Mtetra
.593 .789 .974 r
.75997 .42859 .76371 .43782 .78613 .43602 .78255 .42677 Mtetra
.78255 .42677 .78613 .43602 .80863 .43418 .80521 .42492 Mtetra
.80521 .42492 .80863 .43418 .83122 .43232 .82796 .42304 Mtetra
.593 .79 .974 r
.82796 .42304 .83122 .43232 .85388 .43044 .85079 .42114 Mtetra
.594 .79 .974 r
.85079 .42114 .85388 .43044 .87663 .42854 .8737 .41921 Mtetra
.594 .791 .974 r
.8737 .41921 .87663 .42854 .89946 .42662 .8967 .41727 Mtetra
.8967 .41727 .89946 .42662 .92238 .42467 .91978 .4153 Mtetra
.91978 .4153 .92238 .42467 .94537 .42271 .94294 .41331 Mtetra
.594 .792 .975 r
.94294 .41331 .94537 .42271 .96845 .42073 .96619 .4113 Mtetra
.688 .668 .825 r
.21481 .44662 .22159 .46712 .24257 .45845 .23565 .4424 Mtetra
.635 .683 .878 r
.23565 .4424 .24257 .45845 .2633 .45547 .25637 .44176 Mtetra
.605 .699 .91 r
.25637 .44176 .2633 .45547 .284 .45439 .27713 .44205 Mtetra
.59 .714 .93 r
.27713 .44205 .284 .45439 .30476 .45392 .29797 .44246 Mtetra
.583 .726 .942 r
.29797 .44246 .30476 .45392 .3256 .4536 .31891 .44273 Mtetra
.58 .737 .95 r
.31891 .44273 .3256 .4536 .34652 .45324 .33994 .44278 Mtetra
.579 .745 .956 r
.33994 .44278 .34652 .45324 .36753 .45277 .36107 .4426 Mtetra
.579 .752 .96 r
.36107 .4426 .36753 .45277 .38862 .45217 .3823 .44222 Mtetra
.58 .758 .963 r
.3823 .44222 .38862 .45217 .4098 .45143 .40361 .44165 Mtetra
.581 .763 .965 r
.40361 .44165 .4098 .45143 .43107 .45057 .42501 .44092 Mtetra
.583 .766 .966 r
.42501 .44092 .43107 .45057 .45242 .4496 .4465 .44004 Mtetra
.584 .77 .968 r
.4465 .44004 .45242 .4496 .47386 .44852 .46808 .43903 Mtetra
.585 .773 .969 r
.46808 .43903 .47386 .44852 .49538 .44735 .48974 .43792 Mtetra
.586 .775 .97 r
.48974 .43792 .49538 .44735 .51698 .4461 .51149 .43671 Mtetra
.587 .777 .97 r
.51149 .43671 .51698 .4461 .53866 .44477 .53332 .43541 Mtetra
.588 .779 .971 r
.53332 .43541 .53866 .44477 .56042 .44337 .55523 .43403 Mtetra
.588 .78 .971 r
.55523 .43403 .56042 .44337 .58227 .44191 .57722 .43259 Mtetra
.589 .782 .972 r
.57722 .43259 .58227 .44191 .6042 .4404 .5993 .43108 Mtetra
.59 .783 .972 r
.5993 .43108 .6042 .4404 .6262 .43884 .62146 .42952 Mtetra
.59 .784 .972 r
.62146 .42952 .6262 .43884 .64829 .43722 .64371 .42791 Mtetra
.591 .785 .973 r
.64371 .42791 .64829 .43722 .67047 .43557 .66603 .42625 Mtetra
.591 .786 .973 r
.66603 .42625 .67047 .43557 .69272 .43388 .68844 .42455 Mtetra
.68844 .42455 .69272 .43388 .71505 .43215 .71093 .42281 Mtetra
.592 .787 .973 r
.71093 .42281 .71505 .43215 .73747 .43039 .73351 .42103 Mtetra
.592 .788 .974 r
.73351 .42103 .73747 .43039 .75997 .42859 .75617 .41922 Mtetra
.75617 .41922 .75997 .42859 .78255 .42677 .77891 .41738 Mtetra
.593 .789 .974 r
.77891 .41738 .78255 .42677 .80521 .42492 .80174 .41551 Mtetra
.80174 .41551 .80521 .42492 .82796 .42304 .82465 .41362 Mtetra
.593 .79 .974 r
.82465 .41362 .82796 .42304 .85079 .42114 .84764 .41169 Mtetra
.84764 .41169 .85079 .42114 .8737 .41921 .87072 .40975 Mtetra
.594 .79 .974 r
.87072 .40975 .8737 .41921 .8967 .41727 .89389 .40778 Mtetra
.594 .791 .974 r
.89389 .40778 .8967 .41727 .91978 .4153 .91714 .40579 Mtetra
.91714 .40579 .91978 .4153 .94294 .41331 .94048 .40377 Mtetra
.594 .791 .975 r
.94048 .40377 .94294 .41331 .96619 .4113 .9639 .40174 Mtetra
.635 .637 .835 r
.20795 .42592 .21481 .44662 .23565 .4424 .22865 .42616 Mtetra
.595 .66 .884 r
.22865 .42616 .23565 .4424 .25637 .44176 .24936 .42787 Mtetra
.576 .683 .913 r
.24936 .42787 .25637 .44176 .27713 .44205 .27016 .42955 Mtetra
.569 .703 .932 r
.27016 .42955 .27713 .44205 .29797 .44246 .29109 .43084 Mtetra
.568 .718 .944 r
.29109 .43084 .29797 .44246 .31891 .44273 .31213 .4317 Mtetra
.569 .731 .951 r
.31213 .4317 .31891 .44273 .33994 .44278 .33328 .43217 Mtetra
.571 .741 .957 r
.33328 .43217 .33994 .44278 .36107 .4426 .35453 .4323 Mtetra
.573 .749 .96 r
.35453 .4323 .36107 .4426 .3823 .44222 .37588 .43213 Mtetra
.575 .755 .963 r
.37588 .43213 .3823 .44222 .40361 .44165 .39733 .43173 Mtetra
.578 .761 .965 r
.39733 .43173 .40361 .44165 .42501 .44092 .41887 .43112 Mtetra
.58 .765 .967 r
.41887 .43112 .42501 .44092 .4465 .44004 .4405 .43034 Mtetra
.581 .768 .968 r
.4405 .43034 .4465 .44004 .46808 .43903 .46222 .42941 Mtetra
.583 .771 .969 r
.46222 .42941 .46808 .43903 .48974 .43792 .48402 .42835 Mtetra
.584 .774 .97 r
.48402 .42835 .48974 .43792 .51149 .43671 .50591 .42717 Mtetra
.585 .776 .97 r
.50591 .42717 .51149 .43671 .53332 .43541 .52789 .42591 Mtetra
.586 .778 .971 r
.52789 .42591 .53332 .43541 .55523 .43403 .54996 .42455 Mtetra
.587 .78 .971 r
.54996 .42455 .55523 .43403 .57722 .43259 .5721 .42312 Mtetra
.588 .781 .972 r
.5721 .42312 .57722 .43259 .5993 .43108 .59433 .42162 Mtetra
.589 .782 .972 r
.59433 .42162 .5993 .43108 .62146 .42952 .61665 .42006 Mtetra
.589 .784 .973 r
.61665 .42006 .62146 .42952 .64371 .42791 .63905 .41845 Mtetra
.59 .785 .973 r
.63905 .41845 .64371 .42791 .66603 .42625 .66153 .41679 Mtetra
.591 .785 .973 r
.66153 .41679 .66603 .42625 .68844 .42455 .6841 .41508 Mtetra
.591 .786 .973 r
.6841 .41508 .68844 .42455 .71093 .42281 .70675 .41333 Mtetra
.591 .787 .973 r
.70675 .41333 .71093 .42281 .73351 .42103 .72949 .41154 Mtetra
.592 .788 .974 r
.72949 .41154 .73351 .42103 .75617 .41922 .75231 .40971 Mtetra
.75231 .40971 .75617 .41922 .77891 .41738 .77522 .40786 Mtetra
.592 .789 .974 r
.77522 .40786 .77891 .41738 .80174 .41551 .79821 .40597 Mtetra
.593 .789 .974 r
.79821 .40597 .80174 .41551 .82465 .41362 .82129 .40405 Mtetra
.593 .79 .974 r
.82129 .40405 .82465 .41362 .84764 .41169 .84445 .40211 Mtetra
.84445 .40211 .84764 .41169 .87072 .40975 .8677 .40014 Mtetra
.8677 .40014 .87072 .40975 .89389 .40778 .89104 .39814 Mtetra
.594 .791 .974 r
.89104 .39814 .89389 .40778 .91714 .40579 .91446 .39613 Mtetra
.91446 .39613 .91714 .40579 .94048 .40377 .93797 .39409 Mtetra
.594 .791 .975 r
.93797 .39409 .94048 .40377 .9639 .40174 .96157 .39203 Mtetra
.57 .597 .841 r
.20103 .405 .20795 .42592 .22865 .42616 .22156 .40972 Mtetra
.548 .633 .887 r
.22156 .40972 .22865 .42616 .24936 .42787 .24225 .41381 Mtetra
.544 .665 .916 r
.24225 .41381 .24936 .42787 .27016 .42955 .26311 .41688 Mtetra
.547 .69 .934 r
.26311 .41688 .27016 .42955 .29109 .43084 .28411 .41907 Mtetra
.552 .71 .945 r
.28411 .41907 .29109 .43084 .31213 .4317 .30525 .42053 Mtetra
.557 .725 .952 r
.30525 .42053 .31213 .4317 .33328 .43217 .32652 .42141 Mtetra
.562 .737 .957 r
.32652 .42141 .33328 .43217 .35453 .4323 .34789 .42184 Mtetra
.567 .746 .961 r
.34789 .42184 .35453 .4323 .37588 .43213 .36937 .4219 Mtetra
.571 .753 .964 r
.36937 .4219 .37588 .43213 .39733 .43173 .39096 .42167 Mtetra
.574 .758 .966 r
.39096 .42167 .39733 .43173 .41887 .43112 .41263 .42118 Mtetra
.576 .763 .967 r
.41263 .42118 .41887 .43112 .4405 .43034 .43441 .4205 Mtetra
.579 .767 .968 r
.43441 .4205 .4405 .43034 .46222 .42941 .45627 .41964 Mtetra
.581 .77 .969 r
.45627 .41964 .46222 .42941 .48402 .42835 .47822 .41863 Mtetra
.582 .773 .97 r
.47822 .41863 .48402 .42835 .50591 .42717 .50026 .4175 Mtetra
.584 .775 .971 r
.50026 .4175 .50591 .42717 .52789 .42591 .52239 .41627 Mtetra
.585 .777 .971 r
.52239 .41627 .52789 .42591 .54996 .42455 .5446 .41493 Mtetra
.586 .779 .972 r
.5446 .41493 .54996 .42455 .5721 .42312 .56691 .41352 Mtetra
.587 .781 .972 r
.56691 .41352 .5721 .42312 .59433 .42162 .58929 .41203 Mtetra
.588 .782 .972 r
.58929 .41203 .59433 .42162 .61665 .42006 .61176 .41047 Mtetra
.589 .783 .973 r
.61176 .41047 .61665 .42006 .63905 .41845 .63432 .40885 Mtetra
.589 .784 .973 r
.63432 .40885 .63905 .41845 .66153 .41679 .65697 .40718 Mtetra
.59 .785 .973 r
.65697 .40718 .66153 .41679 .6841 .41508 .6797 .40547 Mtetra
.591 .786 .973 r
.6797 .40547 .6841 .41508 .70675 .41333 .70251 .40371 Mtetra
.591 .787 .973 r
.70251 .40371 .70675 .41333 .72949 .41154 .72541 .4019 Mtetra
.591 .787 .974 r
.72541 .4019 .72949 .41154 .75231 .40971 .7484 .40006 Mtetra
.592 .788 .974 r
.7484 .40006 .75231 .40971 .77522 .40786 .77147 .39819 Mtetra
.77147 .39819 .77522 .40786 .79821 .40597 .79463 .39628 Mtetra
.592 .789 .974 r
.79463 .39628 .79821 .40597 .82129 .40405 .81788 .39434 Mtetra
.593 .789 .974 r
.81788 .39434 .82129 .40405 .84445 .40211 .84121 .39237 Mtetra
.593 .79 .974 r
.84121 .39237 .84445 .40211 .8677 .40014 .86463 .39038 Mtetra
.86463 .39038 .8677 .40014 .89104 .39814 .88814 .38836 Mtetra
.593 .791 .974 r
.88814 .38836 .89104 .39814 .91446 .39613 .91174 .38632 Mtetra
.594 .791 .975 r
.91174 .38632 .91446 .39613 .93797 .39409 .93543 .38425 Mtetra
.93543 .38425 .93797 .39409 .96157 .39203 .9592 .38216 Mtetra
.49 .546 .841 r
.19404 .38387 .20103 .405 .22156 .40972 .2144 .39309 Mtetra
.495 .601 .888 r
.2144 .39309 .22156 .40972 .24225 .41381 .23506 .39956 Mtetra
.509 .645 .917 r
.23506 .39956 .24225 .41381 .26311 .41688 .25595 .40405 Mtetra
.524 .677 .935 r
.25595 .40405 .26311 .41688 .28411 .41907 .27704 .40713 Mtetra
.536 .701 .946 r
.27704 .40713 .28411 .41907 .30525 .42053 .29828 .4092 Mtetra
.546 .719 .953 r
.29828 .4092 .30525 .42053 .32652 .42141 .31966 .41051 Mtetra
.554 .732 .958 r
.31966 .41051 .32652 .42141 .34789 .42184 .34116 .41124 Mtetra
.56 .742 .961 r
.34116 .41124 .34789 .42184 .36937 .4219 .36277 .41153 Mtetra
.566 .75 .964 r
.36277 .41153 .36937 .4219 .39096 .42167 .38449 .41146 Mtetra
.57 .756 .966 r
.38449 .41146 .39096 .42167 .41263 .42118 .40631 .4111 Mtetra
.573 .761 .967 r
.40631 .4111 .41263 .42118 .43441 .4205 .42822 .41051 Mtetra
.576 .766 .968 r
.42822 .41051 .43441 .4205 .45627 .41964 .45023 .40973 Mtetra
.579 .769 .969 r
.45023 .40973 .45627 .41964 .47822 .41863 .47233 .40878 Mtetra
.581 .772 .97 r
.47233 .40878 .47822 .41863 .50026 .4175 .49453 .40769 Mtetra
.582 .775 .971 r
.49453 .40769 .50026 .4175 .52239 .41627 .51681 .40648 Mtetra
.584 .777 .971 r
.51681 .40648 .52239 .41627 .5446 .41493 .53917 .40517 Mtetra
.585 .779 .972 r
.53917 .40517 .5446 .41493 .56691 .41352 .56163 .40377 Mtetra
.586 .78 .972 r
.56163 .40377 .56691 .41352 .58929 .41203 .58418 .40228 Mtetra
.587 .782 .972 r
.58418 .40228 .58929 .41203 .61176 .41047 .60681 .40073 Mtetra
.588 .783 .973 r
.60681 .40073 .61176 .41047 .63432 .40885 .62953 .39911 Mtetra
.589 .784 .973 r
.62953 .39911 .63432 .40885 .65697 .40718 .65233 .39744 Mtetra
.589 .785 .973 r
.65233 .39744 .65697 .40718 .6797 .40547 .67522 .39571 Mtetra
.59 .786 .973 r
.67522 .39571 .6797 .40547 .70251 .40371 .6982 .39394 Mtetra
.591 .786 .973 r
.6982 .39394 .70251 .40371 .72541 .4019 .72127 .39212 Mtetra
.591 .787 .974 r
.72127 .39212 .72541 .4019 .7484 .40006 .74443 .39026 Mtetra
.591 .788 .974 r
.74443 .39026 .7484 .40006 .77147 .39819 .76767 .38837 Mtetra
.592 .788 .974 r
.76767 .38837 .77147 .39819 .79463 .39628 .791 .38644 Mtetra
.592 .789 .974 r
.791 .38644 .79463 .39628 .81788 .39434 .81442 .38448 Mtetra
.81442 .38448 .81788 .39434 .84121 .39237 .83792 .38249 Mtetra
.593 .79 .974 r
.83792 .38249 .84121 .39237 .86463 .39038 .86152 .38047 Mtetra
.86152 .38047 .86463 .39038 .88814 .38836 .88521 .37843 Mtetra
.88521 .37843 .88814 .38836 .91174 .38632 .90898 .37636 Mtetra
.593 .791 .975 r
.90898 .37636 .91174 .38632 .93543 .38425 .93285 .37427 Mtetra
.594 .791 .975 r
.93285 .37427 .93543 .38425 .9592 .38216 .9568 .37215 Mtetra
.393 .482 .832 r
.18697 .36251 .19404 .38387 .2144 .39309 .20714 .37626 Mtetra
.436 .564 .885 r
.20714 .37626 .2144 .39309 .23506 .39956 .22777 .38513 Mtetra
.472 .622 .916 r
.22777 .38513 .23506 .39956 .25595 .40405 .24871 .39104 Mtetra
.499 .663 .935 r
.24871 .39104 .25595 .40405 .27704 .40713 .26987 .39503 Mtetra
.519 .692 .947 r
.26987 .39503 .27704 .40713 .29828 .4092 .29121 .39771 Mtetra
.534 .712 .954 r
.29121 .39771 .29828 .4092 .31966 .41051 .31271 .39944 Mtetra
.545 .727 .959 r
.31271 .39944 .31966 .41051 .34116 .41124 .33433 .40048 Mtetra
.554 .739 .962 r
.33433 .40048 .34116 .41124 .36277 .41153 .35608 .401 Mtetra
.561 .747 .964 r
.35608 .401 .36277 .41153 .38449 .41146 .37793 .4011 Mtetra
.566 .754 .966 r
.37793 .4011 .38449 .41146 .40631 .4111 .39989 .40087 Mtetra
.57 .76 .968 r
.39989 .40087 .40631 .4111 .42822 .41051 .42195 .40038 Mtetra
.574 .764 .969 r
.42195 .40038 .42822 .41051 .45023 .40973 .44411 .39967 Mtetra
.577 .768 .97 r
.44411 .39967 .45023 .40973 .47233 .40878 .46636 .39878 Mtetra
.579 .771 .97 r
.46636 .39878 .47233 .40878 .49453 .40769 .4887 .39773 Mtetra
.581 .774 .971 r
.4887 .39773 .49453 .40769 .51681 .40648 .51114 .39655 Mtetra
.583 .776 .971 r
.51114 .39655 .51681 .40648 .53917 .40517 .53366 .39526 Mtetra
.584 .778 .972 r
.53366 .39526 .53917 .40517 .56163 .40377 .55628 .39387 Mtetra
.585 .78 .972 r
.55628 .39387 .56163 .40377 .58418 .40228 .57898 .3924 Mtetra
.586 .781 .972 r
.57898 .3924 .58418 .40228 .60681 .40073 .60177 .39084 Mtetra
.587 .782 .973 r
.60177 .39084 .60681 .40073 .62953 .39911 .62466 .38922 Mtetra
.588 .783 .973 r
.62466 .38922 .62953 .39911 .65233 .39744 .64763 .38754 Mtetra
.589 .784 .973 r
.64763 .38754 .65233 .39744 .67522 .39571 .67068 .38581 Mtetra
.59 .785 .973 r
.67068 .38581 .67522 .39571 .6982 .39394 .69383 .38402 Mtetra
.59 .786 .974 r
.69383 .38402 .6982 .39394 .72127 .39212 .71707 .38219 Mtetra
.591 .787 .974 r
.71707 .38219 .72127 .39212 .74443 .39026 .74039 .38031 Mtetra
.591 .788 .974 r
.74039 .38031 .74443 .39026 .76767 .38837 .7638 .3784 Mtetra
.592 .788 .974 r
.7638 .3784 .76767 .38837 .791 .38644 .78731 .37645 Mtetra
.592 .789 .974 r
.78731 .37645 .791 .38644 .81442 .38448 .8109 .37447 Mtetra
.8109 .37447 .81442 .38448 .83792 .38249 .83458 .37245 Mtetra
.592 .79 .974 r
.83458 .37245 .83792 .38249 .86152 .38047 .85836 .37041 Mtetra
.593 .79 .974 r
.85836 .37041 .86152 .38047 .88521 .37843 .88222 .36834 Mtetra
.88222 .36834 .88521 .37843 .90898 .37636 .90618 .36625 Mtetra
.593 .791 .975 r
.90618 .36625 .90898 .37636 .93285 .37427 .93022 .36412 Mtetra
.93022 .36412 .93285 .37427 .9568 .37215 .95436 .36198 Mtetra
.277 .402 .809 r
.17983 .34093 .18697 .36251 .20714 .37626 .1998 .35923 Mtetra
.369 .52 .877 r
.1998 .35923 .20714 .37626 .22777 .38513 .22039 .37051 Mtetra
.431 .597 .914 r
.22039 .37051 .22777 .38513 .24871 .39104 .24136 .37786 Mtetra
.473 .648 .935 r
.24136 .37786 .24871 .39104 .26987 .39503 .2626 .38276 Mtetra
.502 .682 .947 r
.2626 .38276 .26987 .39503 .29121 .39771 .28405 .38605 Mtetra
.522 .705 .954 r
.28405 .38605 .29121 .39771 .31271 .39944 .30565 .38822 Mtetra
.536 .722 .959 r
.30565 .38822 .31271 .39944 .33433 .40048 .32741 .38957 Mtetra
.547 .735 .962 r
.32741 .38957 .33433 .40048 .35608 .401 .34928 .39032 Mtetra
.555 .745 .965 r
.34928 .39032 .35608 .401 .37793 .4011 .37128 .39059 Mtetra
.562 .752 .967 r
.37128 .39059 .37793 .4011 .39989 .40087 .39338 .39049 Mtetra
.567 .758 .968 r
.39338 .39049 .39989 .40087 .42195 .40038 .41559 .3901 Mtetra
.571 .763 .969 r
.41559 .3901 .42195 .40038 .44411 .39967 .43789 .38946 Mtetra
.574 .767 .97 r
.43789 .38946 .44411 .39967 .46636 .39878 .4603 .38863 Mtetra
.577 .77 .97 r
.4603 .38863 .46636 .39878 .4887 .39773 .48279 .38762 Mtetra
.579 .773 .971 r
.48279 .38762 .4887 .39773 .51114 .39655 .50538 .38647 Mtetra
.581 .775 .971 r
.50538 .38647 .51114 .39655 .53366 .39526 .52807 .3852 Mtetra
.583 .777 .972 r
.52807 .3852 .53366 .39526 .55628 .39387 .55084 .38383 Mtetra
.584 .779 .972 r
.55084 .38383 .55628 .39387 .57898 .3924 .57371 .38236 Mtetra
.586 .781 .972 r
.57371 .38236 .57898 .3924 .60177 .39084 .59666 .38081 Mtetra
.587 .782 .973 r
.59666 .38081 .60177 .39084 .62466 .38922 .61971 .37918 Mtetra
.588 .783 .973 r
.61971 .37918 .62466 .38922 .64763 .38754 .64285 .37749 Mtetra
.588 .784 .973 r
.64285 .37749 .64763 .38754 .67068 .38581 .66607 .37575 Mtetra
.589 .785 .973 r
.66607 .37575 .67068 .38581 .69383 .38402 .68939 .37395 Mtetra
.59 .786 .974 r
.68939 .37395 .69383 .38402 .71707 .38219 .7128 .3721 Mtetra
.59 .787 .974 r
.7128 .3721 .71707 .38219 .74039 .38031 .73629 .37021 Mtetra
.591 .787 .974 r
.73629 .37021 .74039 .38031 .7638 .3784 .75988 .36828 Mtetra
.591 .788 .974 r
.75988 .36828 .7638 .3784 .78731 .37645 .78356 .36631 Mtetra
.592 .788 .974 r
.78356 .36631 .78731 .37645 .8109 .37447 .80733 .3643 Mtetra
.592 .789 .974 r
.80733 .3643 .8109 .37447 .83458 .37245 .83119 .36226 Mtetra
.83119 .36226 .83458 .37245 .85836 .37041 .85514 .36019 Mtetra
.593 .79 .974 r
.85514 .36019 .85836 .37041 .88222 .36834 .87919 .3581 Mtetra
.87919 .3581 .88222 .36834 .90618 .36625 .90333 .35597 Mtetra
.593 .791 .975 r
.90333 .35597 .90618 .36625 .93022 .36412 .92756 .35382 Mtetra
.92756 .35382 .93022 .36412 .95436 .36198 .95188 .35165 Mtetra
.145 .306 .77 r
.17261 .31913 .17983 .34093 .1998 .35923 .19236 .34199 Mtetra
.295 .47 .863 r
.19236 .34199 .1998 .35923 .22039 .37051 .21291 .35571 Mtetra
.388 .57 .909 r
.21291 .35571 .22039 .37051 .24136 .37786 .23392 .36449 Mtetra
.446 .631 .933 r
.23392 .36449 .24136 .37786 .2626 .38276 .25523 .37032 Mtetra
.484 .671 .947 r
.25523 .37032 .2626 .38276 .28405 .38605 .27678 .37423 Mtetra
.509 .698 .955 r
.27678 .37423 .28405 .38605 .30565 .38822 .2985 .37684 Mtetra
.527 .717 .96 r
.2985 .37684 .30565 .38822 .32741 .38957 .32038 .3785 Mtetra
.54 .731 .963 r
.32038 .3785 .32741 .38957 .34928 .39032 .34239 .37948 Mtetra
.55 .742 .965 r
.34239 .37948 .34928 .39032 .37128 .39059 .36452 .37992 Mtetra
.558 .75 .967 r
.36452 .37992 .37128 .39059 .39338 .39049 .38677 .37996 Mtetra
.564 .756 .968 r
.38677 .37996 .39338 .39049 .41559 .3901 .40913 .37966 Mtetra
.569 .761 .969 r
.40913 .37966 .41559 .3901 .43789 .38946 .43158 .3791 Mtetra
.572 .766 .97 r
.43158 .3791 .43789 .38946 .4603 .38863 .45414 .37832 Mtetra
.575 .769 .971 r
.45414 .37832 .4603 .38863 .48279 .38762 .47679 .37736 Mtetra
.578 .772 .971 r
.47679 .37736 .48279 .38762 .50538 .38647 .49954 .37624 Mtetra
.58 .775 .972 r
.49954 .37624 .50538 .38647 .52807 .3852 .52239 .37499 Mtetra
.582 .777 .972 r
.52239 .37499 .52807 .3852 .55084 .38383 .54533 .37363 Mtetra
.584 .779 .972 r
.54533 .37363 .55084 .38383 .57371 .38236 .56835 .37216 Mtetra
.585 .78 .973 r
.56835 .37216 .57371 .38236 .59666 .38081 .59148 .37061 Mtetra
.586 .782 .973 r
.59148 .37061 .59666 .38081 .61971 .37918 .61469 .36899 Mtetra
.587 .783 .973 r
.61469 .36899 .61971 .37918 .64285 .37749 .638 .36729 Mtetra
.588 .784 .973 r
.638 .36729 .64285 .37749 .66607 .37575 .66139 .36553 Mtetra
.589 .785 .973 r
.66139 .36553 .66607 .37575 .68939 .37395 .68488 .36372 Mtetra
.589 .786 .974 r
.68488 .36372 .68939 .37395 .7128 .3721 .70846 .36186 Mtetra
.59 .786 .974 r
.70846 .36186 .7128 .3721 .73629 .37021 .73213 .35995 Mtetra
.59 .787 .974 r
.73213 .35995 .73629 .37021 .75988 .36828 .7559 .35799 Mtetra
.591 .788 .974 r
.7559 .35799 .75988 .36828 .78356 .36631 .77975 .356 Mtetra
.77975 .356 .78356 .36631 .80733 .3643 .8037 .35397 Mtetra
.592 .789 .974 r
.8037 .35397 .80733 .3643 .83119 .36226 .82775 .35191 Mtetra
.82775 .35191 .83119 .36226 .85514 .36019 .85188 .34981 Mtetra
.592 .79 .974 r
.85188 .34981 .85514 .36019 .87919 .3581 .87611 .34769 Mtetra
.593 .79 .974 r
.87611 .34769 .87919 .3581 .90333 .35597 .90043 .34554 Mtetra
.593 .79 .975 r
.90043 .34554 .90333 .35597 .92756 .35382 .92485 .34336 Mtetra
.593 .791 .975 r
.92485 .34336 .92756 .35382 .95188 .35165 .94936 .34115 Mtetra
.001 .198 .712 r
.16532 .29709 .17261 .31913 .19236 .34199 .18484 .32454 Mtetra
.214 .414 .842 r
.18484 .32454 .19236 .34199 .21291 .35571 .20533 .34071 Mtetra
.341 .54 .902 r
.20533 .34071 .21291 .35571 .23392 .36449 .22637 .35095 Mtetra
.417 .614 .931 r
.22637 .35095 .23392 .36449 .25523 .37032 .24776 .35771 Mtetra
.465 .66 .946 r
.24776 .35771 .25523 .37032 .27678 .37423 .2694 .36225 Mtetra
.496 .691 .955 r
.2694 .36225 .27678 .37423 .2985 .37684 .29124 .36529 Mtetra
.518 .712 .96 r
.29124 .36529 .2985 .37684 .32038 .3785 .31325 .36727 Mtetra
.534 .727 .963 r
.31325 .36727 .32038 .3785 .34239 .37948 .3354 .36848 Mtetra
.545 .739 .966 r
.3354 .36848 .34239 .37948 .36452 .37992 .35767 .3691 Mtetra
.554 .748 .967 r
.35767 .3691 .36452 .37992 .38677 .37996 .38006 .36926 Mtetra
.561 .755 .968 r
.38006 .36926 .38677 .37996 .40913 .37966 .40257 .36907 Mtetra
.566 .76 .969 r
.40257 .36907 .40913 .37966 .43158 .3791 .42518 .36858 Mtetra
.57 .765 .97 r
.42518 .36858 .43158 .3791 .45414 .37832 .44789 .36786 Mtetra
.574 .768 .971 r
.44789 .36786 .45414 .37832 .47679 .37736 .4707 .36694 Mtetra
.577 .771 .971 r
.4707 .36694 .47679 .37736 .49954 .37624 .49361 .36585 Mtetra
.579 .774 .972 r
.49361 .36585 .49954 .37624 .52239 .37499 .51662 .36462 Mtetra
.581 .776 .972 r
.51662 .36462 .52239 .37499 .54533 .37363 .53972 .36327 Mtetra
.583 .778 .972 r
.53972 .36327 .54533 .37363 .56835 .37216 .56292 .36182 Mtetra
.584 .78 .973 r
.56292 .36182 .56835 .37216 .59148 .37061 .58621 .36027 Mtetra
.585 .781 .973 r
.58621 .36027 .59148 .37061 .61469 .36899 .60959 .35863 Mtetra
.586 .782 .973 r
.60959 .35863 .61469 .36899 .638 .36729 .63307 .35693 Mtetra
.587 .784 .973 r
.63307 .35693 .638 .36729 .66139 .36553 .65664 .35516 Mtetra
.588 .785 .973 r
.65664 .35516 .66139 .36553 .68488 .36372 .6803 .35333 Mtetra
.589 .785 .974 r
.6803 .35333 .68488 .36372 .70846 .36186 .70406 .35145 Mtetra
.59 .786 .974 r
.70406 .35145 .70846 .36186 .73213 .35995 .72791 .34952 Mtetra
.59 .787 .974 r
.72791 .34952 .73213 .35995 .7559 .35799 .75185 .34755 Mtetra
.591 .788 .974 r
.75185 .34755 .7559 .35799 .77975 .356 .77589 .34553 Mtetra
.77589 .34553 .77975 .356 .8037 .35397 .80002 .34348 Mtetra
.591 .789 .974 r
.80002 .34348 .8037 .35397 .82775 .35191 .82425 .34139 Mtetra
.592 .789 .974 r
.82425 .34139 .82775 .35191 .85188 .34981 .84857 .33927 Mtetra
.592 .79 .974 r
.84857 .33927 .85188 .34981 .87611 .34769 .87298 .33712 Mtetra
.87298 .33712 .87611 .34769 .90043 .34554 .89749 .33493 Mtetra
.593 .79 .975 r
.89749 .33493 .90043 .34554 .92485 .34336 .9221 .33272 Mtetra
.593 .791 .975 r
.9221 .33272 .92485 .34336 .94936 .34115 .94681 .33049 Mtetra
0 .083 .637 r
.15795 .27482 .16532 .29709 .18484 .32454 .17722 .30687 Mtetra
.127 .352 .814 r
.17722 .30687 .18484 .32454 .20533 .34071 .19765 .3255 Mtetra
.291 .506 .893 r
.19765 .3255 .20533 .34071 .22637 .35095 .21872 .33721 Mtetra
.387 .595 .928 r
.21872 .33721 .22637 .35095 .24776 .35771 .24018 .34491 Mtetra
.445 .648 .945 r
.24018 .34491 .24776 .35771 .2694 .36225 .26192 .35009 Mtetra
.483 .683 .954 r
.26192 .35009 .2694 .36225 .29124 .36529 .28388 .35357 Mtetra
.509 .707 .96 r
.28388 .35357 .29124 .36529 .31325 .36727 .30601 .35588 Mtetra
.527 .724 .963 r
.30601 .35588 .31325 .36727 .3354 .36848 .3283 .35732 Mtetra
.54 .736 .966 r
.3283 .35732 .3354 .36848 .35767 .3691 .35071 .35811 Mtetra
.55 .745 .967 r
.35071 .35811 .35767 .3691 .38006 .36926 .37326 .35841 Mtetra
.557 .753 .969 r
.37326 .35841 .38006 .36926 .40257 .36907 .39591 .35832 Mtetra
.563 .759 .97 r
.39591 .35832 .40257 .36907 .42518 .36858 .41868 .35791 Mtetra
.568 .763 .97 r
.41868 .35791 .42518 .36858 .44789 .36786 .44155 .35724 Mtetra
.572 .767 .971 r
.44155 .35724 .44789 .36786 .4707 .36694 .46452 .35636 Mtetra
.575 .77 .971 r
.46452 .35636 .4707 .36694 .49361 .36585 .48759 .3553 Mtetra
.578 .773 .972 r
.48759 .3553 .49361 .36585 .51662 .36462 .51076 .35409 Mtetra
.58 .776 .972 r
.51076 .35409 .51662 .36462 .53972 .36327 .53403 .35276 Mtetra
.582 .778 .972 r
.53403 .35276 .53972 .36327 .56292 .36182 .5574 .3513 Mtetra
.583 .779 .973 r
.5574 .3513 .56292 .36182 .58621 .36027 .58086 .34976 Mtetra
.585 .781 .973 r
.58086 .34976 .58621 .36027 .60959 .35863 .60441 .34812 Mtetra
.586 .782 .973 r
.60441 .34812 .60959 .35863 .63307 .35693 .62806 .34641 Mtetra
.587 .783 .973 r
.62806 .34641 .63307 .35693 .65664 .35516 .65181 .34463 Mtetra
.588 .784 .973 r
.65181 .34463 .65664 .35516 .6803 .35333 .67565 .34278 Mtetra
.589 .785 .974 r
.67565 .34278 .6803 .35333 .70406 .35145 .69958 .34089 Mtetra
.589 .786 .974 r
.69958 .34089 .70406 .35145 .72791 .34952 .72361 .33894 Mtetra
.59 .787 .974 r
.72361 .33894 .72791 .34952 .75185 .34755 .74774 .33694 Mtetra
.74774 .33694 .75185 .34755 .77589 .34553 .77196 .3349 Mtetra
.591 .788 .974 r
.77196 .3349 .77589 .34553 .80002 .34348 .79628 .33282 Mtetra
.591 .789 .974 r
.79628 .33282 .80002 .34348 .82425 .34139 .82069 .33071 Mtetra
.592 .789 .974 r
.82069 .33071 .82425 .34139 .84857 .33927 .8452 .32856 Mtetra
.8452 .32856 .84857 .33927 .87298 .33712 .8698 .32637 Mtetra
.592 .79 .974 r
.8698 .32637 .87298 .33712 .89749 .33493 .89451 .32416 Mtetra
.593 .79 .975 r
.89451 .32416 .89749 .33493 .9221 .33272 .91931 .32192 Mtetra
.593 .791 .975 r
.91931 .32192 .9221 .33272 .94681 .33049 .94421 .31965 Mtetra
0 0 .495 r
.14985 .2616 .15795 .27482 .17722 .30687 .16951 .28899 Mtetra
.037 .285 .779 r
.16951 .28899 .17722 .30687 .19765 .3255 .18987 .3101 Mtetra
.239 .471 .88 r
.18987 .3101 .19765 .3255 .21872 .33721 .21096 .32329 Mtetra
.356 .575 .923 r
.21096 .32329 .21872 .33721 .24018 .34491 .23249 .33194 Mtetra
.425 .636 .944 r
.23249 .33194 .24018 .34491 .26192 .35009 .25433 .33775 Mtetra
.469 .675 .954 r
.25433 .33775 .26192 .35009 .28388 .35357 .27641 .34168 Mtetra
.499 .701 .96 r
.27641 .34168 .28388 .35357 .30601 .35588 .29867 .34431 Mtetra
.52 .72 .964 r
.29867 .34431 .30601 .35588 .3283 .35732 .32109 .34599 Mtetra
.534 .733 .966 r
.32109 .34599 .3283 .35732 .35071 .35811 .34365 .34696 Mtetra
.546 .743 .968 r
.34365 .34696 .35071 .35811 .37326 .35841 .36634 .34739 Mtetra
.554 .751 .969 r
.36634 .34739 .37326 .35841 .39591 .35832 .38915 .3474 Mtetra
.561 .757 .97 r
.38915 .3474 .39591 .35832 .41868 .35791 .41208 .34706 Mtetra
.566 .762 .97 r
.41208 .34706 .41868 .35791 .44155 .35724 .43511 .34645 Mtetra
.57 .766 .971 r
.43511 .34645 .44155 .35724 .46452 .35636 .45824 .34562 Mtetra
.574 .77 .972 r
.45824 .34562 .46452 .35636 .48759 .3553 .48148 .34459 Mtetra
.576 .773 .972 r
.48148 .34459 .48759 .3553 .51076 .35409 .50482 .3434 Mtetra
.579 .775 .972 r
.50482 .3434 .51076 .35409 .53403 .35276 .52825 .34207 Mtetra
.581 .777 .973 r
.52825 .34207 .53403 .35276 .5574 .3513 .55179 .34063 Mtetra
.583 .779 .973 r
.55179 .34063 .5574 .3513 .58086 .34976 .57542 .33908 Mtetra
.584 .78 .973 r
.57542 .33908 .58086 .34976 .60441 .34812 .59915 .33744 Mtetra
.585 .782 .973 r
.59915 .33744 .60441 .34812 .62806 .34641 .62298 .33572 Mtetra
.586 .783 .973 r
.62298 .33572 .62806 .34641 .65181 .34463 .6469 .33392 Mtetra
.587 .784 .974 r
.6469 .33392 .65181 .34463 .67565 .34278 .67092 .33207 Mtetra
.588 .785 .974 r
.67092 .33207 .67565 .34278 .69958 .34089 .69504 .33015 Mtetra
.589 .786 .974 r
.69504 .33015 .69958 .34089 .72361 .33894 .71925 .32818 Mtetra
.71925 .32818 .72361 .33894 .74774 .33694 .74356 .32616 Mtetra
.59 .787 .974 r
.74356 .32616 .74774 .33694 .77196 .3349 .76797 .3241 Mtetra
.591 .788 .974 r
.76797 .3241 .77196 .3349 .79628 .33282 .79247 .32199 Mtetra
.79247 .32199 .79628 .33282 .82069 .33071 .81708 .31985 Mtetra
.591 .789 .974 r
.81708 .31985 .82069 .33071 .8452 .32856 .84178 .31767 Mtetra
.592 .789 .974 r
.84178 .31767 .8452 .32856 .8698 .32637 .86658 .31546 Mtetra
.592 .79 .974 r
.86658 .31546 .8698 .32637 .89451 .32416 .89147 .31321 Mtetra
.592 .79 .975 r
.89147 .31321 .89451 .32416 .91931 .32192 .91647 .31094 Mtetra
.593 .791 .975 r
.91647 .31094 .91931 .32192 .94421 .31965 .94156 .30864 Mtetra
0 .1 .622 r
.14142 .25112 .14985 .2616 .16951 .28899 .16171 .27088 Mtetra
0 .214 .736 r
.16171 .27088 .16951 .28899 .18987 .3101 .18199 .29449 Mtetra
.184 .432 .864 r
.18199 .29449 .18987 .3101 .21096 .32329 .20309 .30917 Mtetra
.323 .553 .918 r
.20309 .30917 .21096 .32329 .23249 .33194 .22469 .31877 Mtetra
.404 .623 .942 r
.22469 .31877 .23249 .33194 .25433 .33775 .24663 .32523 Mtetra
.455 .667 .954 r
.24663 .32523 .25433 .33775 .27641 .34168 .26882 .32962 Mtetra
.489 .696 .96 r
.26882 .32962 .27641 .34168 .29867 .34431 .29121 .33257 Mtetra
.512 .715 .964 r
.29121 .33257 .29867 .34431 .32109 .34599 .31377 .33449 Mtetra
.529 .73 .966 r
.31377 .33449 .32109 .34599 .34365 .34696 .33648 .33564 Mtetra
.541 .741 .968 r
.33648 .33564 .34365 .34696 .36634 .34739 .35932 .3362 Mtetra
.551 .749 .969 r
.35932 .3362 .36634 .34739 .38915 .3474 .38229 .33631 Mtetra
.558 .756 .97 r
.38229 .33631 .38915 .3474 .41208 .34706 .40537 .33605 Mtetra
.564 .761 .971 r
.40537 .33605 .41208 .34706 .43511 .34645 .42856 .3355 Mtetra
.568 .765 .971 r
.42856 .3355 .43511 .34645 .45824 .34562 .45186 .33471 Mtetra
.572 .769 .972 r
.45186 .33471 .45824 .34562 .48148 .34459 .47527 .33371 Mtetra
.575 .772 .972 r
.47527 .33371 .48148 .34459 .50482 .3434 .49878 .33254 Mtetra
.578 .774 .972 r
.49878 .33254 .50482 .3434 .52825 .34207 .52238 .33123 Mtetra
.58 .776 .973 r
.52238 .33123 .52825 .34207 .55179 .34063 .54609 .32978 Mtetra
.582 .778 .973 r
.54609 .32978 .55179 .34063 .57542 .33908 .5699 .32823 Mtetra
.583 .78 .973 r
.5699 .32823 .57542 .33908 .59915 .33744 .59381 .32659 Mtetra
.585 .781 .973 r
.59381 .32659 .59915 .33744 .62298 .33572 .61782 .32486 Mtetra
.586 .783 .973 r
.61782 .32486 .62298 .33572 .6469 .33392 .64192 .32305 Mtetra
.587 .784 .974 r
.64192 .32305 .6469 .33392 .67092 .33207 .66612 .32118 Mtetra
.588 .785 .974 r
.66612 .32118 .67092 .33207 .69504 .33015 .69042 .31924 Mtetra
.588 .786 .974 r
.69042 .31924 .69504 .33015 .71925 .32818 .71482 .31725 Mtetra
.589 .786 .974 r
.71482 .31725 .71925 .32818 .74356 .32616 .73932 .31521 Mtetra
.59 .787 .974 r
.73932 .31521 .74356 .32616 .76797 .3241 .76392 .31312 Mtetra
.59 .788 .974 r
.76392 .31312 .76797 .3241 .79247 .32199 .78861 .31099 Mtetra
.591 .788 .974 r
.78861 .31099 .79247 .32199 .81708 .31985 .8134 .30882 Mtetra
.591 .789 .974 r
.8134 .30882 .81708 .31985 .84178 .31767 .8383 .30661 Mtetra
.592 .789 .974 r
.8383 .30661 .84178 .31767 .86658 .31546 .86329 .30436 Mtetra
.592 .79 .975 r
.86329 .30436 .86658 .31546 .89147 .31321 .88839 .30209 Mtetra
.88839 .30209 .89147 .31321 .91647 .31094 .91358 .29978 Mtetra
.593 .79 .975 r
.91358 .29978 .91647 .31094 .94156 .30864 .93888 .29744 Mtetra
.033 .426 .866 r
.13287 .24047 .14142 .25112 .16171 .27088 .1538 .25254 Mtetra
0 .141 .686 r
.1538 .25254 .16171 .27088 .18199 .29449 .174 .27867 Mtetra
.127 .391 .845 r
.174 .27867 .18199 .29449 .20309 .30917 .19511 .29486 Mtetra
.289 .531 .91 r
.19511 .29486 .20309 .30917 .22469 .31877 .21678 .30542 Mtetra
.383 .61 .939 r
.21678 .30542 .22469 .31877 .24663 .32523 .23882 .31253 Mtetra
.441 .658 .953 r
.23882 .31253 .24663 .32523 .26882 .32962 .26112 .31737 Mtetra
.479 .69 .96 r
.26112 .31737 .26882 .32962 .29121 .33257 .28365 .32065 Mtetra
.505 .711 .964 r
.28365 .32065 .29121 .33257 .31377 .33449 .30635 .32281 Mtetra
.524 .727 .966 r
.30635 .32281 .31377 .33449 .33648 .33564 .3292 .32414 Mtetra
.537 .738 .968 r
.3292 .32414 .33648 .33564 .35932 .3362 .3522 .32484 Mtetra
.547 .747 .969 r
.3522 .32484 .35932 .3362 .38229 .33631 .37532 .32505 Mtetra
.555 .754 .97 r
.37532 .32505 .38229 .33631 .40537 .33605 .39856 .32487 Mtetra
.562 .76 .971 r
.39856 .32487 .40537 .33605 .42856 .3355 .42192 .32438 Mtetra
.567 .764 .971 r
.42192 .32438 .42856 .3355 .45186 .33471 .44539 .32363 Mtetra
.571 .768 .972 r
.44539 .32363 .45186 .33471 .47527 .33371 .46896 .32266 Mtetra
.574 .771 .972 r
.46896 .32266 .47527 .33371 .49878 .33254 .49264 .32151 Mtetra
.577 .774 .972 r
.49264 .32151 .49878 .33254 .52238 .33123 .51642 .3202 Mtetra
.579 .776 .973 r
.51642 .3202 .52238 .33123 .54609 .32978 .54031 .31877 Mtetra
.581 .778 .973 r
.54031 .31877 .54609 .32978 .5699 .32823 .56429 .31722 Mtetra
.583 .78 .973 r
.56429 .31722 .5699 .32823 .59381 .32659 .58838 .31556 Mtetra
.584 .781 .973 r
.58838 .31556 .59381 .32659 .61782 .32486 .61257 .31382 Mtetra
.585 .782 .973 r
.61257 .31382 .61782 .32486 .64192 .32305 .63686 .312 Mtetra
.586 .783 .974 r
.63686 .312 .64192 .32305 .66612 .32118 .66124 .31011 Mtetra
.587 .784 .974 r
.66124 .31011 .66612 .32118 .69042 .31924 .68573 .30816 Mtetra
.588 .785 .974 r
.68573 .30816 .69042 .31924 .71482 .31725 .71032 .30614 Mtetra
.589 .786 .974 r
.71032 .30614 .71482 .31725 .73932 .31521 .73501 .30408 Mtetra
.589 .787 .974 r
.73501 .30408 .73932 .31521 .76392 .31312 .75979 .30196 Mtetra
.59 .787 .974 r
.75979 .30196 .76392 .31312 .78861 .31099 .78468 .2998 Mtetra
.591 .788 .974 r
.78468 .2998 .78861 .31099 .8134 .30882 .80967 .2976 Mtetra
.591 .789 .974 r
.80967 .2976 .8134 .30882 .8383 .30661 .83476 .29536 Mtetra
.83476 .29536 .8383 .30661 .86329 .30436 .85996 .29309 Mtetra
.592 .79 .975 r
.85996 .29309 .86329 .30436 .88839 .30209 .88525 .29078 Mtetra
.88525 .29078 .88839 .30209 .91358 .29978 .91065 .28844 Mtetra
.91065 .28844 .91358 .29978 .93888 .29744 .93615 .28607 Mtetra
.4 .673 .971 r
.12419 .22967 .13287 .24047 .1538 .25254 .1458 .23397 Mtetra
0 .068 .632 r
.1458 .23397 .1538 .25254 .174 .27867 .1659 .26264 Mtetra
.069 .348 .822 r
.1659 .26264 .174 .27867 .19511 .29486 .18702 .28034 Mtetra
.253 .507 .902 r
.18702 .28034 .19511 .29486 .21678 .30542 .20875 .29187 Mtetra
.361 .596 .936 r
.20875 .29187 .21678 .30542 .23882 .31253 .23089 .29964 Mtetra
.427 .649 .952 r
.23089 .29964 .23882 .31253 .26112 .31737 .25331 .30494 Mtetra
.469 .684 .959 r
.25331 .30494 .26112 .31737 .28365 .32065 .27597 .30855 Mtetra
.498 .707 .964 r
.27597 .30855 .28365 .32065 .30635 .32281 .29881 .31095 Mtetra
.518 .724 .967 r
.29881 .31095 .30635 .32281 .3292 .32414 .32181 .31247 Mtetra
.533 .736 .968 r
.32181 .31247 .3292 .32414 .3522 .32484 .34496 .3133 Mtetra
.544 .745 .969 r
.34496 .3133 .3522 .32484 .37532 .32505 .36824 .31362 Mtetra
.553 .753 .97 r
.36824 .31362 .37532 .32505 .39856 .32487 .39165 .31352 Mtetra
.559 .759 .971 r
.39165 .31352 .39856 .32487 .42192 .32438 .41517 .31308 Mtetra
.565 .763 .971 r
.41517 .31308 .42192 .32438 .44539 .32363 .43881 .31237 Mtetra
.569 .767 .972 r
.43881 .31237 .44539 .32363 .46896 .32266 .46255 .31143 Mtetra
.573 .77 .972 r
.46255 .31143 .46896 .32266 .49264 .32151 .4864 .3103 Mtetra
.576 .773 .973 r
.4864 .3103 .49264 .32151 .51642 .3202 .51036 .30901 Mtetra
.578 .775 .973 r
.51036 .30901 .51642 .3202 .54031 .31877 .53443 .30757 Mtetra
.58 .777 .973 r
.53443 .30757 .54031 .31877 .56429 .31722 .55859 .30602 Mtetra
.582 .779 .973 r
.55859 .30602 .56429 .31722 .58838 .31556 .58286 .30436 Mtetra
.583 .781 .973 r
.58286 .30436 .58838 .31556 .61257 .31382 .60724 .30261 Mtetra
.585 .782 .974 r
.60724 .30261 .61257 .31382 .63686 .312 .63171 .30077 Mtetra
.586 .783 .974 r
.63171 .30077 .63686 .312 .66124 .31011 .65629 .29887 Mtetra
.587 .784 .974 r
.65629 .29887 .66124 .31011 .68573 .30816 .68096 .29689 Mtetra
.588 .785 .974 r
.68096 .29689 .68573 .30816 .71032 .30614 .70574 .29485 Mtetra
.588 .786 .974 r
.70574 .29485 .71032 .30614 .73501 .30408 .73062 .29276 Mtetra
.589 .787 .974 r
.73062 .29276 .73501 .30408 .75979 .30196 .75561 .29062 Mtetra
.59 .787 .974 r
.75561 .29062 .75979 .30196 .78468 .2998 .78069 .28843 Mtetra
.59 .788 .974 r
.78069 .28843 .78468 .2998 .80967 .2976 .80588 .2862 Mtetra
.591 .788 .974 r
.80588 .2862 .80967 .2976 .83476 .29536 .83117 .28393 Mtetra
.591 .789 .974 r
.83117 .28393 .83476 .29536 .85996 .29309 .85657 .28162 Mtetra
.592 .789 .975 r
.85657 .28162 .85996 .29309 .88525 .29078 .88206 .27928 Mtetra
.592 .79 .975 r
.88206 .27928 .88525 .29078 .91065 .28844 .90767 .2769 Mtetra
.90767 .2769 .91065 .28844 .93615 .28607 .93337 .2745 Mtetra
.617 .786 .963 r
.11538 .21869 .12419 .22967 .1458 .23397 .13763 .21604 Mtetra
0 0 .572 r
.13763 .21604 .1458 .23397 .1659 .26264 .15769 .24638 Mtetra
.01 .303 .796 r
.15769 .24638 .1659 .26264 .18702 .28034 .17882 .26561 Mtetra
.217 .482 .892 r
.17882 .26561 .18702 .28034 .20875 .29187 .20061 .27813 Mtetra
.338 .581 .932 r
.20061 .27813 .20875 .29187 .23089 .29964 .22284 .28655 Mtetra
.412 .64 .95 r
.22284 .28655 .23089 .29964 .25331 .30494 .24538 .29232 Mtetra
.459 .678 .959 r
.24538 .29232 .25331 .30494 .27597 .30855 .26817 .29626 Mtetra
.49 .703 .964 r
.26817 .29626 .27597 .30855 .29881 .31095 .29115 .29891 Mtetra
.512 .721 .967 r
.29115 .29891 .29881 .31095 .32181 .31247 .3143 .30061 Mtetra
.529 .734 .968 r
.3143 .30061 .32181 .31247 .34496 .3133 .33761 .30159 Mtetra
.541 .744 .97 r
.33761 .30159 .34496 .3133 .36824 .31362 .36105 .302 Mtetra
.55 .751 .97 r
.36105 .302 .36824 .31362 .39165 .31352 .38462 .30198 Mtetra
.557 .757 .971 r
.38462 .30198 .39165 .31352 .41517 .31308 .40831 .3016 Mtetra
.563 .762 .972 r
.40831 .3016 .41517 .31308 .43881 .31237 .43212 .30093 Mtetra
.568 .766 .972 r
.43212 .30093 .43881 .31237 .46255 .31143 .45604 .30002 Mtetra
.571 .77 .972 r
.45604 .30002 .46255 .31143 .4864 .3103 .48007 .29891 Mtetra
.575 .772 .973 r
.48007 .29891 .4864 .3103 .51036 .30901 .50421 .29763 Mtetra
.577 .775 .973 r
.50421 .29763 .51036 .30901 .53443 .30757 .52845 .2962 Mtetra
.579 .777 .973 r
.52845 .2962 .53443 .30757 .55859 .30602 .5528 .29464 Mtetra
.581 .779 .973 r
.5528 .29464 .55859 .30602 .58286 .30436 .57726 .29298 Mtetra
.583 .78 .973 r
.57726 .29298 .58286 .30436 .60724 .30261 .60182 .29121 Mtetra
.584 .782 .974 r
.60182 .29121 .60724 .30261 .63171 .30077 .62648 .28936 Mtetra
.585 .783 .974 r
.62648 .28936 .63171 .30077 .65629 .29887 .65125 .28744 Mtetra
.586 .784 .974 r
.65125 .28744 .65629 .29887 .68096 .29689 .67612 .28544 Mtetra
.587 .785 .974 r
.67612 .28544 .68096 .29689 .70574 .29485 .70109 .28338 Mtetra
.588 .786 .974 r
.70109 .28338 .70574 .29485 .73062 .29276 .72617 .28126 Mtetra
.589 .786 .974 r
.72617 .28126 .73062 .29276 .75561 .29062 .75135 .27909 Mtetra
.589 .787 .974 r
.75135 .27909 .75561 .29062 .78069 .28843 .77663 .27688 Mtetra
.59 .788 .974 r
.77663 .27688 .78069 .28843 .80588 .2862 .80202 .27461 Mtetra
.591 .788 .974 r
.80202 .27461 .80588 .2862 .83117 .28393 .82752 .27231 Mtetra
.591 .789 .974 r
.82752 .27231 .83117 .28393 .85657 .28162 .85312 .26997 Mtetra
.591 .789 .975 r
.85312 .26997 .85657 .28162 .88206 .27928 .87882 .26759 Mtetra
.592 .79 .975 r
.87882 .26759 .88206 .27928 .90767 .2769 .90463 .26518 Mtetra
.90463 .26518 .90767 .2769 .93337 .2745 .93055 .26273 Mtetra
.617 .786 .963 r
.10642 .20755 .11538 .21869 .13763 .21604 .12883 .20485 Mtetra
0 0 .468 r
.12883 .20485 .13763 .21604 .15769 .24638 .14937 .2299 Mtetra
0 .257 .767 r
.14937 .2299 .15769 .24638 .17882 .26561 .17049 .25067 Mtetra
.18 .455 .881 r
.17049 .25067 .17882 .26561 .20061 .27813 .19234 .26418 Mtetra
.315 .566 .928 r
.19234 .26418 .20061 .27813 .22284 .28655 .21467 .27327 Mtetra
.396 .631 .948 r
.21467 .27327 .22284 .28655 .24538 .29232 .23733 .2795 Mtetra
.448 .671 .958 r
.23733 .2795 .24538 .29232 .26817 .29626 .26025 .28379 Mtetra
.483 .698 .964 r
.26025 .28379 .26817 .29626 .29115 .29891 .28337 .28669 Mtetra
.507 .717 .967 r
.28337 .28669 .29115 .29891 .3143 .30061 .30668 .28857 Mtetra
.524 .731 .969 r
.30668 .28857 .3143 .30061 .33761 .30159 .33014 .28968 Mtetra
.537 .742 .97 r
.33014 .28968 .33761 .30159 .36105 .302 .35375 .2902 Mtetra
.547 .75 .971 r
.35375 .2902 .36105 .302 .38462 .30198 .37748 .29026 Mtetra
.555 .756 .971 r
.37748 .29026 .38462 .30198 .40831 .3016 .40134 .28994 Mtetra
.561 .761 .972 r
.40134 .28994 .40831 .3016 .43212 .30093 .42533 .28931 Mtetra
.566 .765 .972 r
.42533 .28931 .43212 .30093 .45604 .30002 .44942 .28843 Mtetra
.57 .769 .972 r
.44942 .28843 .45604 .30002 .48007 .29891 .47363 .28734 Mtetra
.573 .772 .973 r
.47363 .28734 .48007 .29891 .50421 .29763 .49795 .28606 Mtetra
.576 .774 .973 r
.49795 .28606 .50421 .29763 .52845 .2962 .52238 .28464 Mtetra
.579 .776 .973 r
.52238 .28464 .52845 .2962 .5528 .29464 .54692 .28308 Mtetra
.581 .778 .973 r
.54692 .28308 .5528 .29464 .57726 .29298 .57156 .28141 Mtetra
.582 .78 .973 r
.57156 .28141 .57726 .29298 .60182 .29121 .59631 .27963 Mtetra
.584 .781 .974 r
.59631 .27963 .60182 .29121 .62648 .28936 .62116 .27776 Mtetra
.585 .783 .974 r
.62116 .27776 .62648 .28936 .65125 .28744 .64612 .27582 Mtetra
.586 .784 .974 r
.64612 .27582 .65125 .28744 .67612 .28544 .67119 .2738 Mtetra
.587 .785 .974 r
.67119 .2738 .67612 .28544 .70109 .28338 .69636 .27171 Mtetra
.588 .785 .974 r
.69636 .27171 .70109 .28338 .72617 .28126 .72164 .26957 Mtetra
.589 .786 .974 r
.72164 .26957 .72617 .28126 .75135 .27909 .74702 .26737 Mtetra
.589 .787 .974 r
.74702 .26737 .75135 .27909 .77663 .27688 .77251 .26512 Mtetra
.59 .788 .974 r
.77251 .26512 .77663 .27688 .80202 .27461 .7981 .26283 Mtetra
.7981 .26283 .80202 .27461 .82752 .27231 .8238 .26049 Mtetra
.591 .789 .974 r
.8238 .26049 .82752 .27231 .85312 .26997 .84961 .25812 Mtetra
.591 .789 .975 r
.84961 .25812 .85312 .26997 .87882 .26759 .87553 .2557 Mtetra
.592 .79 .975 r
.87553 .2557 .87882 .26759 .90463 .26518 .90155 .25325 Mtetra
.90155 .25325 .90463 .26518 .93055 .26273 .92768 .25077 Mtetra
.617 .786 .963 r
.09733 .19623 .10642 .20755 .12883 .20485 .1199 .19349 Mtetra
0 .132 .652 r
.1199 .19349 .12883 .20485 .14937 .2299 .14093 .2132 Mtetra
0 .21 .736 r
.14093 .2132 .14937 .2299 .17049 .25067 .16205 .23551 Mtetra
.141 .428 .868 r
.16205 .23551 .17049 .25067 .19234 .26418 .18396 .25002 Mtetra
.291 .55 .923 r
.18396 .25002 .19234 .26418 .21467 .27327 .20637 .25979 Mtetra
.381 .621 .946 r
.20637 .25979 .21467 .27327 .23733 .2795 .22915 .26649 Mtetra
.437 .665 .958 r
.22915 .26649 .23733 .2795 .26025 .28379 .2522 .27112 Mtetra
.475 .694 .964 r
.2522 .27112 .26025 .28379 .28337 .28669 .27547 .27427 Mtetra
.501 .714 .967 r
.27547 .27427 .28337 .28669 .30668 .28857 .29893 .27633 Mtetra
.52 .729 .969 r
.29893 .27633 .30668 .28857 .33014 .28968 .32255 .27759 Mtetra
.534 .74 .97 r
.32255 .27759 .33014 .28968 .35375 .2902 .34632 .27821 Mtetra
.545 .748 .971 r
.34632 .27821 .35375 .2902 .37748 .29026 .37023 .27835 Mtetra
.553 .755 .971 r
.37023 .27835 .37748 .29026 .40134 .28994 .39427 .27808 Mtetra
.559 .76 .972 r
.39427 .27808 .40134 .28994 .42533 .28931 .41842 .2775 Mtetra
.565 .765 .972 r
.41842 .2775 .42533 .28931 .44942 .28843 .4427 .27665 Mtetra
.569 .768 .973 r
.4427 .27665 .44942 .28843 .47363 .28734 .46709 .27557 Mtetra
.572 .771 .973 r
.46709 .27557 .47363 .28734 .49795 .28606 .49159 .27431 Mtetra
.575 .774 .973 r
.49159 .27431 .49795 .28606 .52238 .28464 .51621 .27289 Mtetra
.578 .776 .973 r
.51621 .27289 .52238 .28464 .54692 .28308 .54093 .27133 Mtetra
.58 .778 .973 r
.54093 .27133 .54692 .28308 .57156 .28141 .56577 .26964 Mtetra
.582 .78 .973 r
.56577 .26964 .57156 .28141 .59631 .27963 .59071 .26785 Mtetra
.583 .781 .974 r
.59071 .26785 .59631 .27963 .62116 .27776 .61576 .26597 Mtetra
.584 .782 .974 r
.61576 .26597 .62116 .27776 .64612 .27582 .64091 .264 Mtetra
.586 .783 .974 r
.64091 .264 .64612 .27582 .67119 .2738 .66618 .26196 Mtetra
.587 .784 .974 r
.66618 .26196 .67119 .2738 .69636 .27171 .69155 .25985 Mtetra
.587 .785 .974 r
.69155 .25985 .69636 .27171 .72164 .26957 .71703 .25768 Mtetra
.588 .786 .974 r
.71703 .25768 .72164 .26957 .74702 .26737 .74262 .25545 Mtetra
.589 .787 .974 r
.74262 .25545 .74702 .26737 .77251 .26512 .76831 .25317 Mtetra
.59 .787 .974 r
.76831 .25317 .77251 .26512 .7981 .26283 .79411 .25085 Mtetra
.59 .788 .974 r
.79411 .25085 .7981 .26283 .8238 .26049 .82002 .24847 Mtetra
.591 .789 .974 r
.82002 .24847 .8238 .26049 .84961 .25812 .84604 .24606 Mtetra
.591 .789 .975 r
.84604 .24606 .84961 .25812 .87553 .2557 .87217 .24361 Mtetra
.87217 .24361 .87553 .2557 .90155 .25325 .89841 .24112 Mtetra
.592 .79 .975 r
.89841 .24112 .90155 .25325 .92768 .25077 .92476 .2386 Mtetra
.617 .786 .963 r
.0881 .18473 .09733 .19623 .1199 .19349 .11082 .18195 Mtetra
0 .353 .82 r
.11082 .18195 .1199 .19349 .14093 .2132 .13237 .19626 Mtetra
0 .162 .702 r
.13237 .19626 .14093 .2132 .16205 .23551 .15348 .22014 Mtetra
.102 .399 .853 r
.15348 .22014 .16205 .23551 .18396 .25002 .17544 .23565 Mtetra
.266 .533 .917 r
.17544 .23565 .18396 .25002 .20637 .25979 .19795 .2461 Mtetra
.365 .611 .944 r
.19795 .2461 .20637 .25979 .22915 .26649 .22085 .25328 Mtetra
.426 .658 .957 r
.22085 .25328 .22915 .26649 .2522 .27112 .24403 .25825 Mtetra
.467 .689 .963 r
.24403 .25825 .2522 .27112 .27547 .27427 .26745 .26165 Mtetra
.495 .711 .967 r
.26745 .26165 .27547 .27427 .29893 .27633 .29106 .26391 Mtetra
.516 .726 .969 r
.29106 .26391 .29893 .27633 .32255 .27759 .31485 .2653 Mtetra
.53 .738 .97 r
.31485 .2653 .32255 .27759 .34632 .27821 .33878 .26603 Mtetra
.542 .747 .971 r
.33878 .26603 .34632 .27821 .37023 .27835 .36286 .26624 Mtetra
.551 .754 .972 r
.36286 .26624 .37023 .27835 .39427 .27808 .38707 .26604 Mtetra
.558 .759 .972 r
.38707 .26604 .39427 .27808 .41842 .2775 .41141 .2655 Mtetra
.563 .764 .972 r
.41141 .2655 .41842 .2775 .4427 .27665 .43586 .26467 Mtetra
.568 .768 .973 r
.43586 .26467 .4427 .27665 .46709 .27557 .46044 .26362 Mtetra
.571 .771 .973 r
.46044 .26362 .46709 .27557 .49159 .27431 .48513 .26236 Mtetra
.574 .773 .973 r
.48513 .26236 .49159 .27431 .51621 .27289 .50993 .26094 Mtetra
.577 .776 .973 r
.50993 .26094 .51621 .27289 .54093 .27133 .53485 .25938 Mtetra
.579 .778 .973 r
.53485 .25938 .54093 .27133 .56577 .26964 .55988 .25768 Mtetra
.581 .779 .974 r
.55988 .25768 .56577 .26964 .59071 .26785 .58501 .25588 Mtetra
.583 .781 .974 r
.58501 .25588 .59071 .26785 .61576 .26597 .61026 .25398 Mtetra
.584 .782 .974 r
.61026 .25398 .61576 .26597 .64091 .264 .63562 .25199 Mtetra
.585 .783 .974 r
.63562 .25199 .64091 .264 .66618 .26196 .66108 .24993 Mtetra
.586 .784 .974 r
.66108 .24993 .66618 .26196 .69155 .25985 .68666 .24779 Mtetra
.587 .785 .974 r
.68666 .24779 .69155 .25985 .71703 .25768 .71234 .24559 Mtetra
.588 .786 .974 r
.71234 .24559 .71703 .25768 .74262 .25545 .73814 .24333 Mtetra
.589 .787 .974 r
.73814 .24333 .74262 .25545 .76831 .25317 .76404 .24102 Mtetra
.76404 .24102 .76831 .25317 .79411 .25085 .79006 .23866 Mtetra
.59 .788 .974 r
.79006 .23866 .79411 .25085 .82002 .24847 .81618 .23625 Mtetra
.81618 .23625 .82002 .24847 .84604 .24606 .84242 .2338 Mtetra
.591 .789 .975 r
.84242 .2338 .84604 .24606 .87217 .24361 .86876 .23131 Mtetra
.86876 .23131 .87217 .24361 .89841 .24112 .89522 .22878 Mtetra
.592 .79 .975 r
.89522 .22878 .89841 .24112 .92476 .2386 .92179 .22622 Mtetra
.617 .786 .963 r
.07871 .17305 .0881 .18473 .11082 .18195 .1016 .17022 Mtetra
.211 .552 .932 r
.1016 .17022 .11082 .18195 .13237 .19626 .1237 .17908 Mtetra
0 .115 .666 r
.1237 .17908 .13237 .19626 .15348 .22014 .14479 .20453 Mtetra
.063 .37 .837 r
.14479 .20453 .15348 .22014 .17544 .23565 .1668 .22106 Mtetra
.241 .516 .91 r
.1668 .22106 .17544 .23565 .19795 .2461 .1894 .2322 Mtetra
.348 .6 .941 r
.1894 .2322 .19795 .2461 .22085 .25328 .21241 .23986 Mtetra
.415 .651 .956 r
.21241 .23986 .22085 .25328 .24403 .25825 .23573 .24518 Mtetra
.459 .685 .963 r
.23573 .24518 .24403 .25825 .26745 .26165 .2593 .24883 Mtetra
.49 .707 .967 r
.2593 .24883 .26745 .26165 .29106 .26391 .28307 .25128 Mtetra
.511 .724 .969 r
.28307 .25128 .29106 .26391 .31485 .2653 .30701 .25281 Mtetra
.527 .736 .97 r
.30701 .25281 .31485 .2653 .33878 .26603 .33112 .25365 Mtetra
.539 .745 .971 r
.33112 .25365 .33878 .26603 .36286 .26624 .35537 .25394 Mtetra
.548 .752 .972 r
.35537 .25394 .36286 .26624 .38707 .26604 .37976 .2538 Mtetra
.556 .758 .972 r
.37976 .2538 .38707 .26604 .41141 .2655 .40427 .25329 Mtetra
.562 .763 .972 r
.40427 .25329 .41141 .2655 .43586 .26467 .42892 .2525 Mtetra
.566 .767 .973 r
.42892 .2525 .43586 .26467 .46044 .26362 .45368 .25146 Mtetra
.57 .77 .973 r
.45368 .25146 .46044 .26362 .48513 .26236 .47856 .25022 Mtetra
.573 .773 .973 r
.47856 .25022 .48513 .26236 .50993 .26094 .50355 .2488 Mtetra
.576 .775 .973 r
.50355 .2488 .50993 .26094 .53485 .25938 .52866 .24723 Mtetra
.578 .777 .973 r
.52866 .24723 .53485 .25938 .55988 .25768 .55389 .24552 Mtetra
.58 .779 .974 r
.55389 .24552 .55988 .25768 .58501 .25588 .57922 .24371 Mtetra
.582 .78 .974 r
.57922 .24371 .58501 .25588 .61026 .25398 .60467 .24179 Mtetra
.584 .782 .974 r
.60467 .24179 .61026 .25398 .63562 .25199 .63023 .23978 Mtetra
.585 .783 .974 r
.63023 .23978 .63562 .25199 .66108 .24993 .6559 .23769 Mtetra
.586 .784 .974 r
.6559 .23769 .66108 .24993 .68666 .24779 .68169 .23552 Mtetra
.587 .785 .974 r
.68169 .23552 .68666 .24779 .71234 .24559 .70758 .23329 Mtetra
.588 .786 .974 r
.70758 .23329 .71234 .24559 .73814 .24333 .73358 .231 Mtetra
.73358 .231 .73814 .24333 .76404 .24102 .7597 .22866 Mtetra
.589 .787 .974 r
.7597 .22866 .76404 .24102 .79006 .23866 .78593 .22626 Mtetra
.59 .788 .974 r
.78593 .22626 .79006 .23866 .81618 .23625 .81227 .22382 Mtetra
.59 .788 .975 r
.81227 .22382 .81618 .23625 .84242 .2338 .83873 .22133 Mtetra
.591 .789 .975 r
.83873 .22133 .84242 .2338 .86876 .23131 .8653 .2188 Mtetra
.8653 .2188 .86876 .23131 .89522 .22878 .89198 .21623 Mtetra
.591 .79 .975 r
.89198 .21623 .89522 .22878 .92179 .22622 .91877 .21363 Mtetra
.617 .786 .963 r
.06918 .16119 .07871 .17305 .1016 .17022 .09223 .15831 Mtetra
.437 .693 .973 r
.09223 .15831 .1016 .17022 .1237 .17908 .1149 .16165 Mtetra
0 .068 .629 r
.1149 .16165 .1237 .17908 .14479 .20453 .13596 .1887 Mtetra
.023 .34 .82 r
.13596 .1887 .14479 .20453 .1668 .22106 .15802 .20625 Mtetra
.216 .498 .903 r
.15802 .20625 .1668 .22106 .1894 .2322 .18072 .21808 Mtetra
.332 .589 .939 r
.18072 .21808 .1894 .2322 .21241 .23986 .20384 .22623 Mtetra
.404 .644 .955 r
.20384 .22623 .21241 .23986 .23573 .24518 .2273 .23189 Mtetra
.451 .68 .962 r
.2273 .23189 .23573 .24518 .2593 .24883 .25101 .23581 Mtetra
.484 .704 .967 r
.25101 .23581 .2593 .24883 .28307 .25128 .27494 .23844 Mtetra
.507 .721 .969 r
.27494 .23844 .28307 .25128 .30701 .25281 .29905 .24012 Mtetra
.524 .734 .97 r
.29905 .24012 .30701 .25281 .33112 .25365 .32333 .24107 Mtetra
.536 .744 .971 r
.32333 .24107 .33112 .25365 .35537 .25394 .34776 .24144 Mtetra
.546 .751 .972 r
.34776 .24144 .35537 .25394 .37976 .2538 .37232 .24135 Mtetra
.554 .757 .972 r
.37232 .24135 .37976 .2538 .40427 .25329 .39702 .24089 Mtetra
.56 .762 .973 r
.39702 .24089 .40427 .25329 .42892 .2525 .42185 .24012 Mtetra
.565 .766 .973 r
.42185 .24012 .42892 .2525 .45368 .25146 .4468 .2391 Mtetra
.569 .769 .973 r
.4468 .2391 .45368 .25146 .47856 .25022 .47188 .23787 Mtetra
.573 .772 .973 r
.47188 .23787 .47856 .25022 .50355 .2488 .49707 .23645 Mtetra
.575 .775 .973 r
.49707 .23645 .50355 .2488 .52866 .24723 .52237 .23487 Mtetra
.578 .777 .974 r
.52237 .23487 .52866 .24723 .55389 .24552 .5478 .23316 Mtetra
.58 .778 .974 r
.5478 .23316 .55389 .24552 .57922 .24371 .57334 .23132 Mtetra
.582 .78 .974 r
.57334 .23132 .57922 .24371 .60467 .24179 .59899 .22939 Mtetra
.583 .781 .974 r
.59899 .22939 .60467 .24179 .63023 .23978 .62475 .22735 Mtetra
.584 .783 .974 r
.62475 .22735 .63023 .23978 .6559 .23769 .65063 .22524 Mtetra
.585 .784 .974 r
.65063 .22524 .6559 .23769 .68169 .23552 .67663 .22304 Mtetra
.586 .785 .974 r
.67663 .22304 .68169 .23552 .70758 .23329 .70273 .22078 Mtetra
.587 .785 .974 r
.70273 .22078 .70758 .23329 .73358 .231 .72895 .21846 Mtetra
.588 .786 .974 r
.72895 .21846 .73358 .231 .7597 .22866 .75529 .21608 Mtetra
.589 .787 .974 r
.75529 .21608 .7597 .22866 .78593 .22626 .78173 .21365 Mtetra
.589 .788 .974 r
.78173 .21365 .78593 .22626 .81227 .22382 .8083 .21117 Mtetra
.59 .788 .975 r
.8083 .21117 .81227 .22382 .83873 .22133 .83497 .20864 Mtetra
.59 .789 .975 r
.83497 .20864 .83873 .22133 .8653 .2188 .86177 .20607 Mtetra
.591 .789 .975 r
.86177 .20607 .8653 .2188 .89198 .21623 .88867 .20346 Mtetra
.591 .79 .975 r
.88867 .20346 .89198 .21623 .91877 .21363 .9157 .20081 Mtetra
.617 .786 .963 r
.05949 .14913 .06918 .16119 .09223 .15831 .08271 .1462 Mtetra
.6 .778 .966 r
.08271 .1462 .09223 .15831 .1149 .16165 .10597 .14398 Mtetra
0 .023 .591 r
.10597 .14398 .1149 .16165 .13596 .1887 .12701 .17263 Mtetra
0 .309 .801 r
.12701 .17263 .13596 .1887 .15802 .20625 .14911 .19121 Mtetra
.19 .48 .895 r
.14911 .19121 .15802 .20625 .18072 .21808 .17189 .20374 Mtetra
.315 .578 .935 r
.17189 .20374 .18072 .21808 .20384 .22623 .19514 .21238 Mtetra
.393 .637 .953 r
.19514 .21238 .20384 .22623 .2273 .23189 .21873 .2184 Mtetra
.443 .675 .962 r
.21873 .2184 .2273 .23189 .25101 .23581 .2426 .22257 Mtetra
.478 .7 .966 r
.2426 .22257 .25101 .23581 .27494 .23844 .26668 .2254 Mtetra
.502 .718 .969 r
.26668 .2254 .27494 .23844 .29905 .24012 .29096 .22722 Mtetra
.52 .732 .97 r
.29096 .22722 .29905 .24012 .32333 .24107 .31541 .22828 Mtetra
.534 .742 .971 r
.31541 .22828 .32333 .24107 .34776 .24144 .34001 .22873 Mtetra
.544 .75 .972 r
.34001 .22873 .34776 .24144 .37232 .24135 .36476 .2287 Mtetra
.552 .756 .972 r
.36476 .2287 .37232 .24135 .39702 .24089 .38965 .22828 Mtetra
.559 .761 .973 r
.38965 .22828 .39702 .24089 .42185 .24012 .41467 .22754 Mtetra
.564 .765 .973 r
.41467 .22754 .42185 .24012 .4468 .2391 .43981 .22653 Mtetra
.568 .769 .973 r
.43981 .22653 .4468 .2391 .47188 .23787 .46508 .22531 Mtetra
.572 .772 .973 r
.46508 .22531 .47188 .23787 .49707 .23645 .49047 .22389 Mtetra
.575 .774 .973 r
.49047 .22389 .49707 .23645 .52237 .23487 .51598 .2223 Mtetra
.577 .776 .974 r
.51598 .2223 .52237 .23487 .5478 .23316 .5416 .22058 Mtetra
.579 .778 .974 r
.5416 .22058 .5478 .23316 .57334 .23132 .56735 .21873 Mtetra
.581 .78 .974 r
.56735 .21873 .57334 .23132 .59899 .22939 .59321 .21677 Mtetra
.583 .781 .974 r
.59321 .21677 .59899 .22939 .62475 .22735 .61918 .21471 Mtetra
.584 .782 .974 r
.61918 .21471 .62475 .22735 .65063 .22524 .64527 .21257 Mtetra
.585 .783 .974 r
.64527 .21257 .65063 .22524 .67663 .22304 .67148 .21035 Mtetra
.586 .784 .974 r
.67148 .21035 .67663 .22304 .70273 .22078 .6978 .20806 Mtetra
.587 .785 .974 r
.6978 .20806 .70273 .22078 .72895 .21846 .72424 .2057 Mtetra
.588 .786 .974 r
.72424 .2057 .72895 .21846 .75529 .21608 .75079 .20329 Mtetra
.589 .787 .974 r
.75079 .20329 .75529 .21608 .78173 .21365 .77746 .20081 Mtetra
.77746 .20081 .78173 .21365 .8083 .21117 .80425 .19829 Mtetra
.59 .788 .975 r
.80425 .19829 .8083 .21117 .83497 .20864 .83115 .19573 Mtetra
.59 .789 .975 r
.83115 .19573 .83497 .20864 .86177 .20607 .85817 .19311 Mtetra
.591 .789 .975 r
.85817 .19311 .86177 .20607 .88867 .20346 .88531 .19046 Mtetra
.88531 .19046 .88867 .20346 .9157 .20081 .91257 .18777 Mtetra
.617 .786 .963 r
.04964 .13687 .05949 .14913 .08271 .1462 .07304 .1339 Mtetra
.07304 .1339 .08271 .1462 .10597 .14398 .09653 .13092 Mtetra
0 0 .526 r
.09653 .13092 .10597 .14398 .12701 .17263 .11792 .15632 Mtetra
0 .277 .781 r
.11792 .15632 .12701 .17263 .14911 .19121 .14007 .17594 Mtetra
.163 .461 .887 r
.14007 .17594 .14911 .19121 .17189 .20374 .16293 .18918 Mtetra
.298 .567 .932 r
.16293 .18918 .17189 .20374 .19514 .21238 .1863 .19831 Mtetra
.381 .63 .952 r
.1863 .19831 .19514 .21238 .21873 .2184 .21003 .20469 Mtetra
.435 .67 .961 r
.21003 .20469 .21873 .2184 .2426 .22257 .23404 .20912 Mtetra
.472 .697 .966 r
.23404 .20912 .2426 .22257 .26668 .2254 .25829 .21214 Mtetra
.498 .716 .969 r
.25829 .21214 .26668 .2254 .29096 .22722 .28273 .21411 Mtetra
.517 .73 .97 r
.28273 .21411 .29096 .22722 .31541 .22828 .30736 .21527 Mtetra
.531 .74 .971 r
.30736 .21527 .31541 .22828 .34001 .22873 .33214 .2158 Mtetra
.542 .749 .972 r
.33214 .2158 .34001 .22873 .36476 .2287 .35708 .21583 Mtetra
.55 .755 .972 r
.35708 .21583 .36476 .2287 .38965 .22828 .38215 .21545 Mtetra
.557 .76 .973 r
.38215 .21545 .38965 .22828 .41467 .22754 .40736 .21474 Mtetra
.562 .765 .973 r
.40736 .21474 .41467 .22754 .43981 .22653 .4327 .21375 Mtetra
.567 .768 .973 r
.4327 .21375 .43981 .22653 .46508 .22531 .45817 .21253 Mtetra
.571 .771 .973 r
.45817 .21253 .46508 .22531 .49047 .22389 .48376 .21111 Mtetra
.574 .774 .973 r
.48376 .21111 .49047 .22389 .51598 .2223 .50947 .20952 Mtetra
.576 .776 .974 r
.50947 .20952 .51598 .2223 .5416 .22058 .5353 .20778 Mtetra
.579 .778 .974 r
.5353 .20778 .5416 .22058 .56735 .21873 .56125 .20592 Mtetra
.58 .779 .974 r
.56125 .20592 .56735 .21873 .59321 .21677 .58732 .20394 Mtetra
.582 .781 .974 r
.58732 .20394 .59321 .21677 .61918 .21471 .61351 .20186 Mtetra
.584 .782 .974 r
.61351 .20186 .61918 .21471 .64527 .21257 .63982 .19969 Mtetra
.585 .783 .974 r
.63982 .19969 .64527 .21257 .67148 .21035 .66624 .19743 Mtetra
.586 .784 .974 r
.66624 .19743 .67148 .21035 .6978 .20806 .69278 .19511 Mtetra
.587 .785 .974 r
.69278 .19511 .6978 .20806 .72424 .2057 .71944 .19272 Mtetra
.588 .786 .974 r
.71944 .19272 .72424 .2057 .75079 .20329 .74622 .19026 Mtetra
.588 .787 .974 r
.74622 .19026 .75079 .20329 .77746 .20081 .77312 .18775 Mtetra
.589 .787 .974 r
.77312 .18775 .77746 .20081 .80425 .19829 .80013 .18519 Mtetra
.59 .788 .975 r
.80013 .18519 .80425 .19829 .83115 .19573 .82726 .18258 Mtetra
.82726 .18258 .83115 .19573 .85817 .19311 .85452 .17993 Mtetra
.591 .789 .975 r
.85452 .17993 .85817 .19311 .88531 .19046 .88189 .17723 Mtetra
.88189 .17723 .88531 .19046 .91257 .18777 .90938 .17449 Mtetra
.617 .786 .963 r
.03963 .12441 .04964 .13687 .07304 .1339 .0632 .12139 Mtetra
.0632 .12139 .07304 .1339 .09653 .13092 .08686 .11836 Mtetra
0 .102 .627 r
.08686 .11836 .09653 .13092 .11792 .15632 .10869 .13976 Mtetra
0 .246 .76 r
.10869 .13976 .11792 .15632 .14007 .17594 .13088 .16043 Mtetra
.136 .442 .877 r
.13088 .16043 .14007 .17594 .16293 .18918 .15383 .17438 Mtetra
.28 .555 .928 r
.15383 .17438 .16293 .18918 .1863 .19831 .17731 .18401 Mtetra
.369 .622 .95 r
.17731 .18401 .1863 .19831 .21003 .20469 .20118 .19075 Mtetra
.427 .665 .961 r
.20118 .19075 .21003 .20469 .23404 .20912 .22534 .19544 Mtetra
.466 .693 .966 r
.22534 .19544 .23404 .20912 .25829 .21214 .24975 .19866 Mtetra
.493 .713 .969 r
.24975 .19866 .25829 .21214 .28273 .21411 .27437 .20078 Mtetra
.513 .728 .97 r
.27437 .20078 .28273 .21411 .30736 .21527 .29917 .20205 Mtetra
.528 .739 .971 r
.29917 .20205 .30736 .21527 .33214 .2158 .32414 .20266 Mtetra
.539 .747 .972 r
.32414 .20266 .33214 .2158 .35708 .21583 .34926 .20274 Mtetra
.548 .754 .973 r
.34926 .20274 .35708 .21583 .38215 .21545 .37453 .20241 Mtetra
.555 .759 .973 r
.37453 .20241 .38215 .21545 .40736 .21474 .39993 .20172 Mtetra
.561 .764 .973 r
.39993 .20172 .40736 .21474 .4327 .21375 .42547 .20075 Mtetra
.566 .768 .973 r
.42547 .20075 .4327 .21375 .45817 .21253 .45114 .19953 Mtetra
.57 .771 .973 r
.45114 .19953 .45817 .21253 .48376 .21111 .47693 .19811 Mtetra
.573 .773 .974 r
.47693 .19811 .48376 .21111 .50947 .20952 .50285 .19652 Mtetra
.576 .775 .974 r
.50285 .19652 .50947 .20952 .5353 .20778 .52889 .19476 Mtetra
.578 .777 .974 r
.52889 .19476 .5353 .20778 .56125 .20592 .55505 .19288 Mtetra
.58 .779 .974 r
.55505 .19288 .56125 .20592 .58732 .20394 .58134 .19088 Mtetra
.582 .781 .974 r
.58134 .19088 .58732 .20394 .61351 .20186 .60774 .18877 Mtetra
.583 .782 .974 r
.60774 .18877 .61351 .20186 .63982 .19969 .63427 .18657 Mtetra
.584 .783 .974 r
.63427 .18657 .63982 .19969 .66624 .19743 .66091 .18429 Mtetra
.585 .784 .974 r
.66091 .18429 .66624 .19743 .69278 .19511 .68768 .18193 Mtetra
.586 .785 .974 r
.68768 .18193 .69278 .19511 .71944 .19272 .71456 .1795 Mtetra
.587 .786 .974 r
.71456 .1795 .71944 .19272 .74622 .19026 .74157 .17701 Mtetra
.588 .786 .974 r
.74157 .17701 .74622 .19026 .77312 .18775 .76869 .17446 Mtetra
.589 .787 .974 r
.76869 .17446 .77312 .18775 .80013 .18519 .79594 .17186 Mtetra
.589 .788 .975 r
.79594 .17186 .80013 .18519 .82726 .18258 .82331 .1692 Mtetra
.59 .788 .975 r
.82331 .1692 .82726 .18258 .85452 .17993 .8508 .16651 Mtetra
.59 .789 .975 r
.8508 .16651 .85452 .17993 .88189 .17723 .87841 .16376 Mtetra
.591 .789 .975 r
.87841 .16376 .88189 .17723 .90938 .17449 .90614 .16098 Mtetra
.617 .786 .963 r
.02946 .11175 .03963 .12441 .0632 .12139 .0532 .10868 Mtetra
.0532 .10868 .0632 .12139 .08686 .11836 .07704 .10559 Mtetra
0 .258 .753 r
.07704 .10559 .08686 .11836 .10869 .13976 .09933 .12294 Mtetra
0 .214 .737 r
.09933 .12294 .10869 .13976 .13088 .16043 .12155 .14468 Mtetra
.109 .422 .867 r
.12155 .14468 .13088 .16043 .15383 .17438 .14458 .15934 Mtetra
.262 .543 .923 r
.14458 .15934 .15383 .17438 .17731 .18401 .16818 .16948 Mtetra
.357 .615 .948 r
.16818 .16948 .17731 .18401 .20118 .19075 .19218 .17658 Mtetra
.418 .66 .96 r
.19218 .17658 .20118 .19075 .22534 .19544 .2165 .18154 Mtetra
.459 .689 .966 r
.2165 .18154 .22534 .19544 .24975 .19866 .24107 .18496 Mtetra
.488 .71 .969 r
.24107 .18496 .24975 .19866 .27437 .20078 .26586 .18722 Mtetra
.509 .726 .97 r
.26586 .18722 .27437 .20078 .29917 .20205 .29085 .1886 Mtetra
.525 .737 .972 r
.29085 .1886 .29917 .20205 .32414 .20266 .316 .18929 Mtetra
.537 .746 .972 r
.316 .18929 .32414 .20266 .34926 .20274 .34131 .18943 Mtetra
.546 .753 .973 r
.34131 .18943 .34926 .20274 .37453 .20241 .36677 .18914 Mtetra
.554 .759 .973 r
.36677 .18914 .37453 .20241 .39993 .20172 .39237 .18848 Mtetra
.56 .763 .973 r
.39237 .18848 .39993 .20172 .42547 .20075 .41811 .18752 Mtetra
.565 .767 .973 r
.41811 .18752 .42547 .20075 .45114 .19953 .44398 .18631 Mtetra
.569 .77 .973 r
.44398 .18631 .45114 .19953 .47693 .19811 .46999 .18489 Mtetra
.572 .773 .974 r
.46999 .18489 .47693 .19811 .50285 .19652 .49611 .18328 Mtetra
.575 .775 .974 r
.49611 .18328 .50285 .19652 .52889 .19476 .52237 .18152 Mtetra
.577 .777 .974 r
.52237 .18152 .52889 .19476 .55505 .19288 .54875 .17961 Mtetra
.579 .779 .974 r
.54875 .17961 .55505 .19288 .58134 .19088 .57525 .17759 Mtetra
.581 .78 .974 r
.57525 .17759 .58134 .19088 .60774 .18877 .60187 .17546 Mtetra
.583 .782 .974 r
.60187 .17546 .60774 .18877 .63427 .18657 .62862 .17323 Mtetra
.584 .783 .974 r
.62862 .17323 .63427 .18657 .66091 .18429 .65549 .17091 Mtetra
.585 .784 .974 r
.65549 .17091 .66091 .18429 .68768 .18193 .68248 .16852 Mtetra
.586 .785 .974 r
.68248 .16852 .68768 .18193 .71456 .1795 .70959 .16605 Mtetra
.587 .786 .974 r
.70959 .16605 .71456 .1795 .74157 .17701 .73683 .16352 Mtetra
.588 .786 .974 r
.73683 .16352 .74157 .17701 .76869 .17446 .76419 .16093 Mtetra
.589 .787 .975 r
.76419 .16093 .76869 .17446 .79594 .17186 .79167 .15828 Mtetra
.589 .788 .975 r
.79167 .15828 .79594 .17186 .82331 .1692 .81928 .15558 Mtetra
.59 .788 .975 r
.81928 .15558 .82331 .1692 .8508 .16651 .84701 .15284 Mtetra
.59 .789 .975 r
.84701 .15284 .8508 .16651 .87841 .16376 .87486 .15005 Mtetra
.591 .789 .975 r
.87486 .15005 .87841 .16376 .90614 .16098 .90284 .14722 Mtetra
0 g
.89362 0 m
.98022 .38351 L
s
.98022 .38351 m
1 .65325 L
s
1 .65325 m
.91448 .33294 L
s
.91448 .33294 m
.89362 0 L
s
.02946 .11175 m
0 .4272 L
s
0 .4272 m
.91448 .33294 L
s
.91448 .33294 m
.89362 0 L
s
.89362 0 m
.02946 .11175 L
s
.02946 .11175 m
.89362 0 L
s
gsave
.44797 -0.02478 -65.9056 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(u) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
0 .4272 m
.29069 .70824 L
s
gsave
.15892 .66839 -66.3192 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(p) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{261.563, 185.125},
  ImageMargins->{{29.5, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.095767,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000450000^A000`40O003h00Oogoo1Woo003oOol6
Ool00?moo`Ioo`00ogoo1Woo003oOol6Ool00?moo`Ioo`00PWoo1000Ogoo0021Ool01000Oomoo`00
P7oo0021Ool01000Oomoo`00P7oo0020Ool200000goo00000020Ool00?moo`Ioo`00ogoo1Woo003o
Ool6Ool00?moo`Ioo`00ogoo1Woo003oOol6Ool00?moo`Ioo`00ogoo1Woo003oOol6Ool00?moo`Io
o`00g7oo10009Goo003DOol80003Ool00`00Oomoo`0SOol00<eoo`L000]oo`03001oogoo02=oo`00
aGoo20004Woo0P0097oo002nOol7000JOol2000TOol00;Ioo`P0025oo`8002Aoo`00[goo1`00:Goo
0P0097oo002XOol7000`Ool00`00Ool0000SOol00:1oo`P003Moo`03001oo`0002=oo`00VGoo1`00
@7oo0P008goo002AOol80017Ool2000SOol008Yoo`L004moo`8002=oo`00PWoo2000EWoo00<007oo
00008Woo001kOol7001NOol00`00Ool0000ROol007=oo`P006Eoo`03001oo`00029oo`00K7oo1`00
KGoo00<007oo00008Woo001TOol8001dOol01000Oomoo`008Goo001MOol7001lOol01000Oomoo`00
8Goo001FOol70023Ool01000Oomoo`008Goo001>Ool8002:Ool01000Oomoo`008Goo0017Ool7002B
Ool01@00Oomoogoo000087oo000oOol8002IOol01@00Oomoogoo000087oo000hOol7002QOol01@00
Oomoogoo000087oo000`Ool8002XOol01@00Oomoogoo000087oo000/Ool4000024lnBae?7T/MCci;
7DlN0?NXOol01@00Oomoogoo000087oo000/Ool01@00Cai?7TlNBah00dlN00A;7TlNCai?7P80mjIo
o`03001oogoo009oo`03001oogoo01eoo`00;7oo00l007oo001;7DlNBae??T/MCai;7DlnBae?7P3g
0AL0YWoo00D007ooOomoo`0001moo`00;7oo00@007oo001oo`9?7P05Bai?7TlNCai;7P02Cah00`1C
0?L0m`2UOol01@00Oomoogoo00007goo000/Ool04@00Oomoo`00Cci;7DlNBae??T/MCai;7DlnBad0
L`1C0=L0Y7oo00D007ooOomoo`0001moo`00;7oo00D007ooOomoo`0000=?7P05Bai?7TlNCai;7P02
Cah205<00`3GOomoo`2QOol00`00Oomoo`02Ool00`00Oomoo`0LOol002]oo`03001oogoo00=oo`0>
001??T/MCai;7DlnBae?7T/MCci;7@1c05<0ej9oo`03001oogoo009oo`03001oogoo01aoo`00:goo
00<007ooOol017oo00@004lNCai?7PM;7P0305<0m`3G0:5oo`03001oogoo009oo`03001oogoo01ao
o`00:goo00<007ooOol01Goo00H004lnBae?7T/MCah2Bah01d[mCah04P1c0;H=^`VJ09Uoo`07Aai;
?d/NBai77T/o000017oo00<007ooOol077oo000[Ool00`00Oomoo`05Ool00`00Bai?7P02Cah6Bah0
1P0b0?L0ePVk2I/=^haooa5;7P03001oogoo009oo`03001oogoo01aoo`00:goo00<007ooOol01Woo
00L004/MCci;7DlNBadfg`02=[h023:n03803`3h2IX=^`VJ3K]oOol03d/NAai;?dLNBai77T/oAai;
7TLNBcm77T/NAai;?`02Bah01TLNBcm;7T/NAai;?`9;7P05Aai;?d/NBah00005Ool00`00Oomoo`0K
Ool002]oo`03001oogoo00Moo`03001;7TlN009?7PDf_P080381603g2IX9^`VK8SdN779oobQ;7P03
001oogoo00=oo`03001oogoo01]oo`00:goo00<007ooOol027oo00L004/MCci;7DlN<[hfg`02=[h0
100A0380n16k0Pfk00@9VR8m7Q`R?FEoo`0SBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/oAai;
7TLNBcm77T/NAai;?dLNBai77T/oAai;7TLNBcm77T/NAai;?`02Bah01TLNBcm;7T/NAai;?`9;7P07
Aai;?d/NBai77T/o00001Goo00<007ooOol06goo000[Ool00`00Oomoo`09Ool00`00Bai?7P02Cah0
1aXM=[hf_SJn0181>@4H00<=^`087Q`R?AhL7QdZOBim:UdZOEEoo`03Bai77T/N009;7P05Aai;7T/N
Bai77P03Bah00dLNBai;7P0^Bah00`00Oomoo`03Ool00`00Oomoo`0KOol002]oo`03001oogoo00Uo
o`0L001?7T/MCci;7DlN5Q`J?AHL03<04@4i0?PA^`fk4M/R728m7Q`^ORYM;WhZGBin<YdfWS:M=Yi5
Ool0>d/NA_i;7dLNBai6oT/OAai;7TKnBam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLN
Bai77T/OAai;7TLNBcm77T/NAai;?dLNBai77T/oAai;7TLNBcm77T/NAai;?dLNBai77T/oAai;7TLN
Bcl00T/N00I77T/oBai;7TLNBcl2Bah01TLNBcm;7T/N001;?`Eoo`03001oogoo01Yoo`00:goo00<0
07ooOol02Woo00<004lNBah00dlN00TJ7AXm6Sd0<P4h0CTAfa7L3K/00b8m00DR?2Ym:Wd^OBYM008b
WP03=YhbWC:N008j_P03=[hj_Woo02ioo`=77P04A_i77TLNBah3Aah01D/NAai77TLNBah00dLN00Y;
7TLNBai77T/NAai;7TLNBai77P=;7P05Aai;7T/NBai77P03Bah01DLNBai;7T/NAah0;T/N00<004/N
Ool017oo00<007ooOol06Woo000[Ool00`00Oomoo`0;Ool07`00Cai;7DlnBae?7P5I6Sd0E04i0AP1
>A6k4M`A^b8m8Q`R?AhL;WhZOBin:UdfWS:M=YhbWCZn=[hj_SJm008j_P0>?]hj_SkN>[i2gSkN@_hn
gT;N?]i2oSkN@_hngPYoo`1KAai2oTLO@_i77T;nAam6oTLN@_i77dKnAai6oTLOA_i77TKnBam6oTLN
A_i;7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dKnBai6oT/OAai;7TKnBam77T/NA_i;7dLNBai6oT/O
Aai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/oAai;7TLNBcm77T/N
Aai;?dLNBai77T/oAai;7TLNBcl00T/N00I77T/oBai;7TLNBcl2Bah01TLNBcm;7T/NAai;?`9;7P04
Aai;?`00Bah5Ool00`00Oomoo`0JOol002Yoo`03001oogoo00eoo`9?7P04Bai?7TlNCah20ET02`0c
0CT1>04i4M/Ag17K9SdR?BHm8Sd00Rim00<^ORim=Yh00SJN00TbWSZn>[hj_SJn?]hjgSkN>[h01SkN
00I2oT;N@_i2gT;n@]h6@_h01TKn@_i2oT;nA_i2oPI6oP0:Aai6oTKnA_i77TKnAai6oTLNA_h3Aah0
1DKnAai77TLNA_h00TLN00E;7TLNAai77T/N00=77P0>Bai77T/NAai;7TLNBai77T/NAai;7TLNBai7
7P=;7P05Aai;7T/NBai77P03Bah01DLNBai;7T/NAah0;4/N00<004/NBah017oo00<007ooOol06Woo
000ZOol00`00Oomoo`0>Ool074/MCai;7DlnBad0M05I0;H1F@EI0APEo1GK4M`R?2IM8S`V?B8l<YhZ
OBin<Ydf_S:M=[hbWC[N0SZn00Df_CkN>[hngSZn008ngP1_@]hngT;n?]i2oSkN@_hngT;n@]i6oT;N
@_i2gTKn@_i6oT;nA_m2oTLN@_i77d;nAai2oTLOA_i77T;nAam6oTLNA_i77dKnAai6oT/OA_i77TKn
Bam6oT/NA_i;7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dLNBai6oT/OAai;7TKnBam77T/NAai;7dLN
Bai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/NAai;?dLNBai77T/oAai;7TLN
Bcm77T/NAai;?dLNBai77T/o009;7P06Aai;?d/NBai77T/o0T/N00I77T/oBai;7TLNBcl2Bah00`00
Bcm;7P04Ool00`00Oomoo`0JOol002Yoo`03001oogoo00ioo`04001?7TlNBah2Cah20ET0102E1ET5
F@5I0aGL00@R?BHm8SdV?@<^O@03;WhbWSJN008fWPDj_PHngP06@]hngSkN?]i2oT;N24;n00A6oT;n
A_i2oPY6oP0:Aai6oTLNA_i77TKnAai6oTLNA_h3Aah01DKnAai77TLNA_h00TLN00E;7TLNAai77T/N
00=77P0>Bai77T/NAai;7TLNBai77T/NAai;7TLNBai77P=;7P05Aai;7T/NBai77P0bBah00`00Bai;
7P05Ool00`00Oomoo`0IOol002Yoo`03001oogoo00moo`0M001;7DlNBae??T/M0GT0U@1e0ET5F@4i
5O`EfaGl9S`VGBHm9Ud^OC:N;Wd^OS:M=[hfWCJn=[djgP02>[h04SJm?]hj_SkN>[i2oSkN@_hngT;n
@]i2oSkN@_i2gT;n@]i6oP92oP1N@]i77d;nA_i2oTLO@_i77T;nAam2oTLN@_i77dKnAai6oTLOA_i7
7TKnAam6oTLNA_i;7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dLNBai6oT/OAai;7TKnBam77T/NA_i;
7dLNBai6oT/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/oAai;
7TLNBcm77T/NAai;?dLNBai77T/oAai;7TLNBcl2Bah01TLNBcm;7T/NAai;?`9;7P06Aai;?d/NBai7
7T/o0T/N00E77T/oBah004LN00Eoo`03001oogoo01Uoo`00:Woo00<007ooOol047oo0dlN00E;7TlN
Cah0UP2E0085NP051ETIo1Wl5M`VG@039Sd01C:N;Wd^OBim=[h00cJN1CZn1ckN00=2gSkN?]h00T;n
00=2gT;n@_h01T;n00A6oT;nA_i2oPI6oP0:Aai6oTKnA_i77TKnAai6oTLNA_h3Aah00dKnAai77P08
Aah04T/NAai77TLNBai77T/NAai;7TLNBai77T/NAai;7TLNBai77P=;7P05Aai;7T/NBai77P03Bah0
0dLNBai;7P0_Bah00`00Baioo`04Ool00`00Oomoo`0IOol002Yoo`03001oogoo015oo`0<Cci;7DlN
Bae??P1c09H0U@Ej1ET5NQGK0QWl018VGBHl9UdV?C:N;WdbWRim=[hbWCJn=YdjgSZm>]hj_S[N>[h3
?]h0KSZn@_hngT;n?]i2oT;N@_hngT;n@]i6oT;NA_i2oTKn@_i77T;nA_i2oTLO@_i77T;nAam6oTLN
@_i77dKnAai6oT/OA_i77TKnBam6oT/NA_i;7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dLNBai6oT/O
Aai;7TKnBam77T/NA_i;7dLNBai6oT/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/N
Aai;7dLNBai77T/oAai;7TLNBcm77T/NAai;?dLNBai77T/oAai;7TLNBcl2Bah01TLNBcm;7T/NAai;
?`9;7P0<Aai;?d/NBai77T/oBai;?TLN001;7T/n17oo00<007ooOol06Goo000ZOol00`00Oomoo`0B
Ool3Cah01D/NCah0eP2F09D00`Ej0QWl00`VGBYM9UdZGBim<Yh^OC9m;Wdf_SJN=[h5>[h6?]h014;N
?]i2gSkN0d;n00=2gT;n@_h014;n00A6oT;nA_i2oPQ6oP0:Aai6oTKnA_i77TKnAai6oTLNA_h3Aah0
14KnAai77T/N0dLN019;7TLNAai77T/NAai;7TLNBai77T/NAai;7TLNBai77T/NAah3Bah01DLNBai;
7T/NAah00d/N00=77T/NBah0<D/N00<004/NBah01Goo00<007ooOol067oo000ZOol00`00Oomoo`0C
Ool02dlnBae?7T/M0180]P3G2GX=V`EI7Q`00QWl00/V?BYM9SdZGC9m<Yh^OC:N=Ydf_SJM008j_P06
?]hj_CkN>[hngSjn13kN00Q2oSkN@_hngT;n@]i2oSkN0T;n05]6oT;NA_i2oTKn@_i77T;nA_i2oTLO
@_i77T;nAam6oTLNA_i77dKnAai6oT/OA_i77TKnBam6oT/NA_i;7dKnBai6oT/OA_i;7TKnBam6oT/N
A_i;7dLNBai6oT/OAai;7TKnBam77T/NA_i;7dLNBai6oT/OAai;7TLNBam77T/NAai;7dLNBai77T/O
Aai;7TLNBam77T/NAai;7dLNBai77T/oAai;7TLNBcm77T/NAai;?`02Bah01TLNBcm;7T/NAai;?`9;
7P06Aai;?d/NBai77T/o0T/N00Y77T/oBai;7TLNBcm;7P00Aai;?`Eoo`03001oogoo01Qoo`00:Woo
00<007ooOol04goo00@003:n<Yhb_P804@030=H0e`VJ0089VP0=7Q`Io2YM9UdZGBIM<YhbOC:N<Wdb
WSJn>[h00SJn00@j_S[N>[hj_PDngP06@_hngT;N@]i2oSkN0d;n00A2gT;n@_i6oP=2oP03A_i2oTKn
00U6oP0:Aai6oTKnA_i77TKnAai6oTLNA_h3Aah014KnAai77T/N0dLN019;7TLNAai77T/NAai;7TLN
Bai77T/NAai;7TLNBai77T/NAah3Bah01DLNBai;7T/NAah00d/N00=77T/NBah0;d/N00@004/NBai;
7PAoo`03001oogoo01Qoo`00:Woo00<007ooOol057oo00h003:n;Yhb_P0A0AP0]P3G2GX=VahL8QdI
o2im0bYM00PbWS9m<Yh^OCZn=Ydj_SJM0SZn00<ngSZm?]h00SkN06Xn_SkN?]i2oSkN@_hngT;n@]i2
oT;N@_i2gTKn@_i6oT;NA_i2oTKn@_i77T;nAai2oTLOA_i77T;nAam6oTLNA_i77dKnAai6oT/OA_i;
7TKnBam6oT/NA_i;7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dLNBai6oT/OAai;7TKnBam77T/NA_i;
7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBcm77T/NAai;?dLNBai77T/oAai;
7TLNBcm77T/NAai;?`9;7P06Aai;?d/NBai77T/o0T/N00I77T/oBai;7TLNBcl2Bah02DLNBcm;7T/n
Aah004/NBci77P04Ool00`00Oomoo`0HOol002Yoo`03001oogoo01Eoo`0=000b_S:N03<04@3h0?LA
^`fK2IXN728L7Q`012YM00@bWS:M<YhbW@8f_P07>[hf_S[N>[hngSZn>]h01CkN00A2oT;N@]i2gPQ2
oP03A_i2oT;n0096oP04@_i6oTKnAah3A_h03TLNA_i77TKnAai6oTLNA_i77TKnAai6oTLNA_h6Aah0
1D/NAai77TLNBah00dLN00Y;7TLNBai77T/NAai;7TLNBai77P=;7P05Aai;7T/NBai77P03Bah00dLN
Bai;7P0aBah01000Bai;7T/N17oo00<007ooOol067oo000YOol00`00Oomoo`0GOol03P001K/^WP0c
0141603g4K/=VR8M7Q`R7AhL;Wh2:Ud03C9m=YhbOCJN<Wdj_SJm>[hfWCkN>[hngSZm00@ngP0:@]hn
gT;n?]i2oSkN@_i2gTKn@]h2@_h0GDKn@_i6oT;nAai2oTKn@_i77TKnAai2oTLOA_i77TKnAam6oTLN
A_i;7dKnAai6oT/OA_i;7TKnBam6oT/NA_i;7dKnBai6oT/OA_i;7TKnBam77T/NA_i;7dLNBai6oT/O
Aai;7TKnBam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBcm77T/N
Aai;?dLNBai77T/oAai;7TLNBcm77T/NAai;?`02Bah01TLNBcm;7T/NAai;?`9;7P06Aai;?d/NBai7
7T/o0T/N00M77T/oBah004LNBcm;7P05Ool00`00Oomoo`0GOol002Uoo`03001oogoo01Qoo`0E05<5
^`0c0141603h5K/A^`fK8SdN728L:Ud^OBiM;WdbWC:N<YdbWSJn00<j_P05=[hngSjn?]hj_P05?]h0
0d;N@_i2gP02@]h8@_h00dKn@_i6oP02A_h014;nA_i6oTLN0dKn00I77TKnAai6oTLNA_h3Aah01DKn
Aai77TLNA_h00TLN00E;7TLNAai77T/N00=77P0>Bai77TLNAai;7TLNBai77T/NAai;7TLNBai77P=;
7P05Aai;7T/NBai77P0eBah01000Bai;7T/N1Goo00<007ooOol05goo000DOol3000BOol00`00Oomo
o`0HOol01@000585^`0c01800P4H07`A^aGK8Q`V?B8L9SdZGBin:Ud^OC:M=YhbWCJN=Ydj_SJm>[hj
_CkN>[hngSZm@_hngT;N?]i2oSkN@_hngT;n?]i2oT;NA_i2gTKn@_i6oT;nA_i2oTLN@_i77T;nAai6
oTLN@_i77TKnAai6oTLOA_i77TKnBam6oTLNA_i;7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dKnBai6
oT/OAai;7TKnBam77T/NA_i;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBam7
7T/NAai;7dLNBai77T/oAai;7TLNBcm77T/NAai;?`9;7P06Aai;?d/NBai77T/o0T/N00I77T/oBai;
7TLNBcl2Bah03TLNBcm;7T/nAai;?d/NBci77P00Bai;?TLNBcl4Ool00`00Oomoo`0GOol001Eoo`03
001oogoo015oo`03001oogoo01Uoo`80D`0;09D0<`4i0APEfaFk5M/R728m8Q`R?@02;Wd01BiM=Yhb
WCJN=Yd01SZn00@ngSjn?]hj_P@ngP04@_i2gT;n@]h6@_h014Kn@_i6oT;n24Kn00Y77TKnA_i6oTLN
A_i77TKnAai6oP=77P05A_i77TLNAai6oP02Aah03T/NAai77TLNBai77T/NAai;7TLNBai77T/NAah3
Bah01DLNBai;7T/NAah00d/N00E77T/NBai;7TLN03=;7P03001;7T/N009;7PAoo`03001oogoo01Mo
o`004goo0`004goo00<007ooOol06Woo01`0D`1B05@5F@Di0APEg16k5M/V?2Hm8Q`^ORiM<Wh^GCJN
<YdfWS:M>[hf_CZn>[dj_SZm?]hj_P8ngP08@_hngT;N?]i2oT;N@_hngP92oP1KA_i2gTKn@_i6oT;n
Aai2oTKn@_i77T;nAai2oTLNA_i77TKnAai6oTLNA_i;7dKnAai6oT/OA_i;7TKnBam6oT/NA_i;7dKn
Bai6oT/OA_i;7TKnBam77T/NA_i;7dLNBai6oT/OAai;7TKnBam77T/NAai;7dLNBai77T/OAai;7TLN
Bam77T/NAai;7dLNBai77T/OAai;7TLNBcm77T/NAai;?dLNBai77T/oAai;7TLNBcl00T/N00I77T/o
Bai;7TLNBcl2Bah01TLNBcm;7T/NAai;?`9;7P0<Aai;?d/NBci77T/oBah004LNBcm;7T/n1Goo00<0
07ooOol05Woo000BOol01000Oomoo`004goo00<007ooOol06goo00<0D`3F03<00PEI00DIfaWL5K/V
?BHl008V?@@^O@03=YhfWCJN00Dj_PHngP08@]hngT;N@]i2oT;N@_i2gPE2oP96oP03@_i6oTKn00Q6
oP0:Aai6oTLNA_i77TKnAai6oTLNA_h3Aah01DKnAai77TLNA_h00TLN00i;7TLNAai77T/NAai;7TLN
Bai77T/NAai;7TLN0d/N00E77T/NBai;7TLN03U;7P03001;7T/N009;7PEoo`03001oogoo01Ioo`00
4Woo00@007ooOol001=oo`03001oogoo01]oo`80D`1n0;H9NPEI1EXEfaWl6M/V?BHl9Sd^OC9n;Wdb
WSJM=[hbWCJn>[dj_SZm?]hj_CkN?[dngSjn@]hngT;n?]i2gSkN@_i2gT;n?]i6oT;nA_i2gTKn@_i6
oT;nAai2oTLN@_i77T;nAai6oTLNA_i77TKnBam6oTLNA_i;7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;
7dKnBai6oT/OAai;7TKnBam77T/NA_i;7dLNBai6oT/OAai;7TKnBam77T/NAai;7dLNBai77T/OAai;
7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBcm77T/NAai;?dLNBai77T/o0T/N00I77T/oBai;7TLN
Bcl2Bah01TLNBcm;7T/NAai;?`9;7P0>Aai;?d/NBai77T/oBai;?TLN001;7T/nAai;?`Eoo`03001o
ogoo01Ioo`004goo10004Woo00<007ooOol077oo00<0D`3G07D00`EI00HIfaWL:SdZGBHl9Sd2<Wd0
1Rim<WdfWSJn=YdfWP@j_PDngP03@]hngT;N00=2gP=2oP05@]i2oT;nA_i2oP03A_h00d;nA_i6oP08
A_h01TLNA_i77TKnAai6oP=77P04A_i77TLNBah3Aah04T/NAai77TLNBai77T/NAai;7TLNBai77T/N
Aai;7TLNBai77P=;7P05Aai;7T/NBai77P0gBah00`00Bai;7P03Bah4Ool00`00Oomoo`0FOol002Uo
o`03001oogoo01aoo`2105@0]P3G3GX=VPEI7O`MnaWl9S`ZGBHl<Yh^OC9n;Wdj_SJM>[hfWCZn>[dn
gSZm?]hn_SkN?[dngSjn@_hngT;n?]i2oT;N@_i2gT;n@]i6oT;nA_i2gTLN@_i6oT;nAai6oTLN@_i7
7TKnAai6oTLNA_i77TKnBam6oTLNA_i;7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dKnBai6oT/OAai;
7TKnBam77T/NA_i;7dLNBai6oT/OAai;7TKnBam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/NAai;
?dLNBai77T/oAai;7TLNBcm77T/NAai;?dLNBai77T/o009;7P06Aai;?d/NBai77T/o0T/N00I77T/o
Bai;7TLNBcl2Bah03DLNBcm;7T/nAai;?d/N00177T/oBai;?TLN00Eoo`03001oogoo01Eoo`00:Goo
00<007ooOol07Goo00H03`3F0=L=NPfJ3GX27O`012YM:SdZGBXm0S9m00HbWS9m=YhfWSJn=Yd2>[h0
0cjn>[hj_P04?]h00d;N@_i2gP02@]h00d;n@]i2oP03@_h00dKn@_i6oP0;A_h02TLNA_i6oTKnAai6
oTLNA_i77TKn0dLN00A6oTLNAai;7P=77P0BBai77T/NAai;7TLNBai77T/NAai;7TLNBai77T/NAai;
7TLN0d/N00E77T/NBai;7TLN03I;7P03001;7T/N009;7PEoo`03001oogoo01Eoo`00:7oo00<007oo
Ool07Woo01T0<`DH0;H0e`ej3IXR71gl7O/^GBYM;UdZG3JN<WdbWS9m>[hfWCZn=YdngSZm?]hj_@03
?]h0GSjm@]hngT;n?]i2oSkN@_i2gTKn@]i6oT;NA_i2oTKn@_i77T;nA_i2oTLNA_i77T;nAai6oTLN
A_i77TKnAai6oT/NA_i77TKnBam6oT/NA_i;7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dLNBai6oT/O
Aai;7TKnBam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBcm77T/N
Aai;?dLNBai77T/o0T/N00I77T/oBai;7TLNBcl2Bah01TLNBcm;7T/NAai;?`9;7P0CAai;?d/NBai7
7T/oBai;?TLNBcm;7T/nAai;?`00Bci77T/oBah01Goo00<007ooOol05Goo000XOol00`00Oomoo`0N
Ool01`2f00l5603F5K/E^PfJ008R7009:Ud^GBYM;UdZGCJM<WdbWSJM00<j_P05=Ydn_Sjn?]hj_P02
?]h01D;N?]i2gT;N@_h00T;N0T;n00M2gT;n@_i6oT;nA_i2oP0<A_h01TLNA_i6oTKnAai6oP=77P05
A_i77TLNBai6oP02Aah03T/NAai77TLNBai77T/NAai;7TLNBai77T/NAah3Bah01DLNBai;7T/NAah0
?4/N00<004/NBah00d/N17oo00<007ooOol05Goo000XOol00`00Oomoo`0OOol01`1D1AL5602f5K/A
VRHL008R701b:U`^GBYM;UdbOCJN<WdfWSJM>[hfWCZn>[dngSZm?]hj_D;N?]i2gSkM@_i2gT;n?]e2
oT;NA_i2gTKn@]i6oT;nA_i2oTKn@_i77T;nA_i2oTLNA_i77TKnAai6oTLNA_i;7TKnBai6oT/NA_i;
7TKnBam6oT/NA_i;7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dLNBai6oT/OAai;7TKnBam77T/NAai;
7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBcm77T/NAai;?dLNBai77T/o0T/N
00I77T/oBai;7TLNBcl2Bah01TLNBcm;7T/NAai;?`9;7P0BAai;?d/NBci77T/oBai;?TLNBcm;7T/n
001;?d/NBci77T/o17oo00<007ooOol05Goo000XOol00`00Oomoo`0OOol0102f05@560DH0QFk00TE
^RHl8Q`R72iM;Wd^GBim<Yd00SJM00<fWSZm>[h00SZn00<n_SkN?[h013kN00E2gSkN@]i2gT;n0092
gPE2oP04A_i2oTKn@_h8A_h01TLNA_i77TKnAai6oP=77P05A_i77TLNBai6oP02Aah01D/NAai77TLN
Bah00dLN00Y;7TLNBai77T/NAai;7TLNBai77P=;7P05Aai;7T/NBai77P0jBah00`00Bai;7P03Bah5
Ool00`00Oomoo`0DOol002Qoo`03001oogoo01moo`1e0=H0]@ei1ALMg1WK5K/V72Xm9Q`Z?BiM<Wd^
GCJN=YdfWSJM>[hjWCZn>[dngSZm?]hn_CkN?]e2oSkN@]i2gD;n@]i2oT;MA_i2gTKn@]i6oT;nA_i2
oTKn@_i77T;nAai6oTLNA_i77TKnAai6oT/NA_i77TKnBai6oT/NA_i;7TKnBai6oT/OA_i;7TKnBam6
oT/NA_i;7dKnBai6oT/OAai;7TKnBam77T/NA_i;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai7
7T/OAai;7TLNBam77T/NAai;?dLNBai77T/o009;7P06Aai;?d/NBai77T/o0T/N00I77T/oBai;7TLN
Bcl2Bah01TLNBcm;7T/NAai;?`9;7P0AAai;?d/NBci77T/oBai;?TLNBcl004/nAai;?d/NBci77P04
Ool00`00Oomoo`0DOol002Qoo`03001oogoo01moo`053CL0]P1C3ET560037M/00bHL9S`V?002<Wd0
0bim;UdfWP03=Yd023Zn>[dj_SZn?]hn_SkN?[h2?]h024;N?]i2gT;N@_i2gT;n@]h2@_h00dKn@_i6
oP02A_h00d;nA_i6oP04A_h02TLNA_i6oTKnAai6oTLNA_i77TKn0dLN00E6oTLNAai;7TKn00977P0:
Bai77T/NAai;7TLNBai77T/NAah3Bah01DLNBai;7T/NAah00d/N00E77T/NBai;7TLN03Q;7P03001;
7T/N00A;7PAoo`03001oogoo01Aoo`00:7oo00<007ooOol087oo02d=5`3F3ET=NAWK7M`IfagK:S`Z
?BHL<Wd^GC9n=YdfWSJM=Yhj_Cjn>[dn_SZm?]hn_D;N?[e2oSkM@_hngT;n@]e2oT;N@_i2gTKn@]i6
oT;NA_i2oTKn@_h00TKn04M77T;nAai6oTLNA_i;7TKnAai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6
oT/NA_i;7TKnBam6oT/NA_i;7dLNBai6oT/OAai;7TKnBam77T/NA_i;7dLNBai77T/OAai;7TLNBam7
7T/NAai;7dLNBai77T/OAai;7TLNBcm77T/NAai;?dLNBai77T/o009;7P06Aai;?d/NBai77T/o0T/N
00I77T/oBai;7TLNBcl2Bah05dLNBcm;7T/NAai;?d/NBci77T/oBai;?TLNBcm;7T/n001;?d/NBci7
7T/oBah017oo00<007ooOol057oo000XOol00`00Oomoo`0POol00a4h0;HIVP023ET01R7k7M/MfbiM
:S`Z?@@bO@04=YdjWSJM>Yh2>[h00cZm>[hj_P04?]h4@]h014;n@]i2oT;N0T;n00A6oT;nA_i2oPY6
oP0:Aai6oTKnA_i77TKnAai6oTLNA_h3Aah014KnAai77T/N0dLN00Y;7TLNBai77T/NAai;7TLNBai7
7P=;7P05Aai;7T/NBai77P0jBah50006Bah5Ool00`00Oomoo`0COol002Qoo`03001oogoo025oo`1g
4CP0]AVj5IXUo27k9Q`QnbiM:S`^GC9m=YdbOCJN=Ydj_SJM>[hj_CkN>[dngSkM@]hn_D;N?]i2oSkM
@_hngT;n@]e6oT;N@_i2gTKn@_i6oT;nAai2oTKn@_i77TKnAai2oTLNA_i77TKnBai6oT/NA_i;7TKn
Bai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/OA_i;7TKnBam77T/NA_i;7dLNBai6oT/OAai;7TKn
Bam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/oAai;7TLNBcm77T/NAai;?`02
Bah01TLNBcm;7T/NAai;?`9;7P06Aai;?d/NBai77T/o0T/N2P0000a;7T/nAai;?`00Bci77T/oBai;
?TLNBcl4Ool00`00Oomoo`0COol002Qoo`03001oogoo025oo`8A>0<IVP0>8O`Qnb7l;UdbGBXl=Wdb
OCIm<Wdj_SZM>[hjW@<n_P04>[dn_SkN@]h2?]h5@]h00d;n@]i2oP03@_h>A_h02TLNA_i6oTKnAai6
oTLNA_i77TKn0TLN00E;7TKnAai77T/N00=77P0:Bai77T/NAai;7TLNBai77T/NAah3Bah01DLNBai;
7T/NAah09D/N2@003d/N00<004/NBah014/N17oo00<007ooOol04goo000XOol00`00Oomoo`0QOol0
726I3ALA>1FI6KXZ6bXl8O/V72iL<Ud^G3JN<WdfWC9m>[hjWCZn>YdngSjm?]hj_D;N?]e2gSjm0T;N
05=2oSkM@_i2gTKn@]e6oT;NA_i2gTKn@_i6oT;nAai2oTKn@_i77TKnAai6oT/NA_i77TKnBai6oT/N
A_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/OAai;7TKnBam77T/NA_i;7dLNBai77T/O
Aai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/NAai;?dLNBai77T/o009;7P03Aai;?d/N
00X00005Bcm;7T/NAai;?`02Bah064LNBcm;7T/nAai;?d/NBci77T/oBai;?TLNBcm;7T/nAah004/N
Bci77T/oBai;?PAoo`03001oogoo01=oo`009goo00<007ooOol08goo00DQVA4h9M/QfQVJ00<Z708^
G@03<Ud^G3JM008fW@05>Ydj_SZM>[hn_@02?[h00ckN?[e2gP02@]h013kN@]i2gT;n0T;N00=2oTKn
@_h00T;n00=6oT;nA_h02DKn00I77TKnAai6oTLNA_h3Aah01DKnAai77T/NA_h00TLN00Y;7TLNBai7
7T/NAai;7TLNBai77P=;7P05Aai;7T/NBai77P0HBah9000RBah00`00Bai;7P04Bah4Ool00`00Oomo
o`0COol002Moo`03001oogoo02=oo`0^7GPQV@dG9M/QfRXl:Q/Z?2HK=WdbG3Im<U`jWSIm=YdjWCjn
>Ydn_SZm?]hn_CkN>[e2gSkM@]hngD;n@]i2oT;MA_i2gTKn@]e6oT;nA_i2oTKn@_i6oT;nAah3A_h0
<TLNA_i77TKnBai6oTLNA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NAai;7TKnBai7
7T/NA_i;7dLNBai6oT/OAai;7TLNBam77T/NAai;7dLNBai77T/OAah900001TLNBcm;7T/NAai;?`9;
7P06Aai;?d/NBai77T/o0T/N00I77T/oBai;7TLNBcl2Bah06dLNBcm;7T/NAai;?d/NBci77T/oBai;
?TLNBcm;7T/nAai;?d/N00177T/oBai;?TLNBcm;7P04Ool00`00Oomoo`0BOol002Moo`03001oogoo
02=oo`<QV@048MXUfb7J;S`2:Q`0139M<WdbOC9m13ZM00Tj_CZn>[dn_Sjm?]hn_SkN?[d014;N00A2
oT;N@_i2gP92oP03A_i2oT;n0096oP03@_i6oTKn00A6oP0:Aai6oTKnA_i77TKnAai6oTLNA_h2Aah0
1T/NA_i77TLNBai6oP977P0:Bai77T/NAai;7TLNBai77T/NAah3Bah01DLNBai;7T/NAah00d/N2P00
=D/N00<004/NBah014/N17oo00<007ooOol04Woo000WOol00`00Oomoo`0SOol0:bgI8ITMN2hK:O/U
fbhl<U`^?38l<U`fOC9L=WdfWCZN>YdjWSZm?[hj_Cjn?[e2gSjm@]hngD;n?]e2gT;MA_i2gTKn@]e6
oT;NA_i2gDKn@_i6oT;n0096oP0SAai6oTLNA_i77TKnBai6oTLNA_i;7TKnBai6oT/NA_i;7TKnBai6
oT/NA_i;7TKnBai6oT/NA_i;7TKnBai77T/NA_i;7`0900005d/NAai;7dLNBai77T/OAai;7TLNBam7
7T/NAai;?dLNBai77T/oAai;7TLNBcl00T/N00I77T/oBai;7TLNBcl2Bah01TLNBcm;7T/NAai;?`9;
7P06Aai;?d/NBai77T/o0T/N01E77T/oBai;?TLNBcm;7T/nAai;?d/NBci77T/o001;?TLNBcm;7T/n
Aah017oo00<007ooOol04Woo000WOol00`00Oomoo`0SOol0137J;MTanR6I0bhK0bhl13Im13ZM00Pn
_Sjm?[hn_Cjn?]e2gSkN1T;N00Q2oT;N@_i2oTKn@_i6oT;n2TKn00Y77TKnA_i6oTLNA_i77TKnAai6
oP977P08Bai6oT/NAai;7TLNBai77PX000=;7P05Aai;7T/NBai77P10Bah00`00Bai;7P04Bah4Ool0
0`00Oomoo`0BOol002Moo`03001oogoo02Aoo`07<OX]fC7j:O/^6bWk=U`00S9L020^?3Ym=W`jWCIl
?[hjWCjn>Ydn_SZm?[hj_D;N?[e2gSjm@_i2gD;n@]e2oT;MA_i2gTKn@]e6oT;nA_i2gDLN0TKn0152
oDLNA_i77TKnAai6oTLNA_i;7TKnBai6oT/NA_i;7TKn00T0000TA_i;7TKnBai77T/NA_i;7TLNBai6
oT/OAai;7TKnBam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/o0T/N00I77T/o
Bai;7TLNBcl2Bah01TLNBcm;7T/NAai;?`9;7P06Aai;?d/NBai77T/o0T/N01]77T/oBai;?TLNBcm;
7T/nAai;?d/NBci77T/oBai;?TLNBcm;7T/n001;?d/NBci;7T/oBah01Goo00<007ooOol04Goo000W
Ool00`00Oomoo`0TOol01BgI<MX]fC7j=S/00RhK0cIL13Im00<jWCjm>Yd00SZM00Hn_Sjm?[hn_D;N
@]d6@]h01TKn@]i2oT;nA_i2oPe6oPX0000=A_i77TLNBai6oT/NAai;7TLNBai77T/NAah00d/N00E7
7T/NBai;7TLN04M;7P03001;7T/N00A;7PAoo`03001oogoo015oo`009goo00<007ooOol097oo02Ta
nRgI<OX]fCHl<S/f?39L=U`bG3IM>WdjWCYl?YdjWCjn>Ydn_Sjm@]hn_D;N?]e2gSjm@]hngDKn@]e6
oT;MA_i2gDKn@]i6oT;MA_i2oTKn00T0000iBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;
7TKnBai6oT/NA_i;7TKnBai77T/NA_i;7TLNBai6oT/NAai;7TLNBam77T/NAai;7dLNBai77T/OAai;
7TLNBam77T/NAai;7dLNBai77T/o009;7P06Aai;?d/NBai77T/o0T/N00I77T/oBai;7TLNBcl2Bah0
1TLNBcm;7T/NAai;?`9;7P0JAai;?d/NBci77T/oBai;?TLNBcm;7T/nAai;?d/NBci77T/oBah004LN
Bcm;7T/nBai;?`D001=oo`009goo00<007ooOol09Goo00@n>RgI<MX]f@<f>`@jO08jW@03>WdjWCjm
00<n_@03@[e2gSjm00=2gP05@]e2gT;N@_i2gP0:000:A_h024LNA_i77TKnAai6oT/NA_h2Aah02T/N
A_i;7TLNBai77T/NAai;7TLN0d/N00E77T/NBai;7TLN04U;7P03001;7T/N00A;7PAoo`03001oogoo
015oo`009goo00<007ooOol09Goo00`j6Shj>QTn>SHk=S`b>cYm>W`jOCYL?[d2?Yd01cZL?[hnWCjn
?Ye2gSjm00T00009@]e6oT;MA_i2gDKn@]i6oT;m00=6oP0jA_e;7TKnAai6oT/NA_i;7TKnBai6oT/N
A_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai77T/NA_i;7TLNBai6oT/N
Aai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBal2Bah01TLNBam;7T/NAai;?`9;7P06Aai;?d/N
Bai77T/o0T/N00I77T/oBai;7TLNBcl2Bah084LNBcm;7T/NAai;?d/NBci77T/oBai;?TLNBcm;7T/n
Aai;?d/NBci77T/oBai;?T/N001;7T/nBai;?d/NBch4Ool00`00Oomoo`0AOol002Moo`03001oogoo
02Ioo`03?QXn>SXJ008nF`03?U`nFcYl008jO0X00003@[e2gSjm00=2gP05@]e6oT;NA_i2gP0BA_h0
1TLNA_i77TKnAai6oP977P06Bai6oT/NAai;7TLN0d/N00E77T/NBai;7TLN00=;7P05Aai;7T/NBai7
7P18Bah00`00Bai;7P04Bah3Ool00`00Oomoo`0AOol002Ioo`03001oogoo02Moo`03?SX0000000L0
0003@YdjW3jm008nW@0E?[e2gSjm@[hn_D;N@[e2gT:mA_i2gDKn@]e6oT;MA_i2gDKnA_e6oT;M00=6
oP0nA_e77TKnAai6oD/NA_i77TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6
oT/NA_i;7TKnBai77T/NA_i;7TLNBai77T/NAai;7TLNBai77T/NAai;7dLNBai77T/OAai;7TLNBam7
7T/NAai;?`9;7P06Aai;?d/NBai77T/o0T/N00I77T/oBai;7TLNBcl2Bah01TLNBcm;7T/NAai;?`9;
7P0OAai;?d/NBai77T/oBai;?TLNBcm;7T/nAai;?d/NBci;7T/oBai;?T/NBcm;7T/n001;?d/NBci;
7T/oBah00goo00<007ooOol04Goo000VOol00`00Oomoo`0OOol90003AUX3?U/00ciL?W`nW002?Y`0
3D:M@[e2_D:m?[e2_Cjm@[e2gD;N@]e2gT;M0092gP03A]i2gTKn0096oP03@]i6oTKn00a6oP0BAai6
oTKnA_i;7TKnAai6oT/NA_i;7TLNBai6oT/NAai;7TLN0d/N00E77T/NBai;7TLN04i;7P03001;7T/N
00A;7P=oo`03001oogoo015oo`009Woo00<007ooOol05Goo2P0027oo00=6FTIIBUX00TIJ00]2NdJL
@W]2WCil@YdnO4:m?Ya2_CjM0092_@0EA]i2_D;N@]e6gT;MA]i2gDKn@]e6oT;MA_i2gDKn@]e6oTKm
A_i2gD/N0096oP0fA_e;7TKnBai6oD/NA_i;7TKmBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/N
A_i;7TKnBai6oT/NAai;7TKnBai77T/NA_i;7TLNBai77T/NAai;7TLNBam77T/NAai;7dLNBai77T/O
0T/N00I77T/OBai;7TLNBcl2Bah01TLNBcm;7T/NAai;?`9;7P06Aai;?d/NBai77T/o0T/N00I77T/o
Bai;7TLNBcl2Bah07DLNBcm;7T/nAai;?d/NBci77T/oBai;?T/NBcm;7T/nBai;?d/NBci;7T/oBah0
04/NBcm;7T/nBah00goo00<007ooOol04Goo000VOol00`00Oomoo`0<Ool9000COol4AUX01DIl@W]6
Nd9kAY`00d:L00E2_D:M@[e2_D;M00=2_@06A]i2gD;M@]e6oT;M0TKN00=6oTKNA_h04DKn019;7TKn
Aai6oT/NA_i;7TKnBai6oT/NAai;7TLNBai77T/NAah3Bah00dLNBai;7P1?Bah00`00Bai;7P04Bah3
Ool00`00Oomoo`0@Ool002Ioo`03001oogoo009oo`X001aoo`96FP0VAUU:FTIJAYa2NdJL@Ya6_D:L
A[e2W4Jm@[a6_D:mA]e2_DKN@[e6gT;MA_i2gDKn@]e6oT;MA_i2gDKnA]e6oTKMA_i6oDKnA_e;7P96
oP0bA_e;7TKnBai6oD/NA_i;7TKmBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6
oT/NAai;7TKnBai77T/NA_i;7TLNBai77T/NAai;7TLNBam77T/NAai;7`9;7P06Aai;7d/NBai77T/O
0T/N00I77T/oBai;7TLNBcl2Bah01TLNBcm;7T/NAai;?`9;7P06Aai;?d/NBai77T/o0T/N02177T/o
Bai;?TLNBcm;7T/nBai;?d/NBci;7T/oBai;?T/NBcm;7T/nBai;?d/NBci;7P00Bai;?T/NBcm;7T/n
0goo00<007ooOol047oo000VOol5000VOol5AUX01T9kAWa2NdIk@Ya6W092W004@[e6_D:mA[d2A]d0
14:mA]e6gDKN0dKM00A6oTKMA_i6gA16oP0BBai6oT/NA_i;7TKnBai77T/NA_i;7TLNBai6oT/NAai;
7TLNEd/N00<004/NBah014/N0goo00<007ooOol047oo000WOol00`00Oomoo`0XOol0D5:JCWUBVTii
BYa:VdZLBY]:_DJLB[a6W4ZmA[a6gDJlB]e2_DKM@[e6gT;MA]i2gDKnA]e6oT;MA_i6gDKnA]e:oTKM
B_i6oD[nA_e;7TKmBai6oT/NA_e;7TKnBai6oD/NA_i;7TKmBai6oT/NA_i;7TKnBai6oT/NA_i;7TKn
Bai6oT/NA_i;7TLNBai6oT/NAai;7TKnBai77T/NA_h3Bah01DLNBai;7T/NAah00d/N00I77T/OBai;
7TLNBcl2Bah01TLNBcm;7T/NAai;?`9;7P06Aai;?d/NBai77T/o0T/N00I77T/oBai;7TLNBcl2Bah0
8TLNBcm;7T/NAai;?d/NBci;7T/oBai;?T/NBcm;7T/nBai;?d/NBci;7T/oBai;?T/NBcm;7T/n001;
?d/NBci;7T/o0goo00<007ooOol047oo000XOol00`00Oomoo`0WOol01DiiCWY>NTjJCWT014ZK0TJl
00E:_4JlA[e6_DKM0096_@E6g@0:A_i6gDKMA_e6oTKMA_i6oDKnA_d2A_h01D[nA_i6oTKnB_h00dKn
00Y:oTKnB_i6oT/NA_i;7TKnBai6oP=;7P05A_i;7T/NBai77P03Bah00dLNBai;7P1DBah00`00Bai;
7P03Bah3Ool00`00Oomoo`0@Ool002Uoo`03001oogoo02Moo`0BCWUBVTiiDYY:VdZLBY]:W4JLB[e6
W4ZlAYa:gDJlA]e6_4[N0TKM03e6_D[nA]e6oTKMB_i6gD[nA]e:oTKmB_i6gD[nA_e:oTKmBai6oD/N
A_e;7TKnBai6oD/NA_i;7TKmBai6oT/NA_e;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/N
Aai;7TKnBai77T/NAai;7TLNBai77P03Bah01DLNBai;7T/NAah00d/N00I77T/OBai;7TLNBcl2Bah0
1TLNBcm;7T/NAai;?`9;7P06Aai;?d/NBai77T/o0T/N02U77T/oBai;7TLNBcm;7T/nAai;?d/NBci;
7T/oBai;?T/NBcm;7T/nBai;?d/NBci;7T/oBai;?T/NBcm;7T/nBai;?`00Bci;7T/oBai;?T/N009o
o`03001oogoo011oo`00:Woo00<007ooOol09Woo00AF^UJIEYUFV@E>^`E:_0M:g@0MA]e:oDKMB_i6
gD[mA_e:oTKmB_i6oT[nA_e:oTKnB_i6oT[nA_i;7TKnB_i6oT/NA_i;7T[nBai6oP03Bah01DKnBai;
7T/NA_h0G4/N00<004/NBah014/N0Woo00<007ooOol047oo000[Ool00`00Oomoo`0UOol0CeJIE[YF
VEJjEYUB^djKD[]>VdkLB[a>g4ZlC]a6_4[MB[a:gDKMB_i6gD[MA]e:oTKMB_i6gD[nA]e:oTKMB_i6
oD[nA_e:oTKmBai6oD/NA_i;7TKmBai6oT/NA_e;7TKnBai6oD/NA_i;7TKmBai6oT/NA_e;7TKnBai6
oT/NAai;7TKnBai77T/NA_i;7TLNBai6oT/NAai;7TLN00=;7P05Aai;7T/NBai77P03Bah01TLNBcm;
7T/NAai;?`9;7P06Aai;?d/NBai77T/o0T/N00I77T/oBai;7TLNBcl2Bah01TLNBcm;7T/NAai;?`=;
7P0RBcm;7T/nBai;?d/NBci;7T/oBai;?T/NBcm;7T/nBai;?d/NBci;7T/oBai;?T/NBcm;7T/nBah0
04/NBci;7T/oBah2Ool00`00Oomoo`0@Ool002aoo`03001oogoo02Eoo`04EYUF^UJIEYT5C[/4C]`0
1DkMB]a:gD[MC]d00d[M00=:oD[MB_d00T[m00E:gD[nB_e:oT[m00=:oP05B_e:oT[nB_i6oP02B_h0
2T/NA_i:oT[nBai:oT/NB_i;7T[nHd/N00<004/NBah00d/N0Woo00<007ooOol047oo000]Ool00`00
Oomoo`0TOol0@5JjEYUN^EZiG]UB^UKKD[YFfe:jC]a>^e;LC[a>gD[LC_e:g4[mB]e:oD[MB_e6gD[n
B]e:oTKMB_i6oD[nA]e;7TKmB_i6oD/NA_e;7TKmBai6oD/NA_e;7TKnBai6oD/NA_i;7TKmBai6oT/N
A_e;7TKnBai6oT/NA_i;7TKn0d/N00E6oT/NBai;7TKn00=;7P05A_i;7T/NBai77P03Bah01DLNBai;
7T/NAah00d/N00I77T/oBai;7TLNBcl2Bah01TLNBcm;7T/NAai;?`9;7P03Aai;?d/N009;7P05Bcm;
7T/NBai;?`03Bah09d/oBai;?T/NBcm;7T/nBai;?d/NBci;7T/oBai;?T/NBcm;7T/nBai;?d/NBci;
7T/oBai;?T/NBcm;7P00Bai;?d/NBci;7T/oOol0000BOol002ioo`03001oogoo02=oo`=J^@05G[UJ
^E:kD[]Ff`02D[/4C]`00d[MC]e:g002B]d00dkmB]e>o@07B_d014[nB_e:oT[m0d[n00U:oD[nB_i;
7T[nBai:oT/NB_h00d/N00E:oT/NBai;7T[n069;7P03001;7T/N00=;7P03Ool007oo015oo`00;goo
00<007ooOol08goo03eJ^EkIF[UN^EZiE]]B^U[KE[YJfe;KD]aBfe;lC]a>oDkLC_e>g4kmB]e>oD[M
B_i:gDknB_e:oT[mBai:oD[nA_e;7T[mBai6oD/NB_e;7TKmBai6oD/NA_e;7T[nBai6oD/NB_i;7TKm
Bai:oT/NA_e;7T[nBai6oP03Bah01DKnBai;7T/NA_h00d/N00E77T/NBai;7TLN00=;7P05Aai;7T/N
Bai77P03Bah01TLNBai;7T/NAai;?P9;7P03Aai;?d/N009;7P05Bcm;7T/NBai;?`03Bah01D/oBai;
7T/NBcl00d/N02U;?d/NBci;7T/oBai;?T/NBcm;7T/nBai;?d/NBci;7T/oBai;?T/NBcm;7T/nBai;
?d/NBci;7T/oBai;?T/NBcl004/nBai;?d/NBcioo`00019oo`00<7oo00<007ooOol08Woo00YN^EZi
F[UJ^EjiE]YFfeKJF]]FfPEBg00>C]a>oDkLC]e:oDkmB]e>oD[mC_e:oDkmB_e:oP=:o@05B_i:oD[n
B_e;7P03B_h01T/NB_i;7T[nBai:oP=;7P03B_i;7T/N069;7P03001;7T/N00=;7P03Ool007oo015o
o`00<Goo00<007ooOol08Woo01=N^EZiH]UN^5[KE[YJfeKJF]]F^UKlD]]Fo5;KD_e>g5;mC]aBo@02
C_d09D[LC_e:oDknB_e>oT[mCai:oDlNB_e;7T[mCai:oD/NB_e;7T[mBai:oD/NB_e;7T[mBai:oT/N
B_e;7T[nBai:oD/NB_i;7TKm00=;7P05A_i;7T/NBai6oP03Bah00dKnBai;7P09Bah01TLNBai;7T/N
Aai;?P9;7P03Aai;?T/N009;7P05Bci;7T/NBai;?`03Bah01D/oBai;7T/NBcl00d/N02m;?d/NBai;
7T/oBai;?T/NBcm;7T/nBai;?d/NBci;7T/oBai;?T/NBcm;7T/nBai;?d/NBci;7T/oBai;?T/NBcm;
7T/nBai;?d/NBch004/oBai;?T/NBcm;7P00019oo`00<Woo00<007ooOol08Goo00=NfF;IG]P00UkI
00YJfeKJE]]JfU[jD]]Fo5KKE_aBf`9Bo003D_e>g4km00A>o@0CB_e>oD[mC_e:oDknB_e>oD[mBai:
oD[nB_e;7T[mBai:oT/NB_h00d/N00E:oT/NBai;7T[n06=;7P03001;7T/N00=;7P03Ool007oo011o
o`00<goo00<007ooOol087oo03QRfEjhH]UN^6;IF]YNne[JG_]JfUkkD]]Fo5;KE_aBo5KmD_aBoE;l
Dae>o5;mC_aC7D[mCae:oDlNB_e?7T[mCai:oDlNB_e?7T[mBai:oDlNB_e;7T[mCai:oD/NB_e?7T[n
Bai:oD/NB_i;7T[m0d/N00E:oD/NBai;7T[n00=;7P03B_i;7T/N019;7P05Bci;7T/NBai;?P03Bah0
1D/oBai;7T/NBcl00d/N00E;?d/NBai;7T/o00=;7P0^Bcm;7T/NBai;?d/NBci;7T/oBai;?T/NBcm;
7T/nBai;?d/NBci;7T/oBai;?T/NBcm;7T/nBai;?d/NBci;7T/oBai;?T/NBcm;7P00Bai;?d/NBci;
7Woo000AOol003Aoo`03001oogoo021oo`9Nf@05H]URf6;HF]YJnP03F]X01E[lE_]FneKkF_`015;l
0dkm00=BoDkmC_d01Dkm00Y?7T[mC_e:oDlNB_e;7T[mBai:o@=;7P03B_i;7T/N06M;7P03001;7T/N
00=;7P03Ool007oo011oo`00=Goo0P0087oo03IN^6KiH]QVf6;HG_]JfUkkG]UNnUKkF_aFfe[lE_]J
o5;lE_eBo5;mC_aC7DklDae>o5<NC_e?7DkmCai:oDlNB_e?7T[mCai:oDlNB_e?7T[mCai:oDlNB_e?
7T[mBai:oDlNB_e;7T[mCah2Bah01D[mBai;7T/NB_d00d/N00=:oD/NBah04T/N00E;?T/NBai;7T/n
00=;7P05Bci;7T/NBai;?`03Bah01D/oBai;7T/NBcl00d/N031;?d/NBci;7T/oBai;?T/NBcm;7T/n
Bai;?d/NBci;7T/oBai;?T/NBcm;7T/nBai;?d/NBci;7T/oBai;?T/NBcm;7T/nBai;?d/NBci;7P00
Bai;?T/NBcm;7Woo000AOol003Moo`03001oogoo01eoo`06I]QRf6;HH]QVf6;H1Ekj00=Fne[lE_/0
0U[k00=Fo5;lE_`00UKl15;m0dkm00I?7DkmCae>oDlMC_d2Cad01TlNB_e?7T/NCai:oFa;7P03001;
7T/n00=;7P03001oogoo00moo`00>7oo00<007ooOol077oo00aRf6KHH]QVnF;HI_QNfEkjG]YNnUkI
Fa`3F_/0:E/LF_]G75;lEaeBo5<MD_aG7E;lDae>oE<MC_eC7D[mCai>oDlNB_e?7T[mCai:oDlNB_e?
7T[mCai:oDlNB_e?7T[mCai:oDlNBae;7T[mCah00T/N00I:oDlNBai;7T[mCah3Bah00dlNBai;7P0=
Bah01D/nBai;7T/NBch00d/N00E;?T/NBai;7T/n00=;7P05Bcm;7T/NBai;?`03Bah0;4/oBai;7T/N
Bcm;7T/nBai;?d/NBci;7T/oBai;?T/NBcm;7T/nBai;?d/NBci;7T/oBai;?T/NBcm;7T/nBai;?d/N
Bci;7T/oBai;?T/NBcm;7T/n0005Ool00`00Oomoo`0?Ool003Uoo`03001oogoo01]oo`9Rf005I]QR
f6KhI]QVn002G_X2H_X00f;iF_]Jn`03F_/00eKlEaaFo002E_`02U<MD_aC7E;mDae>oDlMC_eC7Dkm
0dlM00a>oDlNCae?7TkmCai;7TlNBae?7T/NCaiPBah7Ool00`00Oomoo`03Ool00`00Oomoo`0?Ool0
03Yoo`03001oogoo01]oo`0iI_URf6KhI]MZn6KGH_YNnF;jG_URnUkiGa]JnelKF_YO6eKlEaaFo5/L
D_aG7E;lEaeBo5LMC_eC7DkmDae>oE<NC_e?7T[mCai:oDlNB_e?7T[mCai:oDlNBae?7T[mCai;7DlN
B_e?7T/NCai:oDlN009;7P06B_e?7T/NBai;7DlN0d/N00E?7T/NBai;7TlN00=;7P05Cai;7T/NBai;
?P03Bah01D/nBai;7T/NBch00d/N00E;?T/NBai;7T/n00=;7P0LBci;7T/NBai;?d/NBci;7T/oBai;
?T/NBcm;7T/nBai;?d/NBci;7T/oBai;?T/NBcm;7T/nBahEOol00`00Oomoo`03Ool00`00Oomoo`0?
Ool003]oo`03001oogoo01Yoo`06H]QVn6KHI_QVf6[g0V;j01ERnF;jH_YRnE[kG_]JnelKF_]K75LL
FaaFo5/LDaaG7E;lEaeC75<MC_d00e<M0dlM00eC7DlMCae?7DlNCae?7TlMCai;7DlNBai?7P03Bah0
1DlNBai;7T/NCah0>d/N8goo00<007ooOol00Woo00<007ooOol03goo000lOol00`00Oomoo`0IOol0
@fKhI]MZn6KGI_QVef[hG_URnV;iIaYRnFLJF_YO6ekjGa]NnU/LE_aK75KkFaaBo5LMD_aG7E;lDaeB
o5<MD_eC7TkmDai>oDlNC_eC7TlMCai>oDlNCae?7T[mCai;7DlNB_e?7T/MCai:oDlNBai?7T[mCai;
7TlNBae?7T/NCai;7DlN00=;7P05Cai;7T/NBai?7P03Bah01DlnBai;7T/NCch00d/N00E??T/NBai;
7Tln00=;7P05Bci;7T/NBai;?P03Bah`Ool00`00Oomoo`02Ool00`00Oomoo`0?Ool003eoo`03001o
ogoo01Uoo`06I_QVf6KhJ_MZn6[g1V;i00=O6ekkGa/00UlK00QNne/LFaaK75/KFaaG75LM0ULL1U<M
00A?7E<MDae?7P=?7@06Cai?7DlNCae?7TlM0dlN00A?7DlNBai?7P=;7P03Cai;7T/N01i;7Saoo`03
001oogoo009oo`03001oogoo00moo`00?Woo00<007ooOol067oo04QVefKhI]MZn6KGK_MZmfLJH_UW
6V;iIaUNnUlKG_YO6ekjHa]Jne/LF_]K75[kFaeG75LME_aK7E<MEaeBo5LMCaeC7DkmDai?7E<NC_eC
7TlMDai>oDlNCae?7T[mCai;7DlNBae?7T/MCai;7DlNBae?7T/MCai;7TlNBae?7T/NCai;7DlNBai?
7T/MCah3Bah00dlnOomoo`18Ool01@00Oomoogoo00004Goo000oOol00`00Oomoo`0HOol00fKHJ_QZ
m`03J_L2H_T016KiIaUVnFLI0UlK00UO6V<KGaYS6e/KFaaK6elLFa/00ULL00MG7ELLEaeC7ELMDaeG
7@05Dad02U<NCae?7DlMCai?7DlNCae?7TlM0dlN00Q;7TlNCai?7T/NCai;7TlN0d/N00=?7T/NOol0
EGoo00D007ooOomoo`00015oo`00@7oo00<007ooOol05goo039Zn6KGJ_QZmfkgJ_M^mf;iIaUVnFLI
H_US6ekjHa]NnV<KG_YO75/KGaaK6elLEaaK7ELLFaeG75LMDaaG7E<LEae?7E<MCaeC7TlMDai?7E<N
Cae?7TlMDai?7DlNBae?7T/MHgoo00D007ooOomoo`00015oo`00@Goo00<007ooOol05Woo1V[g00Y^
mfLII_UW6FKiIaUVnF<KGaYS6`=S6P05GaaK6elKGa]O7003Ea`00e/LEaaG7@04Ead4Dad014lMDae?
7E<MJgoo00<007ooOol00Woo00<007ooOol03Woo0012Ool00`00Oomoo`0FOol08FKGK_MZmfkgJ_M_
5f[fIaUVn6/II_Q[6FKhHa]S6V<KGaYS6e/KGaaK6ellFa]K75LLFceG75/LEaaG?E<LEaeC701dOol0
1@00Oomoogoo000047oo0013Ool00`00Oomoo`0EOol01f[hJ_MZmf[gK_MZmVkg009W6@04I_UW6FLI
JaT6HaX00elKGaaO6`02Ga/5FaahOol01@00Oomoogoo000047oo0014Ool00`00Oomoo`0DOol06F[g
K_MZmfkgJ_I_5f[fJaUVn6/II_Q[6FLHJaUO6VLjHaYW6V<JHcaO6ellGa]S?5lK07aoo`05001oogoo
Ool0000@Ool004Eoo`03001oogoo01=oo`=Zm`08J_I^mfkgKaM^mVLIJaQ[6@=[60AS6P03IaYS6UlK
009O6gioo`05001oogooOol0000@Ool004Ioo`03001oogoo01=oo`0DK_MZmVlGJ_I_5fkfKaMVn6/I
IaQ[6FKhJaU[66LJHaUW>V<JIcYS6H5oo`04001oogoo000@Ool004Moo`03001oogoo019oo`04J_M^
mfkgK_L3K_H00g<FJaQ[6004JaP2IaX00f<JIaYW6P22Ool01000Oomoo`0047oo0018Ool00`00Oomo
o`0AOol02flGJ_I_5f[fKaM^mW<FK_I[6FKhJaT00V/H00E[5fLjHaYW>V<I08=oo`04001oogoo000@
Ool004Uoo`03001oogoo015oo`08K_MZmVkfK_I_5fkfKaI^mPA[6003KaQ[66LJ08Ioo`03001oo`00
011oo`00BWoo00<007ooOol047oo00QZmVlGK_Ic5fkfLaI^mW<F0f/H00=_66/HKaP0Qgoo00<007oo
000047oo001;Ool00`00Oomoo`0@Ool02VkfKaM^mVlFK_Ic5VkfLaI[66lH0V/HR7oo00<007oo0000
47oo001<Ool00`00Oomoo`0?Ool02g<GK_Ic5VkfLaI^mW<FK_E_66/HKaP0RGoo00<007oo000047oo
001=Ool00`00Oomoo`0>Ool3K_H00g<FK_Ic5P02LaH3JaR:Ool2000@Ool004ioo`03001oogoo00io
o`09K_Ic5VkfLaI^mG<FL_Ec5V/G08]oo`80011oo`00Cgoo00<007ooOol03Goo00=c5VkfKaH00W<F
00=^mW<FLaD0S7oo00<007oo00003goo001@Ool00`00Oomoo`0<Ool026kfLaI^mW<FK_Ec5VkeLaJ<
Ool00`00Ool0000?Ool0055oo`03001oogoo00aoo`06K_Ic5VkfLaIc5G<FSWoo0P003goo001BOol0
0`00Oomoo`0;Ool01W<FK_Ec5VkeLaIbmHioo`8000moo`00Dgoo0P002goo00I^mW<FLaIc5W;eLaJ>
Ool2000?Ool005Eoo`03001oogoo00Qoo`05LaI^mG<FL_Ec5P2?Ool2000?Ool005Ioo`03001oogoo
00Qoo`04LaIbmG<FLaF@Ool00`00Oomoo`0=Ool005Moo`03001oogoo00Moo`04L_Ec5VkeLaJ:Ool7
000?Ool005Qoo`03001oogoo00Ioo`03LaIc5G<F07eoo`h001Ioo`00FGoo00<007ooOol01Woo00=c
5W;eOol0Kgoo3@0097oo001JOol00`00Oomoo`05Ool00g;eLaIoo`1ROol=000aOol005]oo`03001o
ogoo00Aoo`03001oogoo05Aoo`h003ioo`00G7oo00<007ooOol00goo00<007ooOol0Agoo3@00C7oo
0014Ool3000FOol00`00Oomoo`02Ool00`00Oomoo`0jOol=001IOol004Eoo`03001oogoo01Ioo`05
001oogooOol0000^Ool>001VOol004Eoo`<001Moo`04001oogoo000QOol=001dOol004Eoo`04001o
ogoo000GOol00`00Ool0000DOol=0021Ool004Eoo`04001oogoo000HOol20006Ool>002>Ool004Ao
o`@001Yoo`L009aoo`00ogoo1Woo003oOol6Ool00?moo`Ioo`00ogoo1Woo003oOol6Ool00?moo`Io
o`00ogoo1Woo001lOol200000goo00000002Ool40003Ool20004Ool20004Ool20005Ool00`00Oomo
o`1UOol007eoo`03001oo`0000Uoo`04001oogoo0008Ool01000Oomoo`0017oo00<007ooOol0IGoo
001nOol00`00Oomoo`02Ool40002Ool01000Oomoo`0027oo00@007ooOol000Aoo`03001oogoo06Eo
o`00O7oo0P0000=oo`00000027oo00@007ooOol000Qoo`04001oogoo0005Ool00`00Oomoo`1TOol0
08Uoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol006Ioo`00RWoo0P002Woo0P000goo
1000IWoo003oOol6Ool00?moo`Ioo`00ogoo1Woo003oOol6Ool00001\
\>"],
  ImageRangeCache->{{{0, 260.563}, {184.125, 0}} -> {-0.170508, 0.0461608, \
0.00439067, 0.00439067}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .70824 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1.10169 -0.148196 1.10169 [
[.5 .72074 -20 0 ]
[.5 .72074 20 15 ]
[.44797 -0.02478 -4.90556 -15 ]
[.44797 -0.02478 5.09444 0 ]
[.15892 .66839 -5.31917 0 ]
[.15892 .66839 4.68083 15 ]
[-0.06694 .27471 -10 -6.62571 ]
[-0.06694 .27471 0 8.37429 ]
[ 0 0 0 0 ]
[ 1 .70824 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .72074 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.437500 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(=) show
75.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.08) show
99.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math1Mono
%%DocumentNeededResources: + font Courier
%%DocumentNeededFonts: Math1Mono
%%DocumentNeededFont: + Courier
%%DocumentFonts: font Math1Mono
%%DocumentFonts: + font Courier
grestore
.25 Mabswid
.02946 .11175 m
.89362 0 L
s
gsave
.44797 -0.02478 -65.9056 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(u) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
0 .4272 m
.29069 .70824 L
s
gsave
.15892 .66839 -66.3192 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(p) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.02946 .11175 m
0 .4272 L
s
gsave
-0.06694 .27471 -71 -10.6257 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(q) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.02946 .11175 m
0 .4272 L
s
0 .4272 m
.29069 .70824 L
s
.29069 .70824 m
.30155 .45044 L
s
.30155 .45044 m
.02946 .11175 L
s
.89362 0 m
.98022 .38351 L
s
.98022 .38351 m
1 .65325 L
s
1 .65325 m
.91448 .33294 L
s
.91448 .33294 m
.89362 0 L
s
.02946 .11175 m
0 .4272 L
s
0 .4272 m
.91448 .33294 L
s
.91448 .33294 m
.89362 0 L
s
.89362 0 m
.02946 .11175 L
s
.30155 .45044 m
.98022 .38351 L
s
.98022 .38351 m
1 .65325 L
s
1 .65325 m
.29069 .70824 L
s
.29069 .70824 m
.30155 .45044 L
s
0 0 m
1 0 L
1 .70824 L
0 .70824 L
closepath
clip
newpath
.909 .775 .701 r
.2853 .67311 .2914 .69147 .31332 .63266 .3072 .61852 Mtetra
.864 .788 .774 r
.3072 .61852 .31332 .63266 .33388 .60337 .32781 .5914 Mtetra
.813 .795 .835 r
.32781 .5914 .33388 .60337 .35392 .58671 .34793 .57599 Mtetra
.764 .796 .879 r
.34793 .57599 .35392 .58671 .37374 .57625 .36784 .56633 Mtetra
.722 .794 .908 r
.36784 .56633 .37374 .57625 .39348 .56915 .38769 .55976 Mtetra
.691 .791 .927 r
.38769 .55976 .39348 .56915 .41321 .56399 .40752 .55497 Mtetra
.667 .789 .94 r
.40752 .55497 .41321 .56399 .43295 .56001 .42738 .55126 Mtetra
.649 .788 .948 r
.42738 .55126 .43295 .56001 .45273 .55678 .44727 .54822 Mtetra
.636 .787 .954 r
.44727 .54822 .45273 .55678 .47256 .55404 .46722 .54563 Mtetra
.627 .787 .958 r
.46722 .54563 .47256 .55404 .49244 .55163 .48722 .54334 Mtetra
.62 .786 .961 r
.48722 .54334 .49244 .55163 .51237 .54945 .50728 .54124 Mtetra
.615 .787 .964 r
.50728 .54124 .51237 .54945 .53237 .54742 .52741 .53928 Mtetra
.611 .787 .966 r
.52741 .53928 .53237 .54742 .55244 .5455 .54759 .53741 Mtetra
.608 .787 .967 r
.54759 .53741 .55244 .5455 .57256 .54366 .56785 .53561 Mtetra
.605 .787 .968 r
.56785 .53561 .57256 .54366 .59276 .54187 .58817 .53385 Mtetra
.604 .788 .969 r
.58817 .53385 .59276 .54187 .61301 .54012 .60856 .53212 Mtetra
.602 .788 .97 r
.60856 .53212 .61301 .54012 .63334 .53839 .62901 .5304 Mtetra
.601 .789 .971 r
.62901 .5304 .63334 .53839 .65373 .53667 .64953 .5287 Mtetra
.6 .789 .971 r
.64953 .5287 .65373 .53667 .67419 .53497 .67013 .527 Mtetra
.599 .79 .972 r
.67013 .527 .67419 .53497 .69472 .53327 .69079 .5253 Mtetra
.69079 .5253 .69472 .53327 .71531 .53157 .71152 .5236 Mtetra
.598 .79 .972 r
.71152 .5236 .71531 .53157 .73598 .52987 .73232 .5219 Mtetra
.598 .791 .973 r
.73232 .5219 .73598 .52987 .75671 .52817 .75319 .52019 Mtetra
.597 .791 .973 r
.75319 .52019 .75671 .52817 .77751 .52646 .77413 .51847 Mtetra
.77413 .51847 .77751 .52646 .79839 .52475 .79514 .51675 Mtetra
.79514 .51675 .79839 .52475 .81933 .52303 .81622 .51502 Mtetra
.597 .792 .974 r
.81622 .51502 .81933 .52303 .84034 .5213 .83737 .51327 Mtetra
.83737 .51327 .84034 .5213 .86142 .51956 .8586 .51152 Mtetra
.8586 .51152 .86142 .51956 .88258 .51781 .87989 .50976 Mtetra
.596 .792 .974 r
.87989 .50976 .88258 .51781 .9038 .51606 .90126 .50799 Mtetra
.596 .793 .974 r
.90126 .50799 .9038 .51606 .9251 .51429 .9227 .5062 Mtetra
.9227 .5062 .9251 .51429 .94646 .51252 .94422 .50441 Mtetra
.94422 .50441 .94646 .51252 .9679 .51074 .9658 .50261 Mtetra
.596 .793 .975 r
.9658 .50261 .9679 .51074 .98942 .50894 .98746 .5008 Mtetra
.902 .773 .708 r
.27914 .65458 .2853 .67311 .3072 .61852 .30101 .60423 Mtetra
.855 .785 .782 r
.30101 .60423 .3072 .61852 .32781 .5914 .32167 .57928 Mtetra
.802 .791 .842 r
.32167 .57928 .32781 .5914 .34793 .57599 .34186 .56514 Mtetra
.753 .792 .884 r
.34186 .56514 .34793 .57599 .36784 .56633 .36187 .55628 Mtetra
.713 .79 .912 r
.36187 .55628 .36784 .56633 .38769 .55976 .38182 .55025 Mtetra
.683 .788 .93 r
.38182 .55025 .38769 .55976 .40752 .55497 .40176 .54583 Mtetra
.66 .786 .941 r
.40176 .54583 .40752 .55497 .42738 .55126 .42173 .54239 Mtetra
.644 .785 .949 r
.42173 .54239 .42738 .55126 .44727 .54822 .44175 .53956 Mtetra
.632 .785 .955 r
.44175 .53956 .44727 .54822 .46722 .54563 .46181 .53712 Mtetra
.624 .785 .959 r
.46181 .53712 .46722 .54563 .48722 .54334 .48194 .53494 Mtetra
.617 .785 .962 r
.48194 .53494 .48722 .54334 .50728 .54124 .50212 .53293 Mtetra
.612 .785 .964 r
.50212 .53293 .50728 .54124 .52741 .53928 .52237 .53103 Mtetra
.609 .786 .966 r
.52237 .53103 .52741 .53928 .54759 .53741 .54269 .52921 Mtetra
.606 .786 .967 r
.54269 .52921 .54759 .53741 .56785 .53561 .56307 .52745 Mtetra
.604 .787 .968 r
.56307 .52745 .56785 .53561 .58817 .53385 .58352 .52572 Mtetra
.602 .787 .969 r
.58352 .52572 .58817 .53385 .60856 .53212 .60404 .52401 Mtetra
.601 .788 .97 r
.60404 .52401 .60856 .53212 .62901 .5304 .62462 .52231 Mtetra
.6 .788 .971 r
.62462 .52231 .62901 .5304 .64953 .5287 .64528 .52061 Mtetra
.599 .789 .971 r
.64528 .52061 .64953 .5287 .67013 .527 .66601 .51892 Mtetra
.599 .789 .972 r
.66601 .51892 .67013 .527 .69079 .5253 .6868 .51723 Mtetra
.598 .79 .972 r
.6868 .51723 .69079 .5253 .71152 .5236 .70767 .51552 Mtetra
.70767 .51552 .71152 .5236 .73232 .5219 .72861 .51382 Mtetra
.597 .79 .973 r
.72861 .51382 .73232 .5219 .75319 .52019 .74962 .5121 Mtetra
.597 .791 .973 r
.74962 .5121 .75319 .52019 .77413 .51847 .7707 .51037 Mtetra
.7707 .51037 .77413 .51847 .79514 .51675 .79185 .50864 Mtetra
.79185 .50864 .79514 .51675 .81622 .51502 .81307 .50689 Mtetra
.597 .792 .974 r
.81307 .50689 .81622 .51502 .83737 .51327 .83436 .50514 Mtetra
.596 .792 .974 r
.83436 .50514 .83737 .51327 .8586 .51152 .85573 .50337 Mtetra
.85573 .50337 .8586 .51152 .87989 .50976 .87717 .50159 Mtetra
.87717 .50159 .87989 .50976 .90126 .50799 .89869 .4998 Mtetra
.89869 .4998 .90126 .50799 .9227 .5062 .92027 .498 Mtetra
.596 .793 .974 r
.92027 .498 .9227 .5062 .94422 .50441 .94193 .49619 Mtetra
.94193 .49619 .94422 .50441 .9658 .50261 .96367 .49437 Mtetra
.596 .793 .975 r
.96367 .49437 .9658 .50261 .98746 .5008 .98548 .49254 Mtetra
.894 .77 .717 r
.27293 .63586 .27914 .65458 .30101 .60423 .29476 .58977 Mtetra
.844 .781 .79 r
.29476 .58977 .30101 .60423 .32167 .57928 .31545 .56702 Mtetra
.791 .787 .849 r
.31545 .56702 .32167 .57928 .34186 .56514 .33572 .55416 Mtetra
.742 .787 .889 r
.33572 .55416 .34186 .56514 .36187 .55628 .35582 .54611 Mtetra
.704 .786 .915 r
.35582 .54611 .36187 .55628 .38182 .55025 .37587 .54062 Mtetra
.675 .784 .932 r
.37587 .54062 .38182 .55025 .40176 .54583 .39593 .53658 Mtetra
.654 .783 .943 r
.39593 .53658 .40176 .54583 .42173 .54239 .41601 .53341 Mtetra
.639 .783 .95 r
.41601 .53341 .42173 .54239 .44175 .53956 .43614 .53078 Mtetra
.628 .783 .956 r
.43614 .53078 .44175 .53956 .46181 .53712 .45633 .52849 Mtetra
.62 .783 .96 r
.45633 .52849 .46181 .53712 .48194 .53494 .47658 .52642 Mtetra
.614 .784 .962 r
.47658 .52642 .48194 .53494 .50212 .53293 .49689 .5245 Mtetra
.61 .784 .965 r
.49689 .5245 .50212 .53293 .52237 .53103 .51727 .52267 Mtetra
.607 .785 .966 r
.51727 .52267 .52237 .53103 .54269 .52921 .53771 .5209 Mtetra
.604 .785 .968 r
.53771 .5209 .54269 .52921 .56307 .52745 .55822 .51918 Mtetra
.603 .786 .969 r
.55822 .51918 .56307 .52745 .58352 .52572 .57881 .51748 Mtetra
.601 .787 .969 r
.57881 .51748 .58352 .52572 .60404 .52401 .59946 .51579 Mtetra
.6 .787 .97 r
.59946 .51579 .60404 .52401 .62462 .52231 .62018 .5141 Mtetra
.599 .788 .971 r
.62018 .5141 .62462 .52231 .64528 .52061 .64097 .51242 Mtetra
.598 .788 .971 r
.64097 .51242 .64528 .52061 .66601 .51892 .66183 .51073 Mtetra
.598 .789 .972 r
.66183 .51073 .66601 .51892 .6868 .51723 .68276 .50904 Mtetra
.68276 .50904 .6868 .51723 .70767 .51552 .70377 .50733 Mtetra
.597 .79 .973 r
.70377 .50733 .70767 .51552 .72861 .51382 .72485 .50562 Mtetra
.72485 .50562 .72861 .51382 .74962 .5121 .74599 .5039 Mtetra
.74599 .5039 .74962 .5121 .7707 .51037 .76722 .50216 Mtetra
.596 .791 .973 r
.76722 .50216 .7707 .51037 .79185 .50864 .78851 .50041 Mtetra
.596 .791 .974 r
.78851 .50041 .79185 .50864 .81307 .50689 .80987 .49866 Mtetra
.80987 .49866 .81307 .50689 .83436 .50514 .83131 .49689 Mtetra
.596 .792 .974 r
.83131 .49689 .83436 .50514 .85573 .50337 .85283 .4951 Mtetra
.85283 .4951 .85573 .50337 .87717 .50159 .87441 .49331 Mtetra
.87441 .49331 .87717 .50159 .89869 .4998 .89607 .4915 Mtetra
.89607 .4915 .89869 .4998 .92027 .498 .91781 .48968 Mtetra
.596 .793 .974 r
.91781 .48968 .92027 .498 .94193 .49619 .93962 .48785 Mtetra
.93962 .48785 .94193 .49619 .96367 .49437 .96151 .48601 Mtetra
.596 .793 .975 r
.96151 .48601 .96367 .49437 .98548 .49254 .98347 .48416 Mtetra
.885 .766 .726 r
.26665 .61696 .27293 .63586 .29476 .58977 .28843 .57515 Mtetra
.833 .777 .799 r
.28843 .57515 .29476 .58977 .31545 .56702 .30916 .55461 Mtetra
.778 .782 .856 r
.30916 .55461 .31545 .56702 .33572 .55416 .3295 .54304 Mtetra
.731 .782 .894 r
.3295 .54304 .33572 .55416 .35582 .54611 .34969 .53581 Mtetra
.694 .782 .918 r
.34969 .53581 .35582 .54611 .37587 .54062 .36985 .53086 Mtetra
.667 .781 .934 r
.36985 .53086 .37587 .54062 .39593 .53658 .39001 .5272 Mtetra
.647 .78 .945 r
.39001 .5272 .39593 .53658 .41601 .53341 .41022 .52431 Mtetra
.634 .78 .952 r
.41022 .52431 .41601 .53341 .43614 .53078 .43047 .52188 Mtetra
.624 .781 .957 r
.43047 .52188 .43614 .53078 .45633 .52849 .45078 .51974 Mtetra
.617 .781 .96 r
.45078 .51974 .45633 .52849 .47658 .52642 .47115 .51779 Mtetra
.612 .782 .963 r
.47115 .51779 .47658 .52642 .49689 .5245 .49159 .51595 Mtetra
.608 .783 .965 r
.49159 .51595 .49689 .5245 .51727 .52267 .51209 .51419 Mtetra
.605 .784 .966 r
.51209 .51419 .51727 .52267 .53771 .5209 .53267 .51248 Mtetra
.603 .784 .968 r
.53267 .51248 .53771 .5209 .55822 .51918 .55331 .51079 Mtetra
.601 .785 .969 r
.55331 .51079 .55822 .51918 .57881 .51748 .57403 .50912 Mtetra
.6 .786 .97 r
.57403 .50912 .57881 .51748 .59946 .51579 .59481 .50745 Mtetra
.599 .787 .97 r
.59481 .50745 .59946 .51579 .62018 .5141 .61567 .50578 Mtetra
.598 .787 .971 r
.61567 .50578 .62018 .5141 .64097 .51242 .6366 .50411 Mtetra
.598 .788 .971 r
.6366 .50411 .64097 .51242 .66183 .51073 .6576 .50243 Mtetra
.597 .788 .972 r
.6576 .50243 .66183 .51073 .68276 .50904 .67867 .50073 Mtetra
.597 .789 .972 r
.67867 .50073 .68276 .50904 .70377 .50733 .69981 .49903 Mtetra
.597 .789 .973 r
.69981 .49903 .70377 .50733 .72485 .50562 .72103 .49731 Mtetra
.596 .79 .973 r
.72103 .49731 .72485 .50562 .74599 .5039 .74232 .49558 Mtetra
.74232 .49558 .74599 .5039 .76722 .50216 .76369 .49383 Mtetra
.596 .791 .973 r
.76369 .49383 .76722 .50216 .78851 .50041 .78512 .49208 Mtetra
.596 .791 .974 r
.78512 .49208 .78851 .50041 .80987 .49866 .80663 .4903 Mtetra
.80663 .4903 .80987 .49866 .83131 .49689 .82822 .48852 Mtetra
.82822 .48852 .83131 .49689 .85283 .4951 .84988 .48672 Mtetra
.596 .792 .974 r
.84988 .48672 .85283 .4951 .87441 .49331 .87162 .48491 Mtetra
.87162 .48491 .87441 .49331 .89607 .4915 .89343 .48308 Mtetra
.89343 .48308 .89607 .4915 .91781 .48968 .91531 .48125 Mtetra
.91531 .48125 .91781 .48968 .93962 .48785 .93727 .4794 Mtetra
.596 .793 .974 r
.93727 .4794 .93962 .48785 .96151 .48601 .95931 .47753 Mtetra
.596 .793 .975 r
.95931 .47753 .96151 .48601 .98347 .48416 .98143 .47566 Mtetra
.874 .762 .736 r
.26031 .59787 .26665 .61696 .28843 .57515 .28203 .56037 Mtetra
.819 .772 .808 r
.28203 .56037 .28843 .57515 .30916 .55461 .30279 .54206 Mtetra
.764 .776 .863 r
.30279 .54206 .30916 .55461 .3295 .54304 .3232 .53179 Mtetra
.718 .777 .899 r
.3232 .53179 .3295 .54304 .34969 .53581 .34349 .52537 Mtetra
.683 .777 .922 r
.34349 .52537 .34969 .53581 .36985 .53086 .36375 .52098 Mtetra
.658 .777 .936 r
.36375 .52098 .36985 .53086 .39001 .5272 .38402 .5177 Mtetra
.641 .777 .946 r
.38402 .5177 .39001 .5272 .41022 .52431 .40434 .51508 Mtetra
.628 .778 .953 r
.40434 .51508 .41022 .52431 .43047 .52188 .42472 .51286 Mtetra
.619 .779 .957 r
.42472 .51286 .43047 .52188 .45078 .51974 .44515 .51088 Mtetra
.613 .78 .961 r
.44515 .51088 .45078 .51974 .47115 .51779 .46565 .50904 Mtetra
.609 .781 .963 r
.46565 .50904 .47115 .51779 .49159 .51595 .48622 .50729 Mtetra
.605 .782 .965 r
.48622 .50729 .49159 .51595 .51209 .51419 .50685 .5056 Mtetra
.603 .783 .967 r
.50685 .5056 .51209 .51419 .53267 .51248 .52756 .50394 Mtetra
.601 .784 .968 r
.52756 .50394 .53267 .51248 .55331 .51079 .54833 .5023 Mtetra
.6 .784 .969 r
.54833 .5023 .55331 .51079 .57403 .50912 .56918 .50065 Mtetra
.599 .785 .97 r
.56918 .50065 .57403 .50912 .59481 .50745 .59011 .49901 Mtetra
.598 .786 .97 r
.59011 .49901 .59481 .50745 .61567 .50578 .6111 .49735 Mtetra
.597 .787 .971 r
.6111 .49735 .61567 .50578 .6366 .50411 .63217 .49569 Mtetra
.597 .787 .972 r
.63217 .49569 .6366 .50411 .6576 .50243 .6533 .49401 Mtetra
.597 .788 .972 r
.6533 .49401 .6576 .50243 .67867 .50073 .67452 .49231 Mtetra
.596 .789 .972 r
.67452 .49231 .67867 .50073 .69981 .49903 .6958 .49061 Mtetra
.596 .789 .973 r
.6958 .49061 .69981 .49903 .72103 .49731 .71716 .48888 Mtetra
.71716 .48888 .72103 .49731 .74232 .49558 .7386 .48714 Mtetra
.596 .79 .973 r
.7386 .48714 .74232 .49558 .76369 .49383 .76011 .48539 Mtetra
.76011 .48539 .76369 .49383 .78512 .49208 .78169 .48362 Mtetra
.596 .791 .974 r
.78169 .48362 .78512 .49208 .80663 .4903 .80335 .48183 Mtetra
.80335 .48183 .80663 .4903 .82822 .48852 .82508 .48003 Mtetra
.82508 .48003 .82822 .48852 .84988 .48672 .84689 .47822 Mtetra
.596 .792 .974 r
.84689 .47822 .84988 .48672 .87162 .48491 .86878 .47639 Mtetra
.86878 .47639 .87162 .48491 .89343 .48308 .89074 .47455 Mtetra
.89074 .47455 .89343 .48308 .91531 .48125 .91278 .47269 Mtetra
.91278 .47269 .91531 .48125 .93727 .4794 .93489 .47082 Mtetra
.596 .793 .975 r
.93489 .47082 .93727 .4794 .95931 .47753 .95709 .46893 Mtetra
.95709 .46893 .95931 .47753 .98143 .47566 .97936 .46704 Mtetra
.861 .757 .746 r
.25391 .57859 .26031 .59787 .28203 .56037 .27556 .54542 Mtetra
.804 .766 .818 r
.27556 .54542 .28203 .56037 .30279 .54206 .29635 .52935 Mtetra
.75 .77 .87 r
.29635 .52935 .30279 .54206 .3232 .53179 .31682 .52039 Mtetra
.705 .771 .904 r
.31682 .52039 .3232 .53179 .34349 .52537 .3372 .5148 Mtetra
.673 .772 .925 r
.3372 .5148 .34349 .52537 .36375 .52098 .35756 .51096 Mtetra
.65 .773 .938 r
.35756 .51096 .36375 .52098 .38402 .5177 .37795 .50808 Mtetra
.634 .774 .947 r
.37795 .50808 .38402 .5177 .40434 .51508 .39839 .50574 Mtetra
.623 .775 .954 r
.39839 .50574 .40434 .51508 .42472 .51286 .41889 .50372 Mtetra
.615 .776 .958 r
.41889 .50372 .42472 .51286 .44515 .51088 .43944 .50189 Mtetra
.61 .778 .961 r
.43944 .50189 .44515 .51088 .46565 .50904 .46007 .50017 Mtetra
.606 .779 .964 r
.46007 .50017 .46565 .50904 .48622 .50729 .48077 .49852 Mtetra
.603 .78 .966 r
.48077 .49852 .48622 .50729 .50685 .5056 .50154 .49689 Mtetra
.601 .782 .967 r
.50154 .49689 .50685 .5056 .52756 .50394 .52238 .49529 Mtetra
.599 .783 .968 r
.52238 .49529 .52756 .50394 .54833 .5023 .54329 .49368 Mtetra
.598 .784 .969 r
.54329 .49368 .54833 .5023 .56918 .50065 .56427 .49206 Mtetra
.598 .785 .97 r
.56427 .49206 .56918 .50065 .59011 .49901 .58533 .49044 Mtetra
.597 .786 .971 r
.58533 .49044 .59011 .49901 .6111 .49735 .60646 .4888 Mtetra
.60646 .4888 .6111 .49735 .63217 .49569 .62767 .48714 Mtetra
.596 .787 .972 r
.62767 .48714 .63217 .49569 .6533 .49401 .64895 .48547 Mtetra
.596 .788 .972 r
.64895 .48547 .6533 .49401 .67452 .49231 .67031 .48378 Mtetra
.67031 .48378 .67452 .49231 .6958 .49061 .69174 .48206 Mtetra
.596 .789 .973 r
.69174 .48206 .6958 .49061 .71716 .48888 .71324 .48034 Mtetra
.71324 .48034 .71716 .48888 .7386 .48714 .73482 .47859 Mtetra
.595 .79 .973 r
.73482 .47859 .7386 .48714 .76011 .48539 .75648 .47682 Mtetra
.75648 .47682 .76011 .48539 .78169 .48362 .77821 .47504 Mtetra
.595 .79 .974 r
.77821 .47504 .78169 .48362 .80335 .48183 .80002 .47324 Mtetra
.595 .791 .974 r
.80002 .47324 .80335 .48183 .82508 .48003 .8219 .47143 Mtetra
.8219 .47143 .82508 .48003 .84689 .47822 .84386 .46959 Mtetra
.84386 .46959 .84689 .47822 .86878 .47639 .8659 .46775 Mtetra
.595 .792 .974 r
.8659 .46775 .86878 .47639 .89074 .47455 .88801 .46588 Mtetra
.88801 .46588 .89074 .47455 .91278 .47269 .91021 .46401 Mtetra
.91021 .46401 .91278 .47269 .93489 .47082 .93248 .46212 Mtetra
.595 .792 .975 r
.93248 .46212 .93489 .47082 .95709 .46893 .95483 .46021 Mtetra
.595 .793 .975 r
.95483 .46021 .95709 .46893 .97936 .46704 .97726 .45829 Mtetra
.847 .751 .757 r
.24744 .55913 .25391 .57859 .27556 .54542 .26902 .5303 Mtetra
.787 .759 .827 r
.26902 .5303 .27556 .54542 .29635 .52935 .28982 .51648 Mtetra
.733 .763 .877 r
.28982 .51648 .29635 .52935 .31682 .52039 .31037 .50885 Mtetra
.691 .765 .908 r
.31037 .50885 .31682 .52039 .3372 .5148 .33083 .5041 Mtetra
.661 .767 .928 r
.33083 .5041 .3372 .5148 .35756 .51096 .3513 .50082 Mtetra
.641 .768 .94 r
.3513 .50082 .35756 .51096 .37795 .50808 .3718 .49832 Mtetra
.627 .77 .949 r
.3718 .49832 .37795 .50808 .39839 .50574 .39236 .49627 Mtetra
.617 .772 .955 r
.39236 .49627 .39839 .50574 .41889 .50372 .41298 .49446 Mtetra
.611 .774 .959 r
.41298 .49446 .41889 .50372 .43944 .50189 .43366 .49278 Mtetra
.606 .776 .962 r
.43366 .49278 .43944 .50189 .46007 .50017 .45442 .49118 Mtetra
.603 .778 .964 r
.45442 .49118 .46007 .50017 .48077 .49852 .47525 .48962 Mtetra
.601 .779 .966 r
.47525 .48962 .48077 .49852 .50154 .49689 .49615 .48806 Mtetra
.599 .781 .967 r
.49615 .48806 .50154 .49689 .52238 .49529 .51712 .48651 Mtetra
.598 .782 .968 r
.51712 .48651 .52238 .49529 .54329 .49368 .53817 .48494 Mtetra
.597 .783 .969 r
.53817 .48494 .54329 .49368 .56427 .49206 .55929 .48336 Mtetra
.596 .784 .97 r
.55929 .48336 .56427 .49206 .58533 .49044 .58049 .48175 Mtetra
.596 .785 .971 r
.58049 .48175 .58533 .49044 .60646 .4888 .60176 .48013 Mtetra
.596 .786 .971 r
.60176 .48013 .60646 .4888 .62767 .48714 .62311 .47848 Mtetra
.595 .787 .972 r
.62311 .47848 .62767 .48714 .64895 .48547 .64454 .47681 Mtetra
.64454 .47681 .64895 .48547 .67031 .48378 .66604 .47512 Mtetra
.595 .788 .972 r
.66604 .47512 .67031 .48378 .69174 .48206 .68761 .4734 Mtetra
.595 .788 .973 r
.68761 .4734 .69174 .48206 .71324 .48034 .70926 .47167 Mtetra
.595 .789 .973 r
.70926 .47167 .71324 .48034 .73482 .47859 .73099 .46991 Mtetra
.73099 .46991 .73482 .47859 .75648 .47682 .75279 .46813 Mtetra
.595 .79 .973 r
.75279 .46813 .75648 .47682 .77821 .47504 .77468 .46634 Mtetra
.595 .79 .974 r
.77468 .46634 .77821 .47504 .80002 .47324 .79663 .46453 Mtetra
.595 .791 .974 r
.79663 .46453 .80002 .47324 .8219 .47143 .81867 .46269 Mtetra
.81867 .46269 .8219 .47143 .84386 .46959 .84079 .46084 Mtetra
.84079 .46084 .84386 .46959 .8659 .46775 .86298 .45898 Mtetra
.595 .792 .974 r
.86298 .45898 .8659 .46775 .88801 .46588 .88525 .4571 Mtetra
.88525 .4571 .88801 .46588 .91021 .46401 .9076 .4552 Mtetra
.9076 .4552 .91021 .46401 .93248 .46212 .93003 .45329 Mtetra
.595 .792 .975 r
.93003 .45329 .93248 .46212 .95483 .46021 .95254 .45136 Mtetra
.595 .793 .975 r
.95254 .45136 .95483 .46021 .97726 .45829 .97513 .44942 Mtetra
.829 .743 .769 r
.24091 .53946 .24744 .55913 .26902 .5303 .2624 .51501 Mtetra
.768 .75 .837 r
.2624 .51501 .26902 .5303 .28982 .51648 .28322 .50346 Mtetra
.716 .755 .883 r
.28322 .50346 .28982 .51648 .31037 .50885 .30383 .49715 Mtetra
.677 .758 .912 r
.30383 .49715 .31037 .50885 .33083 .5041 .32438 .49325 Mtetra
.65 .761 .931 r
.32438 .49325 .33083 .5041 .3513 .50082 .34495 .49053 Mtetra
.632 .764 .942 r
.34495 .49053 .3513 .50082 .3718 .49832 .36557 .48844 Mtetra
.62 .767 .95 r
.36557 .48844 .3718 .49832 .39236 .49627 .38624 .48667 Mtetra
.612 .769 .956 r
.38624 .48667 .39236 .49627 .41298 .49446 .40699 .48506 Mtetra
.606 .772 .959 r
.40699 .48506 .41298 .49446 .43366 .49278 .4278 .48355 Mtetra
.602 .774 .962 r
.4278 .48355 .43366 .49278 .45442 .49118 .44869 .48207 Mtetra
.6 .776 .965 r
.44869 .48207 .45442 .49118 .47525 .48962 .46965 .48059 Mtetra
.598 .778 .966 r
.46965 .48059 .47525 .48962 .49615 .48806 .49068 .47911 Mtetra
.597 .78 .968 r
.49068 .47911 .49615 .48806 .51712 .48651 .51179 .47761 Mtetra
.596 .781 .969 r
.51179 .47761 .51712 .48651 .53817 .48494 .53298 .47608 Mtetra
.596 .782 .969 r
.53298 .47608 .53817 .48494 .55929 .48336 .55424 .47453 Mtetra
.595 .783 .97 r
.55424 .47453 .55929 .48336 .58049 .48175 .57558 .47294 Mtetra
.595 .784 .971 r
.57558 .47294 .58049 .48175 .60176 .48013 .597 .47133 Mtetra
.595 .785 .971 r
.597 .47133 .60176 .48013 .62311 .47848 .61849 .46969 Mtetra
.595 .786 .972 r
.61849 .46969 .62311 .47848 .64454 .47681 .64006 .46803 Mtetra
.595 .787 .972 r
.64006 .46803 .64454 .47681 .66604 .47512 .6617 .46633 Mtetra
.595 .788 .972 r
.6617 .46633 .66604 .47512 .68761 .4734 .68343 .46462 Mtetra
.595 .788 .973 r
.68343 .46462 .68761 .4734 .70926 .47167 .70523 .46287 Mtetra
.595 .789 .973 r
.70523 .46287 .70926 .47167 .73099 .46991 .7271 .46111 Mtetra
.7271 .46111 .73099 .46991 .75279 .46813 .74906 .45932 Mtetra
.595 .79 .973 r
.74906 .45932 .75279 .46813 .77468 .46634 .77109 .45751 Mtetra
.595 .79 .974 r
.77109 .45751 .77468 .46634 .79663 .46453 .7932 .45568 Mtetra
.7932 .45568 .79663 .46453 .81867 .46269 .8154 .45384 Mtetra
.595 .791 .974 r
.8154 .45384 .81867 .46269 .84079 .46084 .83767 .45197 Mtetra
.83767 .45197 .84079 .46084 .86298 .45898 .86001 .45008 Mtetra
.86001 .45008 .86298 .45898 .88525 .4571 .88244 .44818 Mtetra
.595 .792 .974 r
.88244 .44818 .88525 .4571 .9076 .4552 .90495 .44626 Mtetra
.90495 .44626 .9076 .4552 .93003 .45329 .92754 .44433 Mtetra
.595 .792 .975 r
.92754 .44433 .93003 .45329 .95254 .45136 .95021 .44238 Mtetra
.95021 .44238 .95254 .45136 .97513 .44942 .97296 .44041 Mtetra
.808 .733 .781 r
.23431 .5196 .24091 .53946 .2624 .51501 .2557 .49953 Mtetra
.746 .74 .847 r
.2557 .49953 .2624 .51501 .28322 .50346 .27653 .49028 Mtetra
.696 .746 .89 r
.27653 .49028 .28322 .50346 .30383 .49715 .2972 .48531 Mtetra
.661 .751 .917 r
.2972 .48531 .30383 .49715 .32438 .49325 .31785 .48226 Mtetra
.638 .755 .933 r
.31785 .48226 .32438 .49325 .34495 .49053 .33852 .48012 Mtetra
.622 .759 .944 r
.33852 .48012 .34495 .49053 .36557 .48844 .35925 .47842 Mtetra
.612 .763 .951 r
.35925 .47842 .36557 .48844 .38624 .48667 .38005 .47693 Mtetra
.606 .767 .957 r
.38005 .47693 .38624 .48667 .40699 .48506 .40091 .47554 Mtetra
.602 .77 .96 r
.40091 .47554 .40699 .48506 .4278 .48355 .42186 .47419 Mtetra
.599 .772 .963 r
.42186 .47419 .4278 .48355 .44869 .48207 .44287 .47283 Mtetra
.597 .775 .965 r
.44287 .47283 .44869 .48207 .46965 .48059 .46397 .47145 Mtetra
.596 .777 .967 r
.46397 .47145 .46965 .48059 .49068 .47911 .48514 .47003 Mtetra
.595 .778 .968 r
.48514 .47003 .49068 .47911 .51179 .47761 .50639 .46858 Mtetra
.594 .78 .969 r
.50639 .46858 .51179 .47761 .53298 .47608 .52772 .46709 Mtetra
.594 .781 .97 r
.52772 .46709 .53298 .47608 .55424 .47453 .54912 .46557 Mtetra
.594 .783 .97 r
.54912 .46557 .55424 .47453 .57558 .47294 .5706 .46401 Mtetra
.594 .784 .971 r
.5706 .46401 .57558 .47294 .597 .47133 .59216 .46241 Mtetra
.594 .785 .971 r
.59216 .46241 .597 .47133 .61849 .46969 .6138 .46078 Mtetra
.594 .786 .972 r
.6138 .46078 .61849 .46969 .64006 .46803 .63552 .45912 Mtetra
.63552 .45912 .64006 .46803 .6617 .46633 .65731 .45742 Mtetra
.594 .787 .973 r
.65731 .45742 .6617 .46633 .68343 .46462 .67918 .4557 Mtetra
.594 .788 .973 r
.67918 .4557 .68343 .46462 .70523 .46287 .70113 .45395 Mtetra
.70113 .45395 .70523 .46287 .7271 .46111 .72316 .45218 Mtetra
.594 .789 .973 r
.72316 .45218 .7271 .46111 .74906 .45932 .74527 .45038 Mtetra
.594 .789 .974 r
.74527 .45038 .74906 .45932 .77109 .45751 .76746 .44856 Mtetra
.594 .79 .974 r
.76746 .44856 .77109 .45751 .7932 .45568 .78972 .44671 Mtetra
.78972 .44671 .7932 .45568 .8154 .45384 .81207 .44485 Mtetra
.595 .791 .974 r
.81207 .44485 .8154 .45384 .83767 .45197 .8345 .44296 Mtetra
.8345 .44296 .83767 .45197 .86001 .45008 .85701 .44106 Mtetra
.85701 .44106 .86001 .45008 .88244 .44818 .8796 .43914 Mtetra
.595 .792 .974 r
.8796 .43914 .88244 .44818 .90495 .44626 .90227 .43719 Mtetra
.90227 .43719 .90495 .44626 .92754 .44433 .92502 .43524 Mtetra
.595 .792 .975 r
.92502 .43524 .92754 .44433 .95021 .44238 .94785 .43326 Mtetra
.94785 .43326 .95021 .44238 .97296 .44041 .97077 .43127 Mtetra
.782 .72 .794 r
.22765 .49954 .23431 .5196 .2557 .49953 .24892 .48388 Mtetra
.721 .728 .856 r
.24892 .48388 .2557 .49953 .27653 .49028 .26977 .47693 Mtetra
.675 .736 .896 r
.26977 .47693 .27653 .49028 .2972 .48531 .2905 .47332 Mtetra
.644 .743 .921 r
.2905 .47332 .2972 .48531 .31785 .48226 .31123 .47113 Mtetra
.625 .749 .936 r
.31123 .47113 .31785 .48226 .33852 .48012 .33201 .46956 Mtetra
.612 .754 .946 r
.33201 .46956 .33852 .48012 .35925 .47842 .35285 .46826 Mtetra
.605 .759 .953 r
.35285 .46826 .35925 .47842 .38005 .47693 .37376 .46707 Mtetra
.6 .764 .957 r
.37376 .46707 .38005 .47693 .40091 .47554 .39476 .46589 Mtetra
.597 .767 .961 r
.39476 .46589 .40091 .47554 .42186 .47419 .41583 .4647 Mtetra
.595 .77 .963 r
.41583 .4647 .42186 .47419 .44287 .47283 .43698 .46346 Mtetra
.594 .773 .965 r
.43698 .46346 .44287 .47283 .46397 .47145 .45821 .46217 Mtetra
.593 .775 .967 r
.45821 .46217 .46397 .47145 .48514 .47003 .47952 .46082 Mtetra
.593 .777 .968 r
.47952 .46082 .48514 .47003 .50639 .46858 .50091 .45943 Mtetra
.593 .779 .969 r
.50091 .45943 .50639 .46858 .52772 .46709 .52238 .45798 Mtetra
.593 .781 .97 r
.52238 .45798 .52772 .46709 .54912 .46557 .54393 .45649 Mtetra
.593 .782 .97 r
.54393 .45649 .54912 .46557 .5706 .46401 .56555 .45494 Mtetra
.593 .783 .971 r
.56555 .45494 .5706 .46401 .59216 .46241 .58726 .45336 Mtetra
.593 .784 .972 r
.58726 .45336 .59216 .46241 .6138 .46078 .60904 .45174 Mtetra
.593 .785 .972 r
.60904 .45174 .6138 .46078 .63552 .45912 .63091 .45008 Mtetra
.593 .786 .972 r
.63091 .45008 .63552 .45912 .65731 .45742 .65285 .44838 Mtetra
.593 .787 .973 r
.65285 .44838 .65731 .45742 .67918 .4557 .67487 .44666 Mtetra
.594 .787 .973 r
.67487 .44666 .67918 .4557 .70113 .45395 .69698 .4449 Mtetra
.594 .788 .973 r
.69698 .4449 .70113 .45395 .72316 .45218 .71916 .44312 Mtetra
.594 .789 .973 r
.71916 .44312 .72316 .45218 .74527 .45038 .74142 .44131 Mtetra
.594 .789 .974 r
.74142 .44131 .74527 .45038 .76746 .44856 .76377 .43947 Mtetra
.594 .79 .974 r
.76377 .43947 .76746 .44856 .78972 .44671 .78619 .43761 Mtetra
.78619 .43761 .78972 .44671 .81207 .44485 .8087 .43573 Mtetra
.8087 .43573 .81207 .44485 .8345 .44296 .83129 .43382 Mtetra
.594 .791 .974 r
.83129 .43382 .8345 .44296 .85701 .44106 .85396 .4319 Mtetra
.595 .791 .974 r
.85396 .4319 .85701 .44106 .8796 .43914 .87671 .42995 Mtetra
.87671 .42995 .8796 .43914 .90227 .43719 .89954 .42799 Mtetra
.595 .792 .974 r
.89954 .42799 .90227 .43719 .92502 .43524 .92246 .42601 Mtetra
.595 .792 .975 r
.92246 .42601 .92502 .43524 .94785 .43326 .94546 .42401 Mtetra
.94546 .42401 .94785 .43326 .97077 .43127 .96854 .422 Mtetra
.751 .704 .807 r
.22092 .47927 .22765 .49954 .24892 .48388 .24207 .46805 Mtetra
.693 .714 .865 r
.24207 .46805 .24892 .48388 .26977 .47693 .26291 .46342 Mtetra
.652 .724 .902 r
.26291 .46342 .26977 .47693 .2905 .47332 .2837 .46117 Mtetra
.627 .734 .924 r
.2837 .46117 .2905 .47332 .31123 .47113 .30452 .45984 Mtetra
.611 .742 .938 r
.30452 .45984 .31123 .47113 .33201 .46956 .3254 .45886 Mtetra
.602 .749 .948 r
.3254 .45886 .33201 .46956 .35285 .46826 .34636 .45797 Mtetra
.597 .755 .954 r
.34636 .45797 .35285 .46826 .37376 .46707 .36739 .45706 Mtetra
.594 .76 .958 r
.36739 .45706 .37376 .46707 .39476 .46589 .38851 .45611 Mtetra
.592 .765 .961 r
.38851 .45611 .39476 .46589 .41583 .4647 .40972 .45507 Mtetra
.591 .768 .964 r
.40972 .45507 .41583 .4647 .43698 .46346 .431 .45395 Mtetra
.591 .771 .966 r
.431 .45395 .43698 .46346 .45821 .46217 .45237 .45276 Mtetra
.591 .774 .967 r
.45237 .45276 .45821 .46217 .47952 .46082 .47382 .45148 Mtetra
.591 .776 .968 r
.47382 .45148 .47952 .46082 .50091 .45943 .49535 .45014 Mtetra
.591 .778 .969 r
.49535 .45014 .50091 .45943 .52238 .45798 .51696 .44874 Mtetra
.591 .78 .97 r
.51696 .44874 .52238 .45798 .54393 .45649 .53865 .44727 Mtetra
.592 .781 .971 r
.53865 .44727 .54393 .45649 .56555 .45494 .56043 .44575 Mtetra
.592 .783 .971 r
.56043 .44575 .56555 .45494 .58726 .45336 .58228 .44418 Mtetra
.592 .784 .972 r
.58228 .44418 .58726 .45336 .60904 .45174 .60422 .44257 Mtetra
.592 .785 .972 r
.60422 .44257 .60904 .45174 .63091 .45008 .62623 .44091 Mtetra
.593 .786 .972 r
.62623 .44091 .63091 .45008 .65285 .44838 .64833 .43921 Mtetra
.593 .786 .973 r
.64833 .43921 .65285 .44838 .67487 .44666 .6705 .43748 Mtetra
.593 .787 .973 r
.6705 .43748 .67487 .44666 .69698 .4449 .69276 .43572 Mtetra
.593 .788 .973 r
.69276 .43572 .69698 .4449 .71916 .44312 .7151 .43392 Mtetra
.7151 .43392 .71916 .44312 .74142 .44131 .73752 .4321 Mtetra
.594 .789 .974 r
.73752 .4321 .74142 .44131 .76377 .43947 .76002 .43025 Mtetra
.76002 .43025 .76377 .43947 .78619 .43761 .78261 .42837 Mtetra
.594 .79 .974 r
.78261 .42837 .78619 .43761 .8087 .43573 .80528 .42647 Mtetra
.80528 .42647 .8087 .43573 .83129 .43382 .82803 .42455 Mtetra
.594 .791 .974 r
.82803 .42455 .83129 .43382 .85396 .4319 .85086 .4226 Mtetra
.85086 .4226 .85396 .4319 .87671 .42995 .87378 .42064 Mtetra
.87378 .42064 .87671 .42995 .89954 .42799 .89678 .41865 Mtetra
.595 .792 .974 r
.89678 .41865 .89954 .42799 .92246 .42601 .91986 .41665 Mtetra
.595 .792 .975 r
.91986 .41665 .92246 .42601 .94546 .42401 .94303 .41462 Mtetra
.94303 .41462 .94546 .42401 .96854 .422 .96628 .41258 Mtetra
.713 .683 .819 r
.21412 .4588 .22092 .47927 .24207 .46805 .23514 .45203 Mtetra
.66 .697 .873 r
.23514 .45203 .24207 .46805 .26291 .46342 .25597 .44973 Mtetra
.627 .711 .907 r
.25597 .44973 .26291 .46342 .2837 .46117 .27681 .44886 Mtetra
.608 .724 .927 r
.27681 .44886 .2837 .46117 .30452 .45984 .29772 .44841 Mtetra
.598 .735 .94 r
.29772 .44841 .30452 .45984 .3254 .45886 .3187 .44801 Mtetra
.592 .744 .949 r
.3187 .44801 .3254 .45886 .34636 .45797 .33977 .44753 Mtetra
.589 .751 .955 r
.33977 .44753 .34636 .45797 .36739 .45706 .36093 .44692 Mtetra
.588 .757 .959 r
.36093 .44692 .36739 .45706 .38851 .45611 .38218 .44618 Mtetra
.588 .762 .962 r
.38218 .44618 .38851 .45611 .40972 .45507 .40352 .44531 Mtetra
.588 .766 .964 r
.40352 .44531 .40972 .45507 .431 .45395 .42494 .44431 Mtetra
.588 .77 .966 r
.42494 .44431 .431 .45395 .45237 .45276 .44645 .44321 Mtetra
.588 .773 .967 r
.44645 .44321 .45237 .45276 .47382 .45148 .46804 .44201 Mtetra
.589 .775 .969 r
.46804 .44201 .47382 .45148 .49535 .45014 .48971 .44072 Mtetra
.589 .777 .969 r
.48971 .44072 .49535 .45014 .51696 .44874 .51147 .43936 Mtetra
.59 .779 .97 r
.51147 .43936 .51696 .44874 .53865 .44727 .53331 .43792 Mtetra
.59 .781 .971 r
.53331 .43792 .53865 .44727 .56043 .44575 .55523 .43642 Mtetra
.591 .782 .971 r
.55523 .43642 .56043 .44575 .58228 .44418 .57723 .43487 Mtetra
.591 .783 .972 r
.57723 .43487 .58228 .44418 .60422 .44257 .59932 .43326 Mtetra
.592 .784 .972 r
.59932 .43326 .60422 .44257 .62623 .44091 .62149 .4316 Mtetra
.592 .785 .972 r
.62149 .4316 .62623 .44091 .64833 .43921 .64374 .42991 Mtetra
.592 .786 .973 r
.64374 .42991 .64833 .43921 .6705 .43748 .66607 .42817 Mtetra
.592 .787 .973 r
.66607 .42817 .6705 .43748 .69276 .43572 .68848 .4264 Mtetra
.593 .788 .973 r
.68848 .4264 .69276 .43572 .7151 .43392 .71098 .42459 Mtetra
.71098 .42459 .7151 .43392 .73752 .4321 .73356 .42276 Mtetra
.593 .789 .974 r
.73356 .42276 .73752 .4321 .76002 .43025 .75623 .42089 Mtetra
.75623 .42089 .76002 .43025 .78261 .42837 .77897 .419 Mtetra
.594 .79 .974 r
.77897 .419 .78261 .42837 .80528 .42647 .8018 .41708 Mtetra
.8018 .41708 .80528 .42647 .82803 .42455 .82472 .41513 Mtetra
.594 .791 .974 r
.82472 .41513 .82803 .42455 .85086 .4226 .84772 .41317 Mtetra
.84772 .41317 .85086 .4226 .87378 .42064 .8708 .41118 Mtetra
.8708 .41118 .87378 .42064 .89678 .41865 .89397 .40917 Mtetra
.594 .792 .974 r
.89397 .40917 .89678 .41865 .91986 .41665 .91722 .40714 Mtetra
.594 .792 .975 r
.91722 .40714 .91986 .41665 .94303 .41462 .94056 .40509 Mtetra
.595 .792 .975 r
.94056 .40509 .94303 .41462 .96628 .41258 .96399 .40302 Mtetra
.666 .656 .83 r
.20725 .43811 .21412 .4588 .23514 .45203 .22812 .43582 Mtetra
.623 .677 .88 r
.22812 .43582 .23514 .45203 .25597 .44973 .24895 .43588 Mtetra
.6 .697 .911 r
.24895 .43588 .25597 .44973 .27681 .44886 .26984 .43639 Mtetra
.588 .714 .93 r
.26984 .43639 .27681 .44886 .29772 .44841 .29083 .43682 Mtetra
.583 .728 .942 r
.29083 .43682 .29772 .44841 .3187 .44801 .31191 .43701 Mtetra
.581 .739 .95 r
.31191 .43701 .3187 .44801 .33977 .44753 .3331 .43694 Mtetra
.581 .747 .956 r
.3331 .43694 .33977 .44753 .36093 .44692 .35438 .43664 Mtetra
.582 .754 .96 r
.35438 .43664 .36093 .44692 .38218 .44618 .37576 .43611 Mtetra
.583 .76 .963 r
.37576 .43611 .38218 .44618 .40352 .44531 .39723 .43541 Mtetra
.584 .764 .965 r
.39723 .43541 .40352 .44531 .42494 .44431 .41879 .43454 Mtetra
.585 .768 .966 r
.41879 .43454 .42494 .44431 .44645 .44321 .44044 .43353 Mtetra
.586 .771 .968 r
.44044 .43353 .44645 .44321 .46804 .44201 .46217 .4324 Mtetra
.587 .774 .969 r
.46217 .4324 .46804 .44201 .48971 .44072 .48399 .43117 Mtetra
.588 .776 .97 r
.48399 .43117 .48971 .44072 .51147 .43936 .50589 .42984 Mtetra
.588 .778 .97 r
.50589 .42984 .51147 .43936 .53331 .43792 .52788 .42843 Mtetra
.589 .78 .971 r
.52788 .42843 .53331 .43792 .55523 .43642 .54995 .42696 Mtetra
.59 .781 .971 r
.54995 .42696 .55523 .43642 .57723 .43487 .57211 .42541 Mtetra
.59 .783 .972 r
.57211 .42541 .57723 .43487 .59932 .43326 .59435 .42381 Mtetra
.591 .784 .972 r
.59435 .42381 .59932 .43326 .62149 .4316 .61667 .42216 Mtetra
.591 .785 .973 r
.61667 .42216 .62149 .4316 .64374 .42991 .63908 .42046 Mtetra
.592 .786 .973 r
.63908 .42046 .64374 .42991 .66607 .42817 .66157 .41872 Mtetra
.592 .787 .973 r
.66157 .41872 .66607 .42817 .68848 .4264 .68414 .41694 Mtetra
.68414 .41694 .68848 .4264 .71098 .42459 .7068 .41512 Mtetra
.593 .788 .973 r
.7068 .41512 .71098 .42459 .73356 .42276 .72954 .41327 Mtetra
.593 .789 .974 r
.72954 .41327 .73356 .42276 .75623 .42089 .75237 .41139 Mtetra
.75237 .41139 .75623 .42089 .77897 .419 .77528 .40948 Mtetra
.593 .79 .974 r
.77528 .40948 .77897 .419 .8018 .41708 .79828 .40754 Mtetra
.594 .79 .974 r
.79828 .40754 .8018 .41708 .82472 .41513 .82136 .40558 Mtetra
.82136 .40558 .82472 .41513 .84772 .41317 .84453 .40359 Mtetra
.594 .791 .974 r
.84453 .40359 .84772 .41317 .8708 .41118 .86778 .40158 Mtetra
.86778 .40158 .8708 .41118 .89397 .40917 .89112 .39954 Mtetra
.89112 .39954 .89397 .40917 .91722 .40714 .91455 .39749 Mtetra
.594 .792 .975 r
.91455 .39749 .91722 .40714 .94056 .40509 .93806 .39541 Mtetra
.93806 .39541 .94056 .40509 .96399 .40302 .96166 .39332 Mtetra
.608 .621 .839 r
.2003 .41721 .20725 .43811 .22812 .43582 .22102 .41941 Mtetra
.58 .653 .886 r
.22102 .41941 .22812 .43582 .24895 .43588 .24183 .42184 Mtetra
.57 .68 .915 r
.24183 .42184 .24895 .43588 .26984 .43639 .26277 .42375 Mtetra
.567 .703 .933 r
.26277 .42375 .26984 .43639 .29083 .43682 .28384 .42507 Mtetra
.568 .72 .944 r
.28384 .42507 .29083 .43682 .31191 .43701 .30503 .42586 Mtetra
.571 .733 .952 r
.30503 .42586 .31191 .43701 .3331 .43694 .32633 .42621 Mtetra
.573 .743 .957 r
.32633 .42621 .3331 .43694 .35438 .43664 .34774 .42621 Mtetra
.576 .751 .96 r
.34774 .42621 .35438 .43664 .37576 .43611 .36925 .42591 Mtetra
.578 .757 .963 r
.36925 .42591 .37576 .43611 .39723 .43541 .39086 .42536 Mtetra
.58 .762 .965 r
.39086 .42536 .39723 .43541 .41879 .43454 .41255 .42462 Mtetra
.582 .767 .967 r
.41255 .42462 .41879 .43454 .44044 .43353 .43434 .42371 Mtetra
.583 .77 .968 r
.43434 .42371 .44044 .43353 .46217 .4324 .45622 .42265 Mtetra
.585 .773 .969 r
.45622 .42265 .46217 .4324 .48399 .43117 .47819 .42147 Mtetra
.586 .775 .97 r
.47819 .42147 .48399 .43117 .50589 .42984 .50024 .42018 Mtetra
.587 .778 .97 r
.50024 .42018 .50589 .42984 .52788 .42843 .52238 .41881 Mtetra
.588 .779 .971 r
.52238 .41881 .52788 .42843 .54995 .42696 .5446 .41735 Mtetra
.589 .781 .972 r
.5446 .41735 .54995 .42696 .57211 .42541 .56691 .41582 Mtetra
.589 .782 .972 r
.56691 .41582 .57211 .42541 .59435 .42381 .58931 .41423 Mtetra
.59 .783 .972 r
.58931 .41423 .59435 .42381 .61667 .42216 .61179 .41258 Mtetra
.591 .784 .973 r
.61179 .41258 .61667 .42216 .63908 .42046 .63435 .41088 Mtetra
.591 .785 .973 r
.63435 .41088 .63908 .42046 .66157 .41872 .657 .40913 Mtetra
.591 .786 .973 r
.657 .40913 .66157 .41872 .68414 .41694 .67974 .40734 Mtetra
.592 .787 .973 r
.67974 .40734 .68414 .41694 .7068 .41512 .70256 .40551 Mtetra
.592 .788 .973 r
.70256 .40551 .7068 .41512 .72954 .41327 .72546 .40365 Mtetra
.592 .788 .974 r
.72546 .40365 .72954 .41327 .75237 .41139 .74846 .40175 Mtetra
.593 .789 .974 r
.74846 .40175 .75237 .41139 .77528 .40948 .77153 .39982 Mtetra
.77153 .39982 .77528 .40948 .79828 .40754 .7947 .39786 Mtetra
.593 .79 .974 r
.7947 .39786 .79828 .40754 .82136 .40558 .81795 .39587 Mtetra
.81795 .39587 .82136 .40558 .84453 .40359 .84129 .39386 Mtetra
.594 .791 .974 r
.84129 .39386 .84453 .40359 .86778 .40158 .86471 .39183 Mtetra
.86471 .39183 .86778 .40158 .89112 .39954 .88822 .38977 Mtetra
.594 .791 .975 r
.88822 .38977 .89112 .39954 .91455 .39749 .91183 .38769 Mtetra
.594 .792 .975 r
.91183 .38769 .91455 .39749 .93806 .39541 .93552 .38559 Mtetra
.93552 .38559 .93806 .39541 .96166 .39332 .95929 .38347 Mtetra
.536 .577 .843 r
.19329 .3961 .2003 .41721 .22102 .41941 .21384 .40281 Mtetra
.532 .624 .889 r
.21384 .40281 .22102 .41941 .24183 .42184 .23462 .40763 Mtetra
.537 .662 .917 r
.23462 .40763 .24183 .42184 .26277 .42375 .25561 .41095 Mtetra
.545 .69 .934 r
.25561 .41095 .26277 .42375 .28384 .42507 .27676 .41316 Mtetra
.553 .711 .945 r
.27676 .41316 .28384 .42507 .30503 .42586 .29805 .41456 Mtetra
.559 .727 .953 r
.29805 .41456 .30503 .42586 .32633 .42621 .31947 .41533 Mtetra
.565 .738 .958 r
.31947 .41533 .32633 .42621 .34774 .42621 .341 .41563 Mtetra
.569 .748 .961 r
.341 .41563 .34774 .42621 .36925 .42591 .36264 .41555 Mtetra
.573 .755 .964 r
.36264 .41555 .36925 .42591 .39086 .42536 .38439 .41517 Mtetra
.576 .76 .966 r
.38439 .41517 .39086 .42536 .41255 .42462 .40622 .41456 Mtetra
.579 .765 .967 r
.40622 .41456 .41255 .42462 .43434 .42371 .42816 .41374 Mtetra
.581 .769 .968 r
.42816 .41374 .43434 .42371 .45622 .42265 .45018 .41275 Mtetra
.583 .772 .969 r
.45018 .41275 .45622 .42265 .47819 .42147 .4723 .41163 Mtetra
.584 .774 .97 r
.4723 .41163 .47819 .42147 .50024 .42018 .4945 .41039 Mtetra
.586 .777 .971 r
.4945 .41039 .50024 .42018 .52238 .41881 .51679 .40904 Mtetra
.587 .779 .971 r
.51679 .40904 .52238 .41881 .5446 .41735 .53917 .4076 Mtetra
.588 .78 .972 r
.53917 .4076 .5446 .41735 .56691 .41582 .56164 .40609 Mtetra
.588 .782 .972 r
.56164 .40609 .56691 .41582 .58931 .41423 .58419 .4045 Mtetra
.589 .783 .972 r
.58419 .4045 .58931 .41423 .61179 .41258 .60683 .40285 Mtetra
.59 .784 .973 r
.60683 .40285 .61179 .41258 .63435 .41088 .62955 .40115 Mtetra
.59 .785 .973 r
.62955 .40115 .63435 .41088 .657 .40913 .65237 .39939 Mtetra
.591 .786 .973 r
.65237 .39939 .657 .40913 .67974 .40734 .67526 .39759 Mtetra
.591 .787 .973 r
.67526 .39759 .67974 .40734 .70256 .40551 .69825 .39575 Mtetra
.592 .787 .974 r
.69825 .39575 .70256 .40551 .72546 .40365 .72132 .39387 Mtetra
.592 .788 .974 r
.72132 .39387 .72546 .40365 .74846 .40175 .74448 .39196 Mtetra
.592 .789 .974 r
.74448 .39196 .74846 .40175 .77153 .39982 .76773 .39001 Mtetra
.593 .789 .974 r
.76773 .39001 .77153 .39982 .7947 .39786 .79106 .38803 Mtetra
.593 .79 .974 r
.79106 .38803 .7947 .39786 .81795 .39587 .81449 .38602 Mtetra
.81449 .38602 .81795 .39587 .84129 .39386 .838 .38399 Mtetra
.838 .38399 .84129 .39386 .86471 .39183 .8616 .38193 Mtetra
.594 .791 .974 r
.8616 .38193 .86471 .39183 .88822 .38977 .88529 .37985 Mtetra
.594 .791 .975 r
.88529 .37985 .88822 .38977 .91183 .38769 .90906 .37774 Mtetra
.90906 .37774 .91183 .38769 .93552 .38559 .93293 .37561 Mtetra
.594 .792 .975 r
.93293 .37561 .93552 .38559 .95929 .38347 .95689 .37346 Mtetra
.448 .519 .839 r
.1862 .37476 .19329 .3961 .21384 .40281 .20657 .38601 Mtetra
.476 .59 .888 r
.20657 .38601 .21384 .40281 .23462 .40763 .22732 .39323 Mtetra
.502 .641 .918 r
.22732 .39323 .23462 .40763 .25561 .41095 .24835 .39797 Mtetra
.522 .677 .935 r
.24835 .39797 .25561 .41095 .27676 .41316 .26958 .40109 Mtetra
.537 .702 .946 r
.26958 .40109 .27676 .41316 .29805 .41456 .29098 .40309 Mtetra
.548 .72 .953 r
.29098 .40309 .29805 .41456 .31947 .41533 .31251 .40429 Mtetra
.556 .734 .958 r
.31251 .40429 .31947 .41533 .341 .41563 .33417 .40489 Mtetra
.563 .744 .962 r
.33417 .40489 .341 .41563 .36264 .41555 .35594 .40504 Mtetra
.568 .752 .964 r
.35594 .40504 .36264 .41555 .38439 .41517 .37782 .40484 Mtetra
.572 .758 .966 r
.37782 .40484 .38439 .41517 .40622 .41456 .3998 .40435 Mtetra
.576 .763 .967 r
.3998 .40435 .40622 .41456 .42816 .41374 .42188 .40362 Mtetra
.578 .767 .969 r
.42188 .40362 .42816 .41374 .45018 .41275 .44405 .40271 Mtetra
.581 .771 .969 r
.44405 .40271 .45018 .41275 .4723 .41163 .46632 .40164 Mtetra
.582 .774 .97 r
.46632 .40164 .4723 .41163 .4945 .41039 .48867 .40044 Mtetra
.584 .776 .971 r
.48867 .40044 .4945 .41039 .51679 .40904 .51112 .39912 Mtetra
.585 .778 .971 r
.51112 .39912 .51679 .40904 .53917 .4076 .53366 .39771 Mtetra
.587 .78 .972 r
.53366 .39771 .53917 .4076 .56164 .40609 .55628 .3962 Mtetra
.588 .781 .972 r
.55628 .3962 .56164 .40609 .58419 .4045 .57899 .39462 Mtetra
.588 .783 .972 r
.57899 .39462 .58419 .4045 .60683 .40285 .60179 .39298 Mtetra
.589 .784 .973 r
.60179 .39298 .60683 .40285 .62955 .40115 .62468 .39127 Mtetra
.59 .785 .973 r
.62468 .39127 .62955 .40115 .65237 .39939 .64766 .38951 Mtetra
.59 .786 .973 r
.64766 .38951 .65237 .39939 .67526 .39759 .67072 .3877 Mtetra
.591 .786 .973 r
.67072 .3877 .67526 .39759 .69825 .39575 .69388 .38585 Mtetra
.591 .787 .974 r
.69388 .38585 .69825 .39575 .72132 .39387 .71712 .38395 Mtetra
.592 .788 .974 r
.71712 .38395 .72132 .39387 .74448 .39196 .74045 .38202 Mtetra
.74045 .38202 .74448 .39196 .76773 .39001 .76386 .38005 Mtetra
.592 .789 .974 r
.76386 .38005 .76773 .39001 .79106 .38803 .78737 .37805 Mtetra
.593 .789 .974 r
.78737 .37805 .79106 .38803 .81449 .38602 .81097 .37602 Mtetra
.593 .79 .974 r
.81097 .37602 .81449 .38602 .838 .38399 .83466 .37396 Mtetra
.83466 .37396 .838 .38399 .8616 .38193 .85843 .37188 Mtetra
.593 .791 .974 r
.85843 .37188 .8616 .38193 .88529 .37985 .8823 .36977 Mtetra
.594 .791 .975 r
.8823 .36977 .88529 .37985 .90906 .37774 .90626 .36763 Mtetra
.90626 .36763 .90906 .37774 .93293 .37561 .93031 .36548 Mtetra
.594 .792 .975 r
.93031 .36548 .93293 .37561 .95689 .37346 .95445 .3633 Mtetra
.342 .447 .824 r
.17904 .3532 .1862 .37476 .20657 .38601 .19921 .36901 Mtetra
.414 .551 .883 r
.19921 .36901 .20657 .38601 .22732 .39323 .21993 .37865 Mtetra
.464 .618 .917 r
.21993 .37865 .22732 .39323 .24835 .39797 .24099 .38482 Mtetra
.497 .663 .936 r
.24099 .38482 .24835 .39797 .26958 .40109 .2623 .38885 Mtetra
.52 .693 .947 r
.2623 .38885 .26958 .40109 .29098 .40309 .2838 .39147 Mtetra
.536 .714 .954 r
.2838 .39147 .29098 .40309 .31251 .40429 .30545 .3931 Mtetra
.548 .729 .959 r
.30545 .3931 .31251 .40429 .33417 .40489 .32724 .39401 Mtetra
.556 .741 .962 r
.32724 .39401 .33417 .40489 .35594 .40504 .34914 .39438 Mtetra
.563 .749 .965 r
.34914 .39438 .35594 .40504 .37782 .40484 .37116 .39435 Mtetra
.568 .756 .966 r
.37116 .39435 .37782 .40484 .3998 .40435 .39329 .39398 Mtetra
.572 .762 .968 r
.39329 .39398 .3998 .40435 .42188 .40362 .41551 .39336 Mtetra
.576 .766 .969 r
.41551 .39336 .42188 .40362 .44405 .40271 .43783 .39252 Mtetra
.579 .77 .97 r
.43783 .39252 .44405 .40271 .46632 .40164 .46025 .39151 Mtetra
.581 .773 .97 r
.46025 .39151 .46632 .40164 .48867 .40044 .48276 .39035 Mtetra
.583 .775 .971 r
.48276 .39035 .48867 .40044 .51112 .39912 .50536 .38906 Mtetra
.584 .777 .971 r
.50536 .38906 .51112 .39912 .53366 .39771 .52806 .38766 Mtetra
.586 .779 .972 r
.52806 .38766 .53366 .39771 .55628 .3962 .55084 .38617 Mtetra
.587 .781 .972 r
.55084 .38617 .55628 .3962 .57899 .39462 .57372 .3846 Mtetra
.588 .782 .972 r
.57372 .3846 .57899 .39462 .60179 .39298 .59668 .38295 Mtetra
.588 .783 .973 r
.59668 .38295 .60179 .39298 .62468 .39127 .61974 .38124 Mtetra
.589 .784 .973 r
.61974 .38124 .62468 .39127 .64766 .38951 .64288 .37947 Mtetra
.59 .785 .973 r
.64288 .37947 .64766 .38951 .67072 .3877 .66611 .37765 Mtetra
.59 .786 .973 r
.66611 .37765 .67072 .3877 .69388 .38585 .68943 .37579 Mtetra
.591 .787 .974 r
.68943 .37579 .69388 .38585 .71712 .38395 .71285 .37388 Mtetra
.591 .788 .974 r
.71285 .37388 .71712 .38395 .74045 .38202 .73635 .37192 Mtetra
.592 .788 .974 r
.73635 .37192 .74045 .38202 .76386 .38005 .75994 .36994 Mtetra
.592 .789 .974 r
.75994 .36994 .76386 .38005 .78737 .37805 .78362 .36792 Mtetra
.78362 .36792 .78737 .37805 .81097 .37602 .8074 .36586 Mtetra
.593 .79 .974 r
.8074 .36586 .81097 .37602 .83466 .37396 .83126 .36378 Mtetra
.83126 .36378 .83466 .37396 .85843 .37188 .85522 .36167 Mtetra
.593 .791 .974 r
.85522 .36167 .85843 .37188 .8823 .36977 .87927 .35953 Mtetra
.593 .791 .975 r
.87927 .35953 .8823 .36977 .90626 .36763 .90341 .35737 Mtetra
.594 .791 .975 r
.90341 .35737 .90626 .36763 .93031 .36548 .92765 .35518 Mtetra
.594 .792 .975 r
.92765 .35518 .93031 .36548 .95445 .3633 .95197 .35297 Mtetra
.218 .36 .794 r
.17181 .33142 .17904 .3532 .19921 .36901 .19176 .3518 Mtetra
.345 .505 .874 r
.19176 .3518 .19921 .36901 .21993 .37865 .21244 .36387 Mtetra
.422 .593 .914 r
.21244 .36387 .21993 .37865 .24099 .38482 .23354 .37149 Mtetra
.471 .647 .935 r
.23354 .37149 .24099 .38482 .2623 .38885 .25492 .37644 Mtetra
.502 .683 .947 r
.25492 .37644 .2623 .38885 .2838 .39147 .27652 .37968 Mtetra
.524 .707 .955 r
.27652 .37968 .2838 .39147 .30545 .3931 .29829 .38174 Mtetra
.539 .724 .959 r
.29829 .38174 .30545 .3931 .32724 .39401 .3202 .38296 Mtetra
.55 .737 .963 r
.3202 .38296 .32724 .39401 .34914 .39438 .34225 .38357 Mtetra
.558 .747 .965 r
.34225 .38357 .34914 .39438 .37116 .39435 .3644 .3837 Mtetra
.564 .754 .967 r
.3644 .3837 .37116 .39435 .39329 .39398 .38667 .38347 Mtetra
.569 .76 .968 r
.38667 .38347 .39329 .39398 .41551 .39336 .40905 .38294 Mtetra
.573 .765 .969 r
.40905 .38294 .41551 .39336 .43783 .39252 .43152 .38218 Mtetra
.576 .768 .97 r
.43152 .38218 .43783 .39252 .46025 .39151 .45409 .38122 Mtetra
.579 .772 .97 r
.45409 .38122 .46025 .39151 .48276 .39035 .47676 .3801 Mtetra
.581 .774 .971 r
.47676 .3801 .48276 .39035 .50536 .38906 .49952 .37884 Mtetra
.583 .777 .972 r
.49952 .37884 .50536 .38906 .52806 .38766 .52238 .37747 Mtetra
.584 .779 .972 r
.52238 .37747 .52806 .38766 .55084 .38617 .54532 .37599 Mtetra
.586 .78 .972 r
.54532 .37599 .55084 .38617 .57372 .3846 .56836 .37442 Mtetra
.587 .782 .973 r
.56836 .37442 .57372 .3846 .59668 .38295 .59149 .37277 Mtetra
.588 .783 .973 r
.59149 .37277 .59668 .38295 .61974 .38124 .61471 .37106 Mtetra
.589 .784 .973 r
.61471 .37106 .61974 .38124 .64288 .37947 .63803 .36928 Mtetra
.589 .785 .973 r
.63803 .36928 .64288 .37947 .66611 .37765 .66143 .36745 Mtetra
.59 .786 .973 r
.66143 .36745 .66611 .37765 .68943 .37579 .68492 .36557 Mtetra
.591 .787 .974 r
.68492 .36557 .68943 .37579 .71285 .37388 .70851 .36364 Mtetra
.70851 .36364 .71285 .37388 .73635 .37192 .73219 .36167 Mtetra
.591 .788 .974 r
.73219 .36167 .73635 .37192 .75994 .36994 .75596 .35966 Mtetra
.592 .789 .974 r
.75596 .35966 .75994 .36994 .78362 .36792 .77982 .35762 Mtetra
.77982 .35762 .78362 .36792 .8074 .36586 .80377 .35554 Mtetra
.592 .79 .974 r
.80377 .35554 .8074 .36586 .83126 .36378 .82782 .35343 Mtetra
.593 .79 .974 r
.82782 .35343 .83126 .36378 .85522 .36167 .85196 .3513 Mtetra
.85196 .3513 .85522 .36167 .87927 .35953 .87619 .34913 Mtetra
.593 .791 .975 r
.87619 .34913 .87927 .35953 .90341 .35737 .90052 .34694 Mtetra
.90052 .34694 .90341 .35737 .92765 .35518 .92494 .34473 Mtetra
.594 .791 .975 r
.92494 .34473 .92765 .35518 .95197 .35297 .94946 .34249 Mtetra
.078 .258 .746 r
.16449 .3094 .17181 .33142 .19176 .3518 .18422 .33438 Mtetra
.268 .453 .857 r
.18422 .33438 .19176 .3518 .21244 .36387 .20484 .3489 Mtetra
.378 .564 .909 r
.20484 .3489 .21244 .36387 .23354 .37149 .22598 .35798 Mtetra
.443 .631 .934 r
.22598 .35798 .23354 .37149 .25492 .37644 .24744 .36386 Mtetra
.484 .672 .947 r
.24744 .36386 .25492 .37644 .27652 .37968 .26914 .36772 Mtetra
.511 .7 .955 r
.26914 .36772 .27652 .37968 .29829 .38174 .29102 .37022 Mtetra
.53 .719 .96 r
.29102 .37022 .29829 .38174 .3202 .38296 .31307 .37176 Mtetra
.543 .733 .963 r
.31307 .37176 .3202 .38296 .34225 .38357 .33524 .37259 Mtetra
.553 .744 .965 r
.33524 .37259 .34225 .38357 .3644 .3837 .35755 .3729 Mtetra
.56 .752 .967 r
.35755 .3729 .3644 .3837 .38667 .38347 .37996 .3728 Mtetra
.566 .758 .968 r
.37996 .3728 .38667 .38347 .40905 .38294 .40249 .37237 Mtetra
.571 .763 .969 r
.40249 .37237 .40905 .38294 .43152 .38218 .42511 .37168 Mtetra
.574 .767 .97 r
.42511 .37168 .43152 .38218 .45409 .38122 .44784 .37078 Mtetra
.577 .771 .971 r
.44784 .37078 .45409 .38122 .47676 .3801 .47067 .3697 Mtetra
.58 .773 .971 r
.47067 .3697 .47676 .3801 .49952 .37884 .49359 .36847 Mtetra
.582 .776 .972 r
.49359 .36847 .49952 .37884 .52238 .37747 .51661 .36711 Mtetra
.583 .778 .972 r
.51661 .36711 .52238 .37747 .54532 .37599 .53972 .36565 Mtetra
.585 .78 .972 r
.53972 .36565 .54532 .37599 .56836 .37442 .56292 .36408 Mtetra
.586 .781 .973 r
.56292 .36408 .56836 .37442 .59149 .37277 .58622 .36244 Mtetra
.587 .783 .973 r
.58622 .36244 .59149 .37277 .61471 .37106 .60961 .36072 Mtetra
.588 .784 .973 r
.60961 .36072 .61471 .37106 .63803 .36928 .6331 .35894 Mtetra
.589 .785 .973 r
.6331 .35894 .63803 .36928 .66143 .36745 .65667 .35709 Mtetra
.59 .786 .973 r
.65667 .35709 .66143 .36745 .68492 .36557 .68034 .3552 Mtetra
.59 .786 .974 r
.68034 .3552 .68492 .36557 .70851 .36364 .70411 .35325 Mtetra
.591 .787 .974 r
.70411 .35325 .70851 .36364 .73219 .36167 .72796 .35126 Mtetra
.591 .788 .974 r
.72796 .35126 .73219 .36167 .75596 .35966 .75191 .34923 Mtetra
.592 .788 .974 r
.75191 .34923 .75596 .35966 .77982 .35762 .77595 .34716 Mtetra
.592 .789 .974 r
.77595 .34716 .77982 .35762 .80377 .35554 .80009 .34506 Mtetra
.80009 .34506 .80377 .35554 .82782 .35343 .82432 .34293 Mtetra
.593 .79 .974 r
.82432 .34293 .82782 .35343 .85196 .3513 .84864 .34076 Mtetra
.84864 .34076 .85196 .3513 .87619 .34913 .87306 .33857 Mtetra
.593 .791 .975 r
.87306 .33857 .87619 .34913 .90052 .34694 .89758 .33635 Mtetra
.89758 .33635 .90052 .34694 .92494 .34473 .92219 .3341 Mtetra
.92219 .3341 .92494 .34473 .94946 .34249 .9469 .33183 Mtetra
0 .145 .679 r
.1571 .28715 .16449 .3094 .18422 .33438 .17659 .31674 Mtetra
.185 .394 .834 r
.17659 .31674 .18422 .33438 .20484 .3489 .19715 .33374 Mtetra
.33 .533 .901 r
.19715 .33374 .20484 .3489 .22598 .35798 .21831 .34427 Mtetra
.414 .613 .931 r
.21831 .34427 .22598 .35798 .24744 .36386 .23985 .35109 Mtetra
.465 .661 .947 r
.23985 .35109 .24744 .36386 .26914 .36772 .26165 .35558 Mtetra
.498 .693 .955 r
.26165 .35558 .26914 .36772 .29102 .37022 .28365 .35852 Mtetra
.52 .714 .96 r
.28365 .35852 .29102 .37022 .31307 .37176 .30582 .36038 Mtetra
.536 .729 .963 r
.30582 .36038 .31307 .37176 .33524 .37259 .32814 .36145 Mtetra
.548 .741 .966 r
.32814 .36145 .33524 .37259 .35755 .3729 .35058 .36193 Mtetra
.556 .75 .967 r
.35058 .36193 .35755 .3729 .37996 .3728 .37315 .36196 Mtetra
.563 .756 .969 r
.37315 .36196 .37996 .3728 .40249 .37237 .39582 .36163 Mtetra
.568 .762 .969 r
.39582 .36163 .40249 .37237 .42511 .37168 .41861 .36102 Mtetra
.572 .766 .97 r
.41861 .36102 .42511 .37168 .44784 .37078 .44149 .36017 Mtetra
.575 .77 .971 r
.44149 .36017 .44784 .37078 .47067 .3697 .46448 .35914 Mtetra
.578 .773 .971 r
.46448 .35914 .47067 .3697 .49359 .36847 .48756 .35794 Mtetra
.58 .775 .972 r
.48756 .35794 .49359 .36847 .51661 .36711 .51075 .3566 Mtetra
.582 .777 .972 r
.51075 .3566 .51661 .36711 .53972 .36565 .53403 .35514 Mtetra
.584 .779 .972 r
.53403 .35514 .53972 .36565 .56292 .36408 .5574 .35359 Mtetra
.585 .781 .973 r
.5574 .35359 .56292 .36408 .58622 .36244 .58087 .35194 Mtetra
.586 .782 .973 r
.58087 .35194 .58622 .36244 .60961 .36072 .60443 .35022 Mtetra
.587 .783 .973 r
.60443 .35022 .60961 .36072 .6331 .35894 .62809 .34842 Mtetra
.588 .784 .973 r
.62809 .34842 .6331 .35894 .65667 .35709 .65184 .34657 Mtetra
.589 .785 .974 r
.65184 .34657 .65667 .35709 .68034 .3552 .67569 .34466 Mtetra
.59 .786 .974 r
.67569 .34466 .68034 .3552 .70411 .35325 .69963 .34269 Mtetra
.59 .787 .974 r
.69963 .34269 .70411 .35325 .72796 .35126 .72367 .34068 Mtetra
.591 .788 .974 r
.72367 .34068 .72796 .35126 .75191 .34923 .7478 .33863 Mtetra
.7478 .33863 .75191 .34923 .77595 .34716 .77202 .33654 Mtetra
.592 .789 .974 r
.77202 .33654 .77595 .34716 .80009 .34506 .79634 .33441 Mtetra
.79634 .33441 .80009 .34506 .82432 .34293 .82076 .33225 Mtetra
.592 .79 .974 r
.82076 .33225 .82432 .34293 .84864 .34076 .84528 .33006 Mtetra
.593 .79 .974 r
.84528 .33006 .84864 .34076 .87306 .33857 .86989 .32783 Mtetra
.593 .791 .975 r
.86989 .32783 .87306 .33857 .89758 .33635 .89459 .32558 Mtetra
.89459 .32558 .89758 .33635 .92219 .3341 .9194 .32331 Mtetra
.9194 .32331 .92219 .3341 .9469 .33183 .9443 .321 Mtetra
0 .028 .598 r
.14963 .26466 .1571 .28715 .17659 .31674 .16886 .29889 Mtetra
.096 .33 .803 r
.16886 .29889 .17659 .31674 .19715 .33374 .18936 .31837 Mtetra
.28 .5 .891 r
.18936 .31837 .19715 .33374 .21831 .34427 .21054 .33038 Mtetra
.384 .594 .928 r
.21054 .33038 .21831 .34427 .23985 .35109 .23215 .33815 Mtetra
.446 .65 .946 r
.23215 .33815 .23985 .35109 .26165 .35558 .25405 .34328 Mtetra
.485 .685 .955 r
.25405 .34328 .26165 .35558 .28365 .35852 .27617 .34666 Mtetra
.511 .709 .96 r
.27617 .34666 .28365 .35852 .30582 .36038 .29847 .34884 Mtetra
.529 .726 .964 r
.29847 .34884 .30582 .36038 .32814 .36145 .32093 .35015 Mtetra
.542 .738 .966 r
.32093 .35015 .32814 .36145 .35058 .36193 .34352 .3508 Mtetra
.552 .747 .968 r
.34352 .3508 .35058 .36193 .37315 .36196 .36623 .35096 Mtetra
.56 .755 .969 r
.36623 .35096 .37315 .36196 .39582 .36163 .38906 .35073 Mtetra
.565 .76 .97 r
.38906 .35073 .39582 .36163 .41861 .36102 .412 .3502 Mtetra
.57 .765 .97 r
.412 .3502 .41861 .36102 .44149 .36017 .43505 .34941 Mtetra
.574 .769 .971 r
.43505 .34941 .44149 .36017 .46448 .35914 .4582 .34841 Mtetra
.577 .772 .971 r
.4582 .34841 .46448 .35914 .48756 .35794 .48145 .34724 Mtetra
.579 .774 .972 r
.48145 .34724 .48756 .35794 .51075 .3566 .5048 .34592 Mtetra
.581 .777 .972 r
.5048 .34592 .51075 .3566 .53403 .35514 .52825 .34448 Mtetra
.583 .779 .973 r
.52825 .34448 .53403 .35514 .5574 .35359 .55179 .34292 Mtetra
.584 .78 .973 r
.55179 .34292 .5574 .35359 .58087 .35194 .57543 .34128 Mtetra
.586 .782 .973 r
.57543 .34128 .58087 .35194 .60443 .35022 .59917 .33955 Mtetra
.587 .783 .973 r
.59917 .33955 .60443 .35022 .62809 .34842 .62301 .33775 Mtetra
.588 .784 .973 r
.62301 .33775 .62809 .34842 .65184 .34657 .64694 .33588 Mtetra
.589 .785 .974 r
.64694 .33588 .65184 .34657 .67569 .34466 .67096 .33395 Mtetra
.589 .786 .974 r
.67096 .33395 .67569 .34466 .69963 .34269 .69509 .33197 Mtetra
.59 .787 .974 r
.69509 .33197 .69963 .34269 .72367 .34068 .7193 .32994 Mtetra
.7193 .32994 .72367 .34068 .7478 .33863 .74362 .32786 Mtetra
.591 .788 .974 r
.74362 .32786 .7478 .33863 .77202 .33654 .76803 .32575 Mtetra
.591 .789 .974 r
.76803 .32575 .77202 .33654 .79634 .33441 .79254 .32359 Mtetra
.592 .789 .974 r
.79254 .32359 .79634 .33441 .82076 .33225 .81715 .3214 Mtetra
.592 .79 .974 r
.81715 .3214 .82076 .33225 .84528 .33006 .84185 .31918 Mtetra
.84185 .31918 .84528 .33006 .86989 .32783 .86666 .31693 Mtetra
.593 .79 .975 r
.86666 .31693 .86989 .32783 .89459 .32558 .89156 .31464 Mtetra
.593 .791 .975 r
.89156 .31464 .89459 .32558 .9194 .32331 .91656 .31233 Mtetra
.91656 .31233 .9194 .32331 .9443 .321 .94166 .31 Mtetra
0 0 .435 r
.14142 .25112 .14963 .26466 .16886 .29889 .16103 .28081 Mtetra
.004 .261 .765 r
.16103 .28081 .16886 .29889 .18936 .31837 .18146 .30279 Mtetra
.227 .463 .877 r
.18146 .30279 .18936 .31837 .21054 .33038 .20266 .3163 Mtetra
.352 .574 .923 r
.20266 .3163 .21054 .33038 .23215 .33815 .22434 .32502 Mtetra
.426 .637 .944 r
.22434 .32502 .23215 .33815 .25405 .34328 .24634 .33079 Mtetra
.471 .677 .955 r
.24634 .33079 .25405 .34328 .27617 .34666 .26858 .33462 Mtetra
.501 .703 .96 r
.26858 .33462 .27617 .34666 .29847 .34884 .29101 .33712 Mtetra
.522 .722 .964 r
.29101 .33712 .29847 .34884 .32093 .35015 .3136 .33867 Mtetra
.537 .735 .966 r
.3136 .33867 .32093 .35015 .34352 .3508 .33634 .3395 Mtetra
.548 .745 .968 r
.33634 .3395 .34352 .3508 .36623 .35096 .35921 .3398 Mtetra
.556 .753 .969 r
.35921 .3398 .36623 .35096 .38906 .35073 .38219 .33967 Mtetra
.563 .759 .97 r
.38219 .33967 .38906 .35073 .412 .3502 .40529 .33921 Mtetra
.568 .764 .971 r
.40529 .33921 .412 .3502 .43505 .34941 .4285 .33847 Mtetra
.572 .768 .971 r
.4285 .33847 .43505 .34941 .4582 .34841 .45182 .33752 Mtetra
.575 .771 .972 r
.45182 .33752 .4582 .34841 .48145 .34724 .47523 .33637 Mtetra
.578 .774 .972 r
.47523 .33637 .48145 .34724 .5048 .34592 .49875 .33507 Mtetra
.58 .776 .972 r
.49875 .33507 .5048 .34592 .52825 .34448 .52237 .33364 Mtetra
.582 .778 .973 r
.52237 .33364 .52825 .34448 .55179 .34292 .54609 .33209 Mtetra
.584 .78 .973 r
.54609 .33209 .55179 .34292 .57543 .34128 .56991 .33045 Mtetra
.585 .781 .973 r
.56991 .33045 .57543 .34128 .59917 .33955 .59383 .32871 Mtetra
.586 .783 .973 r
.59383 .32871 .59917 .33955 .62301 .33775 .61784 .3269 Mtetra
.587 .784 .973 r
.61784 .3269 .62301 .33775 .64694 .33588 .64195 .32502 Mtetra
.588 .785 .974 r
.64195 .32502 .64694 .33588 .67096 .33395 .66616 .32307 Mtetra
.589 .786 .974 r
.66616 .32307 .67096 .33395 .69509 .33197 .69047 .32107 Mtetra
.59 .786 .974 r
.69047 .32107 .69509 .33197 .7193 .32994 .71487 .31902 Mtetra
.59 .787 .974 r
.71487 .31902 .7193 .32994 .74362 .32786 .73938 .31692 Mtetra
.591 .788 .974 r
.73938 .31692 .74362 .32786 .76803 .32575 .76398 .31478 Mtetra
.76398 .31478 .76803 .32575 .79254 .32359 .78868 .3126 Mtetra
.592 .789 .974 r
.78868 .3126 .79254 .32359 .81715 .3214 .81348 .31038 Mtetra
.81348 .31038 .81715 .3214 .84185 .31918 .83837 .30813 Mtetra
.592 .79 .975 r
.83837 .30813 .84185 .31918 .86666 .31693 .86337 .30584 Mtetra
.593 .79 .975 r
.86337 .30584 .86666 .31693 .89156 .31464 .88847 .30353 Mtetra
.593 .791 .975 r
.88847 .30353 .89156 .31464 .91656 .31233 .91367 .30118 Mtetra
.91367 .30118 .91656 .31233 .94166 .31 .93897 .29881 Mtetra
0 .014 .544 r
.13287 .24047 .14142 .25112 .16103 .28081 .15311 .2625 Mtetra
0 .189 .719 r
.15311 .2625 .16103 .28081 .18146 .30279 .17345 .287 Mtetra
.171 .424 .86 r
.17345 .287 .18146 .30279 .20266 .3163 .19467 .30201 Mtetra
.319 .552 .917 r
.19467 .30201 .20266 .3163 .22434 .32502 .21642 .31169 Mtetra
.405 .624 .942 r
.21642 .31169 .22434 .32502 .24634 .33079 .23851 .31811 Mtetra
.457 .669 .954 r
.23851 .31811 .24634 .33079 .26858 .33462 .26087 .3224 Mtetra
.492 .698 .96 r
.26087 .3224 .26858 .33462 .29101 .33712 .28344 .32523 Mtetra
.515 .718 .964 r
.28344 .32523 .29101 .33712 .3136 .33867 .30617 .32701 Mtetra
.532 .732 .967 r
.30617 .32701 .3136 .33867 .33634 .3395 .32906 .32803 Mtetra
.544 .743 .968 r
.32906 .32803 .33634 .3395 .35921 .3398 .35207 .32846 Mtetra
.553 .751 .969 r
.35207 .32846 .35921 .3398 .38219 .33967 .37522 .32843 Mtetra
.56 .757 .97 r
.37522 .32843 .38219 .33967 .40529 .33921 .39848 .32804 Mtetra
.566 .763 .971 r
.39848 .32804 .40529 .33921 .4285 .33847 .42185 .32737 Mtetra
.57 .767 .971 r
.42185 .32737 .4285 .33847 .45182 .33752 .44533 .32645 Mtetra
.574 .77 .972 r
.44533 .32645 .45182 .33752 .47523 .33637 .46892 .32534 Mtetra
.577 .773 .972 r
.46892 .32534 .47523 .33637 .49875 .33507 .49261 .32406 Mtetra
.579 .776 .972 r
.49261 .32406 .49875 .33507 .52237 .33364 .51641 .32263 Mtetra
.581 .778 .973 r
.51641 .32263 .52237 .33364 .54609 .33209 .5403 .32109 Mtetra
.583 .779 .973 r
.5403 .32109 .54609 .33209 .56991 .33045 .5643 .31944 Mtetra
.584 .781 .973 r
.5643 .31944 .56991 .33045 .59383 .32871 .58839 .3177 Mtetra
.586 .782 .973 r
.58839 .3177 .59383 .32871 .61784 .3269 .61259 .31588 Mtetra
.587 .783 .973 r
.61259 .31588 .61784 .3269 .64195 .32502 .63689 .31398 Mtetra
.588 .785 .974 r
.63689 .31398 .64195 .32502 .66616 .32307 .66128 .31202 Mtetra
.66128 .31202 .66616 .32307 .69047 .32107 .68577 .31 Mtetra
.589 .786 .974 r
.68577 .31 .69047 .32107 .71487 .31902 .71037 .30792 Mtetra
.59 .787 .974 r
.71037 .30792 .71487 .31902 .73938 .31692 .73506 .3058 Mtetra
.59 .788 .974 r
.73506 .3058 .73938 .31692 .76398 .31478 .75985 .30363 Mtetra
.591 .788 .974 r
.75985 .30363 .76398 .31478 .78868 .3126 .78475 .30142 Mtetra
.591 .789 .974 r
.78475 .30142 .78868 .3126 .81348 .31038 .80974 .29918 Mtetra
.592 .789 .974 r
.80974 .29918 .81348 .31038 .83837 .30813 .83484 .29689 Mtetra
.592 .79 .975 r
.83484 .29689 .83837 .30813 .86337 .30584 .86004 .29457 Mtetra
.86004 .29457 .86337 .30584 .88847 .30353 .88534 .29223 Mtetra
.593 .791 .975 r
.88534 .29223 .88847 .30353 .91367 .30118 .91074 .28985 Mtetra
.91074 .28985 .91367 .30118 .93897 .29881 .93624 .28744 Mtetra
0 .337 .808 r
.12419 .22967 .13287 .24047 .15311 .2625 .14509 .24397 Mtetra
0 .116 .668 r
.14509 .24397 .15311 .2625 .17345 .287 .16534 .271 Mtetra
.114 .382 .84 r
.16534 .271 .17345 .287 .19467 .30201 .18657 .28753 Mtetra
.285 .529 .91 r
.18657 .28753 .19467 .30201 .21642 .31169 .20838 .29818 Mtetra
.383 .611 .94 r
.20838 .29818 .21642 .31169 .23851 .31811 .23057 .30525 Mtetra
.443 .66 .953 r
.23057 .30525 .23851 .31811 .26087 .3224 .25305 .31 Mtetra
.482 .692 .96 r
.25305 .31 .26087 .3224 .28344 .32523 .27575 .31315 Mtetra
.508 .714 .964 r
.27575 .31315 .28344 .32523 .30617 .32701 .29862 .31518 Mtetra
.526 .729 .967 r
.29862 .31518 .30617 .32701 .32906 .32803 .32166 .31637 Mtetra
.54 .74 .968 r
.32166 .31637 .32906 .32803 .35207 .32846 .34483 .31694 Mtetra
.55 .749 .969 r
.34483 .31694 .35207 .32846 .37522 .32843 .36813 .31701 Mtetra
.558 .756 .97 r
.36813 .31701 .37522 .32843 .39848 .32804 .39156 .3167 Mtetra
.564 .761 .971 r
.39156 .3167 .39848 .32804 .42185 .32737 .4151 .31608 Mtetra
.568 .766 .971 r
.4151 .31608 .42185 .32737 .44533 .32645 .43875 .31521 Mtetra
.572 .769 .972 r
.43875 .31521 .44533 .32645 .46892 .32534 .46251 .31412 Mtetra
.575 .772 .972 r
.46251 .31412 .46892 .32534 .49261 .32406 .48638 .31286 Mtetra
.578 .775 .973 r
.48638 .31286 .49261 .32406 .51641 .32263 .51035 .31145 Mtetra
.58 .777 .973 r
.51035 .31145 .51641 .32263 .5403 .32109 .53442 .30991 Mtetra
.582 .779 .973 r
.53442 .30991 .5403 .32109 .5643 .31944 .5586 .30826 Mtetra
.584 .781 .973 r
.5586 .30826 .5643 .31944 .58839 .3177 .58288 .30651 Mtetra
.585 .782 .973 r
.58288 .30651 .58839 .3177 .61259 .31588 .60726 .30468 Mtetra
.586 .783 .974 r
.60726 .30468 .61259 .31588 .63689 .31398 .63174 .30276 Mtetra
.587 .784 .974 r
.63174 .30276 .63689 .31398 .66128 .31202 .65632 .30078 Mtetra
.588 .785 .974 r
.65632 .30078 .66128 .31202 .68577 .31 .681 .29874 Mtetra
.589 .786 .974 r
.681 .29874 .68577 .31 .71037 .30792 .70579 .29664 Mtetra
.589 .787 .974 r
.70579 .29664 .71037 .30792 .73506 .3058 .73068 .2945 Mtetra
.59 .787 .974 r
.73068 .2945 .73506 .3058 .75985 .30363 .75567 .2923 Mtetra
.591 .788 .974 r
.75567 .2923 .75985 .30363 .78475 .30142 .78076 .29006 Mtetra
.591 .789 .974 r
.78076 .29006 .78475 .30142 .80974 .29918 .80595 .28779 Mtetra
.80595 .28779 .80974 .29918 .83484 .29689 .83125 .28547 Mtetra
.592 .79 .975 r
.83125 .28547 .83484 .29689 .86004 .29457 .85664 .28312 Mtetra
.85664 .28312 .86004 .29457 .88534 .29223 .88215 .28074 Mtetra
.88215 .28074 .88534 .29223 .91074 .28985 .90775 .27832 Mtetra
.593 .791 .975 r
.90775 .27832 .91074 .28985 .93624 .28744 .93347 .27588 Mtetra
.309 .618 .957 r
.11538 .21869 .12419 .22967 .14509 .24397 .13696 .22519 Mtetra
0 .043 .612 r
.13696 .22519 .14509 .24397 .16534 .271 .15711 .25478 Mtetra
.055 .339 .817 r
.15711 .25478 .16534 .271 .18657 .28753 .17835 .27283 Mtetra
.249 .505 .902 r
.17835 .27283 .18657 .28753 .20838 .29818 .20022 .28446 Mtetra
.361 .597 .936 r
.20022 .28446 .20838 .29818 .23057 .30525 .22252 .29219 Mtetra
.429 .651 .952 r
.22252 .29219 .23057 .30525 .25305 .31 .24511 .2974 Mtetra
.472 .686 .96 r
.24511 .2974 .25305 .31 .27575 .31315 .26794 .30089 Mtetra
.5 .709 .964 r
.26794 .30089 .27575 .31315 .29862 .31518 .29096 .30317 Mtetra
.521 .726 .967 r
.29096 .30317 .29862 .31518 .32166 .31637 .31414 .30454 Mtetra
.535 .738 .969 r
.31414 .30454 .32166 .31637 .34483 .31694 .33747 .30524 Mtetra
.546 .747 .97 r
.33747 .30524 .34483 .31694 .36813 .31701 .36094 .30542 Mtetra
.555 .754 .97 r
.36094 .30542 .36813 .31701 .39156 .3167 .38453 .30519 Mtetra
.561 .76 .971 r
.38453 .30519 .39156 .3167 .4151 .31608 .40824 .30462 Mtetra
.567 .765 .972 r
.40824 .30462 .4151 .31608 .43875 .31521 .43206 .30379 Mtetra
.571 .769 .972 r
.43206 .30379 .43875 .31521 .46251 .31412 .456 .30273 Mtetra
.574 .772 .972 r
.456 .30273 .46251 .31412 .48638 .31286 .48004 .30149 Mtetra
.577 .774 .973 r
.48004 .30149 .48638 .31286 .51035 .31145 .50419 .30009 Mtetra
.579 .777 .973 r
.50419 .30009 .51035 .31145 .53442 .30991 .52844 .29855 Mtetra
.581 .778 .973 r
.52844 .29855 .53442 .30991 .5586 .30826 .5528 .2969 Mtetra
.583 .78 .973 r
.5528 .2969 .5586 .30826 .58288 .30651 .57727 .29514 Mtetra
.584 .782 .973 r
.57727 .29514 .58288 .30651 .60726 .30468 .60183 .29329 Mtetra
.586 .783 .974 r
.60183 .29329 .60726 .30468 .63174 .30276 .62651 .29136 Mtetra
.587 .784 .974 r
.62651 .29136 .63174 .30276 .65632 .30078 .65128 .28937 Mtetra
.588 .785 .974 r
.65128 .28937 .65632 .30078 .681 .29874 .67616 .2873 Mtetra
.588 .786 .974 r
.67616 .2873 .681 .29874 .70579 .29664 .70114 .28518 Mtetra
.589 .787 .974 r
.70114 .28518 .70579 .29664 .73068 .2945 .72622 .28301 Mtetra
.59 .787 .974 r
.72622 .28301 .73068 .2945 .75567 .2923 .75141 .28078 Mtetra
.59 .788 .974 r
.75141 .28078 .75567 .2923 .78076 .29006 .7767 .27852 Mtetra
.591 .789 .974 r
.7767 .27852 .78076 .29006 .80595 .28779 .80209 .27621 Mtetra
.80209 .27621 .80595 .28779 .83125 .28547 .82759 .27386 Mtetra
.592 .79 .975 r
.82759 .27386 .83125 .28547 .85664 .28312 .8532 .27147 Mtetra
.8532 .27147 .85664 .28312 .88215 .28074 .87891 .26906 Mtetra
.87891 .26906 .88215 .28074 .90775 .27832 .90472 .26661 Mtetra
.593 .791 .975 r
.90472 .26661 .90775 .27832 .93347 .27588 .93064 .26413 Mtetra
.583 .771 .968 r
.10642 .20755 .11538 .21869 .13696 .22519 .12873 .20618 Mtetra
0 0 .553 r
.12873 .20618 .13696 .22519 .15711 .25478 .14878 .23833 Mtetra
0 .293 .79 r
.14878 .23833 .15711 .25478 .17835 .27283 .17001 .25792 Mtetra
.213 .479 .891 r
.17001 .25792 .17835 .27283 .20022 .28446 .19195 .27054 Mtetra
.338 .582 .933 r
.19195 .27054 .20022 .28446 .22252 .29219 .21433 .27894 Mtetra
.414 .642 .951 r
.21433 .27894 .22252 .29219 .24511 .2974 .23705 .28462 Mtetra
.461 .68 .96 r
.23705 .28462 .24511 .2974 .26794 .30089 .26001 .28844 Mtetra
.493 .705 .964 r
.26001 .28844 .26794 .30089 .29096 .30317 .28317 .29096 Mtetra
.515 .723 .967 r
.28317 .29096 .29096 .30317 .31414 .30454 .30651 .29252 Mtetra
.531 .736 .969 r
.30651 .29252 .31414 .30454 .33747 .30524 .33 .29336 Mtetra
.543 .745 .97 r
.33 .29336 .33747 .30524 .36094 .30542 .35363 .29364 Mtetra
.552 .753 .971 r
.35363 .29364 .36094 .30542 .38453 .30519 .37739 .29348 Mtetra
.559 .759 .971 r
.37739 .29348 .38453 .30519 .40824 .30462 .40127 .29298 Mtetra
.565 .764 .972 r
.40127 .29298 .40824 .30462 .43206 .30379 .42526 .29218 Mtetra
.569 .768 .972 r
.42526 .29218 .43206 .30379 .456 .30273 .44937 .29116 Mtetra
.573 .771 .972 r
.44937 .29116 .456 .30273 .48004 .30149 .4736 .28993 Mtetra
.576 .774 .973 r
.4736 .28993 .48004 .30149 .50419 .30009 .49793 .28854 Mtetra
.578 .776 .973 r
.49793 .28854 .50419 .30009 .52844 .29855 .52237 .28701 Mtetra
.581 .778 .973 r
.52237 .28701 .52844 .29855 .5528 .2969 .54691 .28535 Mtetra
.582 .78 .973 r
.54691 .28535 .5528 .2969 .57727 .29514 .57157 .28358 Mtetra
.584 .781 .973 r
.57157 .28358 .57727 .29514 .60183 .29329 .59632 .28172 Mtetra
.585 .783 .974 r
.59632 .28172 .60183 .29329 .62651 .29136 .62119 .27978 Mtetra
.586 .784 .974 r
.62119 .27978 .62651 .29136 .65128 .28937 .64615 .27776 Mtetra
.587 .785 .974 r
.64615 .27776 .65128 .28937 .67616 .2873 .67123 .27567 Mtetra
.588 .786 .974 r
.67123 .27567 .67616 .2873 .70114 .28518 .69641 .27353 Mtetra
.589 .786 .974 r
.69641 .27353 .70114 .28518 .72622 .28301 .72169 .27133 Mtetra
.589 .787 .974 r
.72169 .27133 .72622 .28301 .75141 .28078 .74708 .26907 Mtetra
.59 .788 .974 r
.74708 .26907 .75141 .28078 .7767 .27852 .77257 .26677 Mtetra
.591 .788 .974 r
.77257 .26677 .7767 .27852 .80209 .27621 .79817 .26443 Mtetra
.591 .789 .974 r
.79817 .26443 .80209 .27621 .82759 .27386 .82388 .26205 Mtetra
.591 .789 .975 r
.82388 .26205 .82759 .27386 .8532 .27147 .84969 .25963 Mtetra
.592 .79 .975 r
.84969 .25963 .8532 .27147 .87891 .26906 .87561 .25718 Mtetra
.87561 .25718 .87891 .26906 .90472 .26661 .90164 .25469 Mtetra
.592 .791 .975 r
.90164 .25469 .90472 .26661 .93064 .26413 .92777 .25217 Mtetra
.617 .786 .963 r
.09733 .19623 .10642 .20755 .12873 .20618 .1199 .19349 Mtetra
0 0 .435 r
.1199 .19349 .12873 .20618 .14878 .23833 .14032 .22166 Mtetra
0 .246 .761 r
.14032 .22166 .14878 .23833 .17001 .25792 .16155 .2428 Mtetra
.175 .453 .88 r
.16155 .2428 .17001 .25792 .19195 .27054 .18355 .25642 Mtetra
.315 .567 .928 r
.18355 .25642 .19195 .27054 .21433 .27894 .20603 .26549 Mtetra
.398 .633 .949 r
.20603 .26549 .21433 .27894 .23705 .28462 .22886 .27164 Mtetra
.451 .674 .959 r
.22886 .27164 .23705 .28462 .26001 .28844 .25196 .2758 Mtetra
.485 .701 .964 r
.25196 .2758 .26001 .28844 .28317 .29096 .27527 .27857 Mtetra
.51 .72 .967 r
.27527 .27857 .28317 .29096 .30651 .29252 .29876 .28031 Mtetra
.527 .733 .969 r
.29876 .28031 .30651 .29252 .33 .29336 .32241 .28129 Mtetra
.54 .744 .97 r
.32241 .28129 .33 .29336 .35363 .29364 .3462 .28167 Mtetra
.549 .751 .971 r
.3462 .28167 .35363 .29364 .37739 .29348 .37013 .28159 Mtetra
.557 .758 .971 r
.37013 .28159 .37739 .29348 .40127 .29298 .39418 .28114 Mtetra
.563 .763 .972 r
.39418 .28114 .40127 .29298 .42526 .29218 .41836 .28039 Mtetra
.568 .767 .972 r
.41836 .28039 .42526 .29218 .44937 .29116 .44265 .27939 Mtetra
.572 .77 .973 r
.44265 .27939 .44937 .29116 .4736 .28993 .46705 .27818 Mtetra
.575 .773 .973 r
.46705 .27818 .4736 .28993 .49793 .28854 .49157 .2768 Mtetra
.578 .775 .973 r
.49157 .2768 .49793 .28854 .52237 .28701 .51619 .27527 Mtetra
.58 .778 .973 r
.51619 .27527 .52237 .28701 .54691 .28535 .54093 .27361 Mtetra
.582 .779 .973 r
.54093 .27361 .54691 .28535 .57157 .28358 .56577 .27183 Mtetra
.583 .781 .974 r
.56577 .27183 .57157 .28358 .59632 .28172 .59072 .26996 Mtetra
.585 .782 .974 r
.59072 .26996 .59632 .28172 .62119 .27978 .61578 .268 Mtetra
.586 .783 .974 r
.61578 .268 .62119 .27978 .64615 .27776 .64094 .26596 Mtetra
.587 .784 .974 r
.64094 .26596 .64615 .27776 .67123 .27567 .66622 .26385 Mtetra
.588 .785 .974 r
.66622 .26385 .67123 .27567 .69641 .27353 .69159 .26168 Mtetra
.588 .786 .974 r
.69159 .26168 .69641 .27353 .72169 .27133 .71708 .25945 Mtetra
.589 .787 .974 r
.71708 .25945 .72169 .27133 .74708 .26907 .74267 .25717 Mtetra
.59 .788 .974 r
.74267 .25717 .74708 .26907 .77257 .26677 .76837 .25484 Mtetra
.76837 .25484 .77257 .26677 .79817 .26443 .79418 .25246 Mtetra
.591 .789 .974 r
.79418 .25246 .79817 .26443 .82388 .26205 .8201 .25004 Mtetra
.591 .789 .975 r
.8201 .25004 .82388 .26205 .84969 .25963 .84612 .24759 Mtetra
.592 .79 .975 r
.84612 .24759 .84969 .25963 .87561 .25718 .87226 .2451 Mtetra
.87226 .2451 .87561 .25718 .90164 .25469 .8985 .24257 Mtetra
.592 .791 .975 r
.8985 .24257 .90164 .25469 .92777 .25217 .92486 .24001 Mtetra
.617 .786 .963 r
.0881 .18473 .09733 .19623 .1199 .19349 .11082 .18195 Mtetra
0 .019 .55 r
.11082 .18195 .1199 .19349 .14032 .22166 .13175 .20475 Mtetra
0 .199 .728 r
.13175 .20475 .14032 .22166 .16155 .2428 .15297 .22746 Mtetra
.137 .425 .867 r
.15297 .22746 .16155 .2428 .18355 .25642 .17502 .24208 Mtetra
.291 .551 .923 r
.17502 .24208 .18355 .25642 .20603 .26549 .1976 .25183 Mtetra
.383 .623 .947 r
.1976 .25183 .20603 .26549 .22886 .27164 .22055 .25845 Mtetra
.44 .667 .958 r
.22055 .25845 .22886 .27164 .25196 .2758 .24378 .26296 Mtetra
.478 .696 .964 r
.24378 .26296 .25196 .2758 .27527 .27857 .26724 .26597 Mtetra
.504 .716 .967 r
.26724 .26597 .27527 .27857 .29876 .28031 .29088 .2679 Mtetra
.523 .731 .969 r
.29088 .2679 .29876 .28031 .32241 .28129 .31469 .26902 Mtetra
.536 .742 .97 r
.31469 .26902 .32241 .28129 .3462 .28167 .33865 .26951 Mtetra
.547 .75 .971 r
.33865 .26951 .3462 .28167 .37013 .28159 .36275 .26951 Mtetra
.555 .756 .972 r
.36275 .26951 .37013 .28159 .39418 .28114 .38698 .26912 Mtetra
.561 .762 .972 r
.38698 .26912 .39418 .28114 .41836 .28039 .41134 .26841 Mtetra
.566 .766 .972 r
.41134 .26841 .41836 .28039 .44265 .27939 .43581 .26743 Mtetra
.57 .77 .973 r
.43581 .26743 .44265 .27939 .46705 .27818 .4604 .26624 Mtetra
.574 .772 .973 r
.4604 .26624 .46705 .27818 .49157 .2768 .4851 .26487 Mtetra
.577 .775 .973 r
.4851 .26487 .49157 .2768 .51619 .27527 .50992 .26334 Mtetra
.579 .777 .973 r
.50992 .26334 .51619 .27527 .54093 .27361 .53484 .26167 Mtetra
.581 .779 .973 r
.53484 .26167 .54093 .27361 .56577 .27183 .55988 .25989 Mtetra
.583 .781 .974 r
.55988 .25989 .56577 .27183 .59072 .26996 .58503 .258 Mtetra
.584 .782 .974 r
.58503 .258 .59072 .26996 .61578 .268 .61028 .25602 Mtetra
.585 .783 .974 r
.61028 .25602 .61578 .268 .64094 .26596 .63565 .25396 Mtetra
.586 .784 .974 r
.63565 .25396 .64094 .26596 .66622 .26385 .66112 .25183 Mtetra
.587 .785 .974 r
.66112 .25183 .66622 .26385 .69159 .26168 .6867 .24963 Mtetra
.588 .786 .974 r
.6867 .24963 .69159 .26168 .71708 .25945 .71239 .24737 Mtetra
.589 .787 .974 r
.71239 .24737 .71708 .25945 .74267 .25717 .7382 .24506 Mtetra
.59 .787 .974 r
.7382 .24506 .74267 .25717 .76837 .25484 .76411 .24269 Mtetra
.59 .788 .974 r
.76411 .24269 .76837 .25484 .79418 .25246 .79013 .24028 Mtetra
.591 .789 .975 r
.79013 .24028 .79418 .25246 .8201 .25004 .81626 .23783 Mtetra
.81626 .23783 .8201 .25004 .84612 .24759 .8425 .23534 Mtetra
.591 .79 .975 r
.8425 .23534 .84612 .24759 .87226 .2451 .86885 .23281 Mtetra
.592 .79 .975 r
.86885 .23281 .87226 .2451 .8985 .24257 .89531 .23024 Mtetra
.89531 .23024 .8985 .24257 .92486 .24001 .92189 .22764 Mtetra
.617 .786 .963 r
.07871 .17305 .0881 .18473 .11082 .18195 .1016 .17022 Mtetra
0 .232 .733 r
.1016 .17022 .11082 .18195 .13175 .20475 .12305 .18761 Mtetra
0 .151 .694 r
.12305 .18761 .13175 .20475 .15297 .22746 .14426 .21189 Mtetra
.097 .396 .852 r
.14426 .21189 .15297 .22746 .17502 .24208 .16636 .22752 Mtetra
.266 .534 .917 r
.16636 .22752 .17502 .24208 .1976 .25183 .18903 .23796 Mtetra
.367 .613 .945 r
.18903 .23796 .1976 .25183 .22055 .25845 .2121 .24506 Mtetra
.429 .66 .957 r
.2121 .24506 .22055 .25845 .24378 .26296 .23547 .24991 Mtetra
.47 .692 .964 r
.23547 .24991 .24378 .26296 .26724 .26597 .25908 .25318 Mtetra
.498 .713 .967 r
.25908 .25318 .26724 .26597 .29088 .2679 .28288 .2553 Mtetra
.518 .728 .969 r
.28288 .2553 .29088 .2679 .31469 .26902 .30685 .25655 Mtetra
.533 .74 .97 r
.30685 .25655 .31469 .26902 .33865 .26951 .33098 .25715 Mtetra
.544 .748 .971 r
.33098 .25715 .33865 .26951 .36275 .26951 .35526 .25723 Mtetra
.553 .755 .972 r
.35526 .25723 .36275 .26951 .38698 .26912 .37966 .25689 Mtetra
.559 .761 .972 r
.37966 .25689 .38698 .26912 .41134 .26841 .4042 .25622 Mtetra
.565 .765 .972 r
.4042 .25622 .41134 .26841 .43581 .26743 .42886 .25528 Mtetra
.569 .769 .973 r
.42886 .25528 .43581 .26743 .4604 .26624 .45363 .2541 Mtetra
.573 .772 .973 r
.45363 .2541 .4604 .26624 .4851 .26487 .47853 .25274 Mtetra
.576 .774 .973 r
.47853 .25274 .4851 .26487 .50992 .26334 .50353 .25121 Mtetra
.578 .777 .973 r
.50353 .25121 .50992 .26334 .53484 .26167 .52866 .24954 Mtetra
.58 .779 .973 r
.52866 .24954 .53484 .26167 .55988 .25989 .55389 .24774 Mtetra
.582 .78 .974 r
.55389 .24774 .55988 .25989 .58503 .258 .57923 .24584 Mtetra
.584 .782 .974 r
.57923 .24584 .58503 .258 .61028 .25602 .60469 .24384 Mtetra
.585 .783 .974 r
.60469 .24384 .61028 .25602 .63565 .25396 .63026 .24176 Mtetra
.586 .784 .974 r
.63026 .24176 .63565 .25396 .66112 .25183 .65594 .2396 Mtetra
.587 .785 .974 r
.65594 .2396 .66112 .25183 .6867 .24963 .68173 .23737 Mtetra
.588 .786 .974 r
.68173 .23737 .6867 .24963 .71239 .24737 .70763 .23508 Mtetra
.589 .787 .974 r
.70763 .23508 .71239 .24737 .7382 .24506 .73364 .23274 Mtetra
.73364 .23274 .7382 .24506 .76411 .24269 .75976 .23034 Mtetra
.59 .788 .974 r
.75976 .23034 .76411 .24269 .79013 .24028 .786 .2279 Mtetra
.59 .788 .975 r
.786 .2279 .79013 .24028 .81626 .23783 .81235 .22541 Mtetra
.591 .789 .975 r
.81235 .22541 .81626 .23783 .8425 .23534 .83881 .22288 Mtetra
.83881 .22288 .8425 .23534 .86885 .23281 .86538 .22031 Mtetra
.592 .79 .975 r
.86538 .22031 .86885 .23281 .89531 .23024 .89206 .2177 Mtetra
.89206 .2177 .89531 .23024 .92189 .22764 .91887 .21506 Mtetra
.617 .786 .963 r
.06918 .16119 .07871 .17305 .1016 .17022 .09223 .15831 Mtetra
.066 .448 .88 r
.09223 .15831 .1016 .17022 .12305 .18761 .11424 .17022 Mtetra
0 .104 .657 r
.11424 .17022 .12305 .18761 .14426 .21189 .13542 .19609 Mtetra
.058 .367 .836 r
.13542 .19609 .14426 .21189 .16636 .22752 .15757 .21274 Mtetra
.241 .517 .911 r
.15757 .21274 .16636 .22752 .18903 .23796 .18034 .22387 Mtetra
.35 .602 .942 r
.18034 .22387 .18903 .23796 .2121 .24506 .20353 .23146 Mtetra
.418 .654 .956 r
.20353 .23146 .2121 .24506 .23547 .24991 .22703 .23666 Mtetra
.462 .687 .963 r
.22703 .23666 .23547 .24991 .25908 .25318 .25078 .24018 Mtetra
.492 .71 .967 r
.25078 .24018 .25908 .25318 .28288 .2553 .27475 .24249 Mtetra
.514 .726 .969 r
.27475 .24249 .28288 .2553 .30685 .25655 .29889 .24389 Mtetra
.529 .738 .97 r
.29889 .24389 .30685 .25655 .33098 .25715 .32319 .24459 Mtetra
.541 .747 .971 r
.32319 .24459 .33098 .25715 .35526 .25723 .34764 .24474 Mtetra
.55 .754 .972 r
.34764 .24474 .35526 .25723 .37966 .25689 .37223 .24447 Mtetra
.558 .76 .972 r
.37223 .24447 .37966 .25689 .4042 .25622 .39694 .24384 Mtetra
.563 .764 .973 r
.39694 .24384 .4042 .25622 .42886 .25528 .42179 .24292 Mtetra
.568 .768 .973 r
.42179 .24292 .42886 .25528 .45363 .2541 .44675 .24176 Mtetra
.572 .771 .973 r
.44675 .24176 .45363 .2541 .47853 .25274 .47184 .2404 Mtetra
.575 .774 .973 r
.47184 .2404 .47853 .25274 .50353 .25121 .49704 .23887 Mtetra
.577 .776 .973 r
.49704 .23887 .50353 .25121 .52866 .24954 .52236 .23719 Mtetra
.58 .778 .974 r
.52236 .23719 .52866 .24954 .55389 .24774 .5478 .23539 Mtetra
.581 .78 .974 r
.5478 .23539 .55389 .24774 .57923 .24584 .57334 .23347 Mtetra
.583 .781 .974 r
.57334 .23347 .57923 .24584 .60469 .24384 .59901 .23145 Mtetra
.584 .783 .974 r
.59901 .23145 .60469 .24384 .63026 .24176 .62478 .22934 Mtetra
.586 .784 .974 r
.62478 .22934 .63026 .24176 .65594 .2396 .65067 .22716 Mtetra
.587 .785 .974 r
.65067 .22716 .65594 .2396 .68173 .23737 .67667 .22491 Mtetra
.587 .786 .974 r
.67667 .22491 .68173 .23737 .70763 .23508 .70278 .22259 Mtetra
.588 .786 .974 r
.70278 .22259 .70763 .23508 .73364 .23274 .72901 .22021 Mtetra
.589 .787 .974 r
.72901 .22021 .73364 .23274 .75976 .23034 .75535 .21778 Mtetra
.59 .788 .974 r
.75535 .21778 .75976 .23034 .786 .2279 .7818 .21529 Mtetra
.59 .788 .975 r
.7818 .21529 .786 .2279 .81235 .22541 .80837 .21277 Mtetra
.591 .789 .975 r
.80837 .21277 .81235 .22541 .83881 .22288 .83505 .21019 Mtetra
.83505 .21019 .83881 .22288 .86538 .22031 .86185 .20758 Mtetra
.591 .79 .975 r
.86185 .20758 .86538 .22031 .89206 .2177 .88876 .20494 Mtetra
.592 .79 .975 r
.88876 .20494 .89206 .2177 .91887 .21506 .91579 .20225 Mtetra
.617 .786 .963 r
.05949 .14913 .06918 .16119 .09223 .15831 .08271 .1462 Mtetra
.321 .623 .959 r
.08271 .1462 .09223 .15831 .11424 .17022 .10529 .15258 Mtetra
0 .057 .62 r
.10529 .15258 .11424 .17022 .13542 .19609 .12645 .18005 Mtetra
.017 .336 .818 r
.12645 .18005 .13542 .19609 .15757 .21274 .14865 .19774 Mtetra
.216 .499 .904 r
.14865 .19774 .15757 .21274 .18034 .22387 .17151 .20956 Mtetra
.334 .591 .939 r
.17151 .20956 .18034 .22387 .20353 .23146 .19481 .21764 Mtetra
.407 .647 .955 r
.19481 .21764 .20353 .23146 .22703 .23666 .21845 .22319 Mtetra
.454 .682 .963 r
.21845 .22319 .22703 .23666 .25078 .24018 .24236 .22697 Mtetra
.486 .706 .967 r
.24236 .22697 .25078 .24018 .27475 .24249 .26648 .22947 Mtetra
.509 .723 .969 r
.26648 .22947 .27475 .24249 .29889 .24389 .29079 .23101 Mtetra
.526 .736 .97 r
.29079 .23101 .29889 .24389 .32319 .24459 .31526 .23182 Mtetra
.539 .745 .971 r
.31526 .23182 .32319 .24459 .34764 .24474 .33989 .23205 Mtetra
.548 .753 .972 r
.33989 .23205 .34764 .24474 .37223 .24447 .36466 .23183 Mtetra
.556 .759 .972 r
.36466 .23183 .37223 .24447 .39694 .24384 .38957 .23124 Mtetra
.562 .763 .973 r
.38957 .23124 .39694 .24384 .42179 .24292 .4146 .23035 Mtetra
.567 .767 .973 r
.4146 .23035 .42179 .24292 .44675 .24176 .43976 .22921 Mtetra
.571 .771 .973 r
.43976 .22921 .44675 .24176 .47184 .2404 .46504 .22786 Mtetra
.574 .773 .973 r
.46504 .22786 .47184 .2404 .49704 .23887 .49044 .22633 Mtetra
.577 .776 .973 r
.49044 .22633 .49704 .23887 .52236 .23719 .51596 .22464 Mtetra
.579 .778 .974 r
.51596 .22464 .52236 .23719 .5478 .23539 .5416 .22282 Mtetra
.581 .779 .974 r
.5416 .22282 .5478 .23539 .57334 .23347 .56735 .22089 Mtetra
.582 .781 .974 r
.56735 .22089 .57334 .23347 .59901 .23145 .59322 .21885 Mtetra
.584 .782 .974 r
.59322 .21885 .59901 .23145 .62478 .22934 .61921 .21672 Mtetra
.585 .783 .974 r
.61921 .21672 .62478 .22934 .65067 .22716 .6453 .21451 Mtetra
.586 .784 .974 r
.6453 .21451 .65067 .22716 .67667 .22491 .67152 .21222 Mtetra
.587 .785 .974 r
.67152 .21222 .67667 .22491 .70278 .22259 .69785 .20987 Mtetra
.588 .786 .974 r
.69785 .20987 .70278 .22259 .72901 .22021 .72429 .20746 Mtetra
.589 .787 .974 r
.72429 .20746 .72901 .22021 .75535 .21778 .75085 .20499 Mtetra
.589 .788 .974 r
.75085 .20499 .75535 .21778 .7818 .21529 .77753 .20247 Mtetra
.59 .788 .975 r
.77753 .20247 .7818 .21529 .80837 .21277 .80432 .1999 Mtetra
.59 .789 .975 r
.80432 .1999 .80837 .21277 .83505 .21019 .83123 .19729 Mtetra
.591 .789 .975 r
.83123 .19729 .83505 .21019 .86185 .20758 .85826 .19464 Mtetra
.591 .79 .975 r
.85826 .19464 .86185 .20758 .88876 .20494 .8854 .19195 Mtetra
.592 .79 .975 r
.8854 .19195 .88876 .20494 .91579 .20225 .91266 .18922 Mtetra
.617 .786 .963 r
.04964 .13687 .05949 .14913 .08271 .1462 .07304 .1339 Mtetra
.518 .738 .974 r
.07304 .1339 .08271 .1462 .10529 .15258 .09622 .13469 Mtetra
0 .012 .581 r
.09622 .13469 .10529 .15258 .12645 .18005 .11735 .16377 Mtetra
0 .305 .799 r
.11735 .16377 .12645 .18005 .14865 .19774 .13959 .1825 Mtetra
.189 .481 .896 r
.13959 .1825 .14865 .19774 .17151 .20956 .16253 .19503 Mtetra
.317 .58 .936 r
.16253 .19503 .17151 .20956 .19481 .21764 .18596 .2036 Mtetra
.395 .64 .954 r
.18596 .2036 .19481 .21764 .21845 .22319 .20974 .2095 Mtetra
.446 .677 .962 r
.20974 .2095 .21845 .22319 .24236 .22697 .23379 .21354 Mtetra
.48 .703 .967 r
.23379 .21354 .24236 .22697 .26648 .22947 .25808 .21623 Mtetra
.505 .721 .969 r
.25808 .21623 .26648 .22947 .29079 .23101 .28255 .21792 Mtetra
.522 .734 .971 r
.28255 .21792 .29079 .23101 .31526 .23182 .30721 .21883 Mtetra
.536 .744 .971 r
.30721 .21883 .31526 .23182 .33989 .23205 .33201 .21915 Mtetra
.546 .751 .972 r
.33201 .21915 .33989 .23205 .36466 .23183 .35697 .21898 Mtetra
.554 .758 .972 r
.35697 .21898 .36466 .23183 .38957 .23124 .38206 .21843 Mtetra
.56 .763 .973 r
.38206 .21843 .38957 .23124 .4146 .23035 .40729 .21757 Mtetra
.565 .767 .973 r
.40729 .21757 .4146 .23035 .43976 .22921 .43265 .21645 Mtetra
.569 .77 .973 r
.43265 .21645 .43976 .22921 .46504 .22786 .45813 .2151 Mtetra
.573 .773 .973 r
.45813 .2151 .46504 .22786 .49044 .22633 .48373 .21357 Mtetra
.576 .775 .974 r
.48373 .21357 .49044 .22633 .51596 .22464 .50945 .21187 Mtetra
.578 .777 .974 r
.50945 .21187 .51596 .22464 .5416 .22282 .5353 .21004 Mtetra
.58 .779 .974 r
.5353 .21004 .5416 .22282 .56735 .22089 .56126 .20809 Mtetra
.582 .781 .974 r
.56126 .20809 .56735 .22089 .59322 .21885 .58734 .20603 Mtetra
.583 .782 .974 r
.58734 .20603 .59322 .21885 .61921 .21672 .61353 .20387 Mtetra
.585 .783 .974 r
.61353 .20387 .61921 .21672 .6453 .21451 .63985 .20163 Mtetra
.586 .784 .974 r
.63985 .20163 .6453 .21451 .67152 .21222 .66628 .19932 Mtetra
.587 .785 .974 r
.66628 .19932 .67152 .21222 .69785 .20987 .69283 .19693 Mtetra
.588 .786 .974 r
.69283 .19693 .69785 .20987 .72429 .20746 .7195 .19448 Mtetra
.588 .787 .974 r
.7195 .19448 .72429 .20746 .75085 .20499 .74628 .19198 Mtetra
.589 .787 .974 r
.74628 .19198 .75085 .20499 .77753 .20247 .77318 .18942 Mtetra
.59 .788 .975 r
.77318 .18942 .77753 .20247 .80432 .1999 .8002 .18681 Mtetra
.59 .789 .975 r
.8002 .18681 .80432 .1999 .83123 .19729 .82734 .18416 Mtetra
.591 .789 .975 r
.82734 .18416 .83123 .19729 .85826 .19464 .8546 .18146 Mtetra
.591 .79 .975 r
.8546 .18146 .85826 .19464 .8854 .19195 .88198 .17873 Mtetra
.592 .79 .975 r
.88198 .17873 .8854 .19195 .91266 .18922 .90948 .17595 Mtetra
.617 .786 .963 r
.03963 .12441 .04964 .13687 .07304 .1339 .0632 .12139 Mtetra
.0632 .12139 .07304 .1339 .09622 .13469 .08686 .11836 Mtetra
0 0 .536 r
.08686 .11836 .09622 .13469 .11735 .16377 .1081 .14725 Mtetra
0 .274 .779 r
.1081 .14725 .11735 .16377 .13959 .1825 .13039 .16703 Mtetra
.163 .462 .887 r
.13039 .16703 .13959 .1825 .16253 .19503 .15342 .18026 Mtetra
.3 .569 .933 r
.15342 .18026 .16253 .19503 .18596 .2036 .17696 .18933 Mtetra
.384 .632 .952 r
.17696 .18933 .18596 .2036 .20974 .2095 .20088 .19559 Mtetra
.438 .672 .962 r
.20088 .19559 .20974 .2095 .23379 .21354 .22509 .1999 Mtetra
.474 .699 .967 r
.22509 .1999 .23379 .21354 .25808 .21623 .24953 .20278 Mtetra
.5 .718 .969 r
.24953 .20278 .25808 .21623 .28255 .21792 .27418 .20461 Mtetra
.519 .732 .971 r
.27418 .20461 .28255 .21792 .30721 .21883 .29901 .20563 Mtetra
.533 .742 .972 r
.29901 .20563 .30721 .21883 .33201 .21915 .324 .20602 Mtetra
.544 .75 .972 r
.324 .20602 .33201 .21915 .35697 .21898 .34915 .20592 Mtetra
.552 .757 .973 r
.34915 .20592 .35697 .21898 .38206 .21843 .37443 .20541 Mtetra
.559 .762 .973 r
.37443 .20541 .38206 .21843 .40729 .21757 .39986 .20457 Mtetra
.564 .766 .973 r
.39986 .20457 .40729 .21757 .43265 .21645 .42541 .20346 Mtetra
.568 .769 .973 r
.42541 .20346 .43265 .21645 .45813 .2151 .45109 .20212 Mtetra
.572 .772 .973 r
.45109 .20212 .45813 .2151 .48373 .21357 .4769 .20059 Mtetra
.575 .775 .974 r
.4769 .20059 .48373 .21357 .50945 .21187 .50283 .19888 Mtetra
.577 .777 .974 r
.50283 .19888 .50945 .21187 .5353 .21004 .52888 .19704 Mtetra
.58 .779 .974 r
.52888 .19704 .5353 .21004 .56126 .20809 .55506 .19507 Mtetra
.581 .78 .974 r
.55506 .19507 .56126 .20809 .58734 .20603 .58135 .19298 Mtetra
.583 .782 .974 r
.58135 .19298 .58734 .20603 .61353 .20387 .60776 .1908 Mtetra
.584 .783 .974 r
.60776 .1908 .61353 .20387 .63985 .20163 .6343 .18853 Mtetra
.585 .784 .974 r
.6343 .18853 .63985 .20163 .66628 .19932 .66095 .18619 Mtetra
.587 .785 .974 r
.66095 .18619 .66628 .19932 .69283 .19693 .68772 .18377 Mtetra
.587 .786 .974 r
.68772 .18377 .69283 .19693 .7195 .19448 .71461 .18128 Mtetra
.588 .787 .974 r
.71461 .18128 .7195 .19448 .74628 .19198 .74163 .17874 Mtetra
.589 .787 .975 r
.74163 .17874 .74628 .19198 .77318 .18942 .76876 .17614 Mtetra
.59 .788 .975 r
.76876 .17614 .77318 .18942 .8002 .18681 .79601 .17349 Mtetra
.79601 .17349 .8002 .18681 .82734 .18416 .82338 .17079 Mtetra
.591 .789 .975 r
.82338 .17079 .82734 .18416 .8546 .18146 .85088 .16805 Mtetra
.85088 .16805 .8546 .18146 .88198 .17873 .8785 .16527 Mtetra
.591 .79 .975 r
.8785 .16527 .88198 .17873 .90948 .17595 .90623 .16245 Mtetra
.617 .786 .963 r
.02946 .11175 .03963 .12441 .0632 .12139 .0532 .10868 Mtetra
.0532 .10868 .0632 .12139 .08686 .11836 .07704 .10559 Mtetra
0 0 .521 r
.07704 .10559 .08686 .11836 .1081 .14725 .09872 .13047 Mtetra
0 .242 .757 r
.09872 .13047 .1081 .14725 .13039 .16703 .12104 .15131 Mtetra
.136 .442 .878 r
.12104 .15131 .13039 .16703 .15342 .18026 .14416 .16526 Mtetra
.282 .557 .929 r
.14416 .16526 .15342 .18026 .17696 .18933 .16782 .17483 Mtetra
.372 .625 .951 r
.16782 .17483 .17696 .18933 .20088 .19559 .19187 .18145 Mtetra
.43 .667 .961 r
.19187 .18145 .20088 .19559 .22509 .1999 .21624 .18602 Mtetra
.468 .695 .966 r
.21624 .18602 .22509 .1999 .24953 .20278 .24085 .1891 Mtetra
.496 .715 .969 r
.24085 .1891 .24953 .20278 .27418 .20461 .26567 .19107 Mtetra
.515 .73 .971 r
.26567 .19107 .27418 .20461 .29901 .20563 .29068 .1922 Mtetra
.53 .741 .972 r
.29068 .1922 .29901 .20563 .324 .20602 .31586 .19267 Mtetra
.541 .749 .972 r
.31586 .19267 .324 .20602 .34915 .20592 .34119 .19263 Mtetra
.55 .756 .973 r
.34119 .19263 .34915 .20592 .37443 .20541 .36667 .19216 Mtetra
.557 .761 .973 r
.36667 .19216 .37443 .20541 .39986 .20457 .39229 .19135 Mtetra
.563 .765 .973 r
.39229 .19135 .39986 .20457 .42541 .20346 .41805 .19025 Mtetra
.567 .769 .973 r
.41805 .19025 .42541 .20346 .45109 .20212 .44394 .18891 Mtetra
.571 .772 .974 r
.44394 .18891 .45109 .20212 .4769 .20059 .46995 .18738 Mtetra
.574 .774 .974 r
.46995 .18738 .4769 .20059 .50283 .19888 .49609 .18567 Mtetra
.577 .776 .974 r
.49609 .18567 .50283 .19888 .52888 .19704 .52236 .18381 Mtetra
.579 .778 .974 r
.52236 .18381 .52888 .19704 .55506 .19507 .54874 .18181 Mtetra
.581 .78 .974 r
.54874 .18181 .55506 .19507 .58135 .19298 .57526 .17971 Mtetra
.582 .781 .974 r
.57526 .17971 .58135 .19298 .60776 .1908 .60189 .1775 Mtetra
.584 .783 .974 r
.60189 .1775 .60776 .1908 .6343 .18853 .62865 .1752 Mtetra
.585 .784 .974 r
.62865 .1752 .6343 .18853 .66095 .18619 .65552 .17282 Mtetra
.586 .785 .974 r
.65552 .17282 .66095 .18619 .68772 .18377 .68252 .17036 Mtetra
.587 .786 .974 r
.68252 .17036 .68772 .18377 .71461 .18128 .70964 .16784 Mtetra
.588 .786 .974 r
.70964 .16784 .71461 .18128 .74163 .17874 .73689 .16526 Mtetra
.589 .787 .975 r
.73689 .16526 .74163 .17874 .76876 .17614 .76425 .16262 Mtetra
.589 .788 .975 r
.76425 .16262 .76876 .17614 .79601 .17349 .79174 .15992 Mtetra
.59 .788 .975 r
.79174 .15992 .79601 .17349 .82338 .17079 .81935 .15718 Mtetra
.59 .789 .975 r
.81935 .15718 .82338 .17079 .85088 .16805 .84709 .15439 Mtetra
.591 .789 .975 r
.84709 .15439 .85088 .16805 .8785 .16527 .87495 .15156 Mtetra
.591 .79 .975 r
.87495 .15156 .8785 .16527 .90623 .16245 .90293 .14869 Mtetra
0 g
.89362 0 m
.98022 .38351 L
s
.98022 .38351 m
1 .65325 L
s
1 .65325 m
.91448 .33294 L
s
.91448 .33294 m
.89362 0 L
s
.02946 .11175 m
0 .4272 L
s
0 .4272 m
.91448 .33294 L
s
.91448 .33294 m
.89362 0 L
s
.89362 0 m
.02946 .11175 L
s
.02946 .11175 m
.89362 0 L
s
gsave
.44797 -0.02478 -65.9056 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(u) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
0 .4272 m
.29069 .70824 L
s
gsave
.15892 .66839 -66.3192 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(p) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{261.5, 185.125},
  ImageMargins->{{30.25, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.095767,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000450000^A000`40O003h00Oogoo1Woo003oOol6
Ool00?moo`Ioo`00ogoo1Woo003oOol6Ool00?moo`Ioo`00PWoo1000Ogoo0021Ool01000Oomoo`00
P7oo0021Ool01000Oomoo`00P7oo0020Ool200000goo00000020Ool00?moo`Ioo`00ogoo1Woo003o
Ool6Ool00?moo`Ioo`00ogoo1Woo003oOol6Ool00?moo`Ioo`00ogoo1Woo003oOol6Ool00?moo`Io
o`00g7oo10009Goo003DOol80003Ool00`00Oomoo`0SOol00<eoo`L000]oo`03001oogoo02=oo`00
aGoo20004Woo0P0097oo002nOol7000JOol2000TOol00;Ioo`P0025oo`8002Aoo`00[goo1`00:Goo
0P0097oo002XOol7000`Ool00`00Ool0000SOol00:1oo`P003Moo`03001oo`0002=oo`00VGoo1`00
@7oo0P008goo002AOol80017Ool2000SOol008Yoo`L004moo`8002=oo`00PWoo2000EWoo00<007oo
00008Woo001kOol7001NOol00`00Ool0000ROol007=oo`P006Eoo`03001oo`00029oo`00K7oo1`00
KGoo00<007oo00008Woo001TOol8001dOol01000Oomoo`008Goo001MOol7001lOol01000Oomoo`00
8Goo001FOol70023Ool01000Oomoo`008Goo001>Ool8002:Ool01000Oomoo`008Goo0017Ool7002B
Ool01@00Oomoogoo000087oo000oOol8002IOol01@00Oomoogoo000087oo000hOol7002QOol01@00
Oomoogoo000087oo000`Ool8002XOol01@00Oomoogoo000087oo000/Ool4000024lnBae?7T/MCci;
7DlN00nXOol01@00Oomoogoo000087oo000/Ool01@00Cai?7TlNBah00dlN00E;7TlNCai?7P0?0:Mo
o`03001oogoo009oo`03001oogoo01eoo`00;7oo00h007ooCci;7DlNBae??T/MCai;7DlnBae?7P0?
Ygoo00D007ooOomoo`0001moo`00;7oo00<007oo00000dlN00E;7TlNCai?7T/N009?7P0301003goo
0:Eoo`05001oogooOol0000OOol002aoo`0@001oogoo001??T/MCai;7DlnBae?7T/MCci;7@0@00nU
Ool01@00Oomoogoo00007goo000/Ool01@00Oomoogoo00000dlN00U;7TlN?]i2oSkN@_hngP0@0=L0
Y7oo00<007ooOol00Woo00<007ooOol077oo000[Ool00`00Oomoo`03Ool03000Cci;7DlNBae2ockN
@_hngT;o01404:Aoo`03001oogoo009oo`03001oogoo01aoo`00:goo00<007ooOol017oo00`004lN
Cai?7T/N@_hngT;n?]i2oP0A0?NSOol00`00Oomoo`02Ool00`00Oomoo`0LOol002]oo`03001oogoo
00Eoo`0<001??T/MCai;7BYn9WdZORIM0380403gW7oo00M77T/oBai;?TLNBcl00004Ool00`00Oomo
o`0LOol002]oo`03001oogoo00Eoo`03001;7TlN009?7P08BahVORIn9WhVO@0B0AP0mi1ooa5;7P03
001oogoo009oo`03001oogoo01aoo`00:goo00<007ooOol01Woo00h004/MCci;7DlNBadZORIm:Wh0
4@0b0?PA^`fkR7oo00E;?d/NBai77T/o009;7P06Aai;?d/NBai77T/o0T/N00U77T/oBai;?TLNBcm;
7T/n00001Goo00<007ooOol06goo000[Ool00`00Oomoo`07Ool00`00Bai?7P02Cah21K/29Wh00`0A
0CT160033K]kOolRBah00`00Oomoo`03Ool00`00Oomoo`0KOol002]oo`03001oogoo00Qoo`0@001;
7DlnBae?7PFk1M`5^`0c0141>@3h4K/=^a7K8Qa]Ool06TLNBcm77T/NAai;?dLNBai77T/oAai;7TLN
Bcm77T/NAai;?dLNBai77T/oAai;7TLNBcl2Bah01TLNBcm;7T/NAai;?`9;7P0;Aai;?d/NBai77T/o
Bai;?TLNBcl00005Ool00`00Oomoo`0KOol002]oo`03001oogoo00Uoo`03001;7TlN009?7P<5^`06
0381>04i4M/Ag0fk0b8m00<R?7ooOol0GGoo00E77T/NBai;7TLN03A;7P03001oogoo00=oo`03001o
ogoo01]oo`00:goo00<007ooOol02Goo01L004lNBae??T/MCah0ePGL05@1>@4H0CTA^a7L4K/R?B8L
8SdR72in;Wd^ORYM04moo`0ZA_i;7dLNBai6oT/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLN
Bam77T/NAai;?dLNBai77T/oAai;7TLNBcm77T/NAai;?dLNBai77T/o0T/N00I77T/oBai;7TLNBcl2
Bah04DLNBcm;7T/NAai;?d/NBci77T/oBai;?TLNBcm;7T/n00001Woo00<007ooOol06Woo000[Ool0
0`00Oomoo`0:Ool00`00Cai;7P03Cah20=H0200c0CT1>04i4M/Ag17K9Sd28Sd3;Wd00bin;WdfWP03
=YhjOol05T/NAai77TLNBai77T/NAai;7TLNBai77T/NAai;7TLNBai77T/NAai;7TLN0d/N00E77T/N
Bai;7TLN00=;7P03Aai;7T/N031;7P03001;7Woo00Aoo`03001oogoo01Yoo`00:goo00<007ooOol0
2goo01`004lNBae??T/MCah0eP3g0CT5F@4H5O`Efa7L8S`VGB8l9SdZGBin;Wd^OS:M=[hbWCJn<Ydj
gP8j_P03=[eoogoo02Qoo`17Bai6oT/OA_i;7TKnBam6oT/NA_i;7dKnBai6oT/OA_i;7TKnBam77T/N
A_i;7dLNBai6oT/OAai;7TKnBam77T/NA_i;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/O
Aai;7TLNBcm77T/NAai;?dLNBai77T/oAai;7TLNBcm77T/NAai;?`02Bah01TLNBcm;7T/NAai;?`9;
7P0@Aai;?d/NBai77T/oBai;?TLNBcm;7T/nAai;?`00Bch5Ool00`00Oomoo`0JOol002Yoo`03001o
ogoo00eoo`9?7P09Bai?7TlNCah0eP2E0ET5F@5I008Eg0055O`R?BHm8SdV?@03;Wd00bin=YhfWP02
=Yh5>[h6?]h01T;N?]hngSkN@_i2gPQ2oP06A_i2oTKn@_i6oT;n24Kn00Y77TKnAai6oTLNA_i77TKn
Aai6oPY77P0BBai77TLNAai;7TLNBai77T/NAai;7TLNBai77T/NAai;7TLN0d/N00E77T/NBai;7TLN
00=;7P03Aai;7T/N039;7P03001;7T/N00Aoo`03001oogoo01Yoo`00:Woo00<007ooOol03Woo01a;
7DlNBae??T/M0340eP1d0CT5F@4i5O`EfaGl9S`VGB8l<Wh^OC:N;WdbOSJM=[hfWCJn=[djgP8j_P1^
=[dngS[N?]hj_T;n?]i2oSkN@_i2gT;n?]i2oT;N@_i2gTKn@_i6oT;NAam2oTKn@_i77d;nAai2oTLO
@_i77TKnAam6oTLNA_i;7dKnAai6oT/OA_i;7TKnBam6oT/NA_i;7dKnBai6oT/OA_i;7TKnBam6oT/N
A_i;7dLNBai6oT/OAai;7TKnBam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/O
Aai;7TLNBcm77T/NAai;?dLNBai77T/oAai;7TLNBcm77T/NAai;?`9;7P06Aai;?d/NBai77T/o0T/N
01=77T/oBai;7TLNBcm;7T/nAai;?d/NBci77T/oBai;?P00Bcm;7P04Ool00`00Oomoo`0JOol002Yo
o`03001oogoo00ioo`04001?7TlNBah2Cah01@0a09D5NPEj1ET00QWl00HEg2IM9SdVGBHm;Wh3;Wd0
1CJn=Yhf_SJN=[h01CZn1SkN00=2gSkN?]h00T;n00=2gT;n@_h01T;n00A6oT;nA_i2oPI6oP0:Aai6
oTKnA_i77TKnAai6oTLNA_h3Aah014KnAai77T/N0dLN00E;7TLNAai77T/N00=77P0:Bai77T/NAai;
7TLNBai77T/NAah3Bah01DLNBai;7T/NAah00d/N00=77T/NBah0=4/N00<004/NBah01Goo00<007oo
Ool06Goo000ZOol00`00Oomoo`0?Ool03000A_i;7TKmBai6oP3G07D5NPEI1GXEf`8Io00B9UdV?2YM
9SdbWRim<Yh^OCJn=Ydf_SJM>]hj_CkN>[hjgSZn0ckN06Xj_T;n?]i2oSkN@_i2gT;n@]i2oT;NA_i2
gTKn@_i6oT;nAam2oTKn@_i77dKnAai2oTLOA_i77TKnAam6oTLNA_i;7dKnAai6oT/OA_i;7TKnBam6
oT/NA_i;7dKnBai6oT/OA_i;7TKnBam77T/NA_i;7dLNBai6oT/OAai;7TKnBam77T/NAai;7dLNBai7
7T/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBcm77T/NAai;?dLNBai77T/oAai;7TLNBcm7
7T/NAai;?`9;7P06Aai;?d/NBai77T/o0T/N01577T/oBai;7TLNBcm;7T/nAai;?d/NBci77T/oBah0
04LN00Eoo`03001oogoo01Uoo`00:Woo00<007ooOol047oo0d/N00E6oT/N0100]P2E00<5NP<Io007
:UdVGBYM:UdbWRim<Wh00SJn00<fWSJn=[h01CZn1CkN00A2gSkN@_hngP=2oP04@]i2oT;nA_h3@_h0
0dKn@_i6oP02A_h014;nA_i6oTLN0dKn00Y77TKnAai6oTLNA_i77TKnAai6oP=77P04A_i77TLNBah3
Aah04T/NAai77TLNBai77T/NAai;7TLNBai77T/NAai;7TLNBai77P=;7P05Aai;7T/NBai77P0iBah0
0`00Baioo`04Ool00`00Oomoo`0IOol002Yoo`03001oogoo015oo`0;Bai6oT/NA_e;7P2f09D9NPEj
1ETN70026O`04BIM:UdV?BYM<WdbWRim<YhfWCZn=Ydj_SJM?]hj_CkN>[h00SkN00a2gSkN?]hngT;n
?]i2oSkN@_i2gT;n@]h2@_h0EdKn@]i6oT;nA_i2oTLO@_i6oT;nAam6oTLN@_i77dKnAai6oTLOA_i7
7TKnBam6oTLNA_i;7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dKnBai6oT/OAai;7TKnBam77T/NA_i;
7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/oAai;
7TLNBcm77T/NAai;?`02Bah01TLNBcm;7T/NAai;?`9;7P06Aai;?d/NBai77T/o0T/N00m77T/oBai;
7TLNBcm;7T/nAai;?d/NBci77P00Bah01Goo00<007ooOol06Goo000ZOol00`00Oomoo`0BOol03BIn
9WdVORIm00d0]P2E2GX9VPEj7Q`Io1hL008ZG@059UdZGC:M<YhbO@03=[h013JN=[hj_S[N0cZn1SkN
0T;N00=2oSkN@_h01D;n00I6oT;n@_i2oTKn@_h6A_h02TLNA_i6oTKnAai6oTLNA_i77TKn0dLN00E6
oTLNAai77TKn00977P05Bai77TLNAai;7P03Aah03T/NAai;7TLNBai77T/NAai;7TLNBai77T/NAah3
Bah01DLNBai;7T/NAah0=d/N00<004/NBah01Goo00<007ooOol067oo000ZOol00`00Oomoo`0COol0
62In9UdVOP0b0?P0]PVK2GX9VaWl7Q`Io2in:UdZOBYM<YhbOC:N<Wdj_SJM>[hfW@8j_P03?]hj_CkN
00<ngP1U@]hngT;n?]i2oSkN@_i2gTKn@]i2oT;NA_i2oTKn@_i6oT;nAai2oTLN@_i77T;nAam6oTLN
@_i77dKnAai6oTLOA_i77TKnBam6oT/NA_i;7dKnBai6oT/OA_i;7TKnBam77T/NA_i;7dLNBai6oT/O
Aai;7TKnBam77T/NA_i;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBcm77T/N
Aai;?dLNBai77T/oAai;7TLNBcm77T/NAai;?`02Bah01TLNBcm;7T/NAai;?`9;7P06Aai;?d/NBai7
7T/o0T/N00i77T/oBai;?TLNBcm;7T/nAai;?d/N00177T/o1Goo00<007ooOol067oo000ZOol00`00
Oomoo`0COol02P009WhVOBIn00d0m`2f2IX9NR8L0QhL00<Io2YM:Ud00RYM00`bWS:M=YhbWCZn=[hj
_SJn?]hj_SkN>[h6?]h014;n@]i2oT;N1T;n00A6oT;nA_i2oPI6oP0:Aai6oTKnA_i77TKnAai6oTLN
A_h3Aah01DKnAai77TLNA_h00dLN00A6oTLNAai;7P=77P0:Bai77T/NAai;7TLNBai77T/NAah3Bah0
1DLNBai;7T/NAah0?D/N00@004/NBai;7PAoo`03001oogoo01Qoo`00:Woo00<007ooOol057oo08H0
005I9Ud0<`3G0?P=VQ6k2GXR7AhL8QdZGBin:UdZOC9m=YhbWCJN<Wdj_SJm>[hfWCkN>[hngSZm@_hn
gT;N?]i2oSkN@_hngT;n?]i2oT;NA_i2gT;n@]i6oT;nA_i2oTKn@_i77T;nAai2oTLN@_i77dKnAai6
oT/OA_i77TKnBam6oT/NA_i;7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dLNBai6oT/OAai;7TKnBam7
7T/NA_i;7dLNBai6oT/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/NAai;?dLNBai7
7T/oAai;7TLNBcm77T/NAai;?dLNBai77T/o0T/N00I77T/oBai;7TLNBcl2Bah05DLNBcm;7T/nAai;
?d/NBci77T/oBai;?TLNBcm;7T/nAah004/NBci77P04Ool00`00Oomoo`0HOol002Yoo`03001oogoo
01Eoo`040001F@0b03<20?L03PfK4K/N728L7Q`R72YM;Wd^GBim<YdbWS:M=Yh5>[h3?]h00cZn?]hn
gP03?]h01D;N@_i2gT;n@]h01T;n00A6oT;nA_i2oPI6oP0:Aai6oTKnA_i77TKnAai6oTLNA_h3Aah0
14KnAai77T/N0dLN019;7TLNAai77T/NAai;7TLNBai77T/NAai;7TLNBai77T/NAah3Bah01DLNBai;
7T/NAah0>d/N00@004/NBai;7PAoo`03001oogoo01Qoo`00:Goo00<007ooOol05goo07h0005I0381
>@3G5M`=VQ6k8Q`R7AhL;WdZGBin:Ud^OC:M=YhbWCJN=Ydj_SJm>[hj_CkN>[hngSZm@_hngT;N?]i2
oT;N@_hngT;n@]i6oT;NA_i2oTKn@_i77T;nA_i2oTLN@_i77T;nAai6oTLNA_i77dKnAai6oT/OA_i7
7TKnBam6oT/NA_i;7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dLNBai6oT/OAai;7TKnBam77T/NAai;
7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBcm77T/NAai;?dLNBai77T/oAai;
7TLNBcl2Bah01TLNBcm;7T/NAai;?`9;7P06Aai;?d/NBai77T/o0T/N01=77T/oBai;?TLNBcm;7T/n
Aai;?d/NBci77T/oBah004LNBcm;7P05Ool00`00Oomoo`0GOol002Uoo`03001oogoo01Qoo`0D0ET0
<`0b0CP0maFk4K/R?B8L8SdR?2im:Ud^OBiM=YhbWCJN=YdfWPDj_P<ngP09>[hngSkN@]hngT;n@]i2
oT;N00I2oP04A_i2oTKn@_h8A_h02TLNA_i6oTKnAai6oTLNA_i77TKn0dLN00A6oTLNAai;7P=77P0B
Bai77TLNAai;7TLNBai77T/NAai;7TLNBai77T/NAai;7TLN0d/N00E77T/NBai;7TLN03U;7P04001;
7T/NBah5Ool00`00Oomoo`0GOol001Aoo`<0019oo`03001oogoo01Qoo`0L0001>00c1CT1>A6k5M`A
^bHm8Q`V?B8L<Wh^GC9n;WdfWS:M=YhbWCZn>[djgSZm>[hj_CkN?[h2?]h024;n?]i2oSkN@_i2gT;n
?]h2@_h0EdKn@]i6oT;nA_i2oTLN@_i6oT;nAai6oTLN@_i77TKnAai6oTLNA_i77TKnBam6oT/NA_i;
7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dKnBai6oT/OAai;7TKnBam77T/NA_i;7dLNBai77T/OAai;
7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/NAai;?dLNBai77T/oAai;7TLNBcm77T/NAai;
?`02Bah01TLNBcm;7T/NAai;?`9;7P06Aai;?d/NBai77T/o0T/N01977T/oBai;?TLNBcm;7T/nAai;
?d/NBci77P00Bai;?TLNBcl4Ool00`00Oomoo`0GOol001Eoo`03001oogoo015oo`03001oogoo01Uo
o`0:00d0E00c1ET1>1WK5K/A^bHm9S`29Sd4;Wd013JN=YdfWSJN1CZn1CkN00A2gSkN@]hngP=2oP04
@]i2oT;nA_h3@_h00dKn@_i6oP09A_h02TLNA_i6oTKnAai6oTLNA_i77TKn0dLN00A6oTLNAai;7P=7
7P0:Bai77TLNAai;7TLNBai77T/NAah3Bah01DLNBai;7T/NAah00d/N00E77T/NBai;7TLN03M;7P03
001;7T/N009;7PAoo`03001oogoo01Moo`004goo0`004goo00<007ooOol06Goo07`0<P0a0385FPDi
6O`EfaWl5M/V?BHl9UdV?3:N;UdbOSJM=[hfWCJn>[dngSZm?]hj_CkN?[e2gSkN@_hngT;n?]i2oT;N
@_i2gT;n@]i6oT;nA_i2gTKn@_i6oT;nAai2oTLN@_i77TKnAai6oTLNA_i77TKnBam6oTLNA_i;7dKn
Bai6oT/OA_i;7TKnBam6oT/NA_i;7dKnBai6oT/OA_i;7TKnBam77T/NA_i;7dLNBai6oT/OAai;7TLN
Bam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/oAai;7TLNBcm77T/NAai;?`9;
7P06Aai;?d/NBai77T/o0T/N00I77T/oBai;7TLNBcl2Bah054LNBcm;7T/NAai;?d/NBci77T/oBai;
?TLNBcm;7P00Aai;?d/NBch5Ool00`00Oomoo`0FOol0019oo`04001oogoo000COol00`00Oomoo`0J
Ool00`0=0;H5F@021ET01aWL6M/Ig1WK:UdV?2Hm008bO@06;WdbOCJN=YhfWCJN1CZn13kN00I2oSkN
@]i2gT;n@]h3@_h01D;NA_i2oTKn@_h01TKn00Y77TKnA_i6oTLNA_i77TKnAai6oP=77P05A_i77TLN
Aai6oP06Aah03T/NAai;7TLNBai77T/NAai;7TLNBai77T/NAah3Bah01DLNBai;7T/NAah0?D/N00<0
04/NBah00T/N1Goo00<007ooOol05Woo000BOol01000Oomoo`004goo00<007ooOol06Woo01P0<`0@
07D5>@EJ1CTMo1GK6O`V?2YM9S`ZGBim<Yh^OC:N=Ydj_SJM?]hj_CkN>[d3?]h0HSjm@]hngT;n?]i2
oSkN@_i2gTKn@]i2oT;NA_i2oTKn@]i77T;nA_i2oTLNA_i77T;nAai6oTLNA_i77TKnAai6oT/OA_i7
7TKnBam6oT/NA_i;7dKnBai6oT/OA_i;7TKnBam77T/NA_i;7dLNBai6oT/OAai;7TKnBam77T/NAai;
7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/oAai;7TLNBcm77T/NAai;?dLNBai77T/oAai;
7TLNBcl2Bah01TLNBcm;7T/NAai;?`9;7P0JAai;?d/NBai77T/oBai;?TLNBcm;7T/nAai;?d/NBci7
7T/oBai;?TLN001;7T/nAai;?`Eoo`03001oogoo01Ioo`004goo10004Woo00<007ooOol06goo00D0
3@2f3GX9NPEI00@Mo00@:SdZGBXm<YdbOC:N<Wdf_SJN>[hfWCjn>[hngSZn?[h5?]h01T;n@]i2gT;N
@_i2gPA2oP04A_i2oTKn@_h6A_h02TLNA_i6oTKnAai6oTLNA_i77TKn0dLN00E6oTLNAai;7TKn0097
7P0>Bai77TLNAai;7TLNBai77T/NAai;7TLNBai77P=;7P05Aai;7T/NBai77P03Bah00dLNBai;7P0i
Bah00`00Bai;7P03Bah4Ool00`00Oomoo`0FOol002Uoo`03001oogoo01]oo`0:0185602f3GX9N@fJ
7O/Mo1Wk;Ud2:Ud0JRHl=YhbOC:N<Wdj_SJM>[hfWCkN>[dngSZm@]hngT;N?]e2gSkN@_hngT;n?]i6
oT;NA_i2gTKn@_i6oT;nA_i2oTLN@_i77T;nAai6oTLNA_i77TKnAai6oT/NA_i77TKnBam6oT/NA_i;
7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dLNBai6oT/OAai;7TKnBam77T/NA_i;7dLNBai77T/OAai;
7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBcm77T/NAai;?dLNBai77T/o0T/N00I77T/oBai;7TLN
Bcl2Bah01TLNBcm;7T/NAai;?`9;7P0IAai;?d/NBci77T/oBai;?TLNBcm;7T/nAai;?d/NBci77T/o
Bah004LNBcm;7T/nAah01Goo00<007ooOol05Goo000YOol00`00Oomoo`0KOol0202E00d0m`2f3GX9
NPej8Q`27O`022iM:Ud^GC9m<YdbOC:N>[d3>[h01CZm?]hn_SkN?[h01CkN00=2gT;n@]h00T;N14;n
00A6oT;nA_i2oPQ6oP0:Aai6oTKnA_i77TKnAai6oTLNA_h3Aah014KnAai77T/N0dLN00i;7TLNAai7
7T/NAai;7TLNBai77T/NAai;7TLN0d/N00E77T/NBai;7TLN03i;7P03001;7T/N009;7PEoo`03001o
ogoo01Eoo`00:7oo00<007ooOol07Goo00H0<P3g1APAVQFk2GT38Q`0KRYL;UdZGBiM<WdfWS9m=Yhf
WCZn=Ydj_SZm?]hj_CkN>[e2oSkN@]hngD;n@]i2oSkN@_i2gTKn@]i6oT;NA_i2oTKn@_i6oT;nAai6
oTLN@_i77TKnAai6oTLNA_i77TKnBai6oT/NA_i;7TKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dKnBai6
oT/OAai;7TKnBam77T/NA_i;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBam7
7T/NAai;?dLNBai77T/oAai;7TLNBcl2Bah01TLNBcm;7T/NAai;?`9;7P06Aai;?d/NBai77T/o0T/N
01M77T/oBai;?TLNBcm;7T/nAai;?d/NBci77T/oBai;?TLNBcl004/nAai;?d/N00Eoo`03001oogoo
01Eoo`00:7oo00<007ooOol07Goo00L0U@0b0?L0ma6J5K/AVP038Q`2;Ud00bYM=YhbW@02=Yd00cJN
>[dj_P02>[h00cjn?]hn_P04?]h01T;N?]i2oT;N@_i2gP92oP03A_i2oT;n0096oP03@_i6oTKn00Q6
oP0:Aai6oTKnA_i77TKnAai6oTLNA_h6Aah03T/NAai;7TLNBai77T/NAai;7TLNBai77T/NAah3Bah0
1DLNBai;7T/NAah0@4/N00<004/NBah00T/N1Goo00<007ooOol05Goo000XOol00`00Oomoo`0MOol0
N@2E07@9F@3g7M/AVQFk9Q`Z?B8L<Wd^GC9m;UdfWS9m=YhbOCZn>Ydj_SZm>[hj_CkN?[dngSkM@_hn
gT;N?]e2oT;N@_i2gTKn@]i6oT;NA_i2oTKn@_i6oT;nAai2oTLNA_i77TKnBai6oTLNA_i;7TKnBai6
oT/NA_i;7TKnBai6oT/NA_i;7dKnBai6oT/OA_i;7TKnBam77T/NA_i;7dLNBai6oT/OAai;7TLNBam7
7T/NAai;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/oAai;7TLNBcm77T/NAai;?dLNBai7
7T/o009;7P06Aai;?d/NBai77T/o0T/N00I77T/oBai;7TLNBcl2Bah05TLNBcm;7T/nAai;?d/NBci7
7T/oBai;?TLNBcm;7T/n001;?d/NBci77T/o17oo00<007ooOol05Goo000XOol00`00Oomoo`0MOol0
1@Cg09D0<PUI0?L00QWK00TE^bHL9S`V?2im;Ud^OBiM=Yh00cJM00Hj_SZm>[hj_SkN?[h2?]h00d;N
?]i2gP03@]h014;n@]i2oT;N0T;n00=6oT;n@_h03DKn00I77TKnAai6oTLNA_h3Aah014KnAai77T/N
0dLN00Y;7TLNBai77T/NAai;7TLNBai77P=;7P05Aai;7T/NBai77P03Bah00dLNBai;7P0lBah00`00
Bai;7P03Bah5Ool00`00Oomoo`0DOol002Qoo`03001oogoo01ioo`0O07@0U@Th2ETI^agK6K/V?BHL
:SdV739m;UdbOS9m=YhfWCZN=Ydn_SZm?]hj_D;N?[e2gSjm@]hngD;n?]h00T;N0552oT;N@_i2gTKn
@_i6oT;NAai2oTKn@_i77TKnAai2oTLNA_i77TKnBai6oTLNA_i;7TKnBai6oT/NA_i;7TKnBai6oT/N
A_i;7dKnBai6oT/OA_i;7TKnBam77T/NA_i;7dLNBai6oT/OAai;7TLNBam77T/NAai;7dLNBai77T/O
Aai;7TLNBam77T/NAai;7dLNBai77T/oAai;7TLNBcl00T/N00I77T/oBai;7TLNBcl2Bah01TLNBcm;
7T/NAai;?`9;7P0MAai;?d/NBai77T/oBai;?TLNBcm;7T/nAai;?d/NBci77T/oBai;?TLNBcl004/n
Aai;?d/NBci77P04Ool00`00Oomoo`0DOol002Qoo`03001oogoo01ioo`052?L0M1FJ2CT9F@036M/0
0bXm9Q`V?004<Wd023JM>[hfWCZN>[hn_SZm>[h5?]h6@]h3@_h01D;NA_i2oTKn@_h02TKn00Y77TKn
Aai6oTLNA_i77TKnAai6oP977P05Bai6oTLNAai;7P03Aah02T/NAai;7TLNBai77T/NAai;7TLN0d/N
00=77T/NBah0@T/N00<004/NBah014/N17oo00<007ooOol057oo000XOol00`00Oomoo`0OOol01@TG
07@EVQEi8O`00QgK00@Z?2iM:S`^G@8bO@1R;UdbOSJM>[hfWCZn>[dngSZm?]hn_D;N?[e2gSjm@_hn
gD;n?]i6oT;MA_i2gTKn@]i6oT;nA_i2gTLN@_i6oT;nAai6oTLNA_i77TKnAai6oT/NA_i;7TKnBai6
oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7dLNBai6oT/OAai;7TKnBam77T/NA_i;7dLNBai7
7T/OAai;7TLNBam77T/NAai;7dLNBai77T/oAai;7TLNBcm77T/NAai;?`9;7P06Aai;?d/NBai77T/o
0T/N00I77T/oBai;7TLNBcl2Bah07dLNBcm;7T/NAai;?d/NBci77T/oBai;?TLNBcm;7T/nAai;?d/N
Bci77T/oBai;?P00Bcm;7T/nAai;?d/N00Aoo`03001oogoo01Aoo`00:7oo00<007ooOol07goo01<4
m`2E5GTEVQEj8O`Qnb7l:S`Z?BXl:SdfOCJM<WdjWSJM>[hfW@03?[h013Zm?[hngT;N0SkN00=2gT;n
@]h00T;N00I6oT;n@_i2oTKn@_h:A_h02TLNA_i6oTKnAai6oTLNA_i77TKn0dLN0156oTLNAai;7TKn
Bai77T/NAai;7TLNBai77T/NAai;7TLN00=;7P05Aai;7T/NBai77P0nBah50006Bah5Ool00`00Oomo
o`0COol002Qoo`03001oogoo01moo`0L6GT4mQFJ4GTEVQEi8O`Mfc9M;U`bGBiL=YhbOCJM<Wdj_SZM
>[hjWCkN>[dngSZm@]hngD;N?[d2@]h03d;n@]e2oT;NA_i2gDKn@]i6oT;nA_i2oTKn@_i77P02A_h0
?T;nAai6oTLNA_i77TKnAai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai77T/NA_i;
7dLNBai6oT/OAai;7TKnBam77T/NA_i;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/oAai;
7TLNBcl2Bah01TLNBcm;7T/NAai;?`9;7P06Aai;?d/NBai77T/o0T/N00I77T/oBai;7TLNBcl2Bah0
14LNBcm;7T/n2P0000a;7T/nAai;?`00Bci77T/oBai;?TLNBcl4Ool00`00Oomoo`0COol002Qoo`03
001oogoo01moo`096EPIN0Cg5IXENAFJ9Q`Z727k00<^G@03;U`fWCJM008fW@04>[hj_CZn>Yd2?[h0
0ckN?[e2gP02@]h013kN@]i2gT;n0T;N00=2oTKn@_h00T;n00=6oT;nA_h02DKn00I77TKnAai6oTLN
A_h2Aah01D/NA_i77TLNBah00dLN00Y;7TLNBai77T/NAai;7TLNBai77P=;7P05Aai;7T/NBai77P0]
Bah9000?Bah00`00Bai;7P04Bah4Ool00`00Oomoo`0COol002Qoo`03001oogoo021oo`1Z5EPINAfj
8M/ANAFJ9Q/Z72iL<Ud^G39M=WdjWSIm>YhjWCjn>[dn_Sjm?]hn_CkN?]e2gSkM@]hngDKn@]i2oT;M
A_i2gTKn@]e6oT;NA_i2oTKn@_i77TKnAai6oTLNA_i;7TKnAai6oT/NA_i;7TKnBai6oT/NA_i;7TKn
Bai6oT/NA_i;7TKnBai6oT/NA_i;7dLNBai6oT/OAai;7TKnBam77T/NAai;7dLNBai77T/OAai;7TLN
Bam77T/NAai;7dLNBai77T/OAai;7TLNBcl2Bah01TLNBcm;7T/NAai;?`9;7P03Aai;?d/N00X0000O
Bcm;7T/NAai;?d/NBci77T/oBai;?TLNBcm;7T/nAai;?d/NBci77T/oBai;?TLN001;7T/nBai;?d/N
Bch017oo00<007ooOol04goo000WOol00`00Oomoo`0QOol03AUi6EPIN1fj8M/M^RXL9Q`Z739M<Wdb
GC9m00@fW@05>[dn_SZm?[hn_@04?]h3@]h02CkN@_i2gT;n@]i6oT;nA_i2oP0:A_h02TLNA_i6oTKn
Aai6oTLNA_i77TKn0TLN00i;7TKnAai77T/NAai;7TLNBai77T/NAai;7TLN0d/N00E77T/NBai;7TLN
01a;7PT0029;7P03001;7T/N00A;7PAoo`03001oogoo01=oo`009goo00<007ooOol08Goo00HIF1Ui
5EPZ6afj8M/2;S`07bHK<WdbG3Im<U`jWSJM>[hjWCjn>Ydn_SZm@]hn_D;N?[e2gSkM@_i2gD;N?]e6
oT;NA_i2gDKn@_i6oT;M00=6oP0k@_i77TKnAai6oTLNA_i77TKnBai6oTLNA_i;7TKnBai6oT/NA_i;
7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBam77T/NA_i;7dLNBai6oT/OAai;7TLNBam77T/NAai;
7dLNBai77T/OAai;7TLNBam77P0900001TLNBcm;7T/NAai;?`9;7P06Aai;?d/NBai77T/o0T/N00I7
7T/oBai;7TLNBcl2Bah06TLNBcm;7T/nAai;?d/NBci77T/oBai;?TLNBcm;7T/nAai;?d/N00177T/o
Bai;?T/NBcl5Ool00`00Oomoo`0BOol002Moo`03001oogoo029oo`036EPINAUH008Yn`088M/^?2hl
;S`bOC9M<WdbG@@jW@06?[hn_Cjn?[dngSjm0ckN1D;N00A2oT;N@_i2gP=6oP03@_i6oTKn00Q6oP0:
Aai6oTKnA_i77TKnAai6oTLNA_h2Aah03T/NA_i;7TLNBai77T/NAai;7TLNBai77T/NAah3Bah01DLN
Bai;7T/NAah01d/N2P00=D/N00<004/NBah014/N17oo00<007ooOol04Woo000WOol00`00Oomoo`0R
Ool01RWJ:KTINBWj:Q/Yn`@^?00O=WdfO3ZM>YdjWSJM>[hn_Cjn>[dngSjm@]hn_D;N?[e2gT;MA_i2
gD;n@]e6oT;NA_i2gDKn@_i6oT;MAah00dKn02E77TKnAai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6
oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai77T/NA_i;7`0900002d/NAai;7dLNBai7
7T/OAai;7TLNBcl00T/N00I77T/oBai;7TLNBcl2Bah01TLNBcm;7T/NAai;?`9;7P06Aai;?d/NBai7
7T/o0T/N02577T/oBai;?TLNBcm;7T/nAai;?d/NBci77T/oBai;?TLNBcm;7T/nAai;?d/NBci;7T/o
001;?T/NBcm;7T/nBah017oo00<007ooOol04Woo000WOol00`00Oomoo`0SOol2:KT4:O/013IL<U`f
G39L0cIm00PjWCjm>Ydj_Cjm?[hn_Cjn0T;N00<ngD;N@]h014;N00A6oT;NA_i2oPa6oP0:Aai6oTKn
A_i77TKnAai6oT/NA_h2Aah02T/NA_i77TLNBai77T/NAai;7TLN0T/N2P00B4/N00<004/NBah014/N
17oo00<007ooOol04Woo000WOol00`00Oomoo`0SOol03BFi:MXY^C8l:OXZ6c9L=U`b?3IM>WdjWCYl
008jW@0^?[hjWCjn?[e2gSjm@]i2gD;N?]e2gT;MA_i2gDKn@]e6oT;MA_i2gTKn@]e6oT;nA_i6oDLN
A_i77TKmBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_h9000084LNBai6oT/NAai;7TKnBai7
7T/NA_i;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBcl2Bah01TLNBcm;7T/N
Aai;?`9;7P06Aai;?d/NBai77T/o0T/N00I77T/oBai;7TLNBcl2Bah07dLNBcm;7T/nAai;?d/NBci7
7T/oBai;?TLNBcm;7T/nBai;?d/NBci;7T/oBai;?P00Bcm;7T/nBai;?d/N00Eoo`03001oogoo015o
o`009goo00<007ooOol08goo00<f6SGj:KT00S8k00Hb6c8k<U`fG39L=U`2>Yd00cYm>Ydn_@02?[d0
1Cjn?[dngSjm?[h00T;N00A2gD;N@]i6oP=2gP03A_i2oTKn00e6oP03Aai6oTLN00X00009A_i;7TLN
Bai77T/NAai;7TLN00=;7P03Aai;7T/N04e;7P03001;7T/N00A;7PAoo`03001oogoo015oo`009goo
00<007ooOol097oo02Hj6SGi>QXb6c8l<Q/jOCIL>WdfG3ZM>WdjWCYl?[hnWCjn?Ye2gSjm@]hn_DKn
@]e2gT;MA_i2gDKn@]e6oT;NA_i2gDKn@]i6oT;m0TKn00=77P0000001`0002e;7TKnBai6oT/NA_i;
7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai77T/NA_i;7TLNBai6oT/NAai;7TLNBam77T/NAai;
7dLNBai77T/OAai;7TLNBal00T/N00I77T/OBai;7TLNBcl2Bah01TLNBcm;7T/NAai;?`9;7P06Aai;
?d/NBai77T/o0T/N00I77T/oBai;7TLNBcl2Bah07TLNBcm;7T/nAai;?d/NBci77T/oBai;?T/NBcm;
7T/nBai;?d/NBci;7T/oBah004/NBcm;7T/nBai;?`D001=oo`009goo00<007ooOol097oo00LenSHJ
=OXf6SYK<S/b6`04>W`4?Yd4?[d014;N@[e2gT:m0d;N00E2gD;N@]i6oT;N00X000Q6oP0BAai6oTLN
A_i;7TKnBai77T/NA_i;7TLNBai77T/NAai;7TLNED/N00<004/NBah014/N17oo00<007ooOol04Goo
000WOol00`00Oomoo`0TOol03CXJ=OTj6SGi?U`jFcYL=U`jOCIL>WdjW3jm008nW@07>Ya2gSjm@[i2
_DKN@[d02@0000E2gDKn@_i6oT;M00=6oP0fA_e77TKnAai6oD/NA_i;7TKnBai6oT/NA_i;7TKnBai6
oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai77T/NA_i;7TLNBai6oT/NAai;7TLNBai7
7T/NAai;7dLNBai77T/O0T/N00I77T/oBai;7TLNBcl2Bah01TLNBcm;7T/NAai;?`9;7P06Aai;?d/N
Bai77T/o0T/N02Q77T/oBai;7TLNBcm;7T/nAai;?d/NBci77T/oBai;?TLNBcm;7T/nBai;?d/NBci;
7T/oBai;?T/NBcm;7T/nBah004/NBci;7T/oBai;?PAoo`03001oogoo015oo`009goo00<007ooOol0
97oo0T8j00<enSHJ=OX00SYK00DjG3il?Y`nO3jM00X00007@]e2gT;MA]i2gTKN@]d00dKn00=6gTKn
A_h024Kn01977TKnA_i6oT/NA_i77TKnBai6oT/NAai;7TKnBai77T/NA_h3Bah01DLNBai;7T/NAah0
E4/N00<004/NBah014/N0goo00<007ooOol04Goo000VOol00`00Oomoo`0VOol00d8iAUX000080000
13jM?Ya2_CjM0T:m0116gT:m@]i2_DKN@[e2gT;MA_i2gDKn@]e6oT;MA_i2g@=6oP0bA]e;7TKnA_i6
oD/NA_i;7TKmBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NAai;7TKnBai7
7T/NA_i;7TLNBai6oT/NAai;7TLNBai77T/NAai;7`9;7P06Aai;7d/NBai77T/O0T/N00I77T/oBai;
7TLNBcl2Bah01TLNBcm;7T/NAai;?`9;7P06Aai;?d/NBai77T/o0T/N02M77T/oBai;7TLNBcm;7T/n
Aai;?d/NBci77T/oBai;?T/NBcm;7T/nBai;?d/NBci;7T/oBai;?T/NBcm;7T/n001;?d/NBci;7T/o
Bah00goo00<007ooOol04Goo000VOol00`00Oomoo`0OOol90002@SX02T9l@W]2Nd9k?YdnO3jL?Wa2
_CjM0T:m00Y2gD:m@[e2_DKN@]e6gD;MA]i6g@96gQ16oP0BBai6oTKnA_i;7TKnAai6oT/NA_i;7TLN
Bai77T/NAai;7TLN0d/N00E77T/NBai;7TLN059;7P03001;7T/N00A;7P=oo`03001oogoo015oo`00
9Woo00<007ooOol05Goo2P0027oo05M2FT8iAUY2>T9l@U]2O4:L@Ye2W4Jm@Ya6_D:lA[e2_D;N@[e6
gT:mA]i2gDKN@]e6oT;MA_i2gDKnA]e6oTKMA_i6oD[nA_e6oTKmBai6oT/NA_e;7TKnBai6oD/NA_i;
7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TLNBai6oT/NAai;7TKnBai77T/NAai;
7TLNBai77T/NAai;7TLNBal00T/N00I77T/OBai;7TLNBal2Bah01TLNBcm;7T/NAai;?`9;7P06Aai;
?d/NBai77T/o0T/N02e77T/oBai;7TLNBcm;7T/nAai;?d/NBci;7T/oBai;?T/NBcm;7T/nBai;?d/N
Bci;7T/oBai;?T/NBcm;7T/nBai;?d/NBci;7T/oBah004/NBcm;7T/nBah00goo00<007ooOol04Goo
000VOol00`00Oomoo`0<Ool9000BOol01T8j@UY2>T8j@W]2O092N`A2W003@[e6_D:m0092_@05A]e2
gDKMA]e6gP03A]d014KnA]e6oTKN34Kn00Y:oTKnB_i6oT/NA_i:oTKnBai6oP=;7P05A_i;7T/NBai7
7P1MBah00`00Bai;7P04Bah3Ool00`00Oomoo`0@Ool002Ioo`03001oogoo009oo`X001]oo`1@CWY:
FDijBUU:W4JKBYa6NdJm@Ya2WD:LA[e2_DJm@[a6_D:mA]e2_DKNA]e6oT;MA_i6gDKnA]e6oTKMA_i6
gD[nA_e:oTKmBai6oD[nA_e;7TKnBai6oD/NA_i;7TKmBai6oT/NA_e;7TKnBai6oT/NA_i;7TKnBai6
oT/NA_i;7TLNBai6oT/NAai;7TKnBai77T/NA_i;7TLNBai77P=;7P06Aai;7T/NBai77T/O0T/N00I7
7T/oBai;7TLNBcl2Bah01TLNBcm;7T/NAai;?`9;7P06Aai;?d/NBai77T/o0T/N02a77T/oBai;7TLN
Bcm;7T/nBai;?d/NBci;7T/oBai;?T/NBcm;7T/nBai;?d/NBci;7T/oBai;?T/NBcm;7T/nBai;?d/N
Bci;7P00Bai;?T/NBcm;7T/n0goo00<007ooOol047oo000VOol5000VOol2BWX01TijBWY:VdJKBY]6
V`A6_096_@03A]e6_DKM00E6g@06A]i6gDKMA]i6oTKM1TKn00i:oTKnA_i6oT/NA_i:oTKnBai6oT/N
A_i;7TKn0d/N00E6oT/NBai;7TKn05m;7P03001;7T/N00A;7P=oo`03001oogoo011oo`009goo00<0
07ooOol09goo019:FDijBUU>NTIkBYa6VdZLAYa:_DJLA[e6W4[MA[a6gDJlB]h3A]d0=4[nA]e:oTKM
B_i6gD[nA]e:oTKmB_i6oD[nA_e:oTKmBai6oD/NA_e;7TKnBai6oD/NA_i;7TKmBai6oT/NA_e;7TKn
Bai6oT/NA_i;7TKnBai6oT/NA_i;7TLNBai6oT/NAai;7TKn0d/N00E6oT/NBai;7TLN00=;7P05Aai;
7T/NBai77P03Bah01TLNBcm;7T/NAai;?`9;7P06Aai;?d/NBai77T/o0T/N00=77T/oBah00T/N00E;
?d/NBai;7T/o00=;7P0UBcm;7T/nBai;?d/NBci;7T/oBai;?T/NBcm;7T/nBai;?d/NBci;7T/oBai;
?T/NBcm;7T/nBai;?d/NBch004/oBai;?T/NBcl00goo00<007ooOol047oo000XOol00`00Oomoo`0V
Ool02DijBWY:NTYjBY]6VdZKAY]:V`04A[`3A[d8A]d01TKnA]e6oTKmA_i6o@96oP05B_i6oDKnA_i:
oP02A_h00d[nBai6oP02B_h01T/NA_i;7T[nBai:oP=;7P03B_i;7T/N061;7P03001;7T/N00=;7P=o
o`03001oogoo011oo`00:Goo00<007ooOol09Woo03iFVU9iEYYBVDjkBY]>_4jKC[]:_4kMB[a:g4Jl
B]e6_4[MA]e:oTKMB_e6gD[nA]e:oTKMB_i6oD[nA]e:oTKmB_i6oD/NA_e;7TKmBai6oT/NA_e;7TKn
Bai6oD/NA_i;7TKmBai6oT/NA_i;7TKnBai6oT/NA_i;7TKn0d/N00E6oT/NBai;7TKn00=;7P05Aai;
7T/NBai77P03Bah01TLNBai;7T/NAai;?P9;7P06Aai;?T/NBai77T/o0T/N00I77T/oBai;7TLNBcl2
Bah01TLNBcm;7T/NAai;?`=;7P0[Bcm;7T/nBai;?d/NBci;7T/oBai;?T/NBcm;7T/nBai;?d/NBci;
7T/oBai;?T/NBcm;7T/nBai;?d/NBci;7T/oBai;?T/NBcl004/nBai;?d/NBch00goo00<007ooOol0
47oo000ZOol00`00Oomoo`0UOol015:IDYYBVE:J0Tjk00=>VdjkC[/01DZl14[M0156gD[MB]e:gDKM
B_e6oD[nA]e:oTKmB_i6oD[nA_i:oTKm00=:oP09A_i:oT[nBai:oT/NB_i;7T[n00=;7P03B_i;7T/N
069;7P03001;7T/N00A;7P9oo`03001oogoo011oo`00:goo00<007ooOol09Goo03]BVEJJDWUFVU:k
D]]B^U;KD[]>g4jlC]a>_4kMB]a>oD[LB_e:gDkmB]e:oDKMB_i:gD[nA]e:oTKmB_i6oD/NA_e:oTKm
Bai6oD/NA_e;7TKmBai6oD/NA_i;7TKmBai6oT/NA_e;7TKnBai6oT/NA_i;7TKn00=;7P05A_i;7T/N
Bai6oP03Bah01DKnBai;7T/NAah00d/N00E77T/NBai;7TLN00=;7P06Aai;?T/NBai77T/o0T/N00=7
7T/oBah00T/N00E;?d/NBai;7T/o00=;7P05Bcm;7T/NBai;?`03Bah0:T/oBai;?T/NBcm;7T/nBai;
?d/NBci;7T/oBai;?T/NBcm;7T/nBai;?d/NBci;7T/oBai;?T/NBcm;7T/nBai;?d/NBci;7P00Bai;
?T/NBcm;7P9oo`03001oogoo011oo`00;7oo00<007ooOol097oo15Zi1E:k1DkL00Q>gD[LB]e:gD[m
B]e:oD[M1T[m00A:oT[mB_i:o@=:oP09B_e:oT[nBai:oT/NB_i;7T[n00=;7P03B_i;7T/N06E;7P04
001;7T/NBch2Bah2Ool00`00Oomoo`0@Ool002eoo`03001oogoo02=oo`0mEYUJ^UJIF[UFVE;KD[]B
fe:jD]]>_4kLC[a>g4[LC]e:g4kmB]e>oD[MC_e:gDknB]e>oT[mC_i:oD/NB_e:oT[mBai:oD/NB_e;
7T[mBai6oD/NB_e;7TKmBai:oT/NA_e;7T[nBai6oD/NB_i;7TKmBai:oT/NA_h00d/N00E6oT/NBai;
7TKn00=;7P05Aai;7T/NBai77P03Bah00dLNBai;7P02Bah01D/nBai;7T/NBch00d/N00E;?d/NBai;
7T/o00=;7P05Bcm;7T/NBai;?`03Bah0<d/oBai;?T/NBcm;7T/nBai;?d/NBci;7T/oBai;?T/NBcm;
7T/nBai;?d/NBci;7T/oBai;?T/NBcm;7T/nBai;?d/NBci;7T/oBai;?T/NBcm;7P00Bai;?d/NBci;
7T/oOol0000BOol002ioo`03001oogoo029oo`EJ^@05E]YFfeKKE]]FfP05D]`024kLC_e>g4kMB_e>
oD[MC_d5B_d01T[nB_e:oT[mB_i:o@I:oP03Bai:oT/N009;7P05B_i;7T/NBai:oP1VBah02000Bai;
7T/NBci;7Woo000BOol002moo`03001oogoo029oo`0fF[UFVEZjG[QNfEJjF]]F^UKKE[YBo4kKD]a>
fdkmC]a>oDkLC_e:gDkmB]e>oD[mC_i:oDlNB_e?7T[mCai:oDlNB_e?7T[mBai:oD/NB_e;7T[mBai:
oD/NB_e;7T[nBai:oD/NB_i;7TKm0d/N00E:oD/NBai;7T[n00=;7P03B_i;7T/N00i;7P05Bci;7T/N
Bai;?P03Bah01D/nBai;7T/NBch00d/N00E;?d/NBai;7T/o00=;7P0eBcm;7T/NBai;?d/NBci;7T/o
Bai;?T/NBcm;7T/nBai;?d/NBci;7T/oBai;?T/NBcm;7T/nBai;?d/NBci;7T/oBai;?T/NBcm;7T/n
Bai;?d/NBci;7T/o001;?T/NBcm;7T/nOol0000BOol0031oo`03001oogoo025oo`07F[UNfEjiG]UN
^EKKE]X00eKK00YBfeKlD]aFo5;KD_a>o5;mC_aBo0A>o@06B_e>oD[mC_e:oD[n0d[m00Y;7T[mB_i:
oD/NB_i;7T[nBai:oP=;7P03B_i;7T/N06A;7P05Bci;7P00Bai;?P03Bah00goo001oo`0AOol0035o
o`03001oogoo021oo`0DG]UN^5kIG[QNfEjhE]]F^U[kF]YFo5;KE_aBfeKlC]aBoDkLD_e>g0=>o@0Q
B]a?7TkmCae:oDlNC_e?7T[mCai:oDlNB_e?7T[mCai:oDlNB_e?7T[mCai:oD/NB_e;7T[nBai:oD/N
B_i;7T[m00=;7P05B_e;7T/NBai:oP0@Bah01D/nBai;7T/NBch00d/N00E;?T/NBai;7T/n00=;7P05
Bci;7T/NBai;?`03Bah0=d/oBai;7T/NBcm;7T/nBai;?d/NBci;7T/oBai;?T/NBcm;7T/nBai;?d/N
Bci;7T/oBai;?T/NBcm;7T/nBai;?d/NBci;7T/oBai;?T/NBcm;7T/nBai;?d/NBch004/oBai;?T/N
Bcm;7P00019oo`00<Woo00<007ooOol07goo00QN^EkIG[UNfEjiG]UJfU[K0e[J00EFo5;KE_aBg5Kl
00EBo09>o@03D_e>oDkm00A>o@07B_e?7T[mC_e:oDlNB_d00T/N00E?7T[mBai;7TlN06];7P05Bch0
04/NBai;?P02Bah00goo001oo`0@Ool003=oo`03001oogoo01moo`0fG[QNfEjhG]URf5[kF]YJne[J
F_]Ffe[lE]]Jo5KKF_aBo5KmD_aBoDklDae>o5;mC_aC7TkmCae>oDlNB_e?7T[mCai:oDlNB_e?7T[m
Cai:oDlNB_e?7T[mCai:oD/NB_e?7T[nBai:oDlN0T/N00I:oDlNBai;7T[mCah2Bah00d/MCai;7P0>
Bah01D/nBai;7T/NBch00d/N00E;?T/NBai;7T/n00=;7P05Bcm;7T/NBai;?`03Bah0=T/oBai;?T/N
Bcm;7T/nBai;?d/NBci;7T/oBai;?T/NBcm;7T/nBai;?d/NBci;7T/oBai;?T/NBcm;7T/nBai;?d/N
Bci;7T/oBai;?T/NBcm;7T/nBai;?d/N001;7T/oBai;?T/NOol0015oo`00=7oo00<007ooOol07Woo
00INfEjiH]QRf6;IH]P2F]X01EkjG]YNnUKkE_`00eKk00=Fo5;lE_`00UKl1E;m0Tkm015?7DkmCae>
oDlNC_e?7T[mCai:oDlNBai?7T/MCai;7TlN06=;7P05Bci;7T/NBai;?P02Bah00`00Bci;7P02Bah0
0d/nOol0000AOol003Eoo`8001ioo`0lH]QRfF;HH]URf6;IF]YNnU[JG_YJfU[lE]]Jo5KkFaaBo5LL
D_aG7E;lDae>o5<MC_aC7DkmDai>oDlMC_e?7TkmCai>oDlNB_e?7T[mCai:oDlNB_e?7T[mCai:oDlN
Bae?7T[mCai;7DlNB_e?7T/NCai;7DlN0T/N00I;7DlNBai;7T/MCah3Bah01DlNBai;7T/NCch00d/N
00E??T/NBai;7T/n00=;7P05Bci;7T/NBai;?P03Bah01D/nBai;7T/NBcl00d/N03Q;?d/NBci;7T/o
Bai;?T/NBcm;7T/nBai;?d/NBci;7T/oBai;?T/NBcm;7T/nBai;?d/NBci;7T/oBai;?T/NBcm;7T/n
Bai;?d/NBci;7T/oBai;?T/NBcm;7T/nBah004/NBci;7T/oBaioo`004Goo000gOol00`00Oomoo`0L
Ool01f;HH]URf6;HI]QVn5kJ00=NnP03G]YJne[k00=Jn`9Fo00=D_aFo5KlDaeBo5<MD_eC7DkmDae>
oE<MC_d00dlM00E>oDlNCae?7T[m00=?7P08Bae?7T/NCai;7TlNBai?7Um;7P09Bci;7T/NBai;?T/N
001;7T/n00=;7P03001oogoo00moo`00>7oo00<007ooOol06goo03eRfF;HH]URefKhH]QNnU[JG_YN
nF;jG]UK75[kF_aFneLLE_aG75KlEaaFo5<MD_aG7E;lDae>oE<MC_eC7TkmDai>oE<NC_e?7TkmCai:
oDlNB_e?7T[mCai;7DlNB_e?7T/MCai:oDlNBae?7T/MCai;7TlNBae?7P02Bah00d/MCai;7P02Bah0
1DlNBai;7T/NCch00d/N00E??T/NBai;7Tln00=;7P05Cci;7T/NBai??P03Bah01D/nBai;7T/NCch0
0d/N03Y;?d/NBci;7T/oBai;?T/NBcm;7T/nBai;?d/NBci;7T/oBai;?T/NBcm;7T/nBai;?d/NBci;
7T/oBai;?T/NBcm;7T/nBai;?d/NBci;7T/oBai;?T/NBcm;7T/nBai;?d/NBch004/oBai;?T/NBcl0
015oo`00>Goo00<007ooOol06goo00=Rf6KHI_P00fKH00ERnUkjH_YNnV;j00=Jn`05Ga]JneKlE_aG
7002E_`01e<LEaeBo5LMDaaC7E;m009C7@I?7@0?Cai?7DlNCae?7TlMCai?7DlNBai?7T/NCai;7TlN
05M;7P05Bci;7T/NBai;?P07Ool00`00Oomoo`03Ool00`00Oomoo`0?Ool003Yoo`03001oogoo01Yo
o`1:H]MVn6;HI_QRef[hG_URnUkIH_YRnF<JF_]O6e[kGa]Jne/LE_aK75KkFaaBo5LMD_aG7E;lDae>
oE<MC_eC7TkmDai>oE<NC_e?7TlMCai:oDlNBae?7T[mCai;7DlNB_e?7T/MCai;7DlNBai?7T/MCai;
7TlNBae?7T/NCai;7DlNBai?7T/NCci;7TlNBai??P=;7P05Cci;7T/NBai??P03Bah01DlnBai;7T/N
Cch00d/N02U??T/NBci;7TlnBai;?T/NCci;7T/nBai;?d/NBci;7T/oBai;?T/NBcm;7T/nBai;?d/N
Bci;7T/oBai;?T/NBcm;7T/nBai;?d/NBci;7T/o011oo`03001oogoo00=oo`03001oogoo00moo`00
>goo00<007ooOol06Goo00UVn6KHI]QVf6[hI_MZn5kjH_X00f;i00=O6e[kF_/00UlK00]Nne/LEaaK
75KlEaeG75LMEaaG7ELL00EC7@04CaeC7DlMCah3Cad01TlNCae?7TlMCai;7@=?7P04Bae?7T/NCah3
Bah01DlNBai;7T/NCah0?4/N7Woo00<007ooOol00Woo00<007ooOol03goo000lOol00`00Oomoo`0I
Ool07fKhH]MZn6KGJ_QVefLJH_US6V;iIaYRnElKF_YO6ekjGa]Fne/LF_]K75KkEaeBo5LMD_aG7E<M
EaeBo5LM009C7@0ZC_eC7TlMDai>oE<NCae?7T[mCai?7DlNBae?7T/MCai;7DlNBae?7T/MCai;7TlN
Bae?7T/NCai;7DlNBai?7T/MCai;7TlNBae??T/NCai;7Tln0d/N00E??T/NBai;7Tln00=;7P0ECci;
7T/NBai??T/NBci;7TlnBai;?T/NCci;7T/nBai??d/NBci;7Tlo02]oo`03001oogoo009oo`03001o
ogoo00moo`00?Goo00<007ooOol067oo00IVf6[hI_MZn6KgJ_L3H_T00f;jH_UW6@02Ga/00ekkGa]O
6P06Fa`2Ea`00eLMEaaG7006Dad014lMDae?7E<N0dlM00I?7TlMCai?7DlNCad3Cah024/NCai?7TlN
Bai?7T/NCah3Bah01DlNBai;7T/NCah074/N>7oo00<007ooOol00Woo00<007ooOol03goo000nOol0
0`00Oomoo`0GOol01F[hI]MZn6KGJ_P00V[g01YRnFLJH_UW6F;iIaYNnV<KG_YS6ekjFaaFne/LFa]O
75/KFaeG75LMEaaG7E<LEaeC75LM0U<M02i?7E<NCaeC7TlMDai?7DlNCae?7TlMCai;7DlNCae?7T/M
Cai;7DlNBae?7T/MCai;7DlnBai?7T/MCci;7TlNBae??T/NCai;7DlnBai?7T/NCci;7TlNBai??TIo
o`05001oogooOol0000AOol003moo`03001oogoo01Ioo`04I_MZn6KgJ_P3J_L06FLIH_UW6FKiIaUR
nElKGaYS6elJGa]K6elLFa]K75/KGaaG75/LEaaK75LLEaeC7ELM00IC7@0;CaeC7DlMDae?7DlNCae?
7TlMCai?7@07Cah024/NCai?7TlNBai?7T/NCah3Bah00dlNBai;7P03Bai>Ool01@00Oomoogoo0000
4Goo0010Ool00`00Oomoo`0FOol00fKGJ_QZm`02J_L07FlGJ_IW6F;iIaYRnFLII_QS6ekjHa]O6V<K
Fa]O75/KGcaK6elLEaaK?ELLFaeC75LmDaaG7E<LDcd00e<M01IC?DlMDai?7E<NCaeC7TlMDci?7DlN
Cae??TlMCai;7DlnBae?7T/MCci;7E]oo`05001oogooOol0000AOol0045oo`03001oogoo01Eoo`03
J_QZmf[g00=Zm`04K_MVnFLII_T3IaT3HaX01V<KHaYS6UlKGaaK6`9O6`EK70EG7@UC7@03Cae?7TlM
00=?7P03Cae?7Woo069oo`03001oogoo009oo`03001oogoo00ioo`00@Woo00<007ooOol057oo0f[g
02QZn6[fK_MZmVlGI_QW6FKhJaUVn6/IGaYS6f<JHa]S6VLkFa]O75lKGcaG75/lEaaK?ELLEceG75Lm
EaaG?ELLEceC7ELMDaeC?TlMDai?7Faoo`05001oogooOol0000@Ool004=oo`03001oogoo01Aoo`=Z
m`04K_MZmfkgK_H3IaT016LHJaU[66<K1F<J1ElK1E/L00=G7ELLEad00ULMM7oo00D007ooOomoo`00
011oo`00A7oo00<007ooOol04goo01iZn6[gK_MZmVlGJ_I_5f[fJaUVn6/II_Q[6FKhIaYS6VLkHaYW
>UlKGcaO6ellGa]K?5/LFcaK75/lFaahOol01@00Oomoogoo000047oo0015Ool00`00Oomoo`0COol2
J_L02VkgJ_M^mfkfKaMW66/IJaQ[6FLH0V/H0V<J0fLJ0elK00ES>elKFaaK75/l07Yoo`05001oogoo
Ool0000@Ool004Ioo`03001oogoo019oo`0IJ_I_5f[fK_MZmVlGK_I[6FKhJaUVn6/IJ_Q[6F<JIcYS
6FLjHaYS>elKHcaO6f<kGa/0OGoo00@007ooOol0011oo`00Agoo00<007ooOol04Goo00U^mf[gK_M^
mVlGK_I_5VkfJaT01F/H0fLJ00AS6VLJIaYS>`9O6gmoo`04001oogoo000@Ool004Qoo`03001oogoo
015oo`0CK_MZmVlGK_Ic5VkfLaM[66/IJ_Q[6F/HKaQ[66LjIaUW>VLIIcX0PWoo00@007ooOol0011o
o`00BGoo00<007ooOol047oo00QZmflGK_I^mfkfKaI^mW<F1V/H00AW6FLJIaYW>XAoo`03001oo`00
011oo`00BWoo00<007ooOol03goo011_5fkfKaM^mW<GK_Ic5VkeJaU[66lHJaQ_66/GKaQW6HIoo`03
001oo`00011oo`00Bgoo00<007ooOol03Woo00E^mVkgK_I_5Vkf009_5P03LaI^mV/H00=[609_68Mo
o`03001oo`00011oo`00C7oo00<007ooOol03Woo00eZmW<GK_Ic5VkeLaI^mW<FJaQ_66/HKaQ[5`28
Ool00`00Ool0000@Ool004eoo`03001oogoo00eoo`06KaM^mVlFK_Ic5Vkf0g<F00A[66lHKaQ_68Uo
o`80011oo`00CWoo00<007ooOol037oo00a^mW<FK_Ic5fkfLaI^mG<FK_E_66/GKcR:Ool2000@Ool0
04moo`03001oogoo00aoo`08K_I_5VkfLaI_5W<FL_Ec5P9_68]oo`03001oo`0000moo`00D7oo00<0
07ooOol02goo00Yc5fkfLaI^mG<FK_Ec5W;eLaI[5h]oo`03001oo`0000moo`00DGoo00<007ooOol0
2goo00Ac5VlFLaIbm@=c5P03LaEoogoo08]oo`8000moo`00DWoo00<007ooOol02Woo00Q^mG<FK_Ic
5VkeLaIbmG<FSGoo0P003goo001COol2000:Ool00g<FK_Ic5P02LaH2LaF>Ool2000?Ool005Eoo`03
001oogoo00Qoo`06LaI^mG<FK_Ec5W;eSWoo0P003goo001FOol00`00Oomoo`07Ool2LaH017;eLaEc
5G<FSgoo00<007ooOol03Goo001GOol00`00Oomoo`06Ool01G<FK_Ec5W;eLaH0RWoo1`003goo001H
Ool00`00Oomoo`05Ool01G;eLaIc5G<FLaD0O7oo3P005Woo001IOol00`00Oomoo`05Ool016keLaIb
mG<FKgoo3@0097oo001JOol00`00Oomoo`04Ool00g<FLaEc5@1SOol=000aOol005]oo`03001oogoo
00=oo`03L_Ec5W;e05Eoo`h003ioo`00G7oo00<007ooOol00goo00=c5G<FOol0Agoo3@00C7oo0014
Ool3000FOol00`00Oomoo`02Ool00g<FOomoo`0jOol=001IOol004Eoo`03001oogoo01Ioo`05001o
ogooOol0000^Ool>001VOol004Eoo`<001Moo`04001oogoo000QOol=001dOol004Eoo`04001oogoo
000GOol00`00Ool0000DOol=0021Ool004Eoo`04001oogoo000HOol20006Ool>002>Ool004Aoo`@0
01Yoo`L009aoo`00ogoo1Woo003oOol6Ool00?moo`Ioo`00ogoo1Woo003oOol6Ool00?moo`Ioo`00
ogoo1Woo001lOol200000goo00000002Ool40003Ool20004Ool20004Ool20004Ool2001WOol007eo
o`03001oo`0000Uoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol006Ioo`00OWoo00<0
07ooOol00Woo10000Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`00IWoo001lOol2
00000goo00000008Ool01000Oomoo`0027oo00@007ooOol000=oo`8006Moo`00RGoo00@007ooOol0
00Qoo`04001oogoo0002Ool01000Oomoo`00IWoo002:Ool2000:Ool20004Ool2001WOol00?moo`Io
o`00ogoo1Woo003oOol6Ool00?moo`Ioo`00\
\>"],
  ImageRangeCache->{{{0, 260.5}, {184.125, 0}} -> {-0.170371, 0.0461608, \
0.00439067, 0.00439067}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .70824 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1.10169 -0.148196 1.10169 [
[.5 .72074 -20 0 ]
[.5 .72074 20 15 ]
[.44797 -0.02478 -4.90556 -15 ]
[.44797 -0.02478 5.09444 0 ]
[.15892 .66839 -5.31917 0 ]
[.15892 .66839 4.68083 15 ]
[-0.06694 .27471 -10 -6.62571 ]
[-0.06694 .27471 0 8.37429 ]
[ 0 0 0 0 ]
[ 1 .70824 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .72074 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.437500 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(=) show
75.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.09) show
99.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math1Mono
%%DocumentNeededResources: + font Courier
%%DocumentNeededFonts: Math1Mono
%%DocumentNeededFont: + Courier
%%DocumentFonts: font Math1Mono
%%DocumentFonts: + font Courier
grestore
.25 Mabswid
.02946 .11175 m
.89362 0 L
s
gsave
.44797 -0.02478 -65.9056 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(u) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
0 .4272 m
.29069 .70824 L
s
gsave
.15892 .66839 -66.3192 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(p) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.02946 .11175 m
0 .4272 L
s
gsave
-0.06694 .27471 -71 -10.6257 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(q) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.02946 .11175 m
0 .4272 L
s
0 .4272 m
.29069 .70824 L
s
.29069 .70824 m
.30155 .45044 L
s
.30155 .45044 m
.02946 .11175 L
s
.89362 0 m
.98022 .38351 L
s
.98022 .38351 m
1 .65325 L
s
1 .65325 m
.91448 .33294 L
s
.91448 .33294 m
.89362 0 L
s
.02946 .11175 m
0 .4272 L
s
0 .4272 m
.91448 .33294 L
s
.91448 .33294 m
.89362 0 L
s
.89362 0 m
.02946 .11175 L
s
.30155 .45044 m
.98022 .38351 L
s
.98022 .38351 m
1 .65325 L
s
1 .65325 m
.29069 .70824 L
s
.29069 .70824 m
.30155 .45044 L
s
0 0 m
1 0 L
1 .70824 L
0 .70824 L
closepath
clip
newpath
.912 .776 .697 r
.2849 .68243 .29101 .70077 .31304 .63989 .30691 .62578 Mtetra
.87 .79 .77 r
.30691 .62578 .31304 .63989 .33367 .6093 .32759 .59735 Mtetra
.819 .797 .831 r
.32759 .59735 .33367 .6093 .35376 .59174 .34776 .58105 Mtetra
.771 .799 .876 r
.34776 .58105 .35376 .59174 .37362 .58063 .36771 .57073 Mtetra
.73 .797 .906 r
.36771 .57073 .37362 .58063 .39338 .57303 .38758 .56366 Mtetra
.698 .795 .925 r
.38758 .56366 .39338 .57303 .41313 .56747 .40744 .55847 Mtetra
.673 .793 .938 r
.40744 .55847 .41313 .56747 .43289 .56317 .42731 .55443 Mtetra
.655 .791 .947 r
.42731 .55443 .43289 .56317 .45268 .55967 .44722 .55113 Mtetra
.641 .79 .953 r
.44722 .55113 .45268 .55967 .47252 .55671 .46718 .54832 Mtetra
.631 .789 .958 r
.46718 .54832 .47252 .55671 .49241 .55411 .48719 .54583 Mtetra
.624 .789 .961 r
.48719 .54583 .49241 .55411 .51236 .55176 .50726 .54357 Mtetra
.618 .789 .963 r
.50726 .54357 .51236 .55176 .53237 .54959 .5274 .54146 Mtetra
.614 .789 .965 r
.5274 .54146 .53237 .54959 .55244 .54755 .54759 .53947 Mtetra
.61 .789 .967 r
.54759 .53947 .55244 .54755 .57257 .54559 .56785 .53755 Mtetra
.608 .789 .968 r
.56785 .53755 .57257 .54559 .59277 .5437 .58818 .53569 Mtetra
.606 .789 .969 r
.58818 .53569 .59277 .5437 .61303 .54186 .60857 .53387 Mtetra
.604 .79 .97 r
.60857 .53387 .61303 .54186 .63336 .54005 .62903 .53207 Mtetra
.603 .79 .971 r
.62903 .53207 .63336 .54005 .65376 .53826 .64956 .53029 Mtetra
.601 .79 .971 r
.64956 .53029 .65376 .53826 .67422 .53649 .67016 .52853 Mtetra
.601 .791 .972 r
.67016 .52853 .67422 .53649 .69475 .53473 .69082 .52677 Mtetra
.6 .791 .972 r
.69082 .52677 .69475 .53473 .71535 .53297 .71156 .52501 Mtetra
.599 .791 .972 r
.71156 .52501 .71535 .53297 .73602 .53122 .73236 .52325 Mtetra
.599 .791 .973 r
.73236 .52325 .73602 .53122 .75676 .52947 .75323 .5215 Mtetra
.598 .792 .973 r
.75323 .5215 .75676 .52947 .77756 .52772 .77418 .51973 Mtetra
.77418 .51973 .77756 .52772 .79844 .52596 .79519 .51797 Mtetra
.79519 .51797 .79844 .52596 .81938 .5242 .81627 .51619 Mtetra
.598 .792 .974 r
.81627 .51619 .81938 .5242 .8404 .52243 .83743 .51441 Mtetra
.597 .793 .974 r
.83743 .51441 .8404 .52243 .86148 .52066 .85865 .51263 Mtetra
.85865 .51263 .86148 .52066 .88264 .51888 .87995 .51083 Mtetra
.87995 .51083 .88264 .51888 .90386 .5171 .90132 .50903 Mtetra
.90132 .50903 .90386 .5171 .92516 .5153 .92277 .50722 Mtetra
.92277 .50722 .92516 .5153 .94653 .5135 .94428 .5054 Mtetra
.597 .793 .975 r
.94428 .5054 .94653 .5135 .96797 .5117 .96587 .50357 Mtetra
.597 .794 .975 r
.96587 .50357 .96797 .5117 .98949 .50988 .98753 .50174 Mtetra
.906 .774 .705 r
.27873 .66392 .2849 .68243 .30691 .62578 .30071 .6115 Mtetra
.861 .787 .778 r
.30071 .6115 .30691 .62578 .32759 .59735 .32144 .58526 Mtetra
.809 .794 .838 r
.32144 .58526 .32759 .59735 .34776 .58105 .34168 .57022 Mtetra
.761 .795 .881 r
.34168 .57022 .34776 .58105 .36771 .57073 .36173 .56071 Mtetra
.721 .794 .909 r
.36173 .56071 .36771 .57073 .38758 .56366 .38171 .55417 Mtetra
.69 .792 .928 r
.38171 .55417 .38758 .56366 .40744 .55847 .40167 .54935 Mtetra
.667 .79 .94 r
.40167 .54935 .40744 .55847 .42731 .55443 .42166 .54558 Mtetra
.65 .789 .948 r
.42166 .54558 .42731 .55443 .44722 .55113 .44169 .54248 Mtetra
.637 .788 .954 r
.44169 .54248 .44722 .55113 .46718 .54832 .46177 .53982 Mtetra
.628 .787 .958 r
.46177 .53982 .46718 .54832 .48719 .54583 .48191 .53744 Mtetra
.621 .787 .961 r
.48191 .53744 .48719 .54583 .50726 .54357 .5021 .53527 Mtetra
.616 .787 .964 r
.5021 .53527 .50726 .54357 .5274 .54146 .52236 .53323 Mtetra
.612 .788 .966 r
.52236 .53323 .5274 .54146 .54759 .53947 .54268 .53128 Mtetra
.609 .788 .967 r
.54268 .53128 .54759 .53947 .56785 .53755 .56307 .5294 Mtetra
.606 .788 .968 r
.56307 .5294 .56785 .53755 .58818 .53569 .58353 .52757 Mtetra
.604 .789 .969 r
.58353 .52757 .58818 .53569 .60857 .53387 .60405 .52577 Mtetra
.603 .789 .97 r
.60405 .52577 .60857 .53387 .62903 .53207 .62465 .52399 Mtetra
.602 .789 .971 r
.62465 .52399 .62903 .53207 .64956 .53029 .64531 .52222 Mtetra
.601 .79 .971 r
.64531 .52222 .64956 .53029 .67016 .52853 .66604 .52046 Mtetra
.6 .79 .972 r
.66604 .52046 .67016 .52853 .69082 .52677 .68684 .5187 Mtetra
.599 .791 .972 r
.68684 .5187 .69082 .52677 .71156 .52501 .70771 .51694 Mtetra
.70771 .51694 .71156 .52501 .73236 .52325 .72865 .51518 Mtetra
.598 .791 .973 r
.72865 .51518 .73236 .52325 .75323 .5215 .74966 .51341 Mtetra
.74966 .51341 .75323 .5215 .77418 .51973 .77074 .51164 Mtetra
.598 .792 .973 r
.77074 .51164 .77418 .51973 .79519 .51797 .7919 .50986 Mtetra
.597 .792 .974 r
.7919 .50986 .79519 .51797 .81627 .51619 .81312 .50808 Mtetra
.81312 .50808 .81627 .51619 .83743 .51441 .83442 .50628 Mtetra
.83442 .50628 .83743 .51441 .85865 .51263 .85579 .50448 Mtetra
.597 .793 .974 r
.85579 .50448 .85865 .51263 .87995 .51083 .87723 .50267 Mtetra
.87723 .50267 .87995 .51083 .90132 .50903 .89875 .50085 Mtetra
.89875 .50085 .90132 .50903 .92277 .50722 .92034 .49902 Mtetra
.92034 .49902 .92277 .50722 .94428 .5054 .942 .49719 Mtetra
.597 .793 .975 r
.942 .49719 .94428 .5054 .96587 .50357 .96374 .49534 Mtetra
.596 .794 .975 r
.96374 .49534 .96587 .50357 .98753 .50174 .98555 .49348 Mtetra
.898 .771 .713 r
.2725 .64522 .27873 .66392 .30071 .6115 .29445 .59707 Mtetra
.851 .784 .786 r
.29445 .59707 .30071 .6115 .32144 .58526 .31522 .57302 Mtetra
.798 .79 .845 r
.31522 .57302 .32144 .58526 .34168 .57022 .33553 .55927 Mtetra
.751 .791 .886 r
.33553 .55927 .34168 .57022 .36173 .56071 .35568 .55055 Mtetra
.712 .79 .913 r
.35568 .55055 .36173 .56071 .38171 .55417 .37576 .54455 Mtetra
.682 .788 .93 r
.37576 .54455 .38171 .55417 .40167 .54935 .39584 .54011 Mtetra
.661 .787 .942 r
.39584 .54011 .40167 .54935 .42166 .54558 .41594 .53662 Mtetra
.645 .786 .949 r
.41594 .53662 .42166 .54558 .44169 .54248 .43609 .53372 Mtetra
.633 .786 .955 r
.43609 .53372 .44169 .54248 .46177 .53982 .45629 .5312 Mtetra
.625 .786 .959 r
.45629 .5312 .46177 .53982 .48191 .53744 .47655 .52894 Mtetra
.618 .786 .962 r
.47655 .52894 .48191 .53744 .5021 .53527 .49687 .52685 Mtetra
.613 .786 .964 r
.49687 .52685 .5021 .53527 .52236 .53323 .51725 .52488 Mtetra
.61 .787 .966 r
.51725 .52488 .52236 .53323 .54268 .53128 .53771 .52298 Mtetra
.607 .787 .967 r
.53771 .52298 .54268 .53128 .56307 .5294 .55823 .52114 Mtetra
.605 .788 .968 r
.55823 .52114 .56307 .5294 .58353 .52757 .57881 .51934 Mtetra
.603 .788 .969 r
.57881 .51934 .58353 .52757 .60405 .52577 .59947 .51756 Mtetra
.602 .789 .97 r
.59947 .51756 .60405 .52577 .62465 .52399 .6202 .51579 Mtetra
.601 .789 .971 r
.6202 .51579 .62465 .52399 .64531 .52222 .64099 .51403 Mtetra
.6 .789 .971 r
.64099 .51403 .64531 .52222 .66604 .52046 .66186 .51227 Mtetra
.599 .79 .972 r
.66186 .51227 .66604 .52046 .68684 .5187 .6828 .51052 Mtetra
.6828 .51052 .68684 .5187 .70771 .51694 .70381 .50876 Mtetra
.598 .791 .973 r
.70381 .50876 .70771 .51694 .72865 .51518 .72489 .50699 Mtetra
.72489 .50699 .72865 .51518 .74966 .51341 .74604 .50522 Mtetra
.74604 .50522 .74966 .51341 .77074 .51164 .76726 .50344 Mtetra
.597 .791 .973 r
.76726 .50344 .77074 .51164 .7919 .50986 .78856 .50165 Mtetra
.597 .792 .974 r
.78856 .50165 .7919 .50986 .81312 .50808 .80993 .49985 Mtetra
.80993 .49985 .81312 .50808 .83442 .50628 .83137 .49804 Mtetra
.83137 .49804 .83442 .50628 .85579 .50448 .85288 .49622 Mtetra
.85288 .49622 .85579 .50448 .87723 .50267 .87447 .4944 Mtetra
.597 .793 .974 r
.87447 .4944 .87723 .50267 .89875 .50085 .89614 .49256 Mtetra
.596 .793 .974 r
.89614 .49256 .89875 .50085 .92034 .49902 .91787 .49071 Mtetra
.91787 .49071 .92034 .49902 .942 .49719 .93969 .48885 Mtetra
.596 .793 .975 r
.93969 .48885 .942 .49719 .96374 .49534 .96157 .48699 Mtetra
.96157 .48699 .96374 .49534 .98555 .49348 .98354 .48511 Mtetra
.889 .768 .722 r
.26621 .62633 .2725 .64522 .29445 .59707 .28811 .58248 Mtetra
.839 .78 .795 r
.28811 .58248 .29445 .59707 .31522 .57302 .30892 .56064 Mtetra
.786 .785 .852 r
.30892 .56064 .31522 .57302 .33553 .55927 .32931 .54817 Mtetra
.739 .787 .891 r
.32931 .54817 .33553 .55927 .35568 .55055 .34954 .54027 Mtetra
.702 .786 .916 r
.34954 .54027 .35568 .55055 .37576 .54455 .36973 .53481 Mtetra
.674 .785 .932 r
.36973 .53481 .37576 .54455 .39584 .54011 .38992 .53075 Mtetra
.654 .784 .943 r
.38992 .53075 .39584 .54011 .41594 .53662 .41014 .52753 Mtetra
.64 .784 .951 r
.41014 .52753 .41594 .53662 .43609 .53372 .43041 .52483 Mtetra
.629 .784 .956 r
.43041 .52483 .43609 .53372 .45629 .5312 .45073 .52247 Mtetra
.621 .784 .96 r
.45073 .52247 .45629 .5312 .47655 .52894 .47112 .52032 Mtetra
.615 .784 .962 r
.47112 .52032 .47655 .52894 .49687 .52685 .49157 .51832 Mtetra
.611 .785 .965 r
.49157 .51832 .49687 .52685 .51725 .52488 .51208 .51641 Mtetra
.608 .786 .966 r
.51208 .51641 .51725 .52488 .53771 .52298 .53266 .51457 Mtetra
.605 .786 .968 r
.53266 .51457 .53771 .52298 .55823 .52114 .55331 .51277 Mtetra
.604 .787 .969 r
.55331 .51277 .55823 .52114 .57881 .51934 .57403 .51099 Mtetra
.602 .787 .97 r
.57403 .51099 .57881 .51934 .59947 .51756 .59483 .50923 Mtetra
.601 .788 .97 r
.59483 .50923 .59947 .51756 .6202 .51579 .61569 .50748 Mtetra
.6 .788 .971 r
.61569 .50748 .6202 .51579 .64099 .51403 .63662 .50573 Mtetra
.599 .789 .971 r
.63662 .50573 .64099 .51403 .66186 .51227 .65763 .50398 Mtetra
.599 .789 .972 r
.65763 .50398 .66186 .51227 .6828 .51052 .6787 .50222 Mtetra
.598 .79 .972 r
.6787 .50222 .6828 .51052 .70381 .50876 .69985 .50046 Mtetra
.598 .79 .973 r
.69985 .50046 .70381 .50876 .72489 .50699 .72107 .49869 Mtetra
.597 .791 .973 r
.72107 .49869 .72489 .50699 .74604 .50522 .74236 .49691 Mtetra
.74236 .49691 .74604 .50522 .76726 .50344 .76373 .49511 Mtetra
.76373 .49511 .76726 .50344 .78856 .50165 .78517 .49331 Mtetra
.597 .792 .974 r
.78517 .49331 .78856 .50165 .80993 .49985 .80669 .4915 Mtetra
.80669 .4915 .80993 .49985 .83137 .49804 .82827 .48968 Mtetra
.82827 .48968 .83137 .49804 .85288 .49622 .84994 .48785 Mtetra
.596 .792 .974 r
.84994 .48785 .85288 .49622 .87447 .4944 .87167 .486 Mtetra
.596 .793 .974 r
.87167 .486 .87447 .4944 .89614 .49256 .89349 .48415 Mtetra
.89349 .48415 .89614 .49256 .91787 .49071 .91537 .48228 Mtetra
.91537 .48228 .91787 .49071 .93969 .48885 .93734 .4804 Mtetra
.596 .793 .975 r
.93734 .4804 .93969 .48885 .96157 .48699 .95938 .47851 Mtetra
.95938 .47851 .96157 .48699 .98354 .48511 .9815 .47661 Mtetra
.879 .765 .731 r
.25986 .60726 .26621 .62633 .28811 .58248 .2817 .56772 Mtetra
.827 .775 .804 r
.2817 .56772 .28811 .58248 .30892 .56064 .30254 .5481 Mtetra
.773 .78 .859 r
.30254 .5481 .30892 .56064 .32931 .54817 .32301 .53693 Mtetra
.728 .782 .896 r
.32301 .53693 .32931 .54817 .34954 .54027 .34333 .52986 Mtetra
.692 .781 .919 r
.34333 .52986 .34954 .54027 .36973 .53481 .36362 .52495 Mtetra
.666 .781 .935 r
.36362 .52495 .36973 .53481 .38992 .53075 .38392 .52127 Mtetra
.648 .781 .945 r
.38392 .52127 .38992 .53075 .41014 .52753 .40426 .51833 Mtetra
.634 .781 .952 r
.40426 .51833 .41014 .52753 .43041 .52483 .42465 .51583 Mtetra
.625 .782 .957 r
.42465 .51583 .43041 .52483 .45073 .52247 .4451 .51362 Mtetra
.618 .782 .96 r
.4451 .51362 .45073 .52247 .47112 .52032 .46561 .51159 Mtetra
.613 .783 .963 r
.46561 .51159 .47112 .52032 .49157 .51832 .48619 .50967 Mtetra
.609 .784 .965 r
.48619 .50967 .49157 .51832 .51208 .51641 .50683 .50783 Mtetra
.606 .785 .967 r
.50683 .50783 .51208 .51641 .53266 .51457 .52755 .50604 Mtetra
.604 .785 .968 r
.52755 .50604 .53266 .51457 .55331 .51277 .54833 .50428 Mtetra
.602 .786 .969 r
.54833 .50428 .55331 .51277 .57403 .51099 .56919 .50253 Mtetra
.601 .787 .97 r
.56919 .50253 .57403 .51099 .59483 .50923 .59012 .50079 Mtetra
.6 .787 .97 r
.59012 .50079 .59483 .50923 .61569 .50748 .61112 .49906 Mtetra
.599 .788 .971 r
.61112 .49906 .61569 .50748 .63662 .50573 .63219 .49731 Mtetra
.598 .789 .972 r
.63219 .49731 .63662 .50573 .65763 .50398 .65333 .49557 Mtetra
.65333 .49557 .65763 .50398 .6787 .50222 .67455 .49381 Mtetra
.598 .79 .972 r
.67455 .49381 .6787 .50222 .69985 .50046 .69584 .49204 Mtetra
.597 .79 .973 r
.69584 .49204 .69985 .50046 .72107 .49869 .7172 .49027 Mtetra
.7172 .49027 .72107 .49869 .74236 .49691 .73864 .48848 Mtetra
.597 .791 .973 r
.73864 .48848 .74236 .49691 .76373 .49511 .76015 .48668 Mtetra
.76015 .48668 .76373 .49511 .78517 .49331 .78174 .48486 Mtetra
.596 .791 .974 r
.78174 .48486 .78517 .49331 .80669 .4915 .8034 .48304 Mtetra
.596 .792 .974 r
.8034 .48304 .80669 .4915 .82827 .48968 .82514 .4812 Mtetra
.82514 .4812 .82827 .48968 .84994 .48785 .84695 .47935 Mtetra
.84695 .47935 .84994 .48785 .87167 .486 .86884 .47749 Mtetra
.86884 .47749 .87167 .486 .89349 .48415 .8908 .47561 Mtetra
.596 .793 .974 r
.8908 .47561 .89349 .48415 .91537 .48228 .91284 .47373 Mtetra
.91284 .47373 .91537 .48228 .93734 .4804 .93496 .47183 Mtetra
.596 .793 .975 r
.93496 .47183 .93734 .4804 .95938 .47851 .95715 .46992 Mtetra
.95715 .46992 .95938 .47851 .9815 .47661 .97943 .468 Mtetra
.868 .76 .742 r
.25345 .588 .25986 .60726 .2817 .56772 .27522 .55279 Mtetra
.813 .77 .813 r
.27522 .55279 .2817 .56772 .30254 .5481 .29609 .53542 Mtetra
.759 .775 .866 r
.29609 .53542 .30254 .5481 .32301 .53693 .31662 .52556 Mtetra
.715 .776 .9 r
.31662 .52556 .32301 .53693 .34333 .52986 .33704 .51931 Mtetra
.682 .777 .923 r
.33704 .51931 .34333 .52986 .36362 .52495 .35744 .51496 Mtetra
.658 .777 .937 r
.35744 .51496 .36362 .52495 .38392 .52127 .37785 .51167 Mtetra
.641 .778 .946 r
.37785 .51167 .38392 .52127 .40426 .51833 .39831 .509 Mtetra
.629 .778 .953 r
.39831 .509 .40426 .51833 .42465 .51583 .41882 .50671 Mtetra
.62 .779 .957 r
.41882 .50671 .42465 .51583 .4451 .51362 .43939 .50465 Mtetra
.614 .781 .961 r
.43939 .50465 .4451 .51362 .46561 .51159 .46003 .50273 Mtetra
.61 .782 .963 r
.46003 .50273 .46561 .51159 .48619 .50967 .48074 .50091 Mtetra
.606 .783 .965 r
.48074 .50091 .48619 .50967 .50683 .50783 .50152 .49914 Mtetra
.604 .784 .967 r
.50152 .49914 .50683 .50783 .52755 .50604 .52237 .4974 Mtetra
.602 .784 .968 r
.52237 .4974 .52755 .50604 .54833 .50428 .54328 .49567 Mtetra
.601 .785 .969 r
.54328 .49567 .54833 .50428 .56919 .50253 .56428 .49396 Mtetra
.6 .786 .97 r
.56428 .49396 .56919 .50253 .59012 .50079 .58534 .49224 Mtetra
.599 .787 .971 r
.58534 .49224 .59012 .50079 .61112 .49906 .60648 .49051 Mtetra
.598 .788 .971 r
.60648 .49051 .61112 .49906 .63219 .49731 .62769 .48878 Mtetra
.598 .788 .972 r
.62769 .48878 .63219 .49731 .65333 .49557 .64898 .48704 Mtetra
.597 .789 .972 r
.64898 .48704 .65333 .49557 .67455 .49381 .67034 .48528 Mtetra
.67034 .48528 .67455 .49381 .69584 .49204 .69177 .48351 Mtetra
.597 .79 .973 r
.69177 .48351 .69584 .49204 .7172 .49027 .71328 .48173 Mtetra
.71328 .48173 .7172 .49027 .73864 .48848 .73486 .47993 Mtetra
.596 .79 .973 r
.73486 .47993 .73864 .48848 .76015 .48668 .75652 .47812 Mtetra
.596 .791 .973 r
.75652 .47812 .76015 .48668 .78174 .48486 .77826 .47629 Mtetra
.596 .791 .974 r
.77826 .47629 .78174 .48486 .8034 .48304 .80007 .47445 Mtetra
.80007 .47445 .8034 .48304 .82514 .4812 .82195 .4726 Mtetra
.596 .792 .974 r
.82195 .4726 .82514 .4812 .84695 .47935 .84392 .47073 Mtetra
.84392 .47073 .84695 .47935 .86884 .47749 .86596 .46885 Mtetra
.86596 .46885 .86884 .47749 .8908 .47561 .88807 .46696 Mtetra
.596 .793 .974 r
.88807 .46696 .8908 .47561 .91284 .47373 .91027 .46505 Mtetra
.91027 .46505 .91284 .47373 .93496 .47183 .93254 .46313 Mtetra
.596 .793 .975 r
.93254 .46313 .93496 .47183 .95715 .46992 .9549 .4612 Mtetra
.9549 .4612 .95715 .46992 .97943 .468 .97733 .45926 Mtetra
.854 .754 .752 r
.24697 .56855 .25345 .588 .27522 .55279 .26867 .53769 Mtetra
.797 .763 .822 r
.26867 .53769 .27522 .55279 .29609 .53542 .28956 .52258 Mtetra
.744 .768 .873 r
.28956 .52258 .29609 .53542 .31662 .52556 .31016 .51404 Mtetra
.702 .77 .905 r
.31016 .51404 .31662 .52556 .33704 .51931 .33067 .50862 Mtetra
.671 .772 .926 r
.33067 .50862 .33704 .51931 .35744 .51496 .35117 .50483 Mtetra
.649 .773 .939 r
.35117 .50483 .35744 .51496 .37785 .51167 .3717 .50193 Mtetra
.634 .774 .948 r
.3717 .50193 .37785 .51167 .39831 .509 .39227 .49954 Mtetra
.623 .776 .954 r
.39227 .49954 .39831 .509 .41882 .50671 .41291 .49746 Mtetra
.616 .777 .958 r
.41291 .49746 .41882 .50671 .43939 .50465 .43361 .49555 Mtetra
.611 .779 .961 r
.43361 .49555 .43939 .50465 .46003 .50273 .45438 .49376 Mtetra
.607 .78 .964 r
.45438 .49376 .46003 .50273 .48074 .50091 .47521 .49202 Mtetra
.604 .781 .966 r
.47521 .49202 .48074 .50091 .50152 .49914 .49613 .49032 Mtetra
.602 .783 .967 r
.49613 .49032 .50152 .49914 .52237 .4974 .51711 .48863 Mtetra
.6 .784 .968 r
.51711 .48863 .52237 .4974 .54328 .49567 .53817 .48695 Mtetra
.599 .785 .969 r
.53817 .48695 .54328 .49567 .56428 .49396 .5593 .48526 Mtetra
.598 .785 .97 r
.5593 .48526 .56428 .49396 .58534 .49224 .5805 .48356 Mtetra
.598 .786 .971 r
.5805 .48356 .58534 .49224 .60648 .49051 .60178 .48185 Mtetra
.597 .787 .971 r
.60178 .48185 .60648 .49051 .62769 .48878 .62313 .48013 Mtetra
.597 .788 .972 r
.62313 .48013 .62769 .48878 .64898 .48704 .64456 .47839 Mtetra
.64456 .47839 .64898 .48704 .67034 .48528 .66606 .47663 Mtetra
.596 .789 .972 r
.66606 .47663 .67034 .48528 .69177 .48351 .68764 .47486 Mtetra
.596 .789 .973 r
.68764 .47486 .69177 .48351 .71328 .48173 .7093 .47307 Mtetra
.596 .79 .973 r
.7093 .47307 .71328 .48173 .73486 .47993 .73103 .47126 Mtetra
.73103 .47126 .73486 .47993 .75652 .47812 .75284 .46944 Mtetra
.596 .791 .973 r
.75284 .46944 .75652 .47812 .77826 .47629 .77472 .4676 Mtetra
.596 .791 .974 r
.77472 .4676 .77826 .47629 .80007 .47445 .79669 .46574 Mtetra
.79669 .46574 .80007 .47445 .82195 .4726 .81872 .46388 Mtetra
.596 .792 .974 r
.81872 .46388 .82195 .4726 .84392 .47073 .84084 .46199 Mtetra
.84084 .46199 .84392 .47073 .86596 .46885 .86304 .46009 Mtetra
.86304 .46009 .86596 .46885 .88807 .46696 .88531 .45818 Mtetra
.88531 .45818 .88807 .46696 .91027 .46505 .90766 .45625 Mtetra
.596 .793 .974 r
.90766 .45625 .91027 .46505 .93254 .46313 .93009 .45431 Mtetra
.596 .793 .975 r
.93009 .45431 .93254 .46313 .9549 .4612 .95261 .45236 Mtetra
.95261 .45236 .9549 .4612 .97733 .45926 .9752 .45039 Mtetra
.837 .747 .764 r
.24042 .5489 .24697 .56855 .26867 .53769 .26204 .52242 Mtetra
.779 .756 .832 r
.26204 .52242 .26867 .53769 .28956 .52258 .28294 .50958 Mtetra
.727 .761 .879 r
.28294 .50958 .28956 .52258 .31016 .51404 .30361 .50237 Mtetra
.688 .764 .91 r
.30361 .50237 .31016 .51404 .33067 .50862 .32421 .4978 Mtetra
.66 .766 .929 r
.32421 .4978 .33067 .50862 .35117 .50483 .34482 .49457 Mtetra
.64 .769 .941 r
.34482 .49457 .35117 .50483 .3717 .50193 .36546 .49206 Mtetra
.627 .771 .949 r
.36546 .49206 .3717 .50193 .39227 .49954 .38615 .48996 Mtetra
.618 .773 .955 r
.38615 .48996 .39227 .49954 .41291 .49746 .40691 .48808 Mtetra
.611 .775 .959 r
.40691 .48808 .41291 .49746 .43361 .49555 .42774 .48633 Mtetra
.607 .777 .962 r
.42774 .48633 .43361 .49555 .45438 .49376 .44864 .48466 Mtetra
.604 .779 .964 r
.44864 .48466 .45438 .49376 .47521 .49202 .46961 .48301 Mtetra
.602 .78 .966 r
.46961 .48301 .47521 .49202 .49613 .49032 .49066 .48138 Mtetra
.6 .781 .967 r
.49066 .48138 .49613 .49032 .51711 .48863 .51178 .47974 Mtetra
.599 .783 .968 r
.51178 .47974 .51711 .48863 .53817 .48695 .53297 .4781 Mtetra
.598 .784 .969 r
.53297 .4781 .53817 .48695 .5593 .48526 .55424 .47644 Mtetra
.597 .785 .97 r
.55424 .47644 .5593 .48526 .5805 .48356 .57559 .47476 Mtetra
.597 .786 .971 r
.57559 .47476 .5805 .48356 .60178 .48185 .59701 .47307 Mtetra
.596 .787 .971 r
.59701 .47307 .60178 .48185 .62313 .48013 .61851 .47135 Mtetra
.596 .787 .972 r
.61851 .47135 .62313 .48013 .64456 .47839 .64008 .46961 Mtetra
.596 .788 .972 r
.64008 .46961 .64456 .47839 .66606 .47663 .66173 .46786 Mtetra
.596 .788 .973 r
.66173 .46786 .66606 .47663 .68764 .47486 .68346 .46608 Mtetra
.596 .789 .973 r
.68346 .46608 .68764 .47486 .7093 .47307 .70526 .46428 Mtetra
.596 .79 .973 r
.70526 .46428 .7093 .47307 .73103 .47126 .72714 .46247 Mtetra
.72714 .46247 .73103 .47126 .75284 .46944 .7491 .46063 Mtetra
.596 .79 .974 r
.7491 .46063 .75284 .46944 .77472 .4676 .77114 .45878 Mtetra
.596 .791 .974 r
.77114 .45878 .77472 .4676 .79669 .46574 .79325 .45691 Mtetra
.595 .791 .974 r
.79325 .45691 .79669 .46574 .81872 .46388 .81545 .45502 Mtetra
.81545 .45502 .81872 .46388 .84084 .46199 .83772 .45312 Mtetra
.595 .792 .974 r
.83772 .45312 .84084 .46199 .86304 .46009 .86007 .4512 Mtetra
.86007 .4512 .86304 .46009 .88531 .45818 .8825 .44927 Mtetra
.596 .792 .974 r
.8825 .44927 .88531 .45818 .90766 .45625 .90502 .44732 Mtetra
.596 .793 .975 r
.90502 .44732 .90766 .45625 .93009 .45431 .92761 .44536 Mtetra
.92761 .44536 .93009 .45431 .95261 .45236 .95028 .44338 Mtetra
.95028 .44338 .95261 .45236 .9752 .45039 .97303 .44139 Mtetra
.818 .738 .776 r
.23381 .52906 .24042 .5489 .26204 .52242 .25533 .50697 Mtetra
.759 .747 .842 r
.25533 .50697 .26204 .52242 .28294 .50958 .27625 .49642 Mtetra
.709 .753 .886 r
.27625 .49642 .28294 .50958 .30361 .50237 .29698 .49055 Mtetra
.673 .757 .914 r
.29698 .49055 .30361 .50237 .32421 .4978 .31767 .48683 Mtetra
.648 .761 .932 r
.31767 .48683 .32421 .4978 .34482 .49457 .33838 .48417 Mtetra
.631 .764 .943 r
.33838 .48417 .34482 .49457 .36546 .49206 .35913 .48206 Mtetra
.62 .767 .95 r
.35913 .48206 .36546 .49206 .38615 .48996 .37995 .48024 Mtetra
.612 .77 .956 r
.37995 .48024 .38615 .48996 .40691 .48808 .40084 .47858 Mtetra
.607 .773 .96 r
.40084 .47858 .40691 .48808 .42774 .48633 .4218 .47699 Mtetra
.603 .775 .962 r
.4218 .47699 .42774 .48633 .44864 .48466 .44283 .47543 Mtetra
.601 .777 .965 r
.44283 .47543 .44864 .48466 .46961 .48301 .46393 .47387 Mtetra
.599 .779 .966 r
.46393 .47387 .46961 .48301 .49066 .48138 .48511 .47231 Mtetra
.598 .78 .968 r
.48511 .47231 .49066 .48138 .51178 .47974 .50637 .47073 Mtetra
.597 .782 .969 r
.50637 .47073 .51178 .47974 .53297 .4781 .52771 .46912 Mtetra
.596 .783 .97 r
.52771 .46912 .53297 .4781 .55424 .47644 .54912 .46749 Mtetra
.596 .784 .97 r
.54912 .46749 .55424 .47644 .57559 .47476 .57061 .46584 Mtetra
.596 .785 .971 r
.57061 .46584 .57559 .47476 .59701 .47307 .59217 .46415 Mtetra
.596 .786 .971 r
.59217 .46415 .59701 .47307 .61851 .47135 .61382 .46245 Mtetra
.595 .787 .972 r
.61382 .46245 .61851 .47135 .64008 .46961 .63554 .46071 Mtetra
.595 .788 .972 r
.63554 .46071 .64008 .46961 .66173 .46786 .65734 .45895 Mtetra
.595 .788 .973 r
.65734 .45895 .66173 .46786 .68346 .46608 .67921 .45717 Mtetra
.595 .789 .973 r
.67921 .45717 .68346 .46608 .70526 .46428 .70117 .45537 Mtetra
.70117 .45537 .70526 .46428 .72714 .46247 .7232 .45354 Mtetra
.595 .79 .973 r
.7232 .45354 .72714 .46247 .7491 .46063 .74531 .4517 Mtetra
.595 .79 .974 r
.74531 .4517 .7491 .46063 .77114 .45878 .7675 .44983 Mtetra
.595 .791 .974 r
.7675 .44983 .77114 .45878 .79325 .45691 .78977 .44795 Mtetra
.78977 .44795 .79325 .45691 .81545 .45502 .81212 .44604 Mtetra
.81212 .44604 .81545 .45502 .83772 .45312 .83456 .44412 Mtetra
.595 .792 .974 r
.83456 .44412 .83772 .45312 .86007 .4512 .85707 .44218 Mtetra
.85707 .44218 .86007 .4512 .8825 .44927 .87966 .44023 Mtetra
.87966 .44023 .8825 .44927 .90502 .44732 .90233 .43826 Mtetra
.595 .792 .975 r
.90233 .43826 .90502 .44732 .92761 .44536 .92509 .43627 Mtetra
.595 .793 .975 r
.92509 .43627 .92761 .44536 .95028 .44338 .94792 .43427 Mtetra
.94792 .43427 .95028 .44338 .97303 .44139 .97084 .43226 Mtetra
.794 .726 .789 r
.22714 .50901 .23381 .52906 .25533 .50697 .24855 .49134 Mtetra
.735 .736 .851 r
.24855 .49134 .25533 .50697 .27625 .49642 .26947 .4831 Mtetra
.689 .743 .893 r
.26947 .4831 .27625 .49642 .29698 .49055 .29027 .47858 Mtetra
.657 .749 .918 r
.29027 .47858 .29698 .49055 .31767 .48683 .31104 .47572 Mtetra
.635 .755 .934 r
.31104 .47572 .31767 .48683 .33838 .48417 .33186 .47363 Mtetra
.621 .759 .945 r
.33186 .47363 .33838 .48417 .35913 .48206 .35273 .47192 Mtetra
.612 .764 .952 r
.35273 .47192 .35913 .48206 .37995 .48024 .37366 .47039 Mtetra
.606 .767 .957 r
.37366 .47039 .37995 .48024 .40084 .47858 .39468 .46894 Mtetra
.602 .77 .96 r
.39468 .46894 .40084 .47858 .4218 .47699 .41576 .46751 Mtetra
.6 .773 .963 r
.41576 .46751 .4218 .47699 .44283 .47543 .43693 .46607 Mtetra
.598 .776 .965 r
.43693 .46607 .44283 .47543 .46393 .47387 .45817 .46461 Mtetra
.597 .778 .967 r
.45817 .46461 .46393 .47387 .48511 .47231 .47949 .46312 Mtetra
.596 .779 .968 r
.47949 .46312 .48511 .47231 .50637 .47073 .50089 .46159 Mtetra
.595 .781 .969 r
.50089 .46159 .50637 .47073 .52771 .46912 .52237 .46002 Mtetra
.595 .782 .97 r
.52237 .46002 .52771 .46912 .54912 .46749 .54392 .45842 Mtetra
.595 .783 .97 r
.54392 .45842 .54912 .46749 .57061 .46584 .56556 .45678 Mtetra
.595 .785 .971 r
.56556 .45678 .57061 .46584 .59217 .46415 .58727 .45511 Mtetra
.595 .786 .972 r
.58727 .45511 .59217 .46415 .61382 .46245 .60906 .45341 Mtetra
.60906 .45341 .61382 .46245 .63554 .46071 .63093 .45168 Mtetra
.595 .787 .972 r
.63093 .45168 .63554 .46071 .65734 .45895 .65288 .44992 Mtetra
.595 .788 .973 r
.65288 .44992 .65734 .45895 .67921 .45717 .67491 .44814 Mtetra
.67491 .44814 .67921 .45717 .70117 .45537 .69701 .44633 Mtetra
.595 .789 .973 r
.69701 .44633 .70117 .45537 .7232 .45354 .7192 .44449 Mtetra
.7192 .44449 .7232 .45354 .74531 .4517 .74147 .44263 Mtetra
.595 .79 .974 r
.74147 .44263 .74531 .4517 .7675 .44983 .76381 .44075 Mtetra
.76381 .44075 .7675 .44983 .78977 .44795 .78624 .43885 Mtetra
.595 .791 .974 r
.78624 .43885 .78977 .44795 .81212 .44604 .80875 .43693 Mtetra
.80875 .43693 .81212 .44604 .83456 .44412 .83134 .43499 Mtetra
.83134 .43499 .83456 .44412 .85707 .44218 .85401 .43303 Mtetra
.595 .792 .974 r
.85401 .43303 .85707 .44218 .87966 .44023 .87677 .43105 Mtetra
.87677 .43105 .87966 .44023 .90233 .43826 .89961 .42906 Mtetra
.595 .792 .975 r
.89961 .42906 .90233 .43826 .92509 .43627 .92253 .42705 Mtetra
.595 .793 .975 r
.92253 .42705 .92509 .43627 .94792 .43427 .94553 .42503 Mtetra
.94553 .42503 .94792 .43427 .97084 .43226 .96861 .42299 Mtetra
.766 .712 .802 r
.22039 .48876 .22714 .50901 .24855 .49134 .24168 .47553 Mtetra
.709 .723 .861 r
.24168 .47553 .24855 .49134 .26947 .4831 .26261 .46961 Mtetra
.667 .732 .899 r
.26261 .46961 .26947 .4831 .29027 .47858 .28346 .46646 Mtetra
.64 .741 .922 r
.28346 .46646 .29027 .47858 .31104 .47572 .30433 .46445 Mtetra
.622 .748 .937 r
.30433 .46445 .31104 .47572 .33186 .47363 .32524 .46295 Mtetra
.612 .755 .946 r
.32524 .46295 .33186 .47363 .35273 .47192 .34623 .46165 Mtetra
.605 .76 .953 r
.34623 .46165 .35273 .47192 .37366 .47039 .36729 .46041 Mtetra
.601 .764 .958 r
.36729 .46041 .37366 .47039 .39468 .46894 .38843 .45917 Mtetra
.598 .768 .961 r
.38843 .45917 .39468 .46894 .41576 .46751 .40965 .4579 Mtetra
.596 .771 .963 r
.40965 .4579 .41576 .46751 .43693 .46607 .43095 .45658 Mtetra
.595 .774 .965 r
.43095 .45658 .43693 .46607 .45817 .46461 .45233 .45521 Mtetra
.594 .776 .967 r
.45233 .45521 .45817 .46461 .47949 .46312 .47379 .45379 Mtetra
.594 .778 .968 r
.47379 .45379 .47949 .46312 .50089 .46159 .49533 .45231 Mtetra
.594 .78 .969 r
.49533 .45231 .50089 .46159 .52237 .46002 .51695 .45079 Mtetra
.594 .782 .97 r
.51695 .45079 .52237 .46002 .54392 .45842 .53865 .44922 Mtetra
.594 .783 .971 r
.53865 .44922 .54392 .45842 .56556 .45678 .56043 .4476 Mtetra
.594 .784 .971 r
.56043 .4476 .56556 .45678 .58727 .45511 .58229 .44594 Mtetra
.594 .785 .972 r
.58229 .44594 .58727 .45511 .60906 .45341 .60423 .44425 Mtetra
.594 .786 .972 r
.60423 .44425 .60906 .45341 .63093 .45168 .62625 .44252 Mtetra
.594 .787 .972 r
.62625 .44252 .63093 .45168 .65288 .44992 .64835 .44076 Mtetra
.594 .787 .973 r
.64835 .44076 .65288 .44992 .67491 .44814 .67053 .43897 Mtetra
.594 .788 .973 r
.67053 .43897 .67491 .44814 .69701 .44633 .6928 .43715 Mtetra
.594 .789 .973 r
.6928 .43715 .69701 .44633 .7192 .44449 .71514 .4353 Mtetra
.71514 .4353 .7192 .44449 .74147 .44263 .73756 .43343 Mtetra
.594 .79 .974 r
.73756 .43343 .74147 .44263 .76381 .44075 .76007 .43154 Mtetra
.595 .79 .974 r
.76007 .43154 .76381 .44075 .78624 .43885 .78266 .42962 Mtetra
.595 .791 .974 r
.78266 .42962 .78624 .43885 .80875 .43693 .80533 .42768 Mtetra
.80533 .42768 .80875 .43693 .83134 .43499 .82808 .42572 Mtetra
.82808 .42572 .83134 .43499 .85401 .43303 .85092 .42374 Mtetra
.595 .792 .974 r
.85092 .42374 .85401 .43303 .87677 .43105 .87384 .42174 Mtetra
.87384 .42174 .87677 .43105 .89961 .42906 .89684 .41973 Mtetra
.595 .792 .975 r
.89684 .41973 .89961 .42906 .92253 .42705 .91993 .41769 Mtetra
.91993 .41769 .92253 .42705 .94553 .42503 .9431 .41564 Mtetra
.595 .793 .975 r
.9431 .41564 .94553 .42503 .96861 .42299 .96635 .41358 Mtetra
.731 .693 .814 r
.21358 .4683 .22039 .48876 .24168 .47553 .23474 .45954 Mtetra
.678 .707 .869 r
.23474 .45954 .24168 .47553 .26261 .46961 .25566 .45595 Mtetra
.643 .72 .904 r
.25566 .45595 .26261 .46961 .28346 .46646 .27657 .45417 Mtetra
.622 .732 .926 r
.27657 .45417 .28346 .46646 .30433 .46445 .29752 .45304 Mtetra
.609 .742 .939 r
.29752 .45304 .30433 .46445 .32524 .46295 .31854 .45212 Mtetra
.602 .749 .948 r
.31854 .45212 .32524 .46295 .34623 .46165 .33964 .45123 Mtetra
.597 .756 .954 r
.33964 .45123 .34623 .46165 .36729 .46041 .36083 .45028 Mtetra
.595 .761 .958 r
.36083 .45028 .36729 .46041 .38843 .45917 .3821 .44926 Mtetra
.593 .766 .962 r
.3821 .44926 .38843 .45917 .40965 .4579 .40345 .44815 Mtetra
.592 .769 .964 r
.40345 .44815 .40965 .4579 .43095 .45658 .42488 .44696 Mtetra
.592 .772 .966 r
.42488 .44696 .43095 .45658 .45233 .45521 .4464 .44568 Mtetra
.592 .775 .967 r
.4464 .44568 .45233 .45521 .47379 .45379 .46801 .44433 Mtetra
.592 .777 .968 r
.46801 .44433 .47379 .45379 .49533 .45231 .48969 .44291 Mtetra
.592 .779 .969 r
.48969 .44291 .49533 .45231 .51695 .45079 .51145 .44142 Mtetra
.592 .781 .97 r
.51145 .44142 .51695 .45079 .53865 .44922 .5333 .43988 Mtetra
.592 .782 .971 r
.5333 .43988 .53865 .44922 .56043 .4476 .55523 .43828 Mtetra
.593 .783 .971 r
.55523 .43828 .56043 .4476 .58229 .44594 .57724 .43664 Mtetra
.593 .785 .972 r
.57724 .43664 .58229 .44594 .60423 .44425 .59933 .43495 Mtetra
.59933 .43495 .60423 .44425 .62625 .44252 .62151 .43323 Mtetra
.593 .786 .972 r
.62151 .43323 .62625 .44252 .64835 .44076 .64376 .43146 Mtetra
.593 .787 .973 r
.64376 .43146 .64835 .44076 .67053 .43897 .6661 .42967 Mtetra
.594 .788 .973 r
.6661 .42967 .67053 .43897 .6928 .43715 .68852 .42784 Mtetra
.68852 .42784 .6928 .43715 .71514 .4353 .71102 .42598 Mtetra
.594 .789 .973 r
.71102 .42598 .71514 .4353 .73756 .43343 .7336 .4241 Mtetra
.594 .789 .974 r
.7336 .4241 .73756 .43343 .76007 .43154 .75627 .42219 Mtetra
.594 .79 .974 r
.75627 .42219 .76007 .43154 .78266 .42962 .77902 .42025 Mtetra
.77902 .42025 .78266 .42962 .80533 .42768 .80186 .41829 Mtetra
.594 .791 .974 r
.80186 .41829 .80533 .42768 .82808 .42572 .82477 .41631 Mtetra
.595 .791 .974 r
.82477 .41631 .82808 .42572 .85092 .42374 .84777 .41431 Mtetra
.84777 .41431 .85092 .42374 .87384 .42174 .87086 .41229 Mtetra
.595 .792 .974 r
.87086 .41229 .87384 .42174 .89684 .41973 .89403 .41025 Mtetra
.595 .792 .975 r
.89403 .41025 .89684 .41973 .91993 .41769 .91729 .40819 Mtetra
.91729 .40819 .91993 .41769 .9431 .41564 .94063 .40612 Mtetra
.595 .793 .975 r
.94063 .40612 .9431 .41564 .96635 .41358 .96406 .40403 Mtetra
.688 .669 .826 r
.20669 .44763 .21358 .4683 .23474 .45954 .22771 .44335 Mtetra
.644 .689 .877 r
.22771 .44335 .23474 .45954 .25566 .45595 .24863 .44212 Mtetra
.617 .707 .909 r
.24863 .44212 .25566 .45595 .27657 .45417 .26959 .44172 Mtetra
.603 .722 .929 r
.26959 .44172 .27657 .45417 .29752 .45304 .29062 .44147 Mtetra
.595 .734 .941 r
.29062 .44147 .29752 .45304 .31854 .45212 .31175 .44115 Mtetra
.591 .744 .949 r
.31175 .44115 .31854 .45212 .33964 .45123 .33296 .44066 Mtetra
.589 .752 .955 r
.33296 .44066 .33964 .45123 .36083 .45028 .35427 .44002 Mtetra
.589 .758 .959 r
.35427 .44002 .36083 .45028 .3821 .44926 .37567 .43921 Mtetra
.588 .763 .962 r
.37567 .43921 .3821 .44926 .40345 .44815 .39716 .43827 Mtetra
.589 .767 .964 r
.39716 .43827 .40345 .44815 .42488 .44696 .41873 .4372 Mtetra
.589 .771 .966 r
.41873 .4372 .42488 .44696 .4464 .44568 .44039 .43601 Mtetra
.589 .774 .968 r
.44039 .43601 .4464 .44568 .46801 .44433 .46214 .43473 Mtetra
.59 .776 .969 r
.46214 .43473 .46801 .44433 .48969 .44291 .48397 .43336 Mtetra
.59 .778 .969 r
.48397 .43336 .48969 .44291 .51145 .44142 .50588 .43192 Mtetra
.591 .78 .97 r
.50588 .43192 .51145 .44142 .5333 .43988 .52788 .4304 Mtetra
.591 .781 .971 r
.52788 .4304 .5333 .43988 .55523 .43828 .54995 .42883 Mtetra
.592 .783 .971 r
.54995 .42883 .55523 .43828 .57724 .43664 .57212 .4272 Mtetra
.592 .784 .972 r
.57212 .4272 .57724 .43664 .59933 .43495 .59436 .42552 Mtetra
.592 .785 .972 r
.59436 .42552 .59933 .43495 .62151 .43323 .61669 .42379 Mtetra
.593 .786 .973 r
.61669 .42379 .62151 .43323 .64376 .43146 .6391 .42203 Mtetra
.593 .787 .973 r
.6391 .42203 .64376 .43146 .6661 .42967 .6616 .42023 Mtetra
.593 .788 .973 r
.6616 .42023 .6661 .42967 .68852 .42784 .68418 .41839 Mtetra
.68418 .41839 .68852 .42784 .71102 .42598 .70684 .41652 Mtetra
.594 .789 .973 r
.70684 .41652 .71102 .42598 .7336 .4241 .72958 .41462 Mtetra
.594 .789 .974 r
.72958 .41462 .7336 .4241 .75627 .42219 .75241 .4127 Mtetra
.594 .79 .974 r
.75241 .4127 .75627 .42219 .77902 .42025 .77533 .41074 Mtetra
.77533 .41074 .77902 .42025 .80186 .41829 .79833 .40876 Mtetra
.594 .791 .974 r
.79833 .40876 .80186 .41829 .82477 .41631 .82141 .40676 Mtetra
.82141 .40676 .82477 .41631 .84777 .41431 .84458 .40474 Mtetra
.84458 .40474 .84777 .41431 .87086 .41229 .86784 .4027 Mtetra
.595 .792 .974 r
.86784 .4027 .87086 .41229 .89403 .41025 .89118 .40063 Mtetra
.595 .792 .975 r
.89118 .40063 .89403 .41025 .91729 .40819 .91461 .39855 Mtetra
.91461 .39855 .91729 .40819 .94063 .40612 .93813 .39645 Mtetra
.93813 .39645 .94063 .40612 .96406 .40403 .96173 .39433 Mtetra
.635 .638 .836 r
.19974 .42675 .20669 .44763 .22771 .44335 .2206 .42697 Mtetra
.604 .666 .884 r
.2206 .42697 .22771 .44335 .24863 .44212 .2415 .42811 Mtetra
.589 .692 .913 r
.2415 .42811 .24863 .44212 .26959 .44172 .26251 .42911 Mtetra
.583 .711 .931 r
.26251 .42911 .26959 .44172 .29062 .44147 .28363 .42975 Mtetra
.581 .727 .943 r
.28363 .42975 .29062 .44147 .31175 .44115 .30486 .43002 Mtetra
.58 .739 .951 r
.30486 .43002 .31175 .44115 .33296 .44066 .32619 .42995 Mtetra
.581 .748 .956 r
.32619 .42995 .33296 .44066 .35427 .44002 .34763 .4296 Mtetra
.582 .755 .96 r
.34763 .4296 .35427 .44002 .37567 .43921 .36915 .42902 Mtetra
.584 .761 .963 r
.36915 .42902 .37567 .43921 .39716 .43827 .39078 .42824 Mtetra
.585 .765 .965 r
.39078 .42824 .39716 .43827 .41873 .4372 .41249 .42729 Mtetra
.586 .769 .967 r
.41249 .42729 .41873 .4372 .44039 .43601 .43429 .4262 Mtetra
.587 .772 .968 r
.43429 .4262 .44039 .43601 .46214 .43473 .45618 .42499 Mtetra
.588 .775 .969 r
.45618 .42499 .46214 .43473 .48397 .43336 .47816 .42368 Mtetra
.589 .777 .97 r
.47816 .42368 .48397 .43336 .50588 .43192 .50022 .42227 Mtetra
.589 .779 .97 r
.50022 .42227 .50588 .43192 .52788 .4304 .52237 .42079 Mtetra
.59 .781 .971 r
.52237 .42079 .52788 .4304 .54995 .42883 .5446 .41923 Mtetra
.591 .782 .971 r
.5446 .41923 .54995 .42883 .57212 .4272 .56692 .41762 Mtetra
.591 .784 .972 r
.56692 .41762 .57212 .4272 .59436 .42552 .58932 .41594 Mtetra
.592 .785 .972 r
.58932 .41594 .59436 .42552 .61669 .42379 .6118 .41422 Mtetra
.592 .786 .973 r
.6118 .41422 .61669 .42379 .6391 .42203 .63437 .41245 Mtetra
.63437 .41245 .6391 .42203 .6616 .42023 .65703 .41064 Mtetra
.593 .787 .973 r
.65703 .41064 .6616 .42023 .68418 .41839 .67977 .4088 Mtetra
.593 .788 .973 r
.67977 .4088 .68418 .41839 .70684 .41652 .70259 .40692 Mtetra
.593 .788 .974 r
.70259 .40692 .70684 .41652 .72958 .41462 .7255 .405 Mtetra
.593 .789 .974 r
.7255 .405 .72958 .41462 .75241 .4127 .7485 .40306 Mtetra
.594 .79 .974 r
.7485 .40306 .75241 .4127 .77533 .41074 .77158 .40109 Mtetra
.77158 .40109 .77533 .41074 .79833 .40876 .79475 .39909 Mtetra
.79475 .39909 .79833 .40876 .82141 .40676 .818 .39707 Mtetra
.594 .791 .974 r
.818 .39707 .82141 .40676 .84458 .40474 .84134 .39502 Mtetra
.84134 .39502 .84458 .40474 .86784 .4027 .86477 .39295 Mtetra
.86477 .39295 .86784 .4027 .89118 .40063 .88829 .39087 Mtetra
.594 .792 .975 r
.88829 .39087 .89118 .40063 .91461 .39855 .91189 .38876 Mtetra
.595 .792 .975 r
.91189 .38876 .91461 .39855 .93813 .39645 .93558 .38663 Mtetra
.93558 .38663 .93813 .39645 .96173 .39433 .95936 .38448 Mtetra
.569 .598 .842 r
.19271 .40565 .19974 .42675 .2206 .42697 .2134 .41039 Mtetra
.558 .64 .888 r
.2134 .41039 .2206 .42697 .2415 .42811 .23428 .41392 Mtetra
.558 .674 .916 r
.23428 .41392 .2415 .42811 .26251 .42911 .25534 .41633 Mtetra
.561 .7 .934 r
.25534 .41633 .26251 .42911 .28363 .42975 .27654 .41787 Mtetra
.565 .719 .945 r
.27654 .41787 .28363 .42975 .30486 .43002 .29787 .41873 Mtetra
.569 .733 .952 r
.29787 .41873 .30486 .43002 .32619 .42995 .31932 .41909 Mtetra
.573 .743 .957 r
.31932 .41909 .32619 .42995 .34763 .4296 .34088 .41904 Mtetra
.576 .752 .961 r
.34088 .41904 .34763 .4296 .36915 .42902 .36254 .41868 Mtetra
.579 .758 .963 r
.36254 .41868 .36915 .42902 .39078 .42824 .3843 .41807 Mtetra
.581 .763 .965 r
.3843 .41807 .39078 .42824 .41249 .42729 .40616 .41724 Mtetra
.583 .768 .967 r
.40616 .41724 .41249 .42729 .43429 .4262 .42811 .41625 Mtetra
.584 .771 .968 r
.42811 .41625 .43429 .4262 .45618 .42499 .45014 .41511 Mtetra
.586 .774 .969 r
.45014 .41511 .45618 .42499 .47816 .42368 .47227 .41385 Mtetra
.587 .776 .97 r
.47227 .41385 .47816 .42368 .50022 .42227 .49448 .41249 Mtetra
.588 .778 .971 r
.49448 .41249 .50022 .42227 .52237 .42079 .51678 .41103 Mtetra
.589 .78 .971 r
.51678 .41103 .52237 .42079 .5446 .41923 .53917 .40949 Mtetra
.59 .782 .972 r
.53917 .40949 .5446 .41923 .56692 .41762 .56164 .40789 Mtetra
.59 .783 .972 r
.56164 .40789 .56692 .41762 .58932 .41594 .5842 .40622 Mtetra
.591 .784 .972 r
.5842 .40622 .58932 .41594 .6118 .41422 .60684 .4045 Mtetra
.591 .785 .973 r
.60684 .4045 .6118 .41422 .63437 .41245 .62957 .40273 Mtetra
.592 .786 .973 r
.62957 .40273 .63437 .41245 .65703 .41064 .65239 .40092 Mtetra
.592 .787 .973 r
.65239 .40092 .65703 .41064 .67977 .4088 .67529 .39906 Mtetra
.592 .788 .973 r
.67529 .39906 .67977 .4088 .70259 .40692 .69828 .39717 Mtetra
.593 .788 .974 r
.69828 .39717 .70259 .40692 .7255 .405 .72136 .39524 Mtetra
.593 .789 .974 r
.72136 .39524 .7255 .405 .7485 .40306 .74452 .39328 Mtetra
.74452 .39328 .7485 .40306 .77158 .40109 .76778 .39129 Mtetra
.593 .79 .974 r
.76778 .39129 .77158 .40109 .79475 .39909 .79111 .38927 Mtetra
.594 .79 .974 r
.79111 .38927 .79475 .39909 .818 .39707 .81454 .38722 Mtetra
.594 .791 .974 r
.81454 .38722 .818 .39707 .84134 .39502 .83805 .38516 Mtetra
.83805 .38516 .84134 .39502 .86477 .39295 .86166 .38306 Mtetra
.86166 .38306 .86477 .39295 .88829 .39087 .88535 .38095 Mtetra
.594 .792 .975 r
.88535 .38095 .88829 .39087 .91189 .38876 .90913 .37881 Mtetra
.90913 .37881 .91189 .38876 .93558 .38663 .933 .37666 Mtetra
.595 .792 .975 r
.933 .37666 .93558 .38663 .95936 .38448 .95696 .37448 Mtetra
.488 .546 .842 r
.18561 .38433 .19271 .40565 .2134 .41039 .20612 .39362 Mtetra
.506 .609 .889 r
.20612 .39362 .2134 .41039 .23428 .41392 .22697 .39955 Mtetra
.524 .655 .918 r
.22697 .39955 .23428 .41392 .25534 .41633 .24807 .40338 Mtetra
.539 .687 .935 r
.24807 .40338 .25534 .41633 .27654 .41787 .26935 .40582 Mtetra
.55 .71 .946 r
.26935 .40582 .27654 .41787 .29787 .41873 .29079 .40729 Mtetra
.558 .727 .953 r
.29079 .40729 .29787 .41873 .31932 .41909 .31236 .40807 Mtetra
.565 .739 .958 r
.31236 .40807 .31932 .41909 .34088 .41904 .33404 .40833 Mtetra
.57 .748 .961 r
.33404 .40833 .34088 .41904 .36254 .41868 .35584 .40819 Mtetra
.574 .756 .964 r
.35584 .40819 .36254 .41868 .3843 .41807 .37774 .40775 Mtetra
.577 .761 .966 r
.37774 .40775 .3843 .41807 .40616 .41724 .39973 .40705 Mtetra
.58 .766 .967 r
.39973 .40705 .40616 .41724 .42811 .41625 .42183 .40615 Mtetra
.582 .77 .968 r
.42183 .40615 .42811 .41625 .45014 .41511 .44401 .40508 Mtetra
.584 .773 .969 r
.44401 .40508 .45014 .41511 .47227 .41385 .46629 .40388 Mtetra
.585 .775 .97 r
.46629 .40388 .47227 .41385 .49448 .41249 .48865 .40255 Mtetra
.586 .778 .971 r
.48865 .40255 .49448 .41249 .51678 .41103 .51111 .40113 Mtetra
.588 .779 .971 r
.51111 .40113 .51678 .41103 .53917 .40949 .53365 .39961 Mtetra
.588 .781 .972 r
.53365 .39961 .53917 .40949 .56164 .40789 .55628 .39802 Mtetra
.589 .782 .972 r
.55628 .39802 .56164 .40789 .5842 .40622 .579 .39636 Mtetra
.59 .784 .972 r
.579 .39636 .5842 .40622 .60684 .4045 .60181 .39464 Mtetra
.591 .785 .973 r
.60181 .39464 .60684 .4045 .62957 .40273 .6247 .39287 Mtetra
.591 .786 .973 r
.6247 .39287 .62957 .40273 .65239 .40092 .64768 .39104 Mtetra
.592 .787 .973 r
.64768 .39104 .65239 .40092 .67529 .39906 .67075 .38918 Mtetra
.67075 .38918 .67529 .39906 .69828 .39717 .69391 .38727 Mtetra
.592 .788 .974 r
.69391 .38727 .69828 .39717 .72136 .39524 .71716 .38532 Mtetra
.593 .789 .974 r
.71716 .38532 .72136 .39524 .74452 .39328 .74049 .38335 Mtetra
.74049 .38335 .74452 .39328 .76778 .39129 .76391 .38134 Mtetra
.593 .79 .974 r
.76391 .38134 .76778 .39129 .79111 .38927 .78742 .3793 Mtetra
.78742 .3793 .79111 .38927 .81454 .38722 .81102 .37723 Mtetra
.594 .791 .974 r
.81102 .37723 .81454 .38722 .83805 .38516 .83471 .37514 Mtetra
.83471 .37514 .83805 .38516 .86166 .38306 .85849 .37302 Mtetra
.85849 .37302 .86166 .38306 .88535 .38095 .88236 .37088 Mtetra
.594 .792 .975 r
.88236 .37088 .88535 .38095 .90913 .37881 .90633 .36871 Mtetra
.90633 .36871 .90913 .37881 .933 .37666 .93038 .36653 Mtetra
.93038 .36653 .933 .37666 .95696 .37448 .95452 .36432 Mtetra
.389 .48 .832 r
.17843 .36278 .18561 .38433 .20612 .39362 .19875 .37664 Mtetra
.448 .573 .887 r
.19875 .37664 .20612 .39362 .22697 .39955 .21957 .38499 Mtetra
.488 .633 .918 r
.21957 .38499 .22697 .39955 .24807 .40338 .24071 .39025 Mtetra
.515 .674 .936 r
.24071 .39025 .24807 .40338 .26935 .40582 .26207 .3936 Mtetra
.533 .701 .947 r
.26207 .3936 .26935 .40582 .29079 .40729 .28361 .39569 Mtetra
.547 .72 .954 r
.28361 .39569 .29079 .40729 .31236 .40807 .30529 .39689 Mtetra
.556 .734 .959 r
.30529 .39689 .31236 .40807 .33404 .40833 .32711 .39746 Mtetra
.563 .745 .962 r
.32711 .39746 .33404 .40833 .35584 .40819 .34904 .39755 Mtetra
.569 .753 .964 r
.34904 .39755 .35584 .40819 .37774 .40775 .37107 .39727 Mtetra
.573 .759 .966 r
.37107 .39727 .37774 .40775 .39973 .40705 .39321 .3967 Mtetra
.577 .764 .968 r
.39321 .3967 .39973 .40705 .42183 .40615 .41545 .3959 Mtetra
.579 .768 .969 r
.41545 .3959 .42183 .40615 .44401 .40508 .43779 .39491 Mtetra
.582 .772 .97 r
.43779 .39491 .44401 .40508 .46629 .40388 .46022 .39376 Mtetra
.583 .774 .97 r
.46022 .39376 .46629 .40388 .48865 .40255 .48274 .39247 Mtetra
.585 .777 .971 r
.48274 .39247 .48865 .40255 .51111 .40113 .50535 .39107 Mtetra
.586 .779 .971 r
.50535 .39107 .51111 .40113 .53365 .39961 .52805 .38958 Mtetra
.587 .78 .972 r
.52805 .38958 .53365 .39961 .55628 .39802 .55084 .388 Mtetra
.588 .782 .972 r
.55084 .388 .55628 .39802 .579 .39636 .57372 .38634 Mtetra
.589 .783 .972 r
.57372 .38634 .579 .39636 .60181 .39464 .59669 .38462 Mtetra
.59 .784 .973 r
.59669 .38462 .60181 .39464 .6247 .39287 .61975 .38285 Mtetra
.59 .785 .973 r
.61975 .38285 .6247 .39287 .64768 .39104 .6429 .38102 Mtetra
.591 .786 .973 r
.6429 .38102 .64768 .39104 .67075 .38918 .66614 .37914 Mtetra
.591 .787 .973 r
.66614 .37914 .67075 .38918 .69391 .38727 .68947 .37722 Mtetra
.592 .788 .974 r
.68947 .37722 .69391 .38727 .71716 .38532 .71288 .37526 Mtetra
.71288 .37526 .71716 .38532 .74049 .38335 .73639 .37326 Mtetra
.593 .789 .974 r
.73639 .37326 .74049 .38335 .76391 .38134 .75999 .37123 Mtetra
.75999 .37123 .76391 .38134 .78742 .3793 .78367 .36917 Mtetra
.593 .79 .974 r
.78367 .36917 .78742 .3793 .81102 .37723 .80745 .36708 Mtetra
.80745 .36708 .81102 .37723 .83471 .37514 .83132 .36496 Mtetra
.594 .791 .974 r
.83132 .36496 .83471 .37514 .85849 .37302 .85528 .36281 Mtetra
.594 .791 .975 r
.85528 .36281 .85849 .37302 .88236 .37088 .87933 .36065 Mtetra
.87933 .36065 .88236 .37088 .90633 .36871 .90348 .35845 Mtetra
.594 .792 .975 r
.90348 .35845 .90633 .36871 .93038 .36653 .92771 .35624 Mtetra
.92771 .35624 .93038 .36653 .95452 .36432 .95204 .35401 Mtetra
.272 .399 .809 r
.17118 .34101 .17843 .36278 .19875 .37664 .19129 .35945 Mtetra
.381 .53 .88 r
.19129 .35945 .19875 .37664 .21957 .38499 .21207 .37024 Mtetra
.448 .609 .916 r
.21207 .37024 .21957 .38499 .24071 .39025 .23324 .37694 Mtetra
.489 .659 .936 r
.23324 .37694 .24071 .39025 .26207 .3936 .25468 .38121 Mtetra
.516 .692 .948 r
.25468 .38121 .26207 .3936 .28361 .39569 .27632 .38392 Mtetra
.535 .714 .955 r
.27632 .38392 .28361 .39569 .30529 .39689 .29812 .38556 Mtetra
.548 .73 .959 r
.29812 .38556 .30529 .39689 .32711 .39746 .32007 .38643 Mtetra
.557 .741 .962 r
.32007 .38643 .32711 .39746 .34904 .39755 .34213 .38675 Mtetra
.564 .75 .965 r
.34213 .38675 .34904 .39755 .37107 .39727 .36431 .38664 Mtetra
.569 .757 .966 r
.36431 .38664 .37107 .39727 .39321 .3967 .3866 .3862 Mtetra
.574 .763 .968 r
.3866 .3862 .39321 .3967 .41545 .3959 .40899 .3855 Mtetra
.577 .767 .969 r
.40899 .3855 .41545 .3959 .43779 .39491 .43147 .38458 Mtetra
.58 .771 .97 r
.43147 .38458 .43779 .39491 .46022 .39376 .45406 .38348 Mtetra
.582 .773 .97 r
.45406 .38348 .46022 .39376 .48274 .39247 .47673 .38224 Mtetra
.584 .776 .971 r
.47673 .38224 .48274 .39247 .50535 .39107 .4995 .38087 Mtetra
.585 .778 .971 r
.4995 .38087 .50535 .39107 .52805 .38958 .52237 .37939 Mtetra
.586 .78 .972 r
.52237 .37939 .52805 .38958 .55084 .388 .54532 .37782 Mtetra
.587 .781 .972 r
.54532 .37782 .55084 .388 .57372 .38634 .56837 .37618 Mtetra
.588 .783 .973 r
.56837 .37618 .57372 .38634 .59669 .38462 .5915 .37446 Mtetra
.589 .784 .973 r
.5915 .37446 .59669 .38462 .61975 .38285 .61473 .37267 Mtetra
.59 .785 .973 r
.61473 .37267 .61975 .38285 .6429 .38102 .63805 .37084 Mtetra
.59 .786 .973 r
.63805 .37084 .6429 .38102 .66614 .37914 .66146 .36895 Mtetra
.591 .787 .973 r
.66146 .36895 .66614 .37914 .68947 .37722 .68496 .36701 Mtetra
.591 .788 .974 r
.68496 .36701 .68947 .37722 .71288 .37526 .70855 .36503 Mtetra
.592 .788 .974 r
.70855 .36503 .71288 .37526 .73639 .37326 .73223 .36302 Mtetra
.592 .789 .974 r
.73223 .36302 .73639 .37326 .75999 .37123 .756 .36097 Mtetra
.593 .789 .974 r
.756 .36097 .75999 .37123 .78367 .36917 .77987 .35888 Mtetra
.593 .79 .974 r
.77987 .35888 .78367 .36917 .80745 .36708 .80383 .35677 Mtetra
.80383 .35677 .80745 .36708 .83132 .36496 .82788 .35462 Mtetra
.593 .791 .974 r
.82788 .35462 .83132 .36496 .85528 .36281 .85202 .35245 Mtetra
.594 .791 .975 r
.85202 .35245 .85528 .36281 .87933 .36065 .87625 .35025 Mtetra
.87625 .35025 .87933 .36065 .90348 .35845 .90058 .34803 Mtetra
.594 .792 .975 r
.90058 .34803 .90348 .35845 .92771 .35624 .92501 .34579 Mtetra
.92501 .34579 .92771 .35624 .95204 .35401 .94953 .34352 Mtetra
.138 .302 .768 r
.16385 .31901 .17118 .34101 .19129 .35945 .18373 .34206 Mtetra
.308 .481 .867 r
.18373 .34206 .19129 .35945 .21207 .37024 .20446 .3553 Mtetra
.405 .583 .913 r
.20446 .3553 .21207 .37024 .23324 .37694 .22567 .36345 Mtetra
.463 .643 .935 r
.22567 .36345 .23324 .37694 .25468 .38121 .24719 .36865 Mtetra
.499 .681 .948 r
.24719 .36865 .25468 .38121 .27632 .38392 .26893 .37198 Mtetra
.522 .707 .955 r
.26893 .37198 .27632 .38392 .29812 .38556 .29085 .37405 Mtetra
.539 .725 .96 r
.29085 .37405 .29812 .38556 .32007 .38643 .31292 .37525 Mtetra
.55 .738 .963 r
.31292 .37525 .32007 .38643 .34213 .38675 .33513 .37579 Mtetra
.559 .747 .965 r
.33513 .37579 .34213 .38675 .36431 .38664 .35745 .37586 Mtetra
.565 .755 .967 r
.35745 .37586 .36431 .38664 .3866 .3862 .37988 .37555 Mtetra
.57 .761 .968 r
.37988 .37555 .3866 .3862 .40899 .3855 .40242 .37494 Mtetra
.574 .766 .969 r
.40242 .37494 .40899 .3855 .43147 .38458 .42506 .37409 Mtetra
.577 .769 .97 r
.42506 .37409 .43147 .38458 .45406 .38348 .4478 .37305 Mtetra
.58 .773 .971 r
.4478 .37305 .45406 .38348 .47673 .38224 .47064 .37185 Mtetra
.582 .775 .971 r
.47064 .37185 .47673 .38224 .4995 .38087 .49357 .37051 Mtetra
.584 .777 .972 r
.49357 .37051 .4995 .38087 .52237 .37939 .5166 .36905 Mtetra
.585 .779 .972 r
.5166 .36905 .52237 .37939 .54532 .37782 .53971 .36749 Mtetra
.587 .781 .972 r
.53971 .36749 .54532 .37782 .56837 .37618 .56293 .36585 Mtetra
.588 .782 .973 r
.56293 .36585 .56837 .37618 .5915 .37446 .58623 .36413 Mtetra
.589 .784 .973 r
.58623 .36413 .5915 .37446 .61473 .37267 .60963 .36234 Mtetra
.589 .785 .973 r
.60963 .36234 .61473 .37267 .63805 .37084 .63312 .3605 Mtetra
.59 .786 .973 r
.63312 .3605 .63805 .37084 .66146 .36895 .6567 .35859 Mtetra
.591 .786 .974 r
.6567 .35859 .66146 .36895 .68496 .36701 .68038 .35664 Mtetra
.591 .787 .974 r
.68038 .35664 .68496 .36701 .70855 .36503 .70414 .35465 Mtetra
.592 .788 .974 r
.70414 .35465 .70855 .36503 .73223 .36302 .728 .35261 Mtetra
.592 .789 .974 r
.728 .35261 .73223 .36302 .756 .36097 .75195 .35054 Mtetra
.75195 .35054 .756 .36097 .77987 .35888 .776 .34843 Mtetra
.593 .79 .974 r
.776 .34843 .77987 .35888 .80383 .35677 .80014 .34629 Mtetra
.80014 .34629 .80383 .35677 .82788 .35462 .82437 .34412 Mtetra
.82437 .34412 .82788 .35462 .85202 .35245 .8487 .34192 Mtetra
.593 .791 .975 r
.8487 .34192 .85202 .35245 .87625 .35025 .87313 .3397 Mtetra
.594 .791 .975 r
.87313 .3397 .87625 .35025 .90058 .34803 .89764 .33745 Mtetra
.594 .792 .975 r
.89764 .33745 .90058 .34803 .92501 .34579 .92226 .33517 Mtetra
.92226 .33517 .92501 .34579 .94953 .34352 .94697 .33287 Mtetra
0 .193 .709 r
.15644 .29677 .16385 .31901 .18373 .34206 .17609 .32444 Mtetra
.228 .425 .848 r
.17609 .32444 .18373 .34206 .20446 .3553 .19676 .34016 Mtetra
.36 .553 .907 r
.19676 .34016 .20446 .3553 .22567 .36345 .218 .34978 Mtetra
.435 .626 .934 r
.218 .34978 .22567 .36345 .24719 .36865 .23959 .35591 Mtetra
.48 .671 .948 r
.23959 .35591 .24719 .36865 .26893 .37198 .26143 .35987 Mtetra
.51 .7 .955 r
.26143 .35987 .26893 .37198 .29085 .37405 .28347 .36238 Mtetra
.53 .72 .96 r
.28347 .36238 .29085 .37405 .31292 .37525 .30568 .36389 Mtetra
.544 .734 .963 r
.30568 .36389 .31292 .37525 .33513 .37579 .32802 .36467 Mtetra
.554 .745 .966 r
.32802 .36467 .33513 .37579 .35745 .37586 .35048 .36491 Mtetra
.561 .753 .967 r
.35048 .36491 .35745 .37586 .37988 .37555 .37306 .36473 Mtetra
.567 .759 .968 r
.37306 .36473 .37988 .37555 .40242 .37494 .39575 .36422 Mtetra
.572 .764 .969 r
.39575 .36422 .40242 .37494 .42506 .37409 .41855 .36345 Mtetra
.575 .768 .97 r
.41855 .36345 .42506 .37409 .4478 .37305 .44145 .36246 Mtetra
.578 .772 .971 r
.44145 .36246 .4478 .37305 .47064 .37185 .46445 .3613 Mtetra
.581 .774 .971 r
.46445 .3613 .47064 .37185 .49357 .37051 .48754 .35998 Mtetra
.583 .777 .972 r
.48754 .35998 .49357 .37051 .5166 .36905 .51073 .35855 Mtetra
.584 .779 .972 r
.51073 .35855 .5166 .36905 .53971 .36749 .53402 .357 Mtetra
.586 .78 .972 r
.53402 .357 .53971 .36749 .56293 .36585 .5574 .35536 Mtetra
.587 .782 .973 r
.5574 .35536 .56293 .36585 .58623 .36413 .58088 .35364 Mtetra
.588 .783 .973 r
.58088 .35364 .58623 .36413 .60963 .36234 .60445 .35185 Mtetra
.589 .784 .973 r
.60445 .35185 .60963 .36234 .63312 .3605 .62811 .34999 Mtetra
.589 .785 .973 r
.62811 .34999 .63312 .3605 .6567 .35859 .65187 .34808 Mtetra
.59 .786 .974 r
.65187 .34808 .6567 .35859 .68038 .35664 .67572 .34611 Mtetra
.591 .787 .974 r
.67572 .34611 .68038 .35664 .70414 .35465 .69967 .3441 Mtetra
.591 .788 .974 r
.69967 .3441 .70414 .35465 .728 .35261 .72371 .34204 Mtetra
.592 .788 .974 r
.72371 .34204 .728 .35261 .75195 .35054 .74784 .33995 Mtetra
.592 .789 .974 r
.74784 .33995 .75195 .35054 .776 .34843 .77207 .33782 Mtetra
.77207 .33782 .776 .34843 .80014 .34629 .7964 .33565 Mtetra
.593 .79 .974 r
.7964 .33565 .80014 .34629 .82437 .34412 .82082 .33345 Mtetra
.82082 .33345 .82437 .34412 .8487 .34192 .84533 .33123 Mtetra
.593 .791 .975 r
.84533 .33123 .8487 .34192 .87313 .3397 .86995 .32897 Mtetra
.86995 .32897 .87313 .3397 .89764 .33745 .89466 .32669 Mtetra
.594 .791 .975 r
.89466 .32669 .89764 .33745 .92226 .33517 .91946 .32438 Mtetra
.594 .792 .975 r
.91946 .32438 .92226 .33517 .94697 .33287 .94437 .32205 Mtetra
0 .076 .633 r
.14896 .27429 .15644 .29677 .17609 .32444 .16835 .30661 Mtetra
.141 .364 .821 r
.16835 .30661 .17609 .32444 .19676 .34016 .18896 .32481 Mtetra
.311 .521 .898 r
.18896 .32481 .19676 .34016 .218 .34978 .21022 .33591 Mtetra
.405 .608 .931 r
.21022 .33591 .218 .34978 .23959 .35591 .23188 .34299 Mtetra
.461 .66 .947 r
.23188 .34299 .23959 .35591 .26143 .35987 .25383 .34758 Mtetra
.497 .692 .955 r
.25383 .34758 .26143 .35987 .28347 .36238 .27599 .35054 Mtetra
.52 .715 .961 r
.27599 .35054 .28347 .36238 .30568 .36389 .29832 .35237 Mtetra
.537 .73 .964 r
.29832 .35237 .30568 .36389 .32802 .36467 .3208 .35338 Mtetra
.549 .742 .966 r
.3208 .35338 .32802 .36467 .35048 .36491 .34341 .35379 Mtetra
.557 .751 .967 r
.34341 .35379 .35048 .36491 .37306 .36473 .36614 .35374 Mtetra
.564 .757 .969 r
.36614 .35374 .37306 .36473 .39575 .36422 .38899 .35333 Mtetra
.569 .763 .97 r
.38899 .35333 .39575 .36422 .41855 .36345 .41194 .35264 Mtetra
.573 .767 .97 r
.41194 .35264 .41855 .36345 .44145 .36246 .435 .3517 Mtetra
.577 .771 .971 r
.435 .3517 .44145 .36246 .46445 .3613 .45816 .35058 Mtetra
.579 .774 .971 r
.45816 .35058 .46445 .3613 .48754 .35998 .48142 .3493 Mtetra
.581 .776 .972 r
.48142 .3493 .48754 .35998 .51073 .35855 .50478 .34788 Mtetra
.583 .778 .972 r
.50478 .34788 .51073 .35855 .53402 .357 .52824 .34635 Mtetra
.585 .78 .973 r
.52824 .34635 .53402 .357 .5574 .35536 .55179 .34471 Mtetra
.586 .781 .973 r
.55179 .34471 .5574 .35536 .58088 .35364 .57544 .34299 Mtetra
.587 .783 .973 r
.57544 .34299 .58088 .35364 .60445 .35185 .59918 .34119 Mtetra
.588 .784 .973 r
.59918 .34119 .60445 .35185 .62811 .34999 .62303 .33932 Mtetra
.589 .785 .973 r
.62303 .33932 .62811 .34999 .65187 .34808 .64696 .3374 Mtetra
.59 .786 .974 r
.64696 .3374 .65187 .34808 .67572 .34611 .67099 .33542 Mtetra
.59 .787 .974 r
.67099 .33542 .67572 .34611 .69967 .3441 .69512 .33338 Mtetra
.591 .787 .974 r
.69512 .33338 .69967 .3441 .72371 .34204 .71934 .33131 Mtetra
.591 .788 .974 r
.71934 .33131 .72371 .34204 .74784 .33995 .74366 .32919 Mtetra
.592 .789 .974 r
.74366 .32919 .74784 .33995 .77207 .33782 .76808 .32703 Mtetra
.76808 .32703 .77207 .33782 .7964 .33565 .79259 .32484 Mtetra
.592 .79 .974 r
.79259 .32484 .7964 .33565 .82082 .33345 .8172 .32261 Mtetra
.593 .79 .974 r
.8172 .32261 .82082 .33345 .84533 .33123 .84191 .32036 Mtetra
.593 .791 .975 r
.84191 .32036 .84533 .33123 .86995 .32897 .86672 .31807 Mtetra
.86672 .31807 .86995 .32897 .89466 .32669 .89162 .31576 Mtetra
.89162 .31576 .89466 .32669 .91946 .32438 .91663 .31342 Mtetra
.594 .792 .975 r
.91663 .31342 .91946 .32438 .94437 .32205 .94173 .31106 Mtetra
0 0 .545 r
.14139 .25157 .14896 .27429 .16835 .30661 .16051 .28856 Mtetra
.051 .297 .786 r
.16051 .28856 .16835 .30661 .18896 .32481 .18105 .30926 Mtetra
.259 .486 .886 r
.18105 .30926 .18896 .32481 .21022 .33591 .20233 .32185 Mtetra
.375 .589 .927 r
.20233 .32185 .21022 .33591 .23188 .34299 .22407 .32988 Mtetra
.442 .648 .946 r
.22407 .32988 .23188 .34299 .25383 .34758 .24611 .33511 Mtetra
.483 .685 .955 r
.24611 .33511 .25383 .34758 .27599 .35054 .26839 .33852 Mtetra
.511 .709 .961 r
.26839 .33852 .27599 .35054 .29832 .35237 .29085 .34067 Mtetra
.53 .726 .964 r
.29085 .34067 .29832 .35237 .3208 .35338 .31347 .34192 Mtetra
.543 .739 .966 r
.31347 .34192 .3208 .35338 .34341 .35379 .33623 .34251 Mtetra
.553 .748 .968 r
.33623 .34251 .34341 .35379 .36614 .35374 .35911 .34259 Mtetra
.561 .756 .969 r
.35911 .34259 .36614 .35374 .38899 .35333 .38212 .34228 Mtetra
.567 .761 .97 r
.38212 .34228 .38899 .35333 .41194 .35264 .40523 .34166 Mtetra
.571 .766 .971 r
.40523 .34166 .41194 .35264 .435 .3517 .42845 .34078 Mtetra
.575 .77 .971 r
.42845 .34078 .435 .3517 .45816 .35058 .45178 .3397 Mtetra
.578 .773 .972 r
.45178 .3397 .45816 .35058 .48142 .3493 .47521 .33845 Mtetra
.58 .775 .972 r
.47521 .33845 .48142 .3493 .50478 .34788 .49874 .33705 Mtetra
.582 .778 .972 r
.49874 .33705 .50478 .34788 .52824 .34635 .52236 .33552 Mtetra
.584 .779 .973 r
.52236 .33552 .52824 .34635 .55179 .34471 .54609 .33389 Mtetra
.585 .781 .973 r
.54609 .33389 .55179 .34471 .57544 .34299 .56992 .33217 Mtetra
.586 .782 .973 r
.56992 .33217 .57544 .34299 .59918 .34119 .59384 .33036 Mtetra
.587 .784 .973 r
.59384 .33036 .59918 .34119 .62303 .33932 .61786 .32849 Mtetra
.588 .785 .973 r
.61786 .32849 .62303 .33932 .64696 .3374 .64197 .32655 Mtetra
.589 .786 .974 r
.64197 .32655 .64696 .3374 .67099 .33542 .66619 .32455 Mtetra
.59 .787 .974 r
.66619 .32455 .67099 .33542 .69512 .33338 .6905 .32249 Mtetra
.6905 .32249 .69512 .33338 .71934 .33131 .71491 .3204 Mtetra
.591 .788 .974 r
.71491 .3204 .71934 .33131 .74366 .32919 .73942 .31825 Mtetra
.591 .789 .974 r
.73942 .31825 .74366 .32919 .76808 .32703 .76402 .31607 Mtetra
.592 .789 .974 r
.76402 .31607 .76808 .32703 .79259 .32484 .78873 .31385 Mtetra
.592 .79 .974 r
.78873 .31385 .79259 .32484 .8172 .32261 .81353 .3116 Mtetra
.81353 .3116 .8172 .32261 .84191 .32036 .83843 .30931 Mtetra
.593 .79 .975 r
.83843 .30931 .84191 .32036 .86672 .31807 .86344 .30699 Mtetra
.593 .791 .975 r
.86344 .30699 .86672 .31807 .89162 .31576 .88854 .30465 Mtetra
.88854 .30465 .89162 .31576 .91663 .31342 .91374 .30227 Mtetra
.91374 .30227 .91663 .31342 .94173 .31106 .93904 .29988 Mtetra
.662 .215 0 r
.13287 .24047 .14139 .25157 .16051 .28856 .15257 .27028 Mtetra
0 .226 .743 r
.15257 .27028 .16051 .28856 .18105 .30926 .17303 .2935 Mtetra
.205 .448 .871 r
.17303 .2935 .18105 .30926 .20233 .32185 .19433 .30759 Mtetra
.342 .568 .922 r
.19433 .30759 .20233 .32185 .22407 .32988 .21613 .31658 Mtetra
.421 .635 .944 r
.21613 .31658 .22407 .32988 .24611 .33511 .23828 .32246 Mtetra
.47 .677 .955 r
.23828 .32246 .24611 .33511 .26839 .33852 .26068 .32632 Mtetra
.501 .704 .961 r
.26068 .32632 .26839 .33852 .29085 .34067 .28327 .3288 Mtetra
.523 .722 .964 r
.28327 .3288 .29085 .34067 .31347 .34192 .30603 .33029 Mtetra
.538 .736 .967 r
.30603 .33029 .31347 .34192 .33623 .34251 .32894 .33105 Mtetra
.549 .746 .968 r
.32894 .33105 .33623 .34251 .35911 .34259 .35198 .33127 Mtetra
.557 .754 .969 r
.35198 .33127 .35911 .34259 .38212 .34228 .37514 .33106 Mtetra
.564 .76 .97 r
.37514 .33106 .38212 .34228 .40523 .34166 .39841 .33051 Mtetra
.569 .765 .971 r
.39841 .33051 .40523 .34166 .42845 .34078 .4218 .32969 Mtetra
.573 .769 .971 r
.4218 .32969 .42845 .34078 .45178 .3397 .44529 .32865 Mtetra
.576 .772 .972 r
.44529 .32865 .45178 .3397 .47521 .33845 .46889 .32742 Mtetra
.579 .775 .972 r
.46889 .32742 .47521 .33845 .49874 .33705 .49259 .32604 Mtetra
.581 .777 .972 r
.49259 .32604 .49874 .33705 .52236 .33552 .5164 .32453 Mtetra
.583 .779 .973 r
.5164 .32453 .52236 .33552 .54609 .33389 .5403 .3229 Mtetra
.584 .781 .973 r
.5403 .3229 .54609 .33389 .56992 .33217 .5643 .32117 Mtetra
.586 .782 .973 r
.5643 .32117 .56992 .33217 .59384 .33036 .58841 .31936 Mtetra
.587 .783 .973 r
.58841 .31936 .59384 .33036 .61786 .32849 .61261 .31747 Mtetra
.588 .784 .974 r
.61261 .31747 .61786 .32849 .64197 .32655 .63691 .31552 Mtetra
.589 .785 .974 r
.63691 .31552 .64197 .32655 .66619 .32455 .66131 .3135 Mtetra
.589 .786 .974 r
.66131 .3135 .66619 .32455 .6905 .32249 .68581 .31143 Mtetra
.59 .787 .974 r
.68581 .31143 .6905 .32249 .71491 .3204 .71041 .30931 Mtetra
.591 .788 .974 r
.71041 .30931 .71491 .3204 .73942 .31825 .7351 .30714 Mtetra
.7351 .30714 .73942 .31825 .76402 .31607 .7599 .30493 Mtetra
.592 .789 .974 r
.7599 .30493 .76402 .31607 .78873 .31385 .7848 .30268 Mtetra
.7848 .30268 .78873 .31385 .81353 .3116 .8098 .3004 Mtetra
.592 .79 .975 r
.8098 .3004 .81353 .3116 .83843 .30931 .8349 .29808 Mtetra
.593 .79 .975 r
.8349 .29808 .83843 .30931 .86344 .30699 .8601 .29573 Mtetra
.593 .791 .975 r
.8601 .29573 .86344 .30699 .88854 .30465 .8854 .29335 Mtetra
.8854 .29335 .88854 .30465 .91374 .30227 .91081 .29095 Mtetra
.91081 .29095 .91374 .30227 .93904 .29988 .93631 .28851 Mtetra
0 .016 .545 r
.12419 .22967 .13287 .24047 .15257 .27028 .14453 .25176 Mtetra
0 .153 .695 r
.14453 .25176 .15257 .27028 .17303 .2935 .1649 .27752 Mtetra
.148 .408 .853 r
.1649 .27752 .17303 .2935 .19433 .30759 .18621 .29313 Mtetra
.309 .546 .916 r
.18621 .29313 .19433 .30759 .21613 .31658 .20809 .30309 Mtetra
.4 .622 .942 r
.20809 .30309 .21613 .31658 .23828 .32246 .23033 .30962 Mtetra
.456 .668 .954 r
.23033 .30962 .23828 .32246 .26068 .32632 .25285 .31394 Mtetra
.491 .698 .961 r
.25285 .31394 .26068 .32632 .28327 .3288 .27558 .31674 Mtetra
.516 .718 .964 r
.27558 .31674 .28327 .3288 .30603 .33029 .29848 .31847 Mtetra
.533 .733 .967 r
.29848 .31847 .30603 .33029 .32894 .33105 .32154 .31942 Mtetra
.545 .744 .968 r
.32154 .31942 .32894 .33105 .35198 .33127 .34473 .31977 Mtetra
.554 .752 .969 r
.34473 .31977 .35198 .33127 .37514 .33106 .36805 .31966 Mtetra
.561 .758 .97 r
.36805 .31966 .37514 .33106 .39841 .33051 .39149 .31919 Mtetra
.567 .764 .971 r
.39149 .31919 .39841 .33051 .4218 .32969 .41504 .31842 Mtetra
.571 .768 .971 r
.41504 .31842 .4218 .32969 .44529 .32865 .43871 .31742 Mtetra
.575 .771 .972 r
.43871 .31742 .44529 .32865 .46889 .32742 .46248 .31622 Mtetra
.578 .774 .972 r
.46248 .31622 .46889 .32742 .49259 .32604 .48635 .31486 Mtetra
.58 .776 .972 r
.48635 .31486 .49259 .32604 .5164 .32453 .51033 .31336 Mtetra
.582 .778 .973 r
.51033 .31336 .5164 .32453 .5403 .3229 .53442 .31173 Mtetra
.584 .78 .973 r
.53442 .31173 .5403 .3229 .5643 .32117 .5586 .31 Mtetra
.585 .782 .973 r
.5586 .31 .5643 .32117 .58841 .31936 .58289 .30818 Mtetra
.586 .783 .973 r
.58289 .30818 .58841 .31936 .61261 .31747 .60727 .30628 Mtetra
.587 .784 .974 r
.60727 .30628 .61261 .31747 .63691 .31552 .63176 .30431 Mtetra
.588 .785 .974 r
.63176 .30431 .63691 .31552 .66131 .3135 .65635 .30228 Mtetra
.589 .786 .974 r
.65635 .30228 .66131 .3135 .68581 .31143 .68104 .30018 Mtetra
.59 .787 .974 r
.68104 .30018 .68581 .31143 .71041 .30931 .70583 .29804 Mtetra
.59 .788 .974 r
.70583 .29804 .71041 .30931 .7351 .30714 .73072 .29585 Mtetra
.591 .788 .974 r
.73072 .29585 .7351 .30714 .7599 .30493 .75571 .29361 Mtetra
.591 .789 .974 r
.75571 .29361 .7599 .30493 .7848 .30268 .78081 .29133 Mtetra
.592 .789 .974 r
.78081 .29133 .7848 .30268 .8098 .3004 .806 .28902 Mtetra
.592 .79 .975 r
.806 .28902 .8098 .3004 .8349 .29808 .8313 .28667 Mtetra
.8313 .28667 .8349 .29808 .8601 .29573 .85671 .28429 Mtetra
.593 .791 .975 r
.85671 .28429 .8601 .29573 .8854 .29335 .88221 .28187 Mtetra
.88221 .28187 .8854 .29335 .91081 .29095 .90782 .27943 Mtetra
.90782 .27943 .91081 .29095 .93631 .28851 .93354 .27696 Mtetra
0 .338 .809 r
.11538 .21869 .12419 .22967 .14453 .25176 .13639 .23302 Mtetra
0 .079 .64 r
.13639 .23302 .14453 .25176 .1649 .27752 .15666 .26133 Mtetra
.09 .366 .832 r
.15666 .26133 .1649 .27752 .18621 .29313 .17798 .27846 Mtetra
.274 .522 .908 r
.17798 .27846 .18621 .29313 .20809 .30309 .19992 .2894 Mtetra
.379 .609 .939 r
.19992 .2894 .20809 .30309 .23033 .30962 .22227 .29659 Mtetra
.441 .66 .954 r
.22227 .29659 .23033 .30962 .25285 .31394 .2449 .30137 Mtetra
.481 .692 .961 r
.2449 .30137 .25285 .31394 .27558 .31674 .26776 .3045 Mtetra
.508 .714 .965 r
.26776 .3045 .27558 .31674 .29848 .31847 .29081 .30648 Mtetra
.527 .73 .967 r
.29081 .30648 .29848 .31847 .32154 .31942 .31402 .3076 Mtetra
.541 .741 .969 r
.31402 .3076 .32154 .31942 .34473 .31977 .33737 .30809 Mtetra
.551 .75 .97 r
.33737 .30809 .34473 .31977 .36805 .31966 .36085 .30808 Mtetra
.559 .757 .97 r
.36085 .30808 .36805 .31966 .39149 .31919 .38446 .30768 Mtetra
.565 .762 .971 r
.38446 .30768 .39149 .31919 .41504 .31842 .40818 .30698 Mtetra
.569 .767 .972 r
.40818 .30698 .41504 .31842 .43871 .31742 .43201 .30601 Mtetra
.573 .77 .972 r
.43201 .30601 .43871 .31742 .46248 .31622 .45596 .30484 Mtetra
.576 .773 .972 r
.45596 .30484 .46248 .31622 .48635 .31486 .48001 .3035 Mtetra
.579 .776 .973 r
.48001 .3035 .48635 .31486 .51033 .31336 .50417 .302 Mtetra
.581 .778 .973 r
.50417 .302 .51033 .31336 .53442 .31173 .52844 .30038 Mtetra
.583 .78 .973 r
.52844 .30038 .53442 .31173 .5586 .31 .5528 .29865 Mtetra
.584 .781 .973 r
.5528 .29865 .5586 .31 .58289 .30818 .57728 .29682 Mtetra
.586 .783 .973 r
.57728 .29682 .58289 .30818 .60727 .30628 .60185 .29491 Mtetra
.587 .784 .974 r
.60185 .29491 .60727 .30628 .63176 .30431 .62653 .29292 Mtetra
.588 .785 .974 r
.62653 .29292 .63176 .30431 .65635 .30228 .65131 .29087 Mtetra
.589 .786 .974 r
.65131 .29087 .65635 .30228 .68104 .30018 .67619 .28875 Mtetra
.589 .787 .974 r
.67619 .28875 .68104 .30018 .70583 .29804 .70117 .28658 Mtetra
.59 .787 .974 r
.70117 .28658 .70583 .29804 .73072 .29585 .72626 .28436 Mtetra
.59 .788 .974 r
.72626 .28436 .73072 .29585 .75571 .29361 .75145 .2821 Mtetra
.591 .789 .974 r
.75145 .2821 .75571 .29361 .78081 .29133 .77675 .27979 Mtetra
.77675 .27979 .78081 .29133 .806 .28902 .80215 .27745 Mtetra
.592 .79 .975 r
.80215 .27745 .806 .28902 .8313 .28667 .82765 .27506 Mtetra
.82765 .27506 .8313 .28667 .85671 .28429 .85326 .27265 Mtetra
.85326 .27265 .85671 .28429 .88221 .28187 .87897 .2702 Mtetra
.593 .791 .975 r
.87897 .2702 .88221 .28187 .90782 .27943 .90479 .26772 Mtetra
.90479 .26772 .90782 .27943 .93354 .27696 .93072 .26521 Mtetra
.311 .619 .957 r
.10642 .20755 .11538 .21869 .13639 .23302 .12815 .21403 Mtetra
0 .007 .582 r
.12815 .21403 .13639 .23302 .15666 .26133 .14831 .24491 Mtetra
.03 .321 .807 r
.14831 .24491 .15666 .26133 .17798 .27846 .16964 .26358 Mtetra
.238 .498 .899 r
.16964 .26358 .17798 .27846 .19992 .2894 .19164 .2755 Mtetra
.356 .594 .936 r
.19164 .2755 .19992 .2894 .22227 .29659 .21408 .28336 Mtetra
.427 .651 .952 r
.21408 .28336 .22227 .29659 .2449 .30137 .23683 .2886 Mtetra
.471 .686 .96 r
.23683 .2886 .2449 .30137 .26776 .3045 .25983 .29207 Mtetra
.501 .71 .965 r
.25983 .29207 .26776 .3045 .29081 .30648 .28302 .29429 Mtetra
.522 .727 .967 r
.28302 .29429 .29081 .30648 .31402 .3076 .30638 .2956 Mtetra
.536 .739 .969 r
.30638 .2956 .31402 .3076 .33737 .30809 .32989 .29622 Mtetra
.548 .748 .97 r
.32989 .29622 .33737 .30809 .36085 .30808 .35354 .29632 Mtetra
.556 .755 .971 r
.35354 .29632 .36085 .30808 .38446 .30768 .37731 .296 Mtetra
.562 .761 .971 r
.37731 .296 .38446 .30768 .40818 .30698 .4012 .29534 Mtetra
.568 .766 .972 r
.4012 .29534 .40818 .30698 .43201 .30601 .42521 .29442 Mtetra
.572 .769 .972 r
.42521 .29442 .43201 .30601 .45596 .30484 .44934 .29328 Mtetra
.575 .773 .972 r
.44934 .29328 .45596 .30484 .48001 .3035 .47357 .29195 Mtetra
.578 .775 .973 r
.47357 .29195 .48001 .3035 .50417 .302 .49791 .29047 Mtetra
.58 .777 .973 r
.49791 .29047 .50417 .302 .52844 .30038 .52236 .28885 Mtetra
.582 .779 .973 r
.52236 .28885 .52844 .30038 .5528 .29865 .54691 .28711 Mtetra
.584 .781 .973 r
.54691 .28711 .5528 .29865 .57728 .29682 .57157 .28527 Mtetra
.585 .782 .974 r
.57157 .28527 .57728 .29682 .60185 .29491 .59634 .28335 Mtetra
.586 .783 .974 r
.59634 .28335 .60185 .29491 .62653 .29292 .62121 .28135 Mtetra
.587 .785 .974 r
.62121 .28135 .62653 .29292 .65131 .29087 .64618 .27927 Mtetra
.588 .786 .974 r
.64618 .27927 .65131 .29087 .67619 .28875 .67126 .27713 Mtetra
.589 .786 .974 r
.67126 .27713 .67619 .28875 .70117 .28658 .69644 .27494 Mtetra
.59 .787 .974 r
.69644 .27494 .70117 .28658 .72626 .28436 .72173 .27269 Mtetra
.59 .788 .974 r
.72173 .27269 .72626 .28436 .75145 .2821 .74712 .2704 Mtetra
.591 .788 .974 r
.74712 .2704 .75145 .2821 .77675 .27979 .77262 .26806 Mtetra
.591 .789 .974 r
.77262 .26806 .77675 .27979 .80215 .27745 .79822 .26568 Mtetra
.592 .789 .975 r
.79822 .26568 .80215 .27745 .82765 .27506 .82393 .26326 Mtetra
.592 .79 .975 r
.82393 .26326 .82765 .27506 .85326 .27265 .84975 .26081 Mtetra
.84975 .26081 .85326 .27265 .87897 .2702 .87568 .25833 Mtetra
.593 .791 .975 r
.87568 .25833 .87897 .2702 .90479 .26772 .90171 .25581 Mtetra
.90171 .25581 .90479 .26772 .93072 .26521 .92785 .25326 Mtetra
.584 .771 .968 r
.09733 .19623 .10642 .20755 .12815 .21403 .1198 .19479 Mtetra
0 0 .523 r
.1198 .19479 .12815 .21403 .14831 .24491 .13984 .22826 Mtetra
0 .275 .779 r
.13984 .22826 .14831 .24491 .16964 .26358 .16117 .24848 Mtetra
.201 .472 .888 r
.16117 .24848 .16964 .26358 .19164 .2755 .18323 .2614 Mtetra
.333 .58 .932 r
.18323 .2614 .19164 .2755 .21408 .28336 .20576 .26993 Mtetra
.412 .642 .951 r
.20576 .26993 .21408 .28336 .23683 .2886 .22864 .27564 Mtetra
.461 .68 .96 r
.22864 .27564 .23683 .2886 .25983 .29207 .25177 .27945 Mtetra
.493 .706 .965 r
.25177 .27945 .25983 .29207 .28302 .29429 .27511 .28192 Mtetra
.516 .724 .967 r
.27511 .28192 .28302 .29429 .30638 .2956 .29862 .28341 Mtetra
.532 .737 .969 r
.29862 .28341 .30638 .2956 .32989 .29622 .32229 .28417 Mtetra
.544 .746 .97 r
.32229 .28417 .32989 .29622 .35354 .29632 .34611 .28436 Mtetra
.553 .754 .971 r
.34611 .28436 .35354 .29632 .37731 .296 .37005 .28412 Mtetra
.56 .76 .971 r
.37005 .28412 .37731 .296 .4012 .29534 .39412 .28352 Mtetra
.566 .765 .972 r
.39412 .28352 .4012 .29534 .42521 .29442 .4183 .28264 Mtetra
.57 .769 .972 r
.4183 .28264 .42521 .29442 .44934 .29328 .44261 .28153 Mtetra
.574 .772 .973 r
.44261 .28153 .44934 .29328 .47357 .29195 .46702 .28022 Mtetra
.577 .775 .973 r
.46702 .28022 .47357 .29195 .49791 .29047 .49155 .27874 Mtetra
.579 .777 .973 r
.49155 .27874 .49791 .29047 .52236 .28885 .51618 .27712 Mtetra
.581 .779 .973 r
.51618 .27712 .52236 .28885 .54691 .28711 .54093 .27538 Mtetra
.583 .78 .973 r
.54093 .27538 .54691 .28711 .57157 .28527 .56578 .27354 Mtetra
.584 .782 .974 r
.56578 .27354 .57157 .28527 .59634 .28335 .59073 .2716 Mtetra
.586 .783 .974 r
.59073 .2716 .59634 .28335 .62121 .28135 .6158 .26957 Mtetra
.587 .784 .974 r
.6158 .26957 .62121 .28135 .64618 .27927 .64097 .26748 Mtetra
.588 .785 .974 r
.64097 .26748 .64618 .27927 .67126 .27713 .66625 .26532 Mtetra
.589 .786 .974 r
.66625 .26532 .67126 .27713 .69644 .27494 .69163 .2631 Mtetra
.589 .787 .974 r
.69163 .2631 .69644 .27494 .72173 .27269 .71712 .26082 Mtetra
.59 .788 .974 r
.71712 .26082 .72173 .27269 .74712 .2704 .74272 .2585 Mtetra
.74272 .2585 .74712 .2704 .77262 .26806 .76842 .25613 Mtetra
.591 .789 .974 r
.76842 .25613 .77262 .26806 .79822 .26568 .79424 .25372 Mtetra
.591 .789 .975 r
.79424 .25372 .79822 .26568 .82393 .26326 .82016 .25126 Mtetra
.592 .79 .975 r
.82016 .25126 .82393 .26326 .84975 .26081 .84618 .24878 Mtetra
.84618 .24878 .84975 .26081 .87568 .25833 .87232 .24625 Mtetra
.592 .791 .975 r
.87232 .24625 .87568 .25833 .90171 .25581 .89857 .2437 Mtetra
.593 .791 .975 r
.89857 .2437 .90171 .25581 .92785 .25326 .92493 .24111 Mtetra
.617 .786 .963 r
.0881 .18473 .09733 .19623 .1198 .19479 .11082 .18195 Mtetra
.584 .147 0 r
.11082 .18195 .1198 .19479 .13984 .22826 .13126 .21138 Mtetra
0 .228 .748 r
.13126 .21138 .13984 .22826 .16117 .24848 .15257 .23317 Mtetra
.163 .445 .876 r
.15257 .23317 .16117 .24848 .18323 .2614 .17469 .24709 Mtetra
.31 .564 .928 r
.17469 .24709 .18323 .2614 .20576 .26993 .19732 .25629 Mtetra
.396 .632 .949 r
.19732 .25629 .20576 .26993 .22864 .27564 .22032 .26248 Mtetra
.45 .674 .959 r
.22032 .26248 .22864 .27564 .25177 .27945 .24358 .26663 Mtetra
.486 .701 .964 r
.24358 .26663 .25177 .27945 .27511 .28192 .26707 .26934 Mtetra
.51 .72 .967 r
.26707 .26934 .27511 .28192 .29862 .28341 .29074 .27102 Mtetra
.528 .734 .969 r
.29074 .27102 .29862 .28341 .32229 .28417 .31457 .27192 Mtetra
.541 .745 .97 r
.31457 .27192 .32229 .28417 .34611 .28436 .33855 .27222 Mtetra
.551 .752 .971 r
.33855 .27222 .34611 .28436 .37005 .28412 .36267 .27205 Mtetra
.558 .759 .972 r
.36267 .27205 .37005 .28412 .39412 .28352 .38691 .27151 Mtetra
.564 .764 .972 r
.38691 .27151 .39412 .28352 .4183 .28264 .41128 .27067 Mtetra
.569 .768 .972 r
.41128 .27067 .4183 .28264 .44261 .28153 .43576 .26958 Mtetra
.573 .771 .973 r
.43576 .26958 .44261 .28153 .46702 .28022 .46036 .26829 Mtetra
.576 .774 .973 r
.46036 .26829 .46702 .28022 .49155 .27874 .48508 .26682 Mtetra
.578 .776 .973 r
.48508 .26682 .49155 .27874 .51618 .27712 .5099 .2652 Mtetra
.58 .778 .973 r
.5099 .2652 .51618 .27712 .54093 .27538 .53484 .26346 Mtetra
.582 .78 .973 r
.53484 .26346 .54093 .27538 .56578 .27354 .55988 .2616 Mtetra
.584 .782 .974 r
.55988 .2616 .56578 .27354 .59073 .2716 .58504 .25965 Mtetra
.585 .783 .974 r
.58504 .25965 .59073 .2716 .6158 .26957 .6103 .25761 Mtetra
.586 .784 .974 r
.6103 .25761 .6158 .26957 .64097 .26748 .63567 .25549 Mtetra
.587 .785 .974 r
.63567 .25549 .64097 .26748 .66625 .26532 .66115 .2533 Mtetra
.588 .786 .974 r
.66115 .2533 .66625 .26532 .69163 .2631 .68674 .25106 Mtetra
.589 .787 .974 r
.68674 .25106 .69163 .2631 .71712 .26082 .71243 .24875 Mtetra
.59 .787 .974 r
.71243 .24875 .71712 .26082 .74272 .2585 .73824 .2464 Mtetra
.59 .788 .974 r
.73824 .2464 .74272 .2585 .76842 .25613 .76415 .24399 Mtetra
.591 .789 .974 r
.76415 .24399 .76842 .25613 .79424 .25372 .79018 .24155 Mtetra
.591 .789 .975 r
.79018 .24155 .79424 .25372 .82016 .25126 .81631 .23906 Mtetra
.592 .79 .975 r
.81631 .23906 .82016 .25126 .84618 .24878 .84256 .23653 Mtetra
.84256 .23653 .84618 .24878 .87232 .24625 .86891 .23397 Mtetra
.592 .791 .975 r
.86891 .23397 .87232 .24625 .89857 .2437 .89538 .23138 Mtetra
.593 .791 .975 r
.89538 .23138 .89857 .2437 .92493 .24111 .92196 .22875 Mtetra
.617 .786 .963 r
.07871 .17305 .0881 .18473 .11082 .18195 .1016 .17022 Mtetra
0 0 .513 r
.1016 .17022 .11082 .18195 .13126 .21138 .12255 .19426 Mtetra
0 .18 .715 r
.12255 .19426 .13126 .21138 .15257 .23317 .14385 .21762 Mtetra
.124 .417 .863 r
.14385 .21762 .15257 .23317 .17469 .24709 .16602 .23256 Mtetra
.286 .548 .922 r
.16602 .23256 .17469 .24709 .19732 .25629 .18875 .24245 Mtetra
.381 .622 .947 r
.18875 .24245 .19732 .25629 .22032 .26248 .21186 .24911 Mtetra
.44 .667 .959 r
.21186 .24911 .22032 .26248 .24358 .26663 .23527 .2536 Mtetra
.478 .697 .964 r
.23527 .2536 .24358 .26663 .26707 .26934 .2589 .25657 Mtetra
.505 .717 .967 r
.2589 .25657 .26707 .26934 .29074 .27102 .28273 .25843 Mtetra
.524 .732 .969 r
.28273 .25843 .29074 .27102 .31457 .27192 .30673 .25947 Mtetra
.537 .743 .97 r
.30673 .25947 .31457 .27192 .33855 .27222 .33088 .25987 Mtetra
.548 .751 .971 r
.33088 .25987 .33855 .27222 .36267 .27205 .35517 .25978 Mtetra
.556 .757 .972 r
.35517 .25978 .36267 .27205 .38691 .27151 .37959 .2593 Mtetra
.562 .763 .972 r
.37959 .2593 .38691 .27151 .41128 .27067 .40414 .2585 Mtetra
.567 .767 .972 r
.40414 .2585 .41128 .27067 .43576 .26958 .42881 .25744 Mtetra
.571 .77 .973 r
.42881 .25744 .43576 .26958 .46036 .26829 .4536 .25616 Mtetra
.575 .773 .973 r
.4536 .25616 .46036 .26829 .48508 .26682 .4785 .2547 Mtetra
.577 .776 .973 r
.4785 .2547 .48508 .26682 .5099 .2652 .50352 .25308 Mtetra
.58 .778 .973 r
.50352 .25308 .5099 .2652 .53484 .26346 .52865 .25133 Mtetra
.582 .78 .974 r
.52865 .25133 .53484 .26346 .55988 .2616 .55389 .24947 Mtetra
.583 .781 .974 r
.55389 .24947 .55988 .2616 .58504 .25965 .57924 .2475 Mtetra
.585 .783 .974 r
.57924 .2475 .58504 .25965 .6103 .25761 .60471 .24544 Mtetra
.586 .784 .974 r
.60471 .24544 .6103 .25761 .63567 .25549 .63028 .2433 Mtetra
.587 .785 .974 r
.63028 .2433 .63567 .25549 .66115 .2533 .65597 .24109 Mtetra
.588 .786 .974 r
.65597 .24109 .66115 .2533 .68674 .25106 .68176 .23881 Mtetra
.589 .786 .974 r
.68176 .23881 .68674 .25106 .71243 .24875 .70767 .23648 Mtetra
.589 .787 .974 r
.70767 .23648 .71243 .24875 .73824 .2464 .73368 .23409 Mtetra
.59 .788 .974 r
.73368 .23409 .73824 .2464 .76415 .24399 .75981 .23165 Mtetra
.59 .789 .975 r
.75981 .23165 .76415 .24399 .79018 .24155 .78605 .22917 Mtetra
.591 .789 .975 r
.78605 .22917 .79018 .24155 .81631 .23906 .8124 .22664 Mtetra
.591 .79 .975 r
.8124 .22664 .81631 .23906 .84256 .23653 .83887 .22408 Mtetra
.592 .79 .975 r
.83887 .22408 .84256 .23653 .86891 .23397 .86544 .22148 Mtetra
.86544 .22148 .86891 .23397 .89538 .23138 .89213 .21884 Mtetra
.592 .791 .975 r
.89213 .21884 .89538 .23138 .92196 .22875 .91894 .21617 Mtetra
.617 .786 .963 r
.06918 .16119 .07871 .17305 .1016 .17022 .09223 .15831 Mtetra
0 .187 .697 r
.09223 .15831 .1016 .17022 .12255 .19426 .11372 .1769 Mtetra
0 .132 .679 r
.11372 .1769 .12255 .19426 .14385 .21762 .135 .20185 Mtetra
.085 .388 .847 r
.135 .20185 .14385 .21762 .16602 .23256 .15722 .21781 Mtetra
.261 .531 .916 r
.15722 .21781 .16602 .23256 .18875 .24245 .18004 .22838 Mtetra
.365 .612 .945 r
.18004 .22838 .18875 .24245 .21186 .24911 .20328 .23553 Mtetra
.429 .661 .958 r
.20328 .23553 .21186 .24911 .23527 .2536 .22682 .24037 Mtetra
.47 .692 .964 r
.22682 .24037 .23527 .2536 .2589 .25657 .2506 .24359 Mtetra
.499 .714 .967 r
.2506 .24359 .2589 .25657 .28273 .25843 .27459 .24564 Mtetra
.519 .729 .969 r
.27459 .24564 .28273 .25843 .30673 .25947 .29876 .24682 Mtetra
.534 .741 .97 r
.29876 .24682 .30673 .25947 .33088 .25987 .32308 .24733 Mtetra
.545 .749 .971 r
.32308 .24733 .33088 .25987 .35517 .25978 .34755 .24732 Mtetra
.554 .756 .972 r
.34755 .24732 .35517 .25978 .37959 .2593 .37215 .24689 Mtetra
.56 .762 .972 r
.37215 .24689 .37959 .2593 .40414 .2585 .39688 .24613 Mtetra
.566 .766 .973 r
.39688 .24613 .40414 .2585 .42881 .25744 .42174 .2451 Mtetra
.57 .77 .973 r
.42174 .2451 .42881 .25744 .4536 .25616 .44672 .24383 Mtetra
.574 .773 .973 r
.44672 .24383 .4536 .25616 .4785 .2547 .47181 .24238 Mtetra
.576 .775 .973 r
.47181 .24238 .4785 .2547 .50352 .25308 .49703 .24076 Mtetra
.579 .777 .973 r
.49703 .24076 .50352 .25308 .52865 .25133 .52235 .239 Mtetra
.581 .779 .974 r
.52235 .239 .52865 .25133 .55389 .24947 .5478 .23712 Mtetra
.583 .781 .974 r
.5478 .23712 .55389 .24947 .57924 .2475 .57335 .23514 Mtetra
.584 .782 .974 r
.57335 .23514 .57924 .2475 .60471 .24544 .59902 .23306 Mtetra
.585 .783 .974 r
.59902 .23306 .60471 .24544 .63028 .2433 .6248 .2309 Mtetra
.587 .784 .974 r
.6248 .2309 .63028 .2433 .65597 .24109 .65069 .22866 Mtetra
.587 .785 .974 r
.65069 .22866 .65597 .24109 .68176 .23881 .6767 .22635 Mtetra
.588 .786 .974 r
.6767 .22635 .68176 .23881 .70767 .23648 .70282 .22399 Mtetra
.589 .787 .974 r
.70282 .22399 .70767 .23648 .73368 .23409 .72905 .22157 Mtetra
.59 .788 .974 r
.72905 .22157 .73368 .23409 .75981 .23165 .75539 .21909 Mtetra
.59 .788 .975 r
.75539 .21909 .75981 .23165 .78605 .22917 .78185 .21657 Mtetra
.591 .789 .975 r
.78185 .21657 .78605 .22917 .8124 .22664 .80842 .21401 Mtetra
.80842 .21401 .8124 .22664 .83887 .22408 .83511 .21141 Mtetra
.592 .79 .975 r
.83511 .21141 .83887 .22408 .86544 .22148 .86191 .20876 Mtetra
.86191 .20876 .86544 .22148 .89213 .21884 .88883 .20608 Mtetra
.592 .791 .975 r
.88883 .20608 .89213 .21884 .91894 .21617 .91586 .20337 Mtetra
.617 .786 .963 r
.05949 .14913 .06918 .16119 .09223 .15831 .08271 .1462 Mtetra
.011 .406 .855 r
.08271 .1462 .09223 .15831 .11372 .1769 .10476 .15929 Mtetra
0 .085 .642 r
.10476 .15929 .11372 .1769 .135 .20185 .12602 .18584 Mtetra
.045 .358 .831 r
.12602 .18584 .135 .20185 .15722 .21781 .14829 .20283 Mtetra
.235 .514 .91 r
.14829 .20283 .15722 .21781 .18004 .22838 .1712 .2141 Mtetra
.348 .601 .942 r
.1712 .2141 .18004 .22838 .20328 .23553 .19456 .22173 Mtetra
.418 .654 .957 r
.19456 .22173 .20328 .23553 .22682 .24037 .21824 .22692 Mtetra
.463 .688 .964 r
.21824 .22692 .22682 .24037 .2506 .24359 .24217 .2304 Mtetra
.493 .711 .967 r
.24217 .2304 .2506 .24359 .27459 .24564 .26632 .23264 Mtetra
.515 .727 .969 r
.26632 .23264 .27459 .24564 .29876 .24682 .29065 .23396 Mtetra
.531 .739 .971 r
.29065 .23396 .29876 .24682 .32308 .24733 .31515 .23457 Mtetra
.542 .748 .971 r
.31515 .23457 .32308 .24733 .34755 .24732 .3398 .23464 Mtetra
.551 .755 .972 r
.3398 .23464 .34755 .24732 .37215 .24689 .36458 .23427 Mtetra
.559 .761 .972 r
.36458 .23427 .37215 .24689 .39688 .24613 .3895 .23355 Mtetra
.564 .765 .973 r
.3895 .23355 .39688 .24613 .42174 .2451 .41455 .23254 Mtetra
.569 .769 .973 r
.41455 .23254 .42174 .2451 .44672 .24383 .43972 .23129 Mtetra
.572 .772 .973 r
.43972 .23129 .44672 .24383 .47181 .24238 .46501 .22985 Mtetra
.576 .775 .973 r
.46501 .22985 .47181 .24238 .49703 .24076 .49042 .22823 Mtetra
.578 .777 .973 r
.49042 .22823 .49703 .24076 .52235 .239 .51595 .22646 Mtetra
.58 .779 .974 r
.51595 .22646 .52235 .239 .5478 .23712 .5416 .22457 Mtetra
.582 .78 .974 r
.5416 .22457 .5478 .23712 .57335 .23514 .56736 .22257 Mtetra
.584 .782 .974 r
.56736 .22257 .57335 .23514 .59902 .23306 .59323 .22047 Mtetra
.585 .783 .974 r
.59323 .22047 .59902 .23306 .6248 .2309 .61922 .21828 Mtetra
.586 .784 .974 r
.61922 .21828 .6248 .2309 .65069 .22866 .64533 .21601 Mtetra
.587 .785 .974 r
.64533 .21601 .65069 .22866 .6767 .22635 .67155 .21368 Mtetra
.588 .786 .974 r
.67155 .21368 .6767 .22635 .70282 .22399 .69788 .21128 Mtetra
.589 .787 .974 r
.69788 .21128 .70282 .22399 .72905 .22157 .72433 .20883 Mtetra
.589 .788 .974 r
.72433 .20883 .72905 .22157 .75539 .21909 .7509 .20632 Mtetra
.59 .788 .975 r
.7509 .20632 .75539 .21909 .78185 .21657 .77758 .20376 Mtetra
.591 .789 .975 r
.77758 .20376 .78185 .21657 .80842 .21401 .80438 .20116 Mtetra
.80438 .20116 .80842 .21401 .83511 .21141 .83129 .19851 Mtetra
.591 .79 .975 r
.83129 .19851 .83511 .21141 .86191 .20876 .85832 .19583 Mtetra
.592 .79 .975 r
.85832 .19583 .86191 .20876 .88883 .20608 .88547 .1931 Mtetra
.592 .791 .975 r
.88547 .1931 .88883 .20608 .91586 .20337 .91273 .19035 Mtetra
.617 .786 .963 r
.04964 .13687 .05949 .14913 .08271 .1462 .07304 .1339 Mtetra
.273 .593 .948 r
.07304 .1339 .08271 .1462 .10476 .15929 .09567 .14143 Mtetra
0 .038 .604 r
.09567 .14143 .10476 .15929 .12602 .18584 .1169 .16959 Mtetra
.004 .327 .813 r
.1169 .16959 .12602 .18584 .14829 .20283 .13922 .18761 Mtetra
.21 .496 .902 r
.13922 .18761 .14829 .20283 .1712 .2141 .16222 .19959 Mtetra
.331 .591 .939 r
.16222 .19959 .1712 .2141 .19456 .22173 .18569 .20771 Mtetra
.406 .647 .956 r
.18569 .20771 .19456 .22173 .21824 .22692 .20951 .21326 Mtetra
.455 .683 .963 r
.20951 .21326 .21824 .22692 .24217 .2304 .2336 .21699 Mtetra
.487 .707 .967 r
.2336 .21699 .24217 .2304 .26632 .23264 .25791 .21942 Mtetra
.51 .724 .969 r
.25791 .21942 .26632 .23264 .29065 .23396 .28241 .22088 Mtetra
.527 .737 .971 r
.28241 .22088 .29065 .23396 .31515 .23457 .30709 .2216 Mtetra
.54 .746 .972 r
.30709 .2216 .31515 .23457 .3398 .23464 .33191 .22175 Mtetra
.549 .754 .972 r
.33191 .22175 .3398 .23464 .36458 .23427 .35689 .22144 Mtetra
.557 .76 .972 r
.35689 .22144 .36458 .23427 .3895 .23355 .382 .22076 Mtetra
.563 .764 .973 r
.382 .22076 .3895 .23355 .41455 .23254 .40724 .21977 Mtetra
.567 .768 .973 r
.40724 .21977 .41455 .23254 .43972 .23129 .4326 .21854 Mtetra
.571 .771 .973 r
.4326 .21854 .43972 .23129 .46501 .22985 .45809 .2171 Mtetra
.575 .774 .973 r
.45809 .2171 .46501 .22985 .49042 .22823 .48371 .21548 Mtetra
.577 .776 .974 r
.48371 .21548 .49042 .22823 .51595 .22646 .50944 .21371 Mtetra
.58 .778 .974 r
.50944 .21371 .51595 .22646 .5416 .22457 .53529 .2118 Mtetra
.581 .78 .974 r
.53529 .2118 .5416 .22457 .56736 .22257 .56126 .20978 Mtetra
.583 .782 .974 r
.56126 .20978 .56736 .22257 .59323 .22047 .58735 .20766 Mtetra
.584 .783 .974 r
.58735 .20766 .59323 .22047 .61922 .21828 .61355 .20544 Mtetra
.586 .784 .974 r
.61355 .20544 .61922 .21828 .64533 .21601 .63987 .20315 Mtetra
.587 .785 .974 r
.63987 .20315 .64533 .21601 .67155 .21368 .66631 .20078 Mtetra
.588 .786 .974 r
.66631 .20078 .67155 .21368 .69788 .21128 .69286 .19835 Mtetra
.588 .787 .974 r
.69286 .19835 .69788 .21128 .72433 .20883 .71954 .19586 Mtetra
.589 .787 .974 r
.71954 .19586 .72433 .20883 .7509 .20632 .74633 .19331 Mtetra
.59 .788 .975 r
.74633 .19331 .7509 .20632 .77758 .20376 .77323 .19072 Mtetra
.59 .789 .975 r
.77323 .19072 .77758 .20376 .80438 .20116 .80026 .18807 Mtetra
.591 .789 .975 r
.80026 .18807 .80438 .20116 .83129 .19851 .8274 .18539 Mtetra
.591 .79 .975 r
.8274 .18539 .83129 .19851 .85832 .19583 .85466 .18266 Mtetra
.592 .79 .975 r
.85466 .18266 .85832 .19583 .88547 .1931 .88205 .17989 Mtetra
.88205 .17989 .88547 .1931 .91273 .19035 .90955 .17709 Mtetra
.617 .786 .963 r
.03963 .12441 .04964 .13687 .07304 .1339 .0632 .12139 Mtetra
.483 .719 .975 r
.0632 .12139 .07304 .1339 .09567 .14143 .08645 .1233 Mtetra
0 0 .565 r
.08645 .1233 .09567 .14143 .1169 .16959 .10764 .15309 Mtetra
0 .296 .793 r
.10764 .15309 .1169 .16959 .13922 .18761 .13 .17216 Mtetra
.183 .477 .894 r
.13 .17216 .13922 .18761 .16222 .19959 .1531 .18485 Mtetra
.314 .579 .936 r
.1531 .18485 .16222 .19959 .18569 .20771 .17669 .19347 Mtetra
.395 .64 .954 r
.17669 .19347 .18569 .20771 .20951 .21326 .20065 .19937 Mtetra
.446 .678 .963 r
.20065 .19937 .20951 .21326 .2336 .21699 .22489 .20336 Mtetra
.481 .704 .967 r
.22489 .20336 .2336 .21699 .25791 .21942 .24936 .20599 Mtetra
.506 .722 .969 r
.24936 .20599 .25791 .21942 .28241 .22088 .27404 .20759 Mtetra
.524 .735 .971 r
.27404 .20759 .28241 .22088 .30709 .2216 .29889 .20842 Mtetra
.537 .745 .972 r
.29889 .20842 .30709 .2216 .33191 .22175 .3239 .20864 Mtetra
.547 .752 .972 r
.3239 .20864 .33191 .22175 .35689 .22144 .34906 .20839 Mtetra
.555 .759 .973 r
.34906 .20839 .35689 .22144 .382 .22076 .37436 .20775 Mtetra
.561 .763 .973 r
.37436 .20775 .382 .22076 .40724 .21977 .3998 .20679 Mtetra
.566 .767 .973 r
.3998 .20679 .40724 .21977 .4326 .21854 .42536 .20557 Mtetra
.57 .771 .973 r
.42536 .20557 .4326 .21854 .45809 .2171 .45106 .20413 Mtetra
.574 .774 .973 r
.45106 .20413 .45809 .2171 .48371 .21548 .47687 .20251 Mtetra
.577 .776 .974 r
.47687 .20251 .48371 .21548 .50944 .21371 .50281 .20073 Mtetra
.579 .778 .974 r
.50281 .20073 .50944 .21371 .53529 .2118 .52888 .19881 Mtetra
.581 .78 .974 r
.52888 .19881 .53529 .2118 .56126 .20978 .55506 .19677 Mtetra
.583 .781 .974 r
.55506 .19677 .56126 .20978 .58735 .20766 .58136 .19462 Mtetra
.584 .783 .974 r
.58136 .19462 .58735 .20766 .61355 .20544 .60778 .19238 Mtetra
.585 .784 .974 r
.60778 .19238 .61355 .20544 .63987 .20315 .63432 .19006 Mtetra
.586 .785 .974 r
.63432 .19006 .63987 .20315 .66631 .20078 .66098 .18766 Mtetra
.587 .786 .974 r
.66098 .18766 .66631 .20078 .69286 .19835 .68776 .18519 Mtetra
.588 .786 .974 r
.68776 .18519 .69286 .19835 .71954 .19586 .71465 .18267 Mtetra
.589 .787 .974 r
.71465 .18267 .71954 .19586 .74633 .19331 .74167 .18008 Mtetra
.589 .788 .975 r
.74167 .18008 .74633 .19331 .77323 .19072 .76881 .17744 Mtetra
.59 .788 .975 r
.76881 .17744 .77323 .19072 .80026 .18807 .79606 .17476 Mtetra
.591 .789 .975 r
.79606 .17476 .80026 .18807 .8274 .18539 .82344 .17203 Mtetra
.591 .79 .975 r
.82344 .17203 .8274 .18539 .85466 .18266 .85094 .16925 Mtetra
.85094 .16925 .85466 .18266 .88205 .17989 .87856 .16644 Mtetra
.592 .79 .975 r
.87856 .16644 .88205 .17989 .90955 .17709 .90631 .16359 Mtetra
.617 .786 .963 r
.02946 .11175 .03963 .12441 .0632 .12139 .0532 .10868 Mtetra
.0532 .10868 .0632 .12139 .08645 .1233 .07704 .10559 Mtetra
0 0 .523 r
.07704 .10559 .08645 .1233 .10764 .15309 .09825 .13634 Mtetra
0 .264 .772 r
.09825 .13634 .10764 .15309 .13 .17216 .12064 .15647 Mtetra
.157 .458 .885 r
.12064 .15647 .13 .17216 .1531 .18485 .14382 .16987 Mtetra
.297 .568 .932 r
.14382 .16987 .1531 .18485 .17669 .19347 .16754 .17899 Mtetra
.383 .632 .953 r
.16754 .17899 .17669 .19347 .20065 .19937 .19163 .18525 Mtetra
.438 .673 .962 r
.19163 .18525 .20065 .19937 .22489 .20336 .21603 .18951 Mtetra
.475 .7 .967 r
.21603 .18951 .22489 .20336 .24936 .20599 .24067 .19233 Mtetra
.501 .719 .969 r
.24067 .19233 .24936 .20599 .27404 .20759 .26552 .19407 Mtetra
.52 .733 .971 r
.26552 .19407 .27404 .20759 .29889 .20842 .29055 .19501 Mtetra
.534 .743 .972 r
.29055 .19501 .29889 .20842 .3239 .20864 .31575 .19531 Mtetra
.545 .751 .972 r
.31575 .19531 .3239 .20864 .34906 .20839 .3411 .19511 Mtetra
.553 .758 .973 r
.3411 .19511 .34906 .20839 .37436 .20775 .3666 .19451 Mtetra
.56 .763 .973 r
.3666 .19451 .37436 .20775 .3998 .20679 .39223 .19358 Mtetra
.565 .767 .973 r
.39223 .19358 .3998 .20679 .42536 .20557 .418 .19237 Mtetra
.569 .77 .973 r
.418 .19237 .42536 .20557 .45106 .20413 .4439 .19094 Mtetra
.573 .773 .974 r
.4439 .19094 .45106 .20413 .47687 .20251 .46992 .18931 Mtetra
.576 .776 .974 r
.46992 .18931 .47687 .20251 .50281 .20073 .49607 .18752 Mtetra
.578 .778 .974 r
.49607 .18752 .50281 .20073 .52888 .19881 .52235 .18559 Mtetra
.58 .779 .974 r
.52235 .18559 .52888 .19881 .55506 .19677 .54874 .18353 Mtetra
.582 .781 .974 r
.54874 .18353 .55506 .19677 .58136 .19462 .57526 .18136 Mtetra
.584 .782 .974 r
.57526 .18136 .58136 .19462 .60778 .19238 .6019 .17909 Mtetra
.585 .783 .974 r
.6019 .17909 .60778 .19238 .63432 .19006 .62867 .17674 Mtetra
.586 .785 .974 r
.62867 .17674 .63432 .19006 .66098 .18766 .65555 .1743 Mtetra
.587 .785 .974 r
.65555 .1743 .66098 .18766 .68776 .18519 .68256 .1718 Mtetra
.588 .786 .974 r
.68256 .1718 .68776 .18519 .71465 .18267 .70968 .16924 Mtetra
.589 .787 .975 r
.70968 .16924 .71465 .18267 .74167 .18008 .73693 .16661 Mtetra
.589 .788 .975 r
.73693 .16661 .74167 .18008 .76881 .17744 .7643 .16393 Mtetra
.59 .788 .975 r
.7643 .16393 .76881 .17744 .79606 .17476 .7918 .1612 Mtetra
.59 .789 .975 r
.7918 .1612 .79606 .17476 .82344 .17203 .81941 .15842 Mtetra
.591 .789 .975 r
.81941 .15842 .82344 .17203 .85094 .16925 .84715 .1556 Mtetra
.591 .79 .975 r
.84715 .1556 .85094 .16925 .87856 .16644 .87502 .15274 Mtetra
.592 .79 .975 r
.87502 .15274 .87856 .16644 .90631 .16359 .90301 .14984 Mtetra
0 g
.89362 0 m
.98022 .38351 L
s
.98022 .38351 m
1 .65325 L
s
1 .65325 m
.91448 .33294 L
s
.91448 .33294 m
.89362 0 L
s
.02946 .11175 m
0 .4272 L
s
0 .4272 m
.91448 .33294 L
s
.91448 .33294 m
.89362 0 L
s
.89362 0 m
.02946 .11175 L
s
.02946 .11175 m
.89362 0 L
s
gsave
.44797 -0.02478 -65.9056 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(u) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
0 .4272 m
.29069 .70824 L
s
gsave
.15892 .66839 -66.3192 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(p) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{261.5, 185.063},
  ImageMargins->{{30.25, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.095767,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000450000^A000`40O003h00Oogoo1Woo003oOol6
Ool00?moo`Ioo`00ogoo1Woo003oOol6Ool00?moo`Ioo`00PWoo1000Ogoo0021Ool01000Oomoo`00
P7oo0021Ool01000Oomoo`00P7oo0020Ool200000goo00000020Ool00?moo`Ioo`00ogoo1Woo003o
Ool6Ool00?moo`Ioo`00ogoo1Woo003oOol6Ool00?moo`Ioo`00ogoo1Woo003oOol6Ool00?moo`Io
o`00ogoo1Woo003LOol4000UOol00=Aoo`P000=oo`03001oogoo02=oo`00c7oo20002goo00<007oo
Ool08goo0034Ool8000COol2000TOol00;aoo`P001]oo`8002Aoo`00]Goo1`008goo0P0097oo002]
Ool8000ZOol2000TOol00:Eoo`P0039oo`03001oo`0002=oo`00WGoo2000>Woo00<007oo00008goo
002FOol70013Ool2000SOol008ioo`P004Yoo`8002=oo`00QWoo2000DWoo00<007oo00008Woo001n
Ool8001JOol00`00Ool0000ROol007Ioo`P0069oo`03001oo`00029oo`00Kgoo1`00JWoo00<007oo
00008Woo001WOol8001aOol00`00Ool0000ROol005moo`P007Uoo`04001oogoo000QOol005Moo`P0
085oo`04001oogoo000QOol0051oo`L008Uoo`04001oogoo000QOol004Qoo`P0091oo`04001oogoo
000QOol0041oo`P009Qoo`05001oogooOol0000POol003Qoo`P00:1oo`05001oogooOol0000POol0
031oo`P00:Qoo`05001oogooOol0000POol002aoo`@00007Cci;7DlNBae??T/MCah0ZGoo00D007oo
Oomoo`00021oo`00;7oo00D004lNCai?7T/N00=?7P04Bai?7TlNCajXOol01@00Oomoogoo000087oo
000/Ool03@00Ool004/MCai;7DlnBae?7T/MCci;7@0@0:Moo`03001oogoo009oo`03001oogoo01eo
o`00;7oo00@007oo001oo`9?7P04Bai?7S[N?]h3>]h00`0@Oomoo`2UOol01@00Oomoogoo00007goo
000/Ool03P00Oomoo`00Cci;7DlNBae??S[N?]hjgSkO016WOol01@00Oomoogoo00007goo000/Ool0
1@00Oomoogoo00000dlN00A;7TlN8UdngP8jgP03015oogoo0:Aoo`05001oogooOol0000OOol002]o
o`03001oogoo00=oo`0;001??T/MCai;7B9N7UdRGQhm01403`2UOol00`00Oomoo`02Ool00`00Oomo
o`0LOol002]oo`03001oogoo00Aoo`05001?7TlNCai;7P038Ud00aiM0140n02TOol00`00Oomoo`02
Ool00`00Oomoo`0LOol002]oo`03001oogoo00Eoo`0;001??T/MCai;7@FK7UdRGP0b0140m`2SOol0
0`00Oomoo`02Ool00`00Oomoo`0LOol002]oo`03001oogoo00Eoo`03001;7TlN009?7P07Bah1VP6J
0IX0<P0A0?P0UWoo34/N00<007ooOol00Woo00<007ooOol077oo000[Ool00`00Oomoo`06Ool03000
Bae??T/MCai;7@FK0IX5V`0A0CT0mhYoo`05Bcm;7T/NAai;?`02Bah04DLNBcm;7T/NAai;?d/NBci7
7T/oBai;?TLNBcm;7T/n00001Goo00<007ooOol06goo000[Ool00`00Oomoo`07Ool00`00Bai?7P02
Cah01P2e0IX1VP0b0141608Afgeoob9;7P03001oogoo00=oo`03001oogoo01]oo`00:goo00<007oo
Ool027oo00h004/MCci;7DlN09D0]P6J03<1604i4K/Ag16kMGoo00a77T/NAai;?dLNBai77T/oAai;
7TLNBcl2Bah01TLNBcm;7T/NAai;?`9;7P0CAai;?d/NBai77T/oBai;?TLNBcm;7T/nAai;?d/NBci7
7T/o00001Goo00<007ooOol06goo000[Ool00`00Oomoo`09Ool00`00Bai?7P02Cah20;D0101C0ET1
604H0Q7K00<A^bHmOol0Igoo<d/N00<007ooOol00goo00<007ooOol06goo000[Ool00`00Oomoo`09
Ool04P00Cai;7DlnBae?7P2E0;H0<P5I0CTEo17K4M`R?2IM8S`V?EYoo`0TAai;7TLNBam77T/NAai;
7dLNBai77T/OAai;7TLNBam77T/NAai;?dLNBai77T/oAai;7TLNBcm77T/NAai;?dLNBai77T/o0T/N
00I77T/oBai;7TLNBcl2Bah04DLNBcm;7T/nAai;?d/NBci77T/oBai;?TLNBcm;7T/n00001Goo00<0
07ooOol06goo000[Ool00`00Oomoo`0:Ool00`00Cai;7P03Cah0302e07D1>@5I0CTEg1GK5M`R?BHm
8SdV?@<^O@03;Wioogoo049oo`0=Aai;7TLNBai77T/NAai;7TLNBai77T/NAah00d/N00E77T/NBai;
7TLN03Y;7P03001;7Woo00Aoo`03001oogoo01Yoo`00:goo00<007ooOol02goo01X004lNBae??T/M
0100U@1D0CT1F@4i5O`AfaGl9S`VGB8l<Wh^OC:N;WdbOSJM=[hfWCJn=7oo0496oT/OA_i;7TKnBam7
7T/NA_i;7dLNBai6oT/OAai;7TKnBam77T/NA_i;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai7
7T/OAai;7TLNBcm77T/NAai;?dLNBai77T/oAai;7TLNBcm77T/NAai;?dLNBai77T/oAai;7TLNBcl2
Bah064LNBcm;7T/NAai;?d/NBci77T/oBai;?TLNBcm;7T/nAai;?d/NBci77T/o001;?PEoo`03001o
ogoo01Yoo`00:Woo00<007ooOol03Goo0TlN011;7TlNCah0401d1EX5F@5I5O`Io1GK9UdV?BIM9Sd^
OP<^O@05=[hfWSJn=Yhf_P03>[h00c[N>[hngP03?]hJOol01TLNA_i77TKnAai6oP=77P05A_i77TLN
Aai6oP06Aah01D/NAai77TLNBah00dLN00Y;7TLNBai77T/NAai;7TLNBai77P=;7P05Aai;7T/NBai7
7P03Bah00dLNBai;7P0fBah00`00Baioo`04Ool00`00Oomoo`0JOol002Yoo`03001oogoo00ioo`0N
A_i;7TKmBai6oP2f07@5NPEI1GXEfaWl5M/VGBHl9UdV?C:N;WdbWRim=[hfWCJn=YdjgSZm?]hj_S[N
1CkN06E2oSkN@_hngT;n@]i2oT;N@_i2gTKn@_i6oT;nA_i2oTLO@_i77T;nAam6oTLN@_i77dKnAai6
oTLOA_i77TKnBam6oTLNA_i;7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dLNBai6oT/OAai;7TKnBam7
7T/NA_i;7dLNBai6oT/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/NAai;?dLNBai7
7T/oAai;7TLNBcm77T/NAai;?dLNBai77T/o009;7P06Aai;?d/NBai77T/o0T/N01M77T/oBai;7TLN
Bcm;7T/nAai;?d/NBci77T/oBai;?TLNBcm;7T/n001;?d/N00Aoo`03001oogoo01Yoo`00:Woo00<0
07ooOol03Woo00`004/NBai6oT/N00l0]P1d1EX5F@Ej5O`26O`02RYM9UdZGBIM<Yh^OC9n<Wdf_SJN
0SJn00DjgSZn>[hj_S[N00DngP92gP03@_hngT;n00E2oP06A_i2oT;n@_i6oT;n0dKn00A2oTKnA_i7
7P=6oP06Aai6oTLNA_i77TKn0dLN00=6oTLNAah014LN019;7TLNAai77T/NAai;7TLNBai77T/NAai;
7TLNBai77T/NAah3Bah01DLNBai;7T/NAah00d/N00E77T/NBai;7TLN03I;7P03001;7T/N00Eoo`03
001oogoo01Uoo`00:Woo00<007ooOol03goo00L002IMBai6oD/N09H0M@021GX05@EI7Q`Io1Wl9UdZ
GBHm:UdVGC:N;WdbWSJM>[hfWCZn=YdngSZm?]hj_P02?]h034;N?]hngSkN@_hngT;n?]i2oT;N@_i2
gP92oP1KA_i2oTKn@_i77T;nAam2oTLN@_i77dKnAai2oTLOA_i77TKnAam6oTLNA_i;7dKnAai6oT/O
A_i;7TKnBam6oT/NA_i;7dKnBai6oT/OAai;7TKnBam77T/NA_i;7dLNBai77T/OAai;7TLNBam77T/N
Aai;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/oAai;7TLNBcm77T/NAai;?dLNBai77T/o
Aai;7TLNBcl00T/N00I77T/oBai;7TLNBcl2Bah05DLNBcm;7T/NAai;?d/NBci77T/oBai;?TLNBcm;
7T/nAai;?d/N00177P05Ool00`00Oomoo`0IOol002Yoo`03001oogoo011oo`0E9WhVOBIn9We8P02f
07D5NPUj1ETN71Wl7O`VGBYM9UdZGC:M<YhbOC:N008f_P07=Yhf_SJn?]hj_S[N>[h01CkN00E2gT;n
@]i2oT;N00I2oP04A_i2oTKn@_h8A_h02TLNA_i6oTKnAai6oTLNA_i77TKn0dLN00=6oTLNAah014LN
019;7TLNAai77T/NAai;7TLNBai77T/NAai;7TLNBai77T/NAah3Bah01DLNBai;7T/NAah0?D/N00<0
04/NOol017oo00<007ooOol06Goo000ZOol00`00Oomoo`0AOol03BIn9UdVOR9M0?L0UPVJ1GX9VQWl
7Q`Io1hL00<ZG@08;WhbOC:N;WdbWSJM>[hfW@8j_P04?]hj_CkN>[h2?]h0ID;N?]hngSkN@_hngT;n
?]i6oT;N@_i2gTKn@_i6oT;nA_i2oTLN@_i77d;nAai2oTLOA_i77T;nAam6oTLNA_i77dKnBai6oT/O
A_i;7TKnBam6oT/NA_i;7dKnBai6oT/OA_i;7TKnBam77T/NA_i;7dLNBai6oT/OAai;7TLNBam77T/N
Aai;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/oAai;7TLNBcm77T/NAai;?dLNBai77T/o
Aai;7TLNBcl00T/N00I77T/oBai;7TLNBcl2Bah05dLNBcm;7T/NAai;?d/NBci77T/oBai;?TLNBcm;
7T/nAai;?d/NBci77P00Bah01Goo00<007ooOol06Goo000ZOol00`00Oomoo`0BOol02BIn9WdVOTAP
0=L0]PVJ1GX9NP027Q`00aWl:UdZG@02:Ud023:N<YdfWS:M>[hf_SZn=[h2>[h00ckN>[hngP05?]h0
14;n@]i2oT;N24;n00A6oT;nA_i2oPQ6oP0:Aai6oTLNA_i77TKnAai6oTLNA_h6Aah01D/NAai77TLN
Bah00dLN00Y;7TLNBai77T/NAai;7TLNBai77P=;7P05Aai;7T/NBai77P03Bah00dLNBai;7P0iBah0
0`00Bai;7P04Ool00`00Oomoo`0IOol002Yoo`03001oogoo01=oo`0=0ETVGBIn0=H0m`fJ3K/5NR8M
7Q`R7Agl;Wh00bYM00`fWS:M=YhbOCZn=[dj_SJm?]hj_SkN>[d2?]h0Hd;N?]i2oSkN@_hngT;n?]i2
oT;NA_i2gTKn@]i77T;nA_i2oTLN@_i77T;nAai2oTLNA_i77dKnAai6oT/OA_i77TKnBam6oT/NA_i;
7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dLNBai6oT/OAai;7TKnBam77T/NA_i;7dLNBai77T/OAai;
7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/NAai;?dLNBai77T/oAai;7TLNBcm77T/NAai;
?`02Bah01TLNBcm;7T/NAai;?`9;7P0JAai;?d/NBci77T/oBai;?TLNBcm;7T/nAai;?d/NBci77T/o
Bai;?TLNBcm;7P00Aai;?`Eoo`03001oogoo01Qoo`00:Woo00<007ooOol04goo00@0005I0ET04P80
e`033IX=V`fJ00<N7008:Ud^OBiM;WdbWC:N<YdfWPDj_PTngP05@]i2oT;N@_i2gP06@_h014Kn@_i6
oT;n1TKn00Y77TKnA_i6oTLNA_i77TKnAai6oP=77P04A_i77TLNBah3Aah01D/NAai77TLNBah00dLN
00Y;7TLNBai77T/NAai;7TLNBai77P=;7P05Aai;7T/NBai77P0mBah00`00Bai;7P05Ool00`00Oomo
o`0HOol002Yoo`03001oogoo01Aoo`1n0001F@0c0AP0eP3g3IX=^b8L9SdN728M:Ud^ORYM;WdbWCJn
<YdfWSJm>[hf_CZn>[dngSZn?]hj_D;n?]i2oSkN@_i2gT;n?]i2oT;NA_i2gTKn@_i6oT;nAai2oTKn
@_i77TKnAai2oTLNA_i77TKnAam6oTLNA_i;7dKnAai6oT/OA_i;7TKnBam6oT/NA_i;7dKnBai6oT/O
A_i;7TKnBam77T/NA_i;7dLNBai6oT/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/N
Aai;7dLNBai77T/OAai;7TLNBcm77T/NAai;?dLNBai77T/o0T/N00I77T/oBai;7TLNBcl2Bah074LN
Bcm;7T/NAai;?d/NBci77T/oBai;?TLNBcm;7T/nAai;?d/NBci77T/oBai;?TLN001;7T/n1Goo00<0
07ooOol067oo000ZOol00`00Oomoo`0EOol20ET00`0A0AP160024K/02PfK8Q`R?B8L;WdZGBim;Udf
WS:M0cJN13Zn1ckN00=2gSkN@_h00T;n00=2gT;n@_h01T;n0dKn00=2oTKnA_h014Kn00Y77TKnA_i6
oTLNA_i77TKnAai6oP=77P04A_i77TLNBah3Aah03T/NAai;7TLNBai77T/NAai;7TLNBai77T/NAah3
Bah01DLNBai;7T/NAah00d/N00=77T/NBah0>D/N00<004/NBah01Goo00<007ooOol067oo000YOol0
0`00Oomoo`0GOol09@4h05@04@4H0?LEfa6k8SdR72Hm8Q`^ORiM<Wh^OCJN<Ydf_S:M>[hj_C[N>[dj
_SZm?]hn_SkN>[e2oSkN@_hngT;n@]i2oSkN0092oP1CA_i2gTKn@_i6oT;nAai2oTKn@_i77TKnAai2
oTLNA_i77TKnAam6oTLNA_i;7dKnAai6oT/OA_i;7TKnBam6oT/NA_i;7dKnBai6oT/OA_i;7TKnBam7
7T/NA_i;7dLNBai6oT/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/NAai;?dLNBai7
7T/oAai;7TLNBcm77T/NAai;?`02Bah01TLNBcm;7T/NAai;?`9;7P06Aai;?d/NBai77T/o0T/N01M7
7T/oBai;?TLNBcm;7T/nAai;?d/NBci77T/oBai;?TLNBcm;7P00Aai;?d/N00Eoo`03001oogoo01Mo
o`00:Goo00<007ooOol067oo00D0<`1C1CT161GK008A^`039SdR728m00D^O@04=YhfWCJN=Yh4>[h6
?]h014;N?]i2gSkN0d;n00A2gT;n@_i6oP=2oP03A_i2oTKn00E6oP06Aai6oTLNA_i77TKn0dLN00E6
oTLNAai77TKn00=77P04A_i77TLNBah3Aah02T/NAai;7TLNBai77T/NAai;7TLN0d/N00E77T/NBai;
7TLN045;7P04001;7T/NBah5Ool00`00Oomoo`0GOol001Aoo`<0019oo`03001oogoo01Qoo`0L0140
<`0b1CP161GK6M`V?2Hm8S`V?Bim;Wh^GC9n=Ydf_SJM=[hfWCkN>[dngSZm?]hj_CkN?[h2?]h024;n
?]i2oSkN@_i2gT;n@]h2@_h0CdKn@]i6oT;nA_i2oTLN@_i6oT;nAai6oTLN@_i77dKnAai6oTLOA_i;
7TKnBam6oT/NA_i;7dKnBai6oT/OA_i;7TKnBam77T/NA_i;7dLNBai6oT/OAai;7TKnBam77T/NA_i;
7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBcm77T/NAai;?dLNBai77T/o009;
7P06Aai;?d/NBai77T/o0T/N00I77T/oBai;7TLNBcl2Bah06TLNBcm;7T/NAai;?d/NBci77T/oBai;
?TLNBcm;7T/nAai;?d/NBci77P00Bai;?TLNBcl4Ool00`00Oomoo`0GOol001Eoo`03001oogoo015o
o`03001oogoo01Uoo`0509D0<`Di1CTIg0025M/29Sd01RHl9SdbOC9m;WdbO@8fWP03=YdfWSZn00@j
_P@ngP04@_i2gT;N@]h6@_h014Kn@_i6oT;n1TKn00Y77TKnA_i6oTLNA_i77TKnAai6oP=77P05A_i7
7TLNBai6oP02Aah01D/NAai77TLNBah00dLN00Y;7TLNBai77T/NAai;7TLNBai77P=;7P05Aai;7T/N
Bai77P0oBah00`00Bai;7P02Bah4Ool00`00Oomoo`0GOol001=oo`<001=oo`03001oogoo01Uoo`1h
0100E0EI1ET5>1gl5M/Ig2Hl:UdV?2YM;WdbORim<YhfWCZn=Ydj_SZm?]hj_CkN>[dngSjm@]hngT;n
?]i2oSkN@_i2gTKn@]i2oT;NA_i2oTKn@_i6oT;nA_i2oTLN@_i77T;nAai6oTLNA_i;7TKnAai6oT/O
A_i;7TKnBam6oT/NA_i;7dKnBai6oT/OA_i;7TKnBam77T/NA_i;7dLNBai6oT/OAai;7TLNBam77T/N
Aai;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/oAai;7TLNBcm77T/NAai;?dLNBai77T/o
0T/N00I77T/oBai;7TLNBcl2Bah01TLNBcm;7T/NAai;?`9;7P0HAai;?d/NBci77T/oBai;?TLNBcm;
7T/nAai;?d/NBci77T/oBah004LNBcm;7T/n1Goo00<007ooOol05Woo000BOol01000Oomoo`004goo
00<007ooOol06Goo00d0453005@9F@Uj6O`Mo1Wl7O`Z?BYM9SdZG@02<Wd02Rim=[hfWSZn=Ydf_SZn
?]hj_Sjn13kN00=2gT;n@]h00T;N1T;n00A6oT;nA_i2oPI6oP0:Aai6oTKnA_i77TKnAai6oTLNA_h3
Aah014KnAai77T/N0dLN019;7TLNAai77T/NAai;7TLNBai77T/NAai;7TLNBai77T/NAai5Bah00`00
Bai;7P02Bah5Ool00`00Oomoo`0FOol0019oo`04001oogoo000COol00`00Oomoo`0IOol02P0c0140
ePUj1ET9NQWk7O`Ifagl0RYM00dV?3JN<WdbWS9m>[hfWCZn=YdngSZm?]hj_@02?]h0Ed;N?]e2gT;N
@_hngT;n@]i6oT;NA_i2gTKn@_i6oT;nA_i2oTLN@_i77T;nAai6oTLNA_i77TKnAai6oT/NA_i77TKn
Bam6oT/NA_i;7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dLNBai6oT/OAai;7TKnBam77T/NAai;7dLN
Bai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBcm77T/NAai;?`02Bah01TLNBcm;7T/N
Aai;?`9;7P06Aai;?d/NBai77T/o0T/N01i77T/oBai;?TLNBcm;7T/nAai;?d/NBci77T/oBai;?TLN
Bcm;7T/nAai;?d/NBci77P00Bai;?TLNBcl5Ool00`00Oomoo`0FOol001=oo`@0019oo`03001oogoo
01Yoo`09011@`02E2GX9F@Uj8Q`Mo1Wl008ZG@06;UdZGC:M<WdbWS9m0cZn00Dj_CkN?[hngSjn00Dn
gP03@]i2oT;N0092gPI2oP=6oP03@_i6oTKn00A6oP0:Aai6oTKnA_i77TKnAai6oTLNA_h3Aah014Kn
Aai77T/N0dLN00Y;7TLNBai77T/NAai;7TLNBai77P=;7P05Aai;7T/NBai77P13Bah00`00Bai;7P03
Bah4Ool00`00Oomoo`0FOol002Uoo`03001oogoo01Yoo`1c05@0403g3IXAV`EI8Q`Mo28L7O`^GBYM
;UdbOCJN<WdfWSJM>[hfWCZn>[dngSZn?]hj_D;n?]i2gSkM@_i2gT;n@]i2oT;NA_i2gTKn@]i6oT;n
Aai2oTKn@_i77TKnAai2oTLNA_i77TKnAai6oTLNA_i;7TKnAai6oT/OA_i;7TKnBam6oT/NA_i;7dKn
Bai6oT/OA_i;7TKnBam77T/NA_i;7dLNBai6oT/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLN
Bam77T/NAai;?dLNBai77T/oAai;7TLNBcl00T/N00I77T/oBai;7TLNBcl2Bah01TLNBcm;7T/NAai;
?`9;7P0MAai;?d/NBci77T/oBai;?TLNBcm;7T/nAai;?d/NBci77T/oBai;?TLNBcm;7P00Aai;?d/N
Bci77P04Ool00`00Oomoo`0FOol002Uoo`03001oogoo01]oo`030145603G008AVP043IXR728L8Q`2
;Ud00bYM;UdbW@02=Yd00cJN>[dj_P02>[h03Cjn?]hn_SkN?[i2gSkN@]hngT;n@]i2oT;N0092oP06
A_i2oT;n@_i6oT;n2TKn00Y77TKnA_i6oTLNA_i77TKnAai6oPI77P0>Bai77T/NAai;7TLNBai77T/N
Aai;7TLNBai77P=;7P05Aai;7T/NBai77P12Bah00`00Bai;7P02Bah5Ool00`00Oomoo`0EOol002Qo
o`03001oogoo01aoo`1d03<04@DH0?L=VQ6K3IXV?Agl8Q`^GC9m;UdfWS9m=YhbOCZn>Ydj_SZm>[hn
_CkN?[hngSkM@_hngT;n?]e2oT;N@_i2gT;n@]i6oT;NA_i2oTKn@_i77T;nAai2oTLNA_i77TKnBai6
oTLNA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7dKnBai6oT/OA_i;7TKnBam77T/NA_i;7dLNBai6
oT/OAai;7TKnBam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/NAai;?dLNBai77T/oAai;7TLNBcm7
7T/NAai;?`9;7P06Aai;?d/NBai77T/o0T/N00I77T/oBai;7TLNBcl2Bah06dLNBcm;7T/nAai;?d/N
Bci77T/oBai;?TLNBcm;7T/nAai;?d/NBci77T/o001;?TLNBcm;7P05Ool00`00Oomoo`0EOol002Qo
o`03001oogoo01aoo`070;H040Dh1API^aFk4IX00bHL00X^OBiM;Ud^GCJN=YdfWSJM>[hj_@<j_P03
?[hngSkN008ngP=2gP05?]i2oT;n@_i2gP02@_h00dKn@_i6oP0;A_h024LNA_i77TKnAai6oTLNA_h2
Aah01D/NA_i77TLNBah00dLN00I;7TLNBai77T/NAah3Bah01DLNBai;7T/NAah00d/N00=77T/NBah0
@T/N00<004/NBah00T/N1Goo00<007ooOol05Goo000XOol00`00Oomoo`0MOol0K@1D1AP5>0DH6M/E
^QWK8Q`V?BHL<Wd^GC9m=YdfWSJM=YhfWCjn>[dngSZm@]hn_D;N?[i2oSkM@_hngT;n@]i6oT;N@_i2
gTKn@_i6oT;NA_i2oTKn@_i77T;nAai2oTLNA_i77TKnBai6oTLNA_i;7TKnBai6oT/NA_i;7TKnBai6
oT/NA_i;7dKnBai6oT/OAai;7TKnBam77T/NA_i;7dLNBai6oT/OAai;7TLNBam77T/NAai;7dLNBai7
7T/OAai;7TLNBam77T/NAai;?dLNBai77T/o009;7P06Aai;?d/NBai77T/o0T/N00I77T/oBai;7TLN
Bcl2Bah08TLNBcm;7T/NAai;?d/NBci77T/oBai;?TLNBcm;7T/nAai;?d/NBci77T/oBai;?TLNBcm;
7T/n001;?d/NBci77T/o17oo00<007ooOol05Goo000XOol00`00Oomoo`0MOol02P2e03<560Dh7M/I
^aFk:SdZ?2HL139m00HfWCJN=YdfWSJM?[h3>[h4?]h6@]h3@_h01D;NA_i6oTKn@_h01TKn00Y77TKn
A_i6oTLNA_i77TKnAai6oP=77P05A_i77TLNBai6oP02Aah02T/NAai;7TLNBai77T/NAai;7TLN0d/N
00E77T/NBai;7TLN04I;7P03001;7T/N00=;7PEoo`03001oogoo01Aoo`00:7oo00<007ooOol07Goo
02/0]P2e4GX560Dh7M/Qo1Fj:SdV?2YM;WdbOBiM<WhfWCZn=Ydj_SZm?]hj_CkN?[i2gSjm@]hn_T;n
?]e2oSkNA_i2gTKn@]i6oT;NA_i2oTKn@]i77P02A_h0@T;nAai6oTLNA_i77TKnAai6oT/NA_i77TKn
Bai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7dLNBai6oT/OAai;7TKnBam77T/NAai;7dLN
Bai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBcm77T/NAai;?`9;7P06Aai;?d/NBai7
7T/o0T/N00I77T/oBai;7TLNBcl2Bah084LNBcm;7T/nAai;?d/NBci77T/oBai;?TLNBcm;7T/nAai;
?d/NBci77T/oBai;?TLNBcl004/nBai;?d/NBch5Ool00`00Oomoo`0DOol002Qoo`03001oogoo01eo
o`0>3CL0]P0c4GT561gk7M/MnbXl:SdZ?2Xm<WdfO@8bO@04=Ydj_SJM>Yh2?[h023Zn?[hngT;N?]i2
gSkN@_h3@]h00d;n@]i2oP03@_h:A_h02TLNA_i6oTKnAai6oTLNA_i77TKn0TLN00E;7TKnAai77T/N
00=77P0:Bai77T/NAai;7TLNBai77T/NAah3Bah01DLNBai;7T/NAah0A4/N00<004/NBah00d/N1Goo
00<007ooOol057oo000XOol00`00Oomoo`0NOol06`dG0;H=FA5j7M/Qo1gK8O`^?2Xm9S`fWS9m=Ydb
OCZn>Ydj_SZM?]hj_CkN>[e2gSkM@]hn_@02@]h0Bd;n@]e2oT;NA_i2gDKn@]i6oT;nA_i2oTKn@_i7
7TKnAai2oT/NA_i77TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NAai;
7TKnBam77T/NA_i;7dLNBai6oT/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/NAai;
?`02Bah01TLNBcm;7T/NAai;?`9;7P06Aai;?d/NBai77T/o0T/N02M77T/oBai;7TLNBcm;7T/nAai;
?d/NBci77T/oBai;?TLNBcm;7T/nAai;?d/NBci77T/oBai;?TLNBcm;7T/n001;?d/NBci;7T/oBah0
17oo00<007ooOol057oo000XOol00`00Oomoo`0NOol020dh0;HI^PeI4GTV71gk7M/3;Ud04BiL<Wdb
OCIm<Wdj_SZm>[hjWCkN?[hngSjn@]hngT;N?]h00T;N00E2oT;N@]i2oTKn00=2oP03A_i2oTKn00U6
oP0:Aai6oTKnA_i77TKnAai6oT/NA_h2Aah02T/NAai;7TLNBai77T/NAai;7TLN0d/N00E77T/NBai;
7TLN04I;7PD000I;7PAoo`03001oogoo01Aoo`00:7oo00<007ooOol07goo01`A>02e7KXIVRHL9O/V
727k;Ud^?2iM:S`jWSIm=YhjWCZn>Ydj_Sjm?]hn_CkN?[e2gSkM@]hng@92gP0<@_i2gDKn@]i6oT;M
A_i2gTKn@_i77T;n0TKn03e77TKnAai6oT/NA_i77TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6
oT/NA_i;7TKnBai6oT/OAai;7TKnBam77T/NA_i;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai7
7T/OAai;7TLNBcm77T/NAai;?`02Bah01TLNBcm;7T/NAai;?`9;7P06Aai;?d/NBai77T/o0T/N0117
7T/oBai;7TLNBcm;7T/nAai;?d/NBci77T/oBai;?PX0000;Bai;?T/NBcl004/nBai;?d/NBci;7P05
Ool00`00Oomoo`0COol002Qoo`03001oogoo01moo`053AL=>1VJ6KXIVP039Q`3<Ud00c9m=WdfW@02
=Yd00cZm>[hj_@02?[h013kN?[hngSkN0d;N00DngT;n@]i2oT;N0092oP04A_i2oTKn@_h<A_h01TLN
A_i77TKnAai6oP977P0>Bai6oTLNAai;7TLNBai77T/NAai;7TLNBai77P=;7P05Aai;7T/NBai77P0a
Bah9000?Bah00`00Bai;7P04Bah4Ool00`00Oomoo`0COol002Qoo`03001oogoo01moo`0V8IT=5a4h
6IXM^QVJ;S`UnbHL;U`bOC9L<WdfWCZN=YdjWSZM?[hj_Cjn?[e2gSjm@]hngD;n@]e2gSkMA_i2gTKn
@]e6oT;nA_i2g@=6oP0j@_i77TKnAai6oT/NA_i77TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6
oT/NA_i;7TKnBai6oT/NAai;7TKnBam77T/NA_i;7dLNBai6oT/OAai;7TLNBam77T/NAai;7dLNBai7
7T/OAai;7TLNBal2Bah01TLNBcm;7T/NAai;?`9;7P06Aai;?d/NBai77T/o0T/N00=77T/oBah02P00
01m;?d/NBci77T/oBai;?TLNBcm;7T/nAai;?d/NBci;7T/oBai;?T/NBcm;7T/nBah004/NBci;7T/o
Bai;?P04Ool00`00Oomoo`0COol002Moo`03001oogoo021oo`8QV@083ALUfbGK6KXZ72hl:S`bO@<b
G@@jW@06?[hn_Cjn?[dngSjn0ckN1D;N0T;n00=6oT;NA_h00TKn00=2oTKnA_h024Kn00I77TKnAai6
oTLNA_h2Aah01T/NA_i77TLNBai6oP977P06Bai77T/NAai;7TLN0d/N00E77T/NBai;7TLN021;7PT0
029;7P03001;7T/N00A;7PAoo`03001oogoo01=oo`009goo00<007ooOol08Goo00/MNB6I3ALUnb7J
9O/Z72hl:Q`fOC9l008fO@0K>YhfWCZN=Ydn_SZm?]hn_D;N?[e2gSkM@]i2gDKn@]e2oT;MA_i2gTKn
@]e6oT;nA_i2gDLN0096oP0k@_i77TKnAai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKn
Bai6oT/NA_i;7TKnBai6oT/NAai;7TKnBam77T/NA_i;7dLNBai6oT/OAai;7TLNBam77T/NAai;7dLN
Bai77T/OAai;7TLNBcm;7P0900001TLNBcm;7T/NAai;?`9;7P0ZAai;?d/NBai77T/oBai;?TLNBcm;
7T/nAai;?d/NBci77T/oBai;?TLNBcm;7T/nBai;?d/NBci;7T/oBai;?T/NBcm;7P00Bai;?d/NBci;
7T/o1Goo00<007ooOol04Woo000WOol00`00Oomoo`0QOol38IT01RGJ9M/Ufc9L<S`^?0@fO@0;>Ydj
_CZM>Ydn_Cjn?[dn_Sjm@]hngP08@]h00dKn@_i6oP0;A_h02TLNA_i6oTKnAai6oTLNA_i77TKn0TLN
00Y;7TLNBai77T/NAai;7TLNBai77P=;7P03Aai;7T/N015;7PX003E;7P03001;7T/N00A;7PAoo`03
001oogoo019oo`009goo00<007ooOol08Goo00XMN26I7GT^6bgk9O/QfS9L;S`bG@8fO@0K<W`fOCZM
?[hjWCjn?[e2gSjm@]i2gD;N?]e2gT;M@_i2gDKn@]e6oT;MA_i2gTKn@_e6oT;n0096oP0YAai6oTKn
A_i;7TKnAai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TLNBai6oT/N
Aai;7TKnBai77T/NAai;7`0900001d/NAai;7dLNBai77T/o009;7P06Aai;?d/NBai77T/o0T/N00I7
7T/oBai;7TLNBcl2Bah01TLNBcm;7T/NAai;?`9;7P0UAai;?d/NBci77T/oBai;?TLNBcm;7T/nAai;
?d/NBci;7T/oBai;?T/NBcm;7T/nBai;?d/NBci;7T/o001;?T/NBcm;7T/nBah017oo00<007ooOol0
4Woo000WOol00`00Oomoo`0ROol00bgI8ITQV@03;Q/2<U`01C8l<U`jOCZM>Wd00SZM00Lj_CZM>Ydn
_CkN?[dn_P02@]h014;M@]i2gTKn0d;N00=6oT;nA_h03DKn00Y77TKnA_i6oT/NA_i77TKnBai6oP97
7P06Bai77T/NAai;7TLN0d/N00=77T/NBah02P00B4/N00<004/NBah014/N17oo00<007ooOol04Woo
000WOol00`00Oomoo`0ROol00c7j;MTanP02;Q/08Bgk<Q`fG3Ym=U`jOCIm>YdfO3jn?Ydn_SZM@]hn
_D;N?[e2gT;M@]hngD;N@]e6oT;MA_i2gDKn@]e6oT;NA_i2o@03A_h05DKmBai6oTLNA_e;7TKnBai6
oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oP09000054LNBai6oT/NAai;7TKnBai77T/NAai;7dLNBai7
7T/OAai;7TLNBal2Bah01TLNBam;7T/NAai;?`9;7P06Aai;?d/NBai77T/o0T/N00I77T/oBai;7TLN
Bcl2Bah01TLNBcm;7T/NAai;?`9;7P0SAai;?d/NBci77T/oBai;?TLNBcm;7T/nBai;?d/NBci;7T/o
Bai;?T/NBcm;7T/nBai;?d/NBch004/oBai;?T/NBcm;7P05Ool00`00Oomoo`0AOol002Moo`03001o
ogoo02=oo`04<MX]fBgJ=S/2;Q/2=U`00cIl=U`nW@02?Yd00cZM?[dn_@02?[d014;N@[e2gSjm0d;N
00M2gD;N@]i6oT;NA_i2gP0>A_h01DLNA_i77TKnAah02P0000E77T/NAai;7TLN00=;7P05Aai;7T/N
Bai77P1?Bah00`00Bai;7P04Bah4Ool00`00Oomoo`0AOol002Moo`03001oogoo02=oo`0O;MTanRgI
>U`f>cYL=S/jOCIL>WdfG3jM>YdnWCZL@]hn_D:n?[e2gSjm@]hn_DKn@]e2gT;MA_i2gDKn@]d00dKn
00Q2gDKnA_i6oTKmAai6oTLN2@0002U;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NAai;
7TKnBai77T/NA_i;7TLNBai6oT/NAai;7TLNBam77T/NAai;7dLNBai77T/O009;7P06Aai;?d/NBai7
7T/o0T/N00I77T/oBai;7TLNBcl2Bah01TLNBcm;7T/NAai;?`9;7P0ZAai;?d/NBci77T/oBai;?TLN
Bcm;7T/nBai;?d/NBci;7T/oBai;?T/NBcm;7T/nBai;?d/NBci;7T/oBai;?T/NBcm;7P00Bai;?d/N
Bci;7T/o1@004goo000WOol00`00Oomoo`0SOol013hJ>QXafRgI0SHk00Hf?3Yl?W`jO3im>Yd3?Yd0
3Cjm@[dn_D:m@]e2gT;M@]i2gDKN@]i6gT;M00=6oP03A]h0000000P0000BAai6oTKnA_i77TKnAai6
oT/NA_i;7TLNBai6oT/NAai;7TKn0d/N00E77T/NBai;7TLN05E;7P03001;7T/N00A;7PAoo`03001o
ogoo015oo`009goo00<007ooOol097oo01Hn>SXJ?SXf>cYL=S/jG3Yl?YdjO3jM?Ya2_CjM@[dn_D;N
?[e2_T:m@]i2_@T00005@]e6oTKnA_i6g@03A_h0;DKmBai6oT/NA_e;7TKnBai6oT/NA_i;7TKnBai6
oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TLNBai6oT/NAai;7TLNBai77T/NAai;7TLNBai7
7P03Bah01TLNBam;7T/NAai;?`9;7P06Aai;?d/NBai77T/o0T/N00I77T/oBai;7TLNBcl2Bah01TLN
Bcm;7T/NAai;?`9;7P0XAai;?d/NBci77T/oBai;?T/NBcm;7T/nBai;?d/NBci;7T/oBai;?T/NBcm;
7T/nBai;?d/NBci;7T/oBai;?T/N001;7T/nBai;?d/NBch4Ool00`00Oomoo`0AOol002Moo`03001o
ogoo02Aoo`04>QXn6SXJ?W`3?U/01Cim>W`nO3Yl@[d02P0000E2gDKN@]e6gT;N0096gPi6oP0>Bai6
oTKnA_i;7TKnBai6oT/NA_i;7TLNBai77P=;7P05Aai;7T/NBai77P1HBah00`00Bai;7P04Bah3Ool0
0`00Oomoo`0AOol002Ioo`03001oogoo02Eoo`03?SXj6Chj00T00016@[dnW4:m?Ye2gT:m@]i2_DKN
@]e6gT;MA_i2gDKn@]e6oTKMA_i6gDKnA_e:oTKmA_i6oD/NA_i;7TKmBai6oT/NA_e;7TKnBai6oT/N
A_i;7TKnBai6oT/NA_i;7TKnBai6oT/NAai;7TKnBai77T/NA_i;7TLNBai6oT/NAai;7TLNBai77T/N
Aah3Bah01TLNBam;7T/NAai;?`9;7P06Aai;?d/NBai77T/o0T/N00I77T/oBai;7TLNBcl2Bah0<dLN
Bcm;7T/NAai;?d/NBci;7T/oBai;?T/NBcm;7T/nBai;?d/NBci;7T/oBai;?T/NBcm;7T/nBai;?d/N
Bci;7T/oBai;?T/NBcm;7T/nBai;?d/NBch004/oBai;?T/NBcm;7P03Ool00`00Oomoo`0AOol002Io
o`03001oogoo01moo`T00003AUXnFcil008nF`04@Ya2WD:L@Y`4@[d02d;MA]e2_DKM@]e6gT;MA]i2
gDKnA]d00TKN3TKn00a;7TKnBai6oT/NAai;7TKnBai77T/NA_h3Bah00dLNBai;7P1LBah01@00Bai;
7T/NBch00T/N0goo00<007ooOol04Goo000VOol00`00Oomoo`0EOol:0007Ool2AUX02TIIBWY2NdJL
@W]6W3jL@YdnO4:M0T:m03U2W4Jm@[e6gT:mA]i2gDKn@]e6oT;MA_i6gDKnA]e6oTKMB_i6oDKnA_e;
7TKmB_i6oD/NA_i;7TKmBai6oT/NA_e;7TKnBai6oD/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NAai;
7TKnBai77T/NA_h00d/N00E77T/NBai;7TLN00=;7P06Aai;7T/NBai77T/O0T/N00I77T/oBai;7TLN
Bcl2Bah01TLNBcm;7T/NAai;?`9;7P06Aai;?d/NBai77T/o0T/N02e77T/oBai;?T/NBcm;7T/nBai;
?d/NBci;7T/oBai;?T/NBcm;7T/nBai;?d/NBci;7T/oBai;?T/NBcm;7T/nBai;?d/NBci;7T/oBah0
04/NBcm;7T/nBah00goo00<007ooOol04Goo000VOol00`00Oomoo`0<Ool9000AOol4AUX2AW/01TJL
AW]6_4JLA[a6W0A2_@04A]e2gDKM@[d2A]d00dKNA]e6g@02A_h00dKMA_i6oP0<A_h01T[nA_i;7TKn
Bai6oP=;7P03A_i;7T/N06=;7P03001;7T/N009;7P03Bci;7Woo009oo`03001oogoo011oo`009Woo
00<007ooOol00Woo2P006goo015:NTIJAUY6FDJL@W]6W49kA[e2W4Jm@Ya6gDJmA]e2_4KN00=6g@0`
A]i6gDKnA]e:oTKMB_i6gD[nA]e:oTKmB_i6oD/NA_e;7TKmBai6oD/NA_i;7TKmBai6oT/NA_e;7TKn
Bai6oD/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NAai;7TKn0d/N00E6oT/NBai;7TLN00=;7P05Aai;
7T/NBai77P03Bah01TLNBcm;7T/NAai;?`9;7P06Aai;?d/NBai77T/o0T/N00=77T/oBah00T/N00E;
?d/NBai;7T/o00=;7P0[Bcm;7T/nBai;?d/NBci;7T/oBai;?T/NBcm;7T/nBai;?d/NBci;7T/oBai;
?T/NBcm;7T/nBai;?d/NBci;7T/oBai;?T/N001;7T/nBai;?d/NBch00goo00<007ooOol047oo000V
Ool5000UOol4AUX3AW/2AY`014JlAYa6_4JL0TJm00=6gDJmA]d01DKM00I6oTKMA]e6oDKnA_d2A_h0
4T[nA_i6oTKnB_i6oT[nA_i;7TKnB_i6oT/NA_i;7T[nBai:oP=;7P03B_i;7T/N061;7P05Bch004/N
Bai;?P03Bah3Ool00`00Oomoo`0@Ool002Moo`03001oogoo02Ioo`0nDYY>NE:JCWU>_4ZKC[a:Vdjl
A[a:gDJlB[a6_4[MA[a:gDKMB_i6gD[mA]e:oTKMB_i6gD[nA_e:oTKMB_i6oD[nA_e;7TKmBai6oD/N
A_e;7TKmBai6oT/NA_e;7TKnBai6oD/NA_i;7TKmBai6oT/NA_i;7TKnBai6oP=;7P05A_i;7T/NBai6
oP03Bah01DLNBai;7T/NAah00d/N00E77T/NBai;7TLN00=;7P06Aai;?d/NBai77T/o0d/N00E;?d/N
Bai;7T/o00=;7P05Bcm;7T/NBai;?`03Bah0;D/oBai;?T/NBcm;7T/nBai;?d/NBci;7T/oBai;?T/N
Bcm;7T/nBai;?d/NBci;7T/oBai;?T/NBcm;7T/nBai;?d/NBci;7T/oBai;?P00Bcm;7T/nBai;?`03
Ool00`00Oomoo`0@Ool002Qoo`03001oogoo02Ioo`04CYY>NTijCWX4BY/5B[`05DKMB]e:gD[MA]e:
gDKMB]e6gD[mA_e:oTKMB_i6oD[nA_e:oTKnB_i6o@03B_h01DKnB_i:oT/NA_h00T[n00A;7T[nBai:
oVQ;7P06001;7T/NBai;?T/N0goo00<007ooOol047oo000YOol00`00Oomoo`0UOol0>diiDYY>NE:J
BY]>_4ZKC[a:VdZlA[a:gDJlB]e6_4[MA[a:oDKMB_i6gD[mA]e:oTKMB_i6oD[nA_e:oTKmBai6oD/N
A_e;7TKmBai6oD/NA_e;7TKmBai6oD/NA_e;7TKnBai6oD/NA_i;7TKnBai:oT/NA_h00d/N00E6oT/N
Bai;7TKn00=;7P05Aai;7T/NBai77P03Bah01DLNBai;7T/NAah00d/N00I77T/nBai;7TLNBcl3Bah0
1D/oBai;7T/NBcl00d/N00E;?d/NBai;7T/o00=;7P0_Bcm;7T/nBai;?d/NBci;7T/oBai;?T/NBcm;
7T/nBai;?d/NBci;7T/oBai;?T/NBcm;7T/nBai;?d/NBci;7T/oBai;?T/NBcm;7T/nBai;?`00Bci;
7T/oBai;?P03Ool00`00Oomoo`0@Ool002Yoo`03001oogoo02Aoo`9FV@0>E[YFVEJIC[]B^djkD[]>
_4kLB[a>g4jlB]e:g09:g@04B_e:gD[MB]d6B_d014[nB_e:oT[m0d[n00A:oD[nB_i;7P=:oP03Bai:
oT/N009;7P03B_i;7T/N06A;7P05Bci;7P00Bai;?P03Bah014/nOomoo`004Woo000[Ool00`00Oomo
o`0SOol0?EJIE[YFVEJjEYUB^djkD[]>^e:kB[a>g4ZlC]a:g4kMB]a>gD[LB_e:gD[mB]e:oTKMB_i:
gD[nA_e:oTKmB_i:oD/NB_e;7T[mBai:oD/NA_e;7T[mBai6oD/NB_i;7TKmBai:oT/NA_e;7T[nBai6
oD/NB_i;7TKn01Q;7P05Bci;7T/NBai;?P03Bah01D/oBai;7T/NBcl00d/N00E;?d/NBai;7T/o00=;
7P0bBcm;7T/nBai;?d/NBci;7T/oBai;?T/NBcm;7T/nBai;?d/NBci;7T/oBai;?T/NBcm;7T/nBai;
?d/NBci;7T/oBai;?T/NBcm;7T/nBai;?d/NBci;7P00Bai;?T/NBcm;7P9oo`03001oogoo011oo`00
;7oo00<007ooOol08goo0eJI019F^UJID[]>^e:kC[]Bg4kLD]a>g5;LC]e>oDkLC]e:oDkmB]d8B_d0
14[nB_e:oT[m0d[n00U:oD/NB_i;7T[nBai:oT/NB_h00d/N00=:oT/NBah0H4/N00I;?T/NBai;7T/n
0002Bah00d/nBai;7P02Ool00`00Oomoo`0@Ool002eoo`03001oogoo029oo`0fE[YFVEJjEYUF^U:j
E]]B^UKKD[YBg4kLD]a>fdkmC]a>oD[LC_e:gDkmB]e>oD[MC_i:gDknB_e:oT[mBai:oD/NB_e?7T[m
Bai:oDlNB_e;7T[mBai:oD/NB_e;7T[nBai:oD/NB_i;7T[m0d/N00E:oD/NBai;7T[n01A;7P05Bci;
7T/NBai;?P03Bah01D/nBai;7T/NBcl00d/N00E;?d/NBai;7T/o00=;7P0gBcm;7T/nBai;?d/NBci;
7T/oBai;?T/NBcm;7T/nBai;?d/NBci;7T/oBai;?T/NBcm;7T/nBai;?d/NBci;7T/oBai;?T/NBcm;
7T/nBai;?d/NBci;7T/oBah004/NBcm;7T/nBai;?goo00004Woo000^Ool00`00Oomoo`0QOol00eZi
G[UJ^@02F[T02UKKD[]FfeJkE]]>g5;LC]aBg4kL0TkM00=>oDkLC_d01Tkm00A:oDkmB_e:oP=:o@0:
Bai:oD[nB_i;7T[nBai:oT/NB_h3Bah00d[nBai;7P1PBah01D/nBai;7T/NBch00d/N00P004/NBai;
7T/nBaioo`004Woo000_Ool00`00Oomoo`0POol055kIF[UN^EZiG]UJ^EKKD[YFfe:jE]]BfeKlD]]F
o5;KD_e>g5;mC]`3C_d07D[LC_e:oDknB_e?7T[mCai:oDlNB_e?7T[mCai:oDlNB_e?7T[mCai:oDlN
B_e;7T[mCai:oT/NB_d00d/N00E:oD/NBai;7T[m00=;7P03B_i;7T/N00i;7P05Bci;7T/NBai;?P03
Bah01D/nBai;7T/NBch00d/N00E;?d/NBai;7T/o00=;7P0iBcm;7T/nBai;?d/NBci;7T/oBai;?T/N
Bcm;7T/nBai;?d/NBci;7T/oBai;?T/NBcm;7T/nBai;?d/NBci;7T/oBai;?T/NBcm;7T/nBai;?d/N
Bci;7T/oBai;?T/NBcl004/nBai;?d/NBcioo`00019oo`00<7oo00<007ooOol087oo0UZi00UN^EZi
F[UJfU[KE]YJfe[JF]/00e;L00IBo4kLC_e>o5;mC]`9C_d02d[mCai:oDkmB_e?7T[mBai:oD/NB_d0
0d/N00=:oT/NBah0H4/N00E;?T/NBai;7T/n00=;7P05Bci;7P00Bai;?P03Bah00goo001oo`0AOol0
035oo`03001oogoo01moo`0fF[UNfEZiG[UN^6;IE]YJfeKJF_]FfUKlE]]Fo5KKE_aBg5;mD_aBoE;L
Dae>oE;mC_a?7T[mCae:oDlNB_e?7T[mCai:oDlNB_e?7T[mCai:oDlNB_e?7T[mCai:oDlNB_e?7T[n
Bai:oDlN0T/N00I:oDlNBai;7T[mCah2Bah00d/MCai;7P02Bah00dlNBai;7P05Bah01D/nBai;7T/N
Bch00d/N00E;?T/NBai;7T/n00=;7P05Bci;7T/NBai;?P03Bah0>d/oBai;?T/NBcm;7T/nBai;?d/N
Bci;7T/oBai;?T/NBcm;7T/nBai;?d/NBci;7T/oBai;?T/NBcm;7T/nBai;?d/NBci;7T/oBai;?T/N
Bcm;7T/nBai;?d/NBci;7T/oBai;?P00Bcm;7T/nBai;?d/N00004Woo000bOol00`00Oomoo`0OOol0
45ZiH]UNfF;IG]QJfe[JF]]JfUkjE_]Fo5KkE_aFne;m0e;l00=BoDkmC_d01Dkm00i?7DkmC_e>oDlN
C_e?7D/MCai:oDlNBai?7T[mHT/N00E;?T/NBai;7T/n00=;7P06Bci;7T/NBai;?P000T/N00E;?T/N
Baioo`00015oo`00<goo00<007ooOol07Woo03]RfEjhH]UN^6;IG[QNne[JG_YJfUkkE]]Fo5KKE_aF
feKlD_aG7E;lE_a>o5<MC_aC7DkmDai>oDlMC_e?7T[mCai:oDlNB_e?7T[mCai:oDlNB_e?7T[mCai:
oDlNB_e?7T[mCai;7DlNB_e?7T/NCai:oDlN009;7P06Bae?7T/NBai;7DlN0d/N00E?7T/NBai;7TlN
00=;7P05Cci;7T/NBai;?P03Bah01DlnBai;7T/NBch00d/N049;?T/NBai;7T/oBai;?T/NBcm;7T/n
Bai;?d/NBci;7T/oBai;?T/NBcm;7T/nBai;?d/NBci;7T/oBai;?T/NBcm;7T/nBai;?d/NBci;7T/o
Bai;?T/NBcm;7T/nBai;?d/NBci;7T/oBai;?T/NBcm;7P00Bai;?d/NBci;7Woo000AOol003Aoo`03
001oogoo01eoo`0;G]URfEkHH]UNfFKHF]YNnU[JG_YJfP03F_/02EKkF_]JneKlD_aFo5;lD_e>o@03
D_d01DkmCae>oE<MC_d00dlM00a>oDlNCae?7TkmCai;7TlNBae?7T/NCah3Bah01DlNBai;7T/NCah0
Dd/N00E;?T/NBai;7T/n00=;7P05Bci;7T/NBai;?P02Bah00`00Bci;7P02Bah00d/nOol0000AOol0
03Eoo`8001ioo`14G[QRfEjhI_URf6KHF]YNnekjH_YNfE[lE_]Jo5KkF_aFo5LLE_aG75KlDaeBo5<M
D_aC7DkmDae>oE<MC_e?7TkmCai:oDlNC_e?7T[mCai:oDlNB_e?7T/MCai:oDlNBae?7T[mCai;7DlN
B_e?7T/NCai;7DlNBai?7T/MCai;7TlNBae?7P=;7P05Cci;7T/NBai??P03Bah01DlnBai;7T/NCch0
0d/N00E??T/NBai;7Tln00=;7P10Cci;7T/nBai;?d/NBci;7T/oBai;?T/NBcm;7T/nBai;?d/NBci;
7T/oBai;?T/NBcm;7T/nBai;?d/NBci;7T/oBai;?T/NBcm;7T/nBai;?d/NBci;7T/oBai;?T/NBcm;
7T/nBai;?d/NBci;7P00Bai;?T/NBcm;7Woo000AOol003Moo`03001oogoo01]oo`03H]URf6KH00=R
f0ENnP03E_]Jne[k009Jn`9Fo00:EaaFo5KlD_eC7E;lDaeBoE<MD_d3Dad5Cad014lNCae?7TlM0dlN
00a;7DlNCai?7T/NCai;7TlNBai?7T/NCai;Bah01D/nBai;7T/NBch00d/N00E;?T/NBai;7T/n00=;
7P09Bci;7T/NBai;?T/N001;7T/n00=;7P03001oogoo00moo`00>7oo00<007ooOol06Woo04YRf6Ki
H]QVf6;HJ_QNnV;jG]URnUkjH_YJnelLF_]O6e[kEaaFo5LLE_aG75;lEaeBo5LMD_aC7DkmDae>oE<N
C_eC7TkmDai>oE<NCae?7TkmCai;7DlNB_e?7T/MCai:oDlNBae?7T/MCai;7TlNBae?7T/NCai;7DlN
Bai?7T/MCai;7TlNBai??T/NCai;7Tln0d/N00E??T/NBai;7Tln00=;7P05Cci;7T/NBai??P03Bah0
@TlnBai;?T/NCci;7T/nBai??d/NBci;7TloBai;?T/NCcm;7T/nBai;?d/NBci;7T/oBai;?T/NBcm;
7T/nBai;?d/NBci;7T/oBai;?T/NBcm;7T/nBai;?d/NBci;7T/oBai;?T/NBcm;7T/nBai;?d/NBch0
04/oBai;?T/NBcl0015oo`00>Goo00<007ooOol06Woo0f;H00=Vn6KHI_P015kj00=RnE[kF_/00e[k
00UFo5LLEaaK75KlEaaC7ELMD_`01e<M00A?7E<MCaeC7@=?7@06Cai?7DlNCae?7TlM0dlN00Q?7DlN
Bai?7T/NCai;7TlN0d/N00=?7T/NBah0@D/N00E;?T/NBai;7T/n00=;7P05Bci;7T/NBai;?P03Bah0
1D/nBai;7T/NBch00goo00<007ooOol00goo00<007ooOol03goo000jOol00`00Oomoo`0IOol0DfKH
H]QVnFKGI_QVef;jG_YRnUkiHaYRnElKF_]O6e[kGa]Fne/LE_aK75KkEaeBo5LMD_aG7E;mDaeBo5<M
D_eC7TkmDai?7E<NC_eC7TlMDai;7DlNCae?7T/MCai;7DlNBae?7T/MCai;7DlNBai?7T/MCai;7TlN
Bae??T/NCai;7DlnBai?7T/NCci;7TlNBai??T/NCai;7TlnBai?7T/NCch00d/N035??T/NBai;7Tln
Bai;?T/NCci;7T/nBai??T/NBci;7TlnBai;?T/NCcm;7T/nBai??d/NBci;7TloBai;?T/NCcm;7T/n
Bai??d/NBci;7T/oBai;?T/NBcm;7T/nBai;?`0@Ool00`00Oomoo`03Ool00`00Oomoo`0?Ool003]o
o`03001oogoo01Uoo`9Vf00?I_QVf6KhH_URnV;iH_YRnF;jG_]O6ekkGa]NnelK00EK7004EaeG75LM
Ea`7Dad014lMDaeC7DlN0dlM00I?7TlMCai?7DlNCad3Cah024lMCai?7TlNBai?7T/NCah3Bah01DlN
Bai;7T/NCah0?4/N6Woo00<007ooOol00Woo00<007ooOol03goo000lOol00`00Oomoo`0HOol0L6KG
I_QVef[hI_MZn5kiHaYRnF;jH_UW6U[kGa]JnV<KG_YK75KkFaaJne/LE_aK7ELLEaeFo5LMDaeG7E;l
Eae?7E<MC_eC7TlMDai?7E<NCae?7TlMDai?7DlNBae?7T/MCai;7DlnBae?7T/MCci;7DlNBae??T/N
Cai;7DlnBai?7T/MCci;7TlNBae??T/NCai;7TlnBai?7T/NCci;7TlNBai??T/NCai;7TlnBai;?T/N
Cci;7T/nBai??T/NBci;7TlnBai;?T/NCcm;7T/nBai??d/NBci;7Tlo9goo00<007ooOol00Woo00<0
07ooOol03goo000mOol00`00Oomoo`0GOol00fKhI]QVn003J_L01f;jH_UVnF;iIaURnFKi009O6`03
GaYO6elK00EK70=G7007EaeG75LMDaeG7E<MEad015<M00=?7E<NCad00TlM00I?7TlMCai?7DlNCad7
Cah024/NCai;7TlNBai?7T/NCah3Bah01DlNBai;7T/NCah074/N=7oo00<007ooOol00Woo00<007oo
Ool03goo000nOol00`00Oomoo`0GOol08F[hI]MZn6KGJ_QVmfLJH_UW6V;iIaYVnF<KG_YS6ekjHa]K
6elLFa]O75/KGaaG75/mEaaK7ELLEaeC75LMDaaG?P03Dad0<ELnCaeC7TlMDci?7E<NCaeC?TlMCai;
7DlnCae?7T/MCci;7DlNBae??T/MCai;7DlnBai?7T/MCci;7TlNBae??T/NCai;7DlnBai?7T/NCci;
7TlnBai??T/NCci;7Tln049oo`05001oogooOol0000AOol003moo`03001oogoo01Ioo`04I]QZmf[g
J_P2J_L016;iIaURnFKi0VLI00IVnElKGa]S6elJHaX2Fa`015/KGaaO6elL0eLL00=K75LMEad00eLM
1e<M00U?7E<MCaeC7TlMCai?7DlNCad02dlN00Q;7TlNCai?7T/NCai;7TlN0d/N00I?7T/NBai;7TlN
Bai:Ool01@00Oomoogoo00004Goo0010Ool00`00Oomoo`0EOol0@F[hI]MZn6KgK_MZmflGH_UW6FKi
IaUVnFLIG_YS6elJHa]NnUllFa]O75/KGcaK6e/lEaaK?ELLFcaC75LmDaaG7E<MEceC7ELmDaeC?TlM
Dai?7E<nCaeC7TlMDci?7DlNCaeC?TlMCai;7DlnCae?7T/MCci;7DlNBae??T/NCah0EWoo00D007oo
Oomoo`00015oo`00@Goo00<007ooOol057oo00=Zmf[hJ_L016[g0fLI00EVnFLIIaU[6ElJ00AS6P03
GaaO6elL00=O6`AK7003EaeG75LM009G7@YC7@04CaeC7TlMDad2Cah00dlMCai?7P03CaiOOol00`00
Oomoo`02Ool00`00Oomoo`0>Ool0049oo`03001oogoo01Aoo`0_I_MZn6[gKaMZmflGJ_IW6FKiIaUV
n6/II_QS6f<JIa]S6V<KHaYO?5lKGcaO6ellFaaK?5/LFcaK75LmEaaG?ELLEceC7ELmDaeG?E<MDciC
7E<nCaeC?TlMDci?7@1XOol01@00Oomoogoo000047oo0013Ool00`00Oomoo`0COol5J_L2K_L01VKi
IaUW6F/IIaQ[60ES6P05IaYS6UlKGa]O>`02Ga/03U/LFcaK75/LEaaG?ELLEaeG75LmDaeG7E<MEce`
Ool01@00Oomoogoo000047oo0014Ool00`00Oomoo`0BOol08f[gKaMZmfkgJ_I_5f[fKaMVn6/II_Q[
6FKhJaUS6V<KHaYW>V<JIcYO6f<lGa]S>elKGcaK75llFa]O?5LLFceG75/mEa`0M7oo00D007ooOomo
o`00011oo`00AGoo00<007ooOol04Woo0f[g00i^mfkfK_M^mV/IIaQW6F/HJaU[66LJHaYW6V<J0VLJ
00]O>elKGa]O6f<kGa]K?5/LFcaK75/l07Qoo`05001oogooOol0000@Ool004Ioo`03001oogoo015o
o`0<K_MZmflGJ_I_5f[fLaM^mV/II_Q[6FLH0V/H00iW>V<JIcYS6FLjIaUS>elKHc]O6f<kFa]O?5/L
Ngoo00@007ooOol0011oo`00Agoo00<007ooOol04Goo00EZmfkfK_M^mflG009^mP03JaQ[6F/H00=[
6004HaYW6VLJIcX2IaX01V<KHc]O6f<kHa]S>geoo`04001oogoo000@Ool004Qoo`03001oogoo011o
o`0<J_I_5f[fKaM^mVlGK_I[6FLHJaU[66lI0V/H00US6FLjIaUW>VLIJcYO6f<kGa/0Ogoo00@007oo
Ool0011oo`00BGoo00<007ooOol03goo0fkg0fkf00=c5VkfJaP01F/H00I_66LJIcYW6FLjIaV3Ool0
0`00Ool0000@Ool004Yoo`03001oogoo00moo`09KaM^mVlGK_Ic5VkfLaI[66lI009[6007JaM_>6/H
IcYW6F/jIaT0Q7oo00<007oo000047oo001;Ool00`00Oomoo`0>Ool3K_H016lGK_I_5Vkf16/H00E_
66/HKaQ_66Lj08Ioo`03001oo`00011oo`00C7oo00<007ooOol03Goo00m_5fkfLaM^mW<FK_Ic5Vke
JaQ[5flhJaQ_66/GKcP0Qgoo00<007oo000047oo001=Ool00`00Oomoo`0<Ool02fkfKaM^mVlFK_Ic
5VkfLaI[66lHJaP00flHRGoo0P0047oo001>Ool00`00Oomoo`0<Ool03FkfLaI^mW<FK_Ec5VkeLaI[
66lHJaM_>6/G08Uoo`80011oo`00Cgoo00<007ooOol02goo0Vkf00=c5VkfLaH00W<F00Ec5FlHJaQ_
66lG08Yoo`03001oo`0000moo`00D7oo00<007ooOol02Woo00a^mW<FK_Ic5VkeLaIbmG<FK_E_>6/G
KcR:Ool00`00Ool0000?Ool0055oo`03001oogoo00Yoo`0:K_I_5W<FLaI^mW<FLaEc5VlGKaR<Ool2
000?Ool0059oo`03001oogoo00Uoo`0:LaI^mW<FK_Ec5VkeLaIbmG<FJaN<Ool2000?Ool005=oo`80
00Yoo`05LaI^mW<FLaEc5P03LaF=Ool2000?Ool005Eoo`03001oogoo00Moo`08K_Ec5VkeLaIbmG<F
L_Eg5Xeoo`8000moo`00EWoo00<007ooOol01Woo0g<F00Ac5G<FLaEc5Hmoo`03001oogoo00eoo`00
Egoo00<007ooOol01Woo00Ic5W;eLaI^mGLFL_F9Ool7000?Ool005Qoo`03001oogoo00Eoo`03LaEc
5W<E009c5Gaoo`h001Ioo`00FGoo00<007ooOol017oo00Ec5VkeLaIbmG<F06moo`d002Aoo`00FWoo
00<007ooOol00goo00=c5G<FLaD00W<EHWoo3@00<Goo001KOol00`00Oomoo`03Ool00g;eLaIbm@1E
Ool>000nOol005aoo`03001oogoo009oo`=c5DQoo`d004aoo`00A7oo0`005Woo00H007ooOomoog;e
MaHlOol=001IOol004Eoo`03001oogoo01Ioo`03001oogoo009c5Bioo`h006Ioo`00AGoo0`005goo
00@007ooOol0025oo`d007Aoo`00AGoo00@007ooOol001Moo`03001oo`0001Aoo`d0085oo`00AGoo
00@007ooOol001Qoo`8000Ioo`h008ioo`00A7oo10006Woo1`00W7oo003oOol6Ool00?moo`Ioo`00
ogoo1Woo003oOol6Ool00?moo`Ioo`00ogoo1Woo003oOol6Ool007aoo`800003Ool00000009oo`@0
00=oo`8000Aoo`8000Aoo`8000=oo`<006Moo`00OGoo00<007oo00002Goo00@007ooOol000Qoo`04
001oogoo0004Ool00`00Oomoo`1UOol007ioo`03001oogoo009oo`@0009oo`04001oogoo0008Ool0
1000Oomoo`000goo0`00IWoo001lOol200000goo00000008Ool01000Oomoo`0027oo00@007ooOol0
009oo`04001oogoo001VOol008Uoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol006Io
o`00RWoo0P002Woo0P0017oo0`00IWoo003oOol6Ool00?moo`Ioo`00ogoo1Woo003oOol6Ool00001
\
\>"],
  ImageRangeCache->{{{0, 260.5}, {184.063, 0}} -> {-0.170612, 0.0461341, \
0.00439245, 0.00439245}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .70824 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1.10169 -0.148196 1.10169 [
[.5 .72074 -17 0 ]
[.5 .72074 17 15 ]
[.44797 -0.02478 -4.90556 -15 ]
[.44797 -0.02478 5.09444 0 ]
[.15892 .66839 -5.31917 0 ]
[.15892 .66839 4.68083 15 ]
[-0.06694 .27471 -10 -6.62571 ]
[-0.06694 .27471 0 8.37429 ]
[ 0 0 0 0 ]
[ 1 .70824 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .72074 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.437500 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(=) show
75.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.1) show
93.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math1Mono
%%DocumentNeededResources: + font Courier
%%DocumentNeededFonts: Math1Mono
%%DocumentNeededFont: + Courier
%%DocumentFonts: font Math1Mono
%%DocumentFonts: + font Courier
grestore
.25 Mabswid
.02946 .11175 m
.89362 0 L
s
gsave
.44797 -0.02478 -65.9056 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(u) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
0 .4272 m
.29069 .70824 L
s
gsave
.15892 .66839 -66.3192 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(p) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.02946 .11175 m
0 .4272 L
s
gsave
-0.06694 .27471 -71 -10.6257 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(q) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.02946 .11175 m
0 .4272 L
s
0 .4272 m
.29069 .70824 L
s
.29069 .70824 m
.30155 .45044 L
s
.30155 .45044 m
.02946 .11175 L
s
.89362 0 m
.98022 .38351 L
s
.98022 .38351 m
1 .65325 L
s
1 .65325 m
.91448 .33294 L
s
.91448 .33294 m
.89362 0 L
s
.02946 .11175 m
0 .4272 L
s
0 .4272 m
.91448 .33294 L
s
.91448 .33294 m
.89362 0 L
s
.89362 0 m
.02946 .11175 L
s
.30155 .45044 m
.98022 .38351 L
s
.98022 .38351 m
1 .65325 L
s
1 .65325 m
.29069 .70824 L
s
.29069 .70824 m
.30155 .45044 L
s
0 0 m
1 0 L
1 .70824 L
0 .70824 L
closepath
clip
newpath
.915 .777 .694 r
.28457 .68991 .29069 .70824 .31281 .64569 .30668 .63159 Mtetra
.873 .791 .766 r
.30668 .63159 .31281 .64569 .3335 .61405 .32742 .60212 Mtetra
.825 .799 .828 r
.32742 .60212 .3335 .61405 .35363 .59578 .34762 .5851 Mtetra
.777 .801 .873 r
.34762 .5851 .35363 .59578 .37351 .58414 .3676 .57426 Mtetra
.736 .8 .903 r
.3676 .57426 .37351 .58414 .3933 .57614 .3875 .56678 Mtetra
.703 .798 .924 r
.3875 .56678 .3933 .57614 .41307 .57026 .40737 .56127 Mtetra
.678 .795 .937 r
.40737 .56127 .41307 .57026 .43284 .5657 .42726 .55698 Mtetra
.659 .793 .946 r
.42726 .55698 .43284 .5657 .45265 .56199 .44718 .55346 Mtetra
.645 .792 .953 r
.44718 .55346 .45265 .56199 .47249 .55885 .46715 .55047 Mtetra
.635 .791 .957 r
.46715 .55047 .47249 .55885 .49239 .5561 .48717 .54783 Mtetra
.627 .791 .961 r
.48717 .54783 .49239 .5561 .51235 .55362 .50725 .54543 Mtetra
.621 .79 .963 r
.50725 .54543 .51235 .55362 .53236 .55133 .52739 .54321 Mtetra
.616 .79 .965 r
.52739 .54321 .53236 .55133 .55244 .54918 .54759 .54111 Mtetra
.612 .79 .967 r
.54759 .54111 .55244 .54918 .57258 .54714 .56786 .53911 Mtetra
.61 .79 .968 r
.56786 .53911 .57258 .54714 .59278 .54517 .58819 .53716 Mtetra
.607 .79 .969 r
.58819 .53716 .59278 .54517 .61305 .54325 .60859 .53527 Mtetra
.605 .791 .97 r
.60859 .53527 .61305 .54325 .63338 .54137 .62905 .53341 Mtetra
.604 .791 .971 r
.62905 .53341 .63338 .54137 .65378 .53953 .64958 .53157 Mtetra
.603 .791 .971 r
.64958 .53157 .65378 .53953 .67425 .5377 .67018 .52975 Mtetra
.602 .791 .972 r
.67018 .52975 .67425 .5377 .69478 .53589 .69085 .52794 Mtetra
.601 .792 .972 r
.69085 .52794 .69478 .53589 .71538 .53409 .71159 .52614 Mtetra
.6 .792 .972 r
.71159 .52614 .71538 .53409 .73605 .5323 .73239 .52434 Mtetra
.6 .792 .973 r
.73239 .52434 .73605 .5323 .75679 .53051 .75327 .52254 Mtetra
.599 .792 .973 r
.75327 .52254 .75679 .53051 .7776 .52872 .77421 .52074 Mtetra
.599 .793 .973 r
.77421 .52074 .7776 .52872 .79848 .52693 .79523 .51894 Mtetra
.598 .793 .974 r
.79523 .51894 .79848 .52693 .81942 .52514 .81631 .51714 Mtetra
.81631 .51714 .81942 .52514 .84044 .52334 .83747 .51533 Mtetra
.83747 .51533 .84044 .52334 .86153 .52154 .8587 .51351 Mtetra
.8587 .51351 .86153 .52154 .88268 .51974 .88 .51169 Mtetra
.597 .793 .974 r
.88 .51169 .88268 .51974 .90391 .51793 .90137 .50987 Mtetra
.597 .794 .974 r
.90137 .50987 .90391 .51793 .92521 .51611 .92282 .50803 Mtetra
.92282 .50803 .92521 .51611 .94658 .51429 .94433 .50619 Mtetra
.597 .794 .975 r
.94433 .50619 .94658 .51429 .96803 .51246 .96592 .50434 Mtetra
.96592 .50434 .96803 .51246 .98954 .51063 .98758 .50249 Mtetra
.908 .775 .702 r
.2784 .67141 .28457 .68991 .30668 .63159 .30047 .61734 Mtetra
.865 .789 .774 r
.30047 .61734 .30668 .63159 .32742 .60212 .32126 .59005 Mtetra
.815 .796 .834 r
.32126 .59005 .32742 .60212 .34762 .5851 .34154 .57429 Mtetra
.767 .798 .878 r
.34154 .57429 .34762 .5851 .3676 .57426 .36162 .56425 Mtetra
.727 .797 .907 r
.36162 .56425 .3676 .57426 .3875 .56678 .38162 .5573 Mtetra
.696 .795 .926 r
.38162 .5573 .3875 .56678 .40737 .56127 .40161 .55217 Mtetra
.672 .793 .939 r
.40161 .55217 .40737 .56127 .42726 .55698 .42161 .54814 Mtetra
.654 .791 .947 r
.42161 .54814 .42726 .55698 .44718 .55346 .44165 .54482 Mtetra
.641 .79 .953 r
.44165 .54482 .44718 .55346 .46715 .55047 .46174 .54198 Mtetra
.631 .789 .958 r
.46174 .54198 .46715 .55047 .48717 .54783 .48188 .53945 Mtetra
.624 .789 .961 r
.48188 .53945 .48717 .54783 .50725 .54543 .50209 .53714 Mtetra
.618 .789 .964 r
.50209 .53714 .50725 .54543 .52739 .54321 .52235 .53498 Mtetra
.614 .789 .965 r
.52235 .53498 .52739 .54321 .54759 .54111 .54268 .53293 Mtetra
.611 .789 .967 r
.54268 .53293 .54759 .54111 .56786 .53911 .56308 .53096 Mtetra
.608 .79 .968 r
.56308 .53096 .56786 .53911 .58819 .53716 .58354 .52905 Mtetra
.606 .79 .969 r
.58354 .52905 .58819 .53716 .60859 .53527 .60407 .52718 Mtetra
.604 .79 .97 r
.60407 .52718 .60859 .53527 .62905 .53341 .62466 .52533 Mtetra
.603 .79 .971 r
.62466 .52533 .62905 .53341 .64958 .53157 .64533 .5235 Mtetra
.602 .791 .971 r
.64533 .5235 .64958 .53157 .67018 .52975 .66606 .52168 Mtetra
.601 .791 .972 r
.66606 .52168 .67018 .52975 .69085 .52794 .68686 .51988 Mtetra
.6 .791 .972 r
.68686 .51988 .69085 .52794 .71159 .52614 .70774 .51807 Mtetra
.6 .792 .972 r
.70774 .51807 .71159 .52614 .73239 .52434 .72868 .51627 Mtetra
.599 .792 .973 r
.72868 .51627 .73239 .52434 .75327 .52254 .74969 .51446 Mtetra
.74969 .51446 .75327 .52254 .77421 .52074 .77078 .51265 Mtetra
.598 .792 .973 r
.77078 .51265 .77421 .52074 .79523 .51894 .79194 .51084 Mtetra
.598 .793 .974 r
.79194 .51084 .79523 .51894 .81631 .51714 .81316 .50903 Mtetra
.81316 .50903 .81631 .51714 .83747 .51533 .83446 .5072 Mtetra
.83446 .5072 .83747 .51533 .8587 .51351 .85583 .50537 Mtetra
.597 .793 .974 r
.85583 .50537 .8587 .51351 .88 .51169 .87728 .50354 Mtetra
.87728 .50354 .88 .51169 .90137 .50987 .8988 .50169 Mtetra
.8988 .50169 .90137 .50987 .92282 .50803 .92039 .49984 Mtetra
.597 .794 .974 r
.92039 .49984 .92282 .50803 .94433 .50619 .94205 .49798 Mtetra
.597 .794 .975 r
.94205 .49798 .94433 .50619 .96592 .50434 .96379 .49611 Mtetra
.96379 .49611 .96592 .50434 .98758 .50249 .9856 .49424 Mtetra
.901 .773 .71 r
.27216 .65272 .2784 .67141 .30047 .61734 .2942 .60292 Mtetra
.855 .786 .782 r
.2942 .60292 .30047 .61734 .32126 .59005 .31503 .57783 Mtetra
.804 .792 .841 r
.31503 .57783 .32126 .59005 .34154 .57429 .33539 .56335 Mtetra
.757 .794 .883 r
.33539 .56335 .34154 .57429 .36162 .56425 .35556 .55411 Mtetra
.718 .793 .911 r
.35556 .55411 .36162 .56425 .38162 .5573 .37567 .54771 Mtetra
.688 .791 .929 r
.37567 .54771 .38162 .5573 .40161 .55217 .39576 .54294 Mtetra
.666 .79 .941 r
.39576 .54294 .40161 .55217 .42161 .54814 .41588 .53919 Mtetra
.649 .789 .949 r
.41588 .53919 .42161 .54814 .44165 .54482 .43604 .53607 Mtetra
.637 .788 .954 r
.43604 .53607 .44165 .54482 .46174 .54198 .45625 .53337 Mtetra
.628 .788 .959 r
.45625 .53337 .46174 .54198 .48188 .53945 .47652 .53096 Mtetra
.621 .788 .962 r
.47652 .53096 .48188 .53945 .50209 .53714 .49685 .52873 Mtetra
.616 .788 .964 r
.49685 .52873 .50209 .53714 .52235 .53498 .51724 .52664 Mtetra
.612 .788 .966 r
.51724 .52664 .52235 .53498 .54268 .53293 .5377 .52464 Mtetra
.609 .789 .967 r
.5377 .52464 .54268 .53293 .56308 .53096 .55823 .52271 Mtetra
.607 .789 .968 r
.55823 .52271 .56308 .53096 .58354 .52905 .57882 .52083 Mtetra
.605 .789 .969 r
.57882 .52083 .58354 .52905 .60407 .52718 .59948 .51897 Mtetra
.603 .79 .97 r
.59948 .51897 .60407 .52718 .62466 .52533 .62021 .51714 Mtetra
.602 .79 .971 r
.62021 .51714 .62466 .52533 .64533 .5235 .64101 .51532 Mtetra
.601 .79 .971 r
.64101 .51532 .64533 .5235 .66606 .52168 .66188 .51351 Mtetra
.6 .791 .972 r
.66188 .51351 .66606 .52168 .68686 .51988 .68282 .5117 Mtetra
.68282 .5117 .68686 .51988 .70774 .51807 .70384 .50989 Mtetra
.599 .791 .973 r
.70384 .50989 .70774 .51807 .72868 .51627 .72492 .50808 Mtetra
.599 .792 .973 r
.72492 .50808 .72868 .51627 .74969 .51446 .74607 .50627 Mtetra
.598 .792 .973 r
.74607 .50627 .74969 .51446 .77078 .51265 .7673 .50446 Mtetra
.7673 .50446 .77078 .51265 .79194 .51084 .7886 .50263 Mtetra
.598 .792 .974 r
.7886 .50263 .79194 .51084 .81316 .50903 .80997 .5008 Mtetra
.598 .793 .974 r
.80997 .5008 .81316 .50903 .83446 .5072 .83141 .49896 Mtetra
.597 .793 .974 r
.83141 .49896 .83446 .5072 .85583 .50537 .85293 .49712 Mtetra
.85293 .49712 .85583 .50537 .87728 .50354 .87452 .49527 Mtetra
.87452 .49527 .87728 .50354 .8988 .50169 .89618 .4934 Mtetra
.89618 .4934 .8988 .50169 .92039 .49984 .91792 .49153 Mtetra
.597 .794 .974 r
.91792 .49153 .92039 .49984 .94205 .49798 .93974 .48965 Mtetra
.597 .794 .975 r
.93974 .48965 .94205 .49798 .96379 .49611 .96163 .48777 Mtetra
.96163 .48777 .96379 .49611 .9856 .49424 .98359 .48587 Mtetra
.893 .77 .719 r
.26586 .63385 .27216 .65272 .2942 .60292 .28786 .58835 Mtetra
.845 .782 .791 r
.28786 .58835 .2942 .60292 .31503 .57783 .30872 .56546 Mtetra
.793 .788 .848 r
.30872 .56546 .31503 .57783 .33539 .56335 .32916 .55228 Mtetra
.746 .79 .888 r
.32916 .55228 .33539 .56335 .35556 .55411 .34942 .54385 Mtetra
.709 .789 .914 r
.34942 .54385 .35556 .55411 .37567 .54771 .36963 .53798 Mtetra
.68 .788 .931 r
.36963 .53798 .37567 .54771 .39576 .54294 .38984 .5336 Mtetra
.659 .787 .942 r
.38984 .5336 .39576 .54294 .41588 .53919 .41008 .53012 Mtetra
.644 .786 .95 r
.41008 .53012 .41588 .53919 .43604 .53607 .43036 .5272 Mtetra
.633 .786 .955 r
.43036 .5272 .43604 .53607 .45625 .53337 .4507 .52465 Mtetra
.625 .786 .959 r
.4507 .52465 .45625 .53337 .47652 .53096 .47109 .52235 Mtetra
.618 .786 .962 r
.47109 .52235 .47652 .53096 .49685 .52873 .49155 .52021 Mtetra
.614 .787 .964 r
.49155 .52021 .49685 .52873 .51724 .52664 .51207 .51819 Mtetra
.61 .787 .966 r
.51207 .51819 .51724 .52664 .5377 .52464 .53266 .51624 Mtetra
.608 .788 .967 r
.53266 .51624 .5377 .52464 .55823 .52271 .55331 .51435 Mtetra
.605 .788 .969 r
.55331 .51435 .55823 .52271 .57882 .52083 .57404 .51249 Mtetra
.604 .789 .969 r
.57404 .51249 .57882 .52083 .59948 .51897 .59484 .51066 Mtetra
.602 .789 .97 r
.59484 .51066 .59948 .51897 .62021 .51714 .6157 .50884 Mtetra
.601 .789 .971 r
.6157 .50884 .62021 .51714 .64101 .51532 .63664 .50703 Mtetra
.6 .79 .971 r
.63664 .50703 .64101 .51532 .66188 .51351 .65765 .50522 Mtetra
.6 .79 .972 r
.65765 .50522 .66188 .51351 .68282 .5117 .67873 .50341 Mtetra
.599 .791 .972 r
.67873 .50341 .68282 .5117 .70384 .50989 .69988 .5016 Mtetra
.599 .791 .973 r
.69988 .5016 .70384 .50989 .72492 .50808 .7211 .49979 Mtetra
.598 .791 .973 r
.7211 .49979 .72492 .50808 .74607 .50627 .7424 .49797 Mtetra
.598 .792 .973 r
.7424 .49797 .74607 .50627 .7673 .50446 .76377 .49614 Mtetra
.76377 .49614 .7673 .50446 .7886 .50263 .78521 .49431 Mtetra
.597 .792 .974 r
.78521 .49431 .7886 .50263 .80997 .5008 .80673 .49246 Mtetra
.80673 .49246 .80997 .5008 .83141 .49896 .82832 .49061 Mtetra
.597 .793 .974 r
.82832 .49061 .83141 .49896 .85293 .49712 .84998 .48875 Mtetra
.84998 .48875 .85293 .49712 .87452 .49527 .87172 .48688 Mtetra
.87172 .48688 .87452 .49527 .89618 .4934 .89354 .485 Mtetra
.89354 .485 .89618 .4934 .91792 .49153 .91543 .48311 Mtetra
.597 .793 .975 r
.91543 .48311 .91792 .49153 .93974 .48965 .93739 .48121 Mtetra
.597 .794 .975 r
.93739 .48121 .93974 .48965 .96163 .48777 .95943 .4793 Mtetra
.596 .794 .975 r
.95943 .4793 .96163 .48777 .98359 .48587 .98155 .47738 Mtetra
.883 .766 .728 r
.2595 .61479 .26586 .63385 .28786 .58835 .28144 .57361 Mtetra
.833 .778 .8 r
.28144 .57361 .28786 .58835 .30872 .56546 .30234 .55295 Mtetra
.78 .784 .855 r
.30234 .55295 .30872 .56546 .32916 .55228 .32285 .54106 Mtetra
.735 .785 .893 r
.32285 .54106 .32916 .55228 .34942 .54385 .34321 .53345 Mtetra
.699 .785 .917 r
.34321 .53345 .34942 .54385 .36963 .53798 .36352 .52813 Mtetra
.672 .784 .933 r
.36352 .52813 .36963 .53798 .38984 .5336 .38384 .52413 Mtetra
.653 .784 .944 r
.38384 .52413 .38984 .5336 .41008 .53012 .4042 .52092 Mtetra
.639 .784 .951 r
.4042 .52092 .41008 .53012 .43036 .5272 .4246 .51821 Mtetra
.629 .784 .956 r
.4246 .51821 .43036 .5272 .4507 .52465 .44506 .51581 Mtetra
.621 .784 .96 r
.44506 .51581 .4507 .52465 .47109 .52235 .46558 .51362 Mtetra
.616 .785 .963 r
.46558 .51362 .47109 .52235 .49155 .52021 .48617 .51158 Mtetra
.611 .786 .965 r
.48617 .51158 .49155 .52021 .51207 .51819 .50682 .50962 Mtetra
.608 .786 .966 r
.50682 .50962 .51207 .51819 .53266 .51624 .52754 .50772 Mtetra
.606 .787 .968 r
.52754 .50772 .53266 .51624 .55331 .51435 .54833 .50587 Mtetra
.604 .787 .969 r
.54833 .50587 .55331 .51435 .57404 .51249 .56919 .50404 Mtetra
.603 .788 .97 r
.56919 .50404 .57404 .51249 .59484 .51066 .59013 .50223 Mtetra
.601 .788 .97 r
.59013 .50223 .59484 .51066 .6157 .50884 .61113 .50042 Mtetra
.6 .789 .971 r
.61113 .50042 .6157 .50884 .63664 .50703 .63221 .49862 Mtetra
.63221 .49862 .63664 .50703 .65765 .50522 .65335 .49682 Mtetra
.599 .79 .972 r
.65335 .49682 .65765 .50522 .67873 .50341 .67457 .49501 Mtetra
.67457 .49501 .67873 .50341 .69988 .5016 .69587 .4932 Mtetra
.598 .791 .973 r
.69587 .4932 .69988 .5016 .7211 .49979 .71723 .49137 Mtetra
.71723 .49137 .7211 .49979 .7424 .49797 .73867 .48955 Mtetra
.73867 .48955 .7424 .49797 .76377 .49614 .76019 .48771 Mtetra
.597 .792 .973 r
.76019 .48771 .76377 .49614 .78521 .49431 .78178 .48586 Mtetra
.597 .792 .974 r
.78178 .48586 .78521 .49431 .80673 .49246 .80344 .484 Mtetra
.80344 .484 .80673 .49246 .82832 .49061 .82518 .48214 Mtetra
.82518 .48214 .82832 .49061 .84998 .48875 .84699 .48026 Mtetra
.597 .793 .974 r
.84699 .48026 .84998 .48875 .87172 .48688 .86888 .47837 Mtetra
.86888 .47837 .87172 .48688 .89354 .485 .89085 .47647 Mtetra
.89085 .47647 .89354 .485 .91543 .48311 .91289 .47456 Mtetra
.596 .793 .975 r
.91289 .47456 .91543 .48311 .93739 .48121 .93501 .47264 Mtetra
.93501 .47264 .93739 .48121 .95943 .4793 .95721 .47071 Mtetra
.596 .794 .975 r
.95721 .47071 .95943 .4793 .98155 .47738 .97948 .46877 Mtetra
.872 .762 .738 r
.25307 .59555 .2595 .61479 .28144 .57361 .27495 .5587 Mtetra
.819 .773 .809 r
.27495 .5587 .28144 .57361 .30234 .55295 .29588 .54028 Mtetra
.767 .778 .862 r
.29588 .54028 .30234 .55295 .32285 .54106 .31646 .5297 Mtetra
.723 .78 .898 r
.31646 .5297 .32285 .54106 .34321 .53345 .33691 .52292 Mtetra
.689 .78 .921 r
.33691 .52292 .34321 .53345 .36352 .52813 .35733 .51815 Mtetra
.664 .78 .935 r
.35733 .51815 .36352 .52813 .38384 .52413 .37777 .51454 Mtetra
.646 .781 .945 r
.37777 .51454 .38384 .52413 .4042 .52092 .39824 .51161 Mtetra
.634 .781 .952 r
.39824 .51161 .4042 .52092 .4246 .51821 .41877 .5091 Mtetra
.624 .782 .957 r
.41877 .5091 .4246 .51821 .44506 .51581 .43935 .50685 Mtetra
.618 .783 .96 r
.43935 .50685 .44506 .51581 .46558 .51362 .46 .50478 Mtetra
.613 .783 .963 r
.46 .50478 .46558 .51362 .48617 .51158 .48072 .50282 Mtetra
.609 .784 .965 r
.48072 .50282 .48617 .51158 .50682 .50962 .5015 .50093 Mtetra
.606 .785 .967 r
.5015 .50093 .50682 .50962 .52754 .50772 .52236 .49909 Mtetra
.604 .786 .968 r
.52236 .49909 .52754 .50772 .54833 .50587 .54328 .49727 Mtetra
.603 .787 .969 r
.54328 .49727 .54833 .50587 .56919 .50404 .56428 .49547 Mtetra
.601 .787 .97 r
.56428 .49547 .56919 .50404 .59013 .50223 .58535 .49368 Mtetra
.6 .788 .97 r
.58535 .49368 .59013 .50223 .61113 .50042 .60649 .49189 Mtetra
.6 .788 .971 r
.60649 .49189 .61113 .50042 .63221 .49862 .62771 .49009 Mtetra
.599 .789 .972 r
.62771 .49009 .63221 .49862 .65335 .49682 .649 .48829 Mtetra
.598 .79 .972 r
.649 .48829 .65335 .49682 .67457 .49501 .67036 .48649 Mtetra
.67036 .48649 .67457 .49501 .69587 .4932 .6918 .48467 Mtetra
.598 .79 .973 r
.6918 .48467 .69587 .4932 .71723 .49137 .71331 .48284 Mtetra
.597 .791 .973 r
.71331 .48284 .71723 .49137 .73867 .48955 .7349 .481 Mtetra
.7349 .481 .73867 .48955 .76019 .48771 .75656 .47916 Mtetra
.75656 .47916 .76019 .48771 .78178 .48586 .77829 .4773 Mtetra
.597 .792 .974 r
.77829 .4773 .78178 .48586 .80344 .484 .80011 .47542 Mtetra
.80011 .47542 .80344 .484 .82518 .48214 .822 .47354 Mtetra
.822 .47354 .82518 .48214 .84699 .48026 .84396 .47164 Mtetra
.596 .793 .974 r
.84396 .47164 .84699 .48026 .86888 .47837 .866 .46974 Mtetra
.866 .46974 .86888 .47837 .89085 .47647 .88812 .46782 Mtetra
.88812 .46782 .89085 .47647 .91289 .47456 .91032 .46589 Mtetra
.596 .793 .975 r
.91032 .46589 .91289 .47456 .93501 .47264 .9326 .46395 Mtetra
.9326 .46395 .93501 .47264 .95721 .47071 .95495 .462 Mtetra
.596 .794 .975 r
.95495 .462 .95721 .47071 .97948 .46877 .97738 .46003 Mtetra
.859 .757 .748 r
.24659 .57611 .25307 .59555 .27495 .5587 .26839 .54362 Mtetra
.804 .767 .818 r
.26839 .54362 .27495 .5587 .29588 .54028 .28934 .52746 Mtetra
.752 .772 .869 r
.28934 .52746 .29588 .54028 .31646 .5297 .30999 .5182 Mtetra
.71 .774 .903 r
.30999 .5182 .31646 .5297 .33691 .52292 .33053 .51225 Mtetra
.678 .775 .924 r
.33053 .51225 .33691 .52292 .35733 .51815 .35106 .50804 Mtetra
.656 .776 .938 r
.35106 .50804 .35733 .51815 .37777 .51454 .37161 .50482 Mtetra
.64 .777 .947 r
.37161 .50482 .37777 .51454 .39824 .51161 .3922 .50217 Mtetra
.628 .779 .953 r
.3922 .50217 .39824 .51161 .41877 .5091 .41285 .49986 Mtetra
.62 .78 .958 r
.41285 .49986 .41877 .5091 .43935 .50685 .43356 .49777 Mtetra
.614 .781 .961 r
.43356 .49777 .43935 .50685 .46 .50478 .45434 .49582 Mtetra
.61 .782 .963 r
.45434 .49582 .46 .50478 .48072 .50282 .47519 .49394 Mtetra
.607 .783 .965 r
.47519 .49394 .48072 .50282 .5015 .50093 .49611 .49212 Mtetra
.604 .784 .967 r
.49611 .49212 .5015 .50093 .52236 .49909 .5171 .49033 Mtetra
.603 .785 .968 r
.5171 .49033 .52236 .49909 .54328 .49727 .53816 .48855 Mtetra
.601 .786 .969 r
.53816 .48855 .54328 .49727 .56428 .49547 .5593 .48678 Mtetra
.6 .787 .97 r
.5593 .48678 .56428 .49547 .58535 .49368 .58051 .48501 Mtetra
.599 .787 .971 r
.58051 .48501 .58535 .49368 .60649 .49189 .60179 .48323 Mtetra
.599 .788 .971 r
.60179 .48323 .60649 .49189 .62771 .49009 .62315 .48145 Mtetra
.598 .789 .972 r
.62315 .48145 .62771 .49009 .649 .48829 .64458 .47965 Mtetra
.64458 .47965 .649 .48829 .67036 .48649 .66609 .47784 Mtetra
.597 .79 .972 r
.66609 .47784 .67036 .48649 .6918 .48467 .68767 .47602 Mtetra
.597 .79 .973 r
.68767 .47602 .6918 .48467 .71331 .48284 .70933 .47419 Mtetra
.70933 .47419 .71331 .48284 .7349 .481 .73106 .47234 Mtetra
.597 .791 .973 r
.73106 .47234 .7349 .481 .75656 .47916 .75287 .47048 Mtetra
.597 .791 .974 r
.75287 .47048 .75656 .47916 .77829 .4773 .77476 .46861 Mtetra
.596 .792 .974 r
.77476 .46861 .77829 .4773 .80011 .47542 .79673 .46672 Mtetra
.79673 .46672 .80011 .47542 .822 .47354 .81877 .46482 Mtetra
.81877 .46482 .822 .47354 .84396 .47164 .84089 .46291 Mtetra
.84089 .46291 .84396 .47164 .866 .46974 .86308 .46098 Mtetra
.596 .793 .974 r
.86308 .46098 .866 .46974 .88812 .46782 .88536 .45904 Mtetra
.88536 .45904 .88812 .46782 .91032 .46589 .90771 .45709 Mtetra
.596 .793 .975 r
.90771 .45709 .91032 .46589 .9326 .46395 .93015 .45513 Mtetra
.93015 .45513 .9326 .46395 .95495 .462 .95266 .45315 Mtetra
.95266 .45315 .95495 .462 .97738 .46003 .97525 .45117 Mtetra
.844 .75 .76 r
.24003 .55647 .24659 .57611 .26839 .54362 .26175 .52837 Mtetra
.787 .76 .828 r
.26175 .52837 .26839 .54362 .28934 .52746 .28272 .51448 Mtetra
.736 .765 .876 r
.28272 .51448 .28934 .52746 .30999 .5182 .30344 .50655 Mtetra
.696 .768 .907 r
.30344 .50655 .30999 .5182 .33053 .51225 .32407 .50144 Mtetra
.667 .77 .927 r
.32407 .50144 .33053 .51225 .35106 .50804 .3447 .4978 Mtetra
.647 .772 .94 r
.3447 .4978 .35106 .50804 .37161 .50482 .36537 .49497 Mtetra
.633 .774 .948 r
.36537 .49497 .37161 .50482 .3922 .50217 .38608 .4926 Mtetra
.623 .776 .954 r
.38608 .4926 .3922 .50217 .41285 .49986 .40686 .4905 Mtetra
.616 .778 .958 r
.40686 .4905 .41285 .49986 .43356 .49777 .4277 .48857 Mtetra
.611 .779 .962 r
.4277 .48857 .43356 .49777 .45434 .49582 .44861 .48673 Mtetra
.607 .781 .964 r
.44861 .48673 .45434 .49582 .47519 .49394 .46959 .48495 Mtetra
.604 .782 .966 r
.46959 .48495 .47519 .49394 .49611 .49212 .49064 .48319 Mtetra
.602 .783 .967 r
.49064 .48319 .49611 .49212 .5171 .49033 .51177 .48145 Mtetra
.601 .784 .968 r
.51177 .48145 .5171 .49033 .53816 .48855 .53297 .47971 Mtetra
.6 .785 .969 r
.53297 .47971 .53816 .48855 .5593 .48678 .55424 .47797 Mtetra
.599 .786 .97 r
.55424 .47797 .5593 .48678 .58051 .48501 .5756 .47622 Mtetra
.598 .787 .971 r
.5756 .47622 .58051 .48501 .60179 .48323 .59702 .47445 Mtetra
.598 .788 .971 r
.59702 .47445 .60179 .48323 .62315 .48145 .61852 .47268 Mtetra
.597 .788 .972 r
.61852 .47268 .62315 .48145 .64458 .47965 .6401 .47088 Mtetra
.597 .789 .972 r
.6401 .47088 .64458 .47965 .66609 .47784 .66175 .46907 Mtetra
.597 .789 .973 r
.66175 .46907 .66609 .47784 .68767 .47602 .68348 .46725 Mtetra
.597 .79 .973 r
.68348 .46725 .68767 .47602 .70933 .47419 .70529 .46541 Mtetra
.596 .79 .973 r
.70529 .46541 .70933 .47419 .73106 .47234 .72718 .46355 Mtetra
.596 .791 .973 r
.72718 .46355 .73106 .47234 .75287 .47048 .74914 .46168 Mtetra
.596 .791 .974 r
.74914 .46168 .75287 .47048 .77476 .46861 .77118 .45979 Mtetra
.77118 .45979 .77476 .46861 .79673 .46672 .79329 .45789 Mtetra
.596 .792 .974 r
.79329 .45789 .79673 .46672 .81877 .46482 .81549 .45597 Mtetra
.81549 .45597 .81877 .46482 .84089 .46291 .83777 .45404 Mtetra
.83777 .45404 .84089 .46291 .86308 .46098 .86012 .4521 Mtetra
.86012 .4521 .86308 .46098 .88536 .45904 .88255 .45014 Mtetra
.596 .793 .974 r
.88255 .45014 .88536 .45904 .90771 .45709 .90507 .44817 Mtetra
.596 .793 .975 r
.90507 .44817 .90771 .45709 .93015 .45513 .92766 .44618 Mtetra
.92766 .44618 .93015 .45513 .95266 .45315 .95033 .44418 Mtetra
.95033 .44418 .95266 .45315 .97525 .45117 .97309 .44217 Mtetra
.825 .741 .772 r
.23341 .53664 .24003 .55647 .26175 .52837 .25504 .51294 Mtetra
.768 .751 .838 r
.25504 .51294 .26175 .52837 .28272 .51448 .27602 .50134 Mtetra
.719 .757 .883 r
.27602 .50134 .28272 .51448 .30344 .50655 .2968 .49475 Mtetra
.682 .762 .912 r
.2968 .49475 .30344 .50655 .32407 .50144 .31753 .49049 Mtetra
.656 .765 .93 r
.31753 .49049 .32407 .50144 .3447 .4978 .33826 .48742 Mtetra
.638 .768 .942 r
.33826 .48742 .3447 .4978 .36537 .49497 .35904 .48498 Mtetra
.626 .771 .95 r
.35904 .48498 .36537 .49497 .38608 .4926 .37988 .48289 Mtetra
.617 .773 .955 r
.37988 .48289 .38608 .4926 .40686 .4905 .40078 .48101 Mtetra
.611 .775 .959 r
.40078 .48101 .40686 .4905 .4277 .48857 .42175 .47923 Mtetra
.607 .777 .962 r
.42175 .47923 .4277 .48857 .44861 .48673 .44279 .47751 Mtetra
.604 .779 .964 r
.44279 .47751 .44861 .48673 .46959 .48495 .4639 .47582 Mtetra
.602 .781 .966 r
.4639 .47582 .46959 .48495 .49064 .48319 .48509 .47413 Mtetra
.6 .782 .967 r
.48509 .47413 .49064 .48319 .51177 .48145 .50636 .47245 Mtetra
.599 .783 .969 r
.50636 .47245 .51177 .48145 .53297 .47971 .5277 .47075 Mtetra
.598 .784 .969 r
.5277 .47075 .53297 .47971 .55424 .47797 .54912 .46903 Mtetra
.598 .785 .97 r
.54912 .46903 .55424 .47797 .5756 .47622 .57061 .4673 Mtetra
.597 .786 .971 r
.57061 .4673 .5756 .47622 .59702 .47445 .59218 .46555 Mtetra
.597 .787 .971 r
.59218 .46555 .59702 .47445 .61852 .47268 .61383 .46378 Mtetra
.597 .788 .972 r
.61383 .46378 .61852 .47268 .6401 .47088 .63556 .46199 Mtetra
.596 .788 .972 r
.63556 .46199 .6401 .47088 .66175 .46907 .65736 .46018 Mtetra
.596 .789 .973 r
.65736 .46018 .66175 .46907 .68348 .46725 .67924 .45835 Mtetra
.67924 .45835 .68348 .46725 .70529 .46541 .7012 .4565 Mtetra
.596 .79 .973 r
.7012 .4565 .70529 .46541 .72718 .46355 .72323 .45464 Mtetra
.72323 .45464 .72718 .46355 .74914 .46168 .74535 .45275 Mtetra
.596 .791 .974 r
.74535 .45275 .74914 .46168 .77118 .45979 .76754 .45085 Mtetra
.76754 .45085 .77118 .45979 .79329 .45789 .78981 .44893 Mtetra
.78981 .44893 .79329 .45789 .81549 .45597 .81217 .447 Mtetra
.596 .792 .974 r
.81217 .447 .81549 .45597 .83777 .45404 .8346 .44505 Mtetra
.8346 .44505 .83777 .45404 .86012 .4521 .85711 .44308 Mtetra
.85711 .44308 .86012 .4521 .88255 .45014 .87971 .4411 Mtetra
.596 .793 .974 r
.87971 .4411 .88255 .45014 .90507 .44817 .90238 .43911 Mtetra
.596 .793 .975 r
.90238 .43911 .90507 .44817 .92766 .44618 .92514 .4371 Mtetra
.92514 .4371 .92766 .44618 .95033 .44418 .94798 .43508 Mtetra
.94798 .43508 .95033 .44418 .97309 .44217 .9709 .43304 Mtetra
.803 .731 .784 r
.22672 .51661 .23341 .53664 .25504 .51294 .24824 .49733 Mtetra
.746 .741 .848 r
.24824 .49733 .25504 .51294 .27602 .50134 .26924 .48804 Mtetra
.699 .749 .89 r
.26924 .48804 .27602 .50134 .2968 .49475 .29008 .4828 Mtetra
.666 .754 .916 r
.29008 .4828 .2968 .49475 .31753 .49049 .31089 .47939 Mtetra
.644 .759 .933 r
.31089 .47939 .31753 .49049 .33826 .48742 .33174 .47689 Mtetra
.628 .763 .944 r
.33174 .47689 .33826 .48742 .35904 .48498 .35263 .47486 Mtetra
.618 .767 .951 r
.35263 .47486 .35904 .48498 .37988 .48289 .37359 .47306 Mtetra
.611 .77 .956 r
.37359 .47306 .37988 .48289 .40078 .48101 .39461 .47138 Mtetra
.607 .773 .96 r
.39461 .47138 .40078 .48101 .42175 .47923 .41571 .46977 Mtetra
.603 .775 .963 r
.41571 .46977 .42175 .47923 .44279 .47751 .43689 .46817 Mtetra
.601 .778 .965 r
.43689 .46817 .44279 .47751 .4639 .47582 .45814 .46656 Mtetra
.6 .779 .966 r
.45814 .46656 .4639 .47582 .48509 .47413 .47947 .46495 Mtetra
.598 .781 .968 r
.47947 .46495 .48509 .47413 .50636 .47245 .50088 .46331 Mtetra
.598 .782 .969 r
.50088 .46331 .50636 .47245 .5277 .47075 .52236 .46165 Mtetra
.597 .784 .97 r
.52236 .46165 .5277 .47075 .54912 .46903 .54392 .45997 Mtetra
.597 .785 .97 r
.54392 .45997 .54912 .46903 .57061 .4673 .56556 .45826 Mtetra
.596 .786 .971 r
.56556 .45826 .57061 .4673 .59218 .46555 .58728 .45652 Mtetra
.596 .787 .971 r
.58728 .45652 .59218 .46555 .61383 .46378 .60907 .45476 Mtetra
.596 .787 .972 r
.60907 .45476 .61383 .46378 .63556 .46199 .63095 .45297 Mtetra
.596 .788 .972 r
.63095 .45297 .63556 .46199 .65736 .46018 .6529 .45116 Mtetra
.596 .789 .973 r
.6529 .45116 .65736 .46018 .67924 .45835 .67493 .44932 Mtetra
.67493 .44932 .67924 .45835 .7012 .4565 .69704 .44747 Mtetra
.596 .79 .973 r
.69704 .44747 .7012 .4565 .72323 .45464 .71923 .44559 Mtetra
.595 .79 .973 r
.71923 .44559 .72323 .45464 .74535 .45275 .7415 .44369 Mtetra
.595 .791 .974 r
.7415 .44369 .74535 .45275 .76754 .45085 .76385 .44178 Mtetra
.76385 .44178 .76754 .45085 .78981 .44893 .78628 .43984 Mtetra
.78628 .43984 .78981 .44893 .81217 .447 .80879 .43789 Mtetra
.595 .792 .974 r
.80879 .43789 .81217 .447 .8346 .44505 .83139 .43592 Mtetra
.596 .792 .974 r
.83139 .43592 .8346 .44505 .85711 .44308 .85406 .43394 Mtetra
.85406 .43394 .85711 .44308 .87971 .4411 .87682 .43194 Mtetra
.87682 .43194 .87971 .4411 .90238 .43911 .89966 .42992 Mtetra
.596 .793 .975 r
.89966 .42992 .90238 .43911 .92514 .4371 .92258 .42789 Mtetra
.92258 .42789 .92514 .4371 .94798 .43508 .94558 .42584 Mtetra
.94558 .42584 .94798 .43508 .9709 .43304 .96867 .42378 Mtetra
.777 .718 .797 r
.21997 .49637 .22672 .51661 .24824 .49733 .24137 .48154 Mtetra
.721 .729 .857 r
.24137 .48154 .24824 .49733 .26924 .48804 .26237 .47457 Mtetra
.679 .739 .896 r
.26237 .47457 .26924 .48804 .29008 .4828 .28327 .47069 Mtetra
.65 .746 .92 r
.28327 .47069 .29008 .4828 .31089 .47939 .30417 .46815 Mtetra
.631 .753 .935 r
.30417 .46815 .31089 .47939 .33174 .47689 .32512 .46623 Mtetra
.619 .759 .945 r
.32512 .46623 .33174 .47689 .35263 .47486 .34613 .46459 Mtetra
.611 .763 .952 r
.34613 .46459 .35263 .47486 .37359 .47306 .36721 .46309 Mtetra
.606 .767 .957 r
.36721 .46309 .37359 .47306 .39461 .47138 .38836 .46163 Mtetra
.602 .771 .961 r
.38836 .46163 .39461 .47138 .41571 .46977 .4096 .46017 Mtetra
.6 .774 .963 r
.4096 .46017 .41571 .46977 .43689 .46817 .43091 .45869 Mtetra
.598 .776 .965 r
.43091 .45869 .43689 .46817 .45814 .46656 .4523 .45718 Mtetra
.597 .778 .967 r
.4523 .45718 .45814 .46656 .47947 .46495 .47377 .45563 Mtetra
.596 .78 .968 r
.47377 .45563 .47947 .46495 .50088 .46331 .49531 .45405 Mtetra
.596 .781 .969 r
.49531 .45405 .50088 .46331 .52236 .46165 .51694 .45243 Mtetra
.596 .783 .97 r
.51694 .45243 .52236 .46165 .54392 .45997 .53865 .45077 Mtetra
.595 .784 .97 r
.53865 .45077 .54392 .45997 .56556 .45826 .56043 .44908 Mtetra
.595 .785 .971 r
.56043 .44908 .56556 .45826 .58728 .45652 .5823 .44736 Mtetra
.595 .786 .972 r
.5823 .44736 .58728 .45652 .60907 .45476 .60424 .4456 Mtetra
.595 .787 .972 r
.60424 .4456 .60907 .45476 .63095 .45297 .62627 .44381 Mtetra
.595 .788 .972 r
.62627 .44381 .63095 .45297 .6529 .45116 .64837 .442 Mtetra
.595 .788 .973 r
.64837 .442 .6529 .45116 .67493 .44932 .67056 .44016 Mtetra
.595 .789 .973 r
.67056 .44016 .67493 .44932 .69704 .44747 .69282 .4383 Mtetra
.69282 .4383 .69704 .44747 .71923 .44559 .71517 .43641 Mtetra
.595 .79 .973 r
.71517 .43641 .71923 .44559 .7415 .44369 .7376 .4345 Mtetra
.595 .79 .974 r
.7376 .4345 .7415 .44369 .76385 .44178 .76011 .43257 Mtetra
.595 .791 .974 r
.76011 .43257 .76385 .44178 .78628 .43984 .7827 .43062 Mtetra
.7827 .43062 .78628 .43984 .80879 .43789 .80537 .42865 Mtetra
.80537 .42865 .80879 .43789 .83139 .43592 .82813 .42666 Mtetra
.595 .792 .974 r
.82813 .42666 .83139 .43592 .85406 .43394 .85096 .42465 Mtetra
.85096 .42465 .85406 .43394 .87682 .43194 .87389 .42263 Mtetra
.87389 .42263 .87682 .43194 .89966 .42992 .89689 .42059 Mtetra
.595 .793 .975 r
.89689 .42059 .89966 .42992 .92258 .42789 .91998 .41853 Mtetra
.91998 .41853 .92258 .42789 .94558 .42584 .94315 .41646 Mtetra
.94315 .41646 .94558 .42584 .96867 .42378 .96641 .41437 Mtetra
.744 .7 .81 r
.21314 .47592 .21997 .49637 .24137 .48154 .23442 .46556 Mtetra
.692 .715 .866 r
.23442 .46556 .24137 .48154 .26237 .47457 .25542 .46093 Mtetra
.656 .727 .902 r
.25542 .46093 .26237 .47457 .28327 .47069 .27637 .45842 Mtetra
.632 .738 .924 r
.27637 .45842 .28327 .47069 .30417 .46815 .29736 .45675 Mtetra
.618 .747 .938 r
.29736 .45675 .30417 .46815 .32512 .46623 .31841 .45542 Mtetra
.609 .754 .947 r
.31841 .45542 .32512 .46623 .34613 .46459 .33954 .45419 Mtetra
.603 .759 .953 r
.33954 .45419 .34613 .46459 .36721 .46309 .36074 .45298 Mtetra
.6 .764 .958 r
.36074 .45298 .36721 .46309 .38836 .46163 .38203 .45173 Mtetra
.598 .768 .961 r
.38203 .45173 .38836 .46163 .4096 .46017 .40339 .45043 Mtetra
.596 .772 .964 r
.40339 .45043 .4096 .46017 .43091 .45869 .42484 .44908 Mtetra
.595 .774 .966 r
.42484 .44908 .43091 .45869 .4523 .45718 .44637 .44766 Mtetra
.595 .777 .967 r
.44637 .44766 .4523 .45718 .47377 .45563 .46798 .44618 Mtetra
.594 .779 .968 r
.46798 .44618 .47377 .45563 .49531 .45405 .48967 .44465 Mtetra
.594 .781 .969 r
.48967 .44465 .49531 .45405 .51694 .45243 .51144 .44307 Mtetra
.594 .782 .97 r
.51144 .44307 .51694 .45243 .53865 .45077 .5333 .44144 Mtetra
.594 .783 .971 r
.5333 .44144 .53865 .45077 .56043 .44908 .55523 .43977 Mtetra
.594 .785 .971 r
.55523 .43977 .56043 .44908 .5823 .44736 .57725 .43806 Mtetra
.594 .786 .972 r
.57725 .43806 .5823 .44736 .60424 .4456 .59934 .43631 Mtetra
.59934 .43631 .60424 .4456 .62627 .44381 .62152 .43453 Mtetra
.594 .787 .972 r
.62152 .43453 .62627 .44381 .64837 .442 .64378 .43271 Mtetra
.594 .788 .973 r
.64378 .43271 .64837 .442 .67056 .44016 .66612 .43087 Mtetra
.595 .789 .973 r
.66612 .43087 .67056 .44016 .69282 .4383 .68855 .42899 Mtetra
.68855 .42899 .69282 .4383 .71517 .43641 .71105 .42709 Mtetra
.595 .79 .973 r
.71105 .42709 .71517 .43641 .7376 .4345 .73364 .42517 Mtetra
.595 .79 .974 r
.73364 .42517 .7376 .4345 .76011 .43257 .75631 .42322 Mtetra
.595 .791 .974 r
.75631 .42322 .76011 .43257 .7827 .43062 .77906 .42126 Mtetra
.77906 .42126 .7827 .43062 .80537 .42865 .8019 .41927 Mtetra
.8019 .41927 .80537 .42865 .82813 .42666 .82482 .41726 Mtetra
.595 .792 .974 r
.82482 .41726 .82813 .42666 .85096 .42465 .84782 .41523 Mtetra
.84782 .41523 .85096 .42465 .87389 .42263 .87091 .41318 Mtetra
.87091 .41318 .87389 .42263 .89689 .42059 .89408 .41112 Mtetra
.595 .792 .975 r
.89408 .41112 .89689 .42059 .91998 .41853 .91734 .40904 Mtetra
.595 .793 .975 r
.91734 .40904 .91998 .41853 .94315 .41646 .94069 .40694 Mtetra
.94069 .40694 .94315 .41646 .96641 .41437 .96412 .40483 Mtetra
.704 .678 .822 r
.20625 .45527 .21314 .47592 .23442 .46556 .22738 .44939 Mtetra
.659 .697 .874 r
.22738 .44939 .23442 .46556 .25542 .46093 .24837 .44712 Mtetra
.631 .714 .907 r
.24837 .44712 .25542 .46093 .27637 .45842 .26938 .446 Mtetra
.614 .728 .927 r
.26938 .446 .27637 .45842 .29736 .45675 .29046 .44521 Mtetra
.604 .74 .94 r
.29046 .44521 .29736 .45675 .31841 .45542 .31161 .44446 Mtetra
.599 .748 .949 r
.31161 .44446 .31841 .45542 .33954 .45419 .33285 .44364 Mtetra
.596 .756 .955 r
.33285 .44364 .33954 .45419 .36074 .45298 .35418 .44272 Mtetra
.594 .761 .959 r
.35418 .44272 .36074 .45298 .38203 .45173 .3756 .4417 Mtetra
.593 .766 .962 r
.3756 .4417 .38203 .45173 .40339 .45043 .3971 .44056 Mtetra
.592 .77 .964 r
.3971 .44056 .40339 .45043 .42484 .44908 .41868 .43932 Mtetra
.592 .773 .966 r
.41868 .43932 .42484 .44908 .44637 .44766 .44035 .438 Mtetra
.592 .775 .967 r
.44035 .438 .44637 .44766 .46798 .44618 .46211 .4366 Mtetra
.592 .778 .968 r
.46211 .4366 .46798 .44618 .48967 .44465 .48395 .43512 Mtetra
.593 .78 .969 r
.48395 .43512 .48967 .44465 .51144 .44307 .50587 .43358 Mtetra
.593 .781 .97 r
.50587 .43358 .51144 .44307 .5333 .44144 .52787 .43198 Mtetra
.593 .783 .971 r
.52787 .43198 .5333 .44144 .55523 .43977 .54995 .43032 Mtetra
.593 .784 .971 r
.54995 .43032 .55523 .43977 .57725 .43806 .57212 .42863 Mtetra
.593 .785 .972 r
.57212 .42863 .57725 .43806 .59934 .43631 .59437 .42688 Mtetra
.593 .786 .972 r
.59437 .42688 .59934 .43631 .62152 .43453 .61671 .4251 Mtetra
.594 .787 .973 r
.61671 .4251 .62152 .43453 .64378 .43271 .63912 .42328 Mtetra
.594 .788 .973 r
.63912 .42328 .64378 .43271 .66612 .43087 .66162 .42143 Mtetra
.66162 .42143 .66612 .43087 .68855 .42899 .6842 .41955 Mtetra
.594 .789 .973 r
.6842 .41955 .68855 .42899 .71105 .42709 .70687 .41764 Mtetra
.594 .789 .974 r
.70687 .41764 .71105 .42709 .73364 .42517 .72962 .4157 Mtetra
.594 .79 .974 r
.72962 .4157 .73364 .42517 .75631 .42322 .75245 .41374 Mtetra
.75245 .41374 .75631 .42322 .77906 .42126 .77537 .41175 Mtetra
.595 .791 .974 r
.77537 .41175 .77906 .42126 .8019 .41927 .79837 .40974 Mtetra
.79837 .40974 .8019 .41927 .82482 .41726 .82146 .40771 Mtetra
.82146 .40771 .82482 .41726 .84782 .41523 .84463 .40566 Mtetra
.595 .792 .974 r
.84463 .40566 .84782 .41523 .87091 .41318 .86789 .40359 Mtetra
.595 .792 .975 r
.86789 .40359 .87091 .41318 .89408 .41112 .89123 .4015 Mtetra
.89123 .4015 .89408 .41112 .91734 .40904 .91466 .3994 Mtetra
.595 .793 .975 r
.91466 .3994 .91734 .40904 .94069 .40694 .93818 .39727 Mtetra
.93818 .39727 .94069 .40694 .96412 .40483 .96179 .39513 Mtetra
.655 .65 .833 r
.19928 .4344 .20625 .45527 .22738 .44939 .22026 .43303 Mtetra
.621 .677 .881 r
.22026 .43303 .22738 .44939 .24837 .44712 .24124 .43313 Mtetra
.603 .7 .912 r
.24124 .43313 .24837 .44712 .26938 .446 .2623 .4334 Mtetra
.594 .718 .93 r
.2623 .4334 .26938 .446 .29046 .44521 .28346 .4335 Mtetra
.59 .732 .942 r
.28346 .4335 .29046 .44521 .31161 .44446 .30472 .43335 Mtetra
.588 .743 .95 r
.30472 .43335 .31161 .44446 .33285 .44364 .32608 .43295 Mtetra
.588 .751 .956 r
.32608 .43295 .33285 .44364 .35418 .44272 .34753 .43233 Mtetra
.588 .758 .96 r
.34753 .43233 .35418 .44272 .3756 .4417 .36908 .43152 Mtetra
.588 .763 .962 r
.36908 .43152 .3756 .4417 .3971 .44056 .39072 .43054 Mtetra
.589 .768 .965 r
.39072 .43054 .3971 .44056 .41868 .43932 .41244 .42943 Mtetra
.589 .771 .966 r
.41244 .42943 .41868 .43932 .44035 .438 .43425 .4282 Mtetra
.59 .774 .968 r
.43425 .4282 .44035 .438 .46211 .4366 .45615 .42687 Mtetra
.59 .777 .969 r
.45615 .42687 .46211 .4366 .48395 .43512 .47814 .42544 Mtetra
.591 .779 .97 r
.47814 .42544 .48395 .43512 .50587 .43358 .50021 .42394 Mtetra
.591 .78 .97 r
.50021 .42394 .50587 .43358 .52787 .43198 .52236 .42237 Mtetra
.592 .782 .971 r
.52236 .42237 .52787 .43198 .54995 .43032 .5446 .42074 Mtetra
.592 .783 .971 r
.5446 .42074 .54995 .43032 .57212 .42863 .56692 .41905 Mtetra
.592 .785 .972 r
.56692 .41905 .57212 .42863 .59437 .42688 .58933 .41732 Mtetra
.593 .786 .972 r
.58933 .41732 .59437 .42688 .61671 .4251 .61182 .41554 Mtetra
.593 .786 .973 r
.61182 .41554 .61671 .4251 .63912 .42328 .63439 .41371 Mtetra
.593 .787 .973 r
.63439 .41371 .63912 .42328 .66162 .42143 .65705 .41186 Mtetra
.593 .788 .973 r
.65705 .41186 .66162 .42143 .6842 .41955 .67979 .40997 Mtetra
.594 .789 .973 r
.67979 .40997 .6842 .41955 .70687 .41764 .70262 .40804 Mtetra
.594 .789 .974 r
.70262 .40804 .70687 .41764 .72962 .4157 .72554 .40609 Mtetra
.594 .79 .974 r
.72554 .40609 .72962 .4157 .75245 .41374 .74853 .40411 Mtetra
.74853 .40411 .75245 .41374 .77537 .41175 .77162 .4021 Mtetra
.594 .791 .974 r
.77162 .4021 .77537 .41175 .79837 .40974 .79479 .40008 Mtetra
.79479 .40008 .79837 .40974 .82146 .40771 .81805 .39802 Mtetra
.595 .791 .974 r
.81805 .39802 .82146 .40771 .84463 .40566 .84139 .39595 Mtetra
.595 .792 .974 r
.84139 .39595 .84463 .40566 .86789 .40359 .86482 .39386 Mtetra
.595 .792 .975 r
.86482 .39386 .86789 .40359 .89123 .4015 .88834 .39174 Mtetra
.88834 .39174 .89123 .4015 .91466 .3994 .91194 .38961 Mtetra
.91194 .38961 .91466 .3994 .93818 .39727 .93564 .38746 Mtetra
.595 .793 .975 r
.93564 .38746 .93818 .39727 .96179 .39513 .95942 .38529 Mtetra
.593 .613 .841 r
.19224 .41331 .19928 .4344 .22026 .43303 .21305 .41647 Mtetra
.578 .652 .887 r
.21305 .41647 .22026 .43303 .24124 .43313 .23401 .41896 Mtetra
.574 .684 .915 r
.23401 .41896 .24124 .43313 .2623 .4334 .25512 .42064 Mtetra
.574 .707 .933 r
.25512 .42064 .2623 .4334 .28346 .4335 .27636 .42163 Mtetra
.575 .724 .944 r
.27636 .42163 .28346 .4335 .30472 .43335 .29773 .42208 Mtetra
.578 .737 .951 r
.29773 .42208 .30472 .43335 .32608 .43295 .31921 .4221 Mtetra
.58 .747 .957 r
.31921 .4221 .32608 .43295 .34753 .43233 .34079 .42178 Mtetra
.582 .755 .96 r
.34079 .42178 .34753 .43233 .36908 .43152 .36246 .42119 Mtetra
.583 .761 .963 r
.36246 .42119 .36908 .43152 .39072 .43054 .38424 .42038 Mtetra
.585 .766 .965 r
.38424 .42038 .39072 .43054 .41244 .42943 .40611 .4194 Mtetra
.586 .77 .967 r
.40611 .4194 .41244 .42943 .43425 .4282 .42806 .41826 Mtetra
.587 .773 .968 r
.42806 .41826 .43425 .4282 .45615 .42687 .45011 .417 Mtetra
.588 .776 .969 r
.45011 .417 .45615 .42687 .47814 .42544 .47224 .41563 Mtetra
.589 .778 .97 r
.47224 .41563 .47814 .42544 .50021 .42394 .49446 .41417 Mtetra
.59 .78 .97 r
.49446 .41417 .50021 .42394 .52236 .42237 .51677 .41262 Mtetra
.59 .781 .971 r
.51677 .41262 .52236 .42237 .5446 .42074 .53916 .41101 Mtetra
.591 .783 .972 r
.53916 .41101 .5446 .42074 .56692 .41905 .56164 .40934 Mtetra
.592 .784 .972 r
.56164 .40934 .56692 .41905 .58933 .41732 .58421 .40761 Mtetra
.592 .785 .972 r
.58421 .40761 .58933 .41732 .61182 .41554 .60686 .40583 Mtetra
.592 .786 .973 r
.60686 .40583 .61182 .41554 .63439 .41371 .62959 .404 Mtetra
.593 .787 .973 r
.62959 .404 .63439 .41371 .65705 .41186 .65241 .40214 Mtetra
.593 .788 .973 r
.65241 .40214 .65705 .41186 .67979 .40997 .67532 .40024 Mtetra
.67532 .40024 .67979 .40997 .70262 .40804 .69831 .3983 Mtetra
.593 .789 .974 r
.69831 .3983 .70262 .40804 .72554 .40609 .72139 .39633 Mtetra
.594 .789 .974 r
.72139 .39633 .72554 .40609 .74853 .40411 .74456 .39433 Mtetra
.594 .79 .974 r
.74456 .39433 .74853 .40411 .77162 .4021 .76781 .39231 Mtetra
.76781 .39231 .77162 .4021 .79479 .40008 .79115 .39026 Mtetra
.594 .791 .974 r
.79115 .39026 .79479 .40008 .81805 .39802 .81458 .38819 Mtetra
.81458 .38819 .81805 .39802 .84139 .39595 .8381 .38609 Mtetra
.8381 .38609 .84139 .39595 .86482 .39386 .86171 .38397 Mtetra
.595 .792 .975 r
.86171 .38397 .86482 .39386 .88834 .39174 .8854 .38183 Mtetra
.8854 .38183 .88834 .39174 .91194 .38961 .90918 .37967 Mtetra
.90918 .37967 .91194 .38961 .93564 .38746 .93306 .37749 Mtetra
.595 .793 .975 r
.93306 .37749 .93564 .38746 .95942 .38529 .95702 .3753 Mtetra
.517 .565 .843 r
.18513 .392 .19224 .41331 .21305 .41647 .20576 .39972 Mtetra
.529 .623 .89 r
.20576 .39972 .21305 .41647 .23401 .41896 .22669 .40461 Mtetra
.541 .665 .918 r
.22669 .40461 .23401 .41896 .25512 .42064 .24785 .40771 Mtetra
.552 .695 .935 r
.24785 .40771 .25512 .42064 .27636 .42163 .26917 .4096 Mtetra
.56 .716 .945 r
.26917 .4096 .27636 .42163 .29773 .42208 .29064 .41065 Mtetra
.566 .732 .953 r
.29064 .41065 .29773 .42208 .31921 .4221 .31223 .41109 Mtetra
.571 .743 .957 r
.31223 .41109 .31921 .4221 .34079 .42178 .33394 .41108 Mtetra
.575 .752 .961 r
.33394 .41108 .34079 .42178 .36246 .42119 .35576 .41072 Mtetra
.578 .758 .964 r
.35576 .41072 .36246 .42119 .38424 .42038 .37767 .41008 Mtetra
.581 .764 .965 r
.37767 .41008 .38424 .42038 .40611 .4194 .39968 .40921 Mtetra
.583 .768 .967 r
.39968 .40921 .40611 .4194 .42806 .41826 .42178 .40817 Mtetra
.585 .772 .968 r
.42178 .40817 .42806 .41826 .45011 .417 .44398 .40698 Mtetra
.586 .774 .969 r
.44398 .40698 .45011 .417 .47224 .41563 .46626 .40566 Mtetra
.587 .777 .97 r
.46626 .40566 .47224 .41563 .49446 .41417 .48863 .40424 Mtetra
.588 .779 .971 r
.48863 .40424 .49446 .41417 .51677 .41262 .5111 .40273 Mtetra
.589 .781 .971 r
.5111 .40273 .51677 .41262 .53916 .41101 .53365 .40114 Mtetra
.59 .782 .972 r
.53365 .40114 .53916 .41101 .56164 .40934 .55628 .39947 Mtetra
.591 .783 .972 r
.55628 .39947 .56164 .40934 .58421 .40761 .57901 .39775 Mtetra
.591 .785 .972 r
.57901 .39775 .58421 .40761 .60686 .40583 .60182 .39597 Mtetra
.592 .786 .973 r
.60182 .39597 .60686 .40583 .62959 .404 .62472 .39414 Mtetra
.592 .787 .973 r
.62472 .39414 .62959 .404 .65241 .40214 .6477 .39227 Mtetra
.6477 .39227 .65241 .40214 .67532 .40024 .67078 .39036 Mtetra
.593 .788 .973 r
.67078 .39036 .67532 .40024 .69831 .3983 .69394 .38841 Mtetra
.593 .789 .974 r
.69394 .38841 .69831 .3983 .72139 .39633 .71719 .38642 Mtetra
.71719 .38642 .72139 .39633 .74456 .39433 .74052 .38441 Mtetra
.594 .79 .974 r
.74052 .38441 .74456 .39433 .76781 .39231 .76395 .38236 Mtetra
.76395 .38236 .76781 .39231 .79115 .39026 .78746 .38029 Mtetra
.594 .791 .974 r
.78746 .38029 .79115 .39026 .81458 .38819 .81107 .3782 Mtetra
.81107 .3782 .81458 .38819 .8381 .38609 .83476 .37607 Mtetra
.83476 .37607 .8381 .38609 .86171 .38397 .85854 .37393 Mtetra
.594 .792 .975 r
.85854 .37393 .86171 .38397 .8854 .38183 .88242 .37176 Mtetra
.88242 .37176 .8854 .38183 .90918 .37967 .90638 .36958 Mtetra
.595 .792 .975 r
.90638 .36958 .90918 .37967 .93306 .37749 .93043 .36737 Mtetra
.93043 .36737 .93306 .37749 .95702 .3753 .95458 .36514 Mtetra
.425 .505 .837 r
.17794 .37047 .18513 .392 .20576 .39972 .19838 .38276 Mtetra
.473 .589 .889 r
.19838 .38276 .20576 .39972 .22669 .40461 .21928 .39007 Mtetra
.506 .645 .919 r
.21928 .39007 .22669 .40461 .24785 .40771 .24048 .3946 Mtetra
.529 .682 .936 r
.24048 .3946 .24785 .40771 .26917 .4096 .26188 .3974 Mtetra
.544 .707 .947 r
.26188 .3974 .26917 .4096 .29064 .41065 .28345 .39907 Mtetra
.555 .725 .954 r
.28345 .39907 .29064 .41065 .31223 .41109 .30516 .39993 Mtetra
.563 .738 .958 r
.30516 .39993 .31223 .41109 .33394 .41108 .327 .40023 Mtetra
.569 .748 .962 r
.327 .40023 .33394 .41108 .35576 .41072 .34895 .40009 Mtetra
.574 .756 .964 r
.34895 .40009 .35576 .41072 .37767 .41008 .371 .39961 Mtetra
.577 .762 .966 r
.371 .39961 .37767 .41008 .39968 .40921 .39316 .39888 Mtetra
.58 .766 .967 r
.39316 .39888 .39968 .40921 .42178 .40817 .41541 .39793 Mtetra
.582 .77 .968 r
.41541 .39793 .42178 .40817 .44398 .40698 .43775 .39682 Mtetra
.584 .773 .969 r
.43775 .39682 .44398 .40698 .46626 .40566 .46019 .39555 Mtetra
.586 .776 .97 r
.46019 .39555 .46626 .40566 .48863 .40424 .48272 .39417 Mtetra
.587 .778 .971 r
.48272 .39417 .48863 .40424 .5111 .40273 .50534 .39268 Mtetra
.588 .78 .971 r
.50534 .39268 .5111 .40273 .53365 .40114 .52805 .39111 Mtetra
.589 .782 .972 r
.52805 .39111 .53365 .40114 .55628 .39947 .55084 .38946 Mtetra
.59 .783 .972 r
.55084 .38946 .55628 .39947 .57901 .39775 .57373 .38774 Mtetra
.59 .784 .972 r
.57373 .38774 .57901 .39775 .60182 .39597 .59671 .38596 Mtetra
.591 .785 .973 r
.59671 .38596 .60182 .39597 .62472 .39414 .61977 .38413 Mtetra
.591 .786 .973 r
.61977 .38413 .62472 .39414 .6477 .39227 .64292 .38225 Mtetra
.592 .787 .973 r
.64292 .38225 .6477 .39227 .67078 .39036 .66616 .38033 Mtetra
.592 .788 .973 r
.66616 .38033 .67078 .39036 .69394 .38841 .6895 .37836 Mtetra
.593 .788 .974 r
.6895 .37836 .69394 .38841 .71719 .38642 .71292 .37636 Mtetra
.593 .789 .974 r
.71292 .37636 .71719 .38642 .74052 .38441 .73643 .37433 Mtetra
.593 .79 .974 r
.73643 .37433 .74052 .38441 .76395 .38236 .76002 .37226 Mtetra
.76002 .37226 .76395 .38236 .78746 .38029 .78371 .37017 Mtetra
.594 .79 .974 r
.78371 .37017 .78746 .38029 .81107 .3782 .8075 .36805 Mtetra
.594 .791 .974 r
.8075 .36805 .81107 .3782 .83476 .37607 .83137 .3659 Mtetra
.83137 .3659 .83476 .37607 .85854 .37393 .85533 .36373 Mtetra
.594 .792 .975 r
.85533 .36373 .85854 .37393 .88242 .37176 .87938 .36154 Mtetra
.87938 .36154 .88242 .37176 .90638 .36958 .90353 .35932 Mtetra
.90353 .35932 .90638 .36958 .93043 .36737 .92777 .35709 Mtetra
.595 .792 .975 r
.92777 .35709 .93043 .36737 .95458 .36514 .9521 .35483 Mtetra
.313 .428 .819 r
.17068 .34871 .17794 .37047 .19838 .38276 .19091 .36559 Mtetra
.41 .549 .884 r
.19091 .36559 .19838 .38276 .21928 .39007 .21177 .37534 Mtetra
.468 .622 .918 r
.21177 .37534 .21928 .39007 .24048 .3946 .233 .38131 Mtetra
.504 .668 .937 r
.233 .38131 .24048 .3946 .26188 .3974 .25449 .38503 Mtetra
.527 .698 .947 r
.25449 .38503 .26188 .3974 .28345 .39907 .27616 .38731 Mtetra
.543 .719 .954 r
.27616 .38731 .28345 .39907 .30516 .39993 .29799 .38861 Mtetra
.554 .734 .959 r
.29799 .38861 .30516 .39993 .327 .40023 .31996 .38922 Mtetra
.563 .745 .962 r
.31996 .38922 .327 .40023 .34895 .40009 .34204 .3893 Mtetra
.569 .753 .965 r
.34204 .3893 .34895 .40009 .371 .39961 .36424 .389 Mtetra
.573 .76 .966 r
.36424 .389 .371 .39961 .39316 .39888 .38654 .38839 Mtetra
.577 .765 .968 r
.38654 .38839 .39316 .39888 .41541 .39793 .40894 .38754 Mtetra
.58 .769 .969 r
.40894 .38754 .41541 .39793 .43775 .39682 .43143 .3865 Mtetra
.582 .772 .97 r
.43143 .3865 .43775 .39682 .46019 .39555 .45403 .38529 Mtetra
.584 .775 .97 r
.45403 .38529 .46019 .39555 .48272 .39417 .47671 .38395 Mtetra
.586 .777 .971 r
.47671 .38395 .48272 .39417 .50534 .39268 .49949 .38249 Mtetra
.587 .779 .971 r
.49949 .38249 .50534 .39268 .52805 .39111 .52236 .38093 Mtetra
.588 .781 .972 r
.52236 .38093 .52805 .39111 .55084 .38946 .54532 .37929 Mtetra
.589 .782 .972 r
.54532 .37929 .55084 .38946 .57373 .38774 .56837 .37758 Mtetra
.59 .784 .973 r
.56837 .37758 .57373 .38774 .59671 .38596 .59151 .3758 Mtetra
.59 .785 .973 r
.59151 .3758 .59671 .38596 .61977 .38413 .61474 .37396 Mtetra
.591 .786 .973 r
.61474 .37396 .61977 .38413 .64292 .38225 .63807 .37208 Mtetra
.591 .787 .973 r
.63807 .37208 .64292 .38225 .66616 .38033 .66148 .37014 Mtetra
.592 .787 .974 r
.66148 .37014 .66616 .38033 .6895 .37836 .68498 .36816 Mtetra
.592 .788 .974 r
.68498 .36816 .6895 .37836 .71292 .37636 .70858 .36615 Mtetra
.593 .789 .974 r
.70858 .36615 .71292 .37636 .73643 .37433 .73226 .36409 Mtetra
.73226 .36409 .73643 .37433 .76002 .37226 .75604 .36201 Mtetra
.593 .79 .974 r
.75604 .36201 .76002 .37226 .78371 .37017 .77991 .35989 Mtetra
.77991 .35989 .78371 .37017 .8075 .36805 .80387 .35774 Mtetra
.594 .791 .974 r
.80387 .35774 .8075 .36805 .83137 .3659 .82792 .35557 Mtetra
.82792 .35557 .83137 .3659 .85533 .36373 .85207 .35337 Mtetra
.594 .791 .975 r
.85207 .35337 .85533 .36373 .87938 .36154 .8763 .35115 Mtetra
.594 .792 .975 r
.8763 .35115 .87938 .36154 .90353 .35932 .90064 .34891 Mtetra
.90064 .34891 .90353 .35932 .92777 .35709 .92506 .34664 Mtetra
.92506 .34664 .92777 .35709 .9521 .35483 .94958 .34436 Mtetra
.184 .336 .784 r
.16334 .32672 .17068 .34871 .19091 .36559 .18335 .34821 Mtetra
.339 .502 .874 r
.18335 .34821 .19091 .36559 .21177 .37534 .20416 .36042 Mtetra
.427 .597 .915 r
.20416 .36042 .21177 .37534 .233 .38131 .22543 .36784 Mtetra
.478 .653 .936 r
.22543 .36784 .233 .38131 .25449 .38503 .24699 .37249 Mtetra
.51 .688 .948 r
.24699 .37249 .25449 .38503 .27616 .38731 .26877 .37539 Mtetra
.531 .712 .955 r
.26877 .37539 .27616 .38731 .29799 .38861 .29072 .37713 Mtetra
.546 .729 .96 r
.29072 .37713 .29799 .38861 .31996 .38922 .31281 .37804 Mtetra
.556 .741 .963 r
.31281 .37804 .31996 .38922 .34204 .3893 .33503 .37836 Mtetra
.564 .75 .965 r
.33503 .37836 .34204 .3893 .36424 .389 .35737 .37823 Mtetra
.569 .757 .967 r
.35737 .37823 .36424 .389 .38654 .38839 .37982 .37775 Mtetra
.574 .763 .968 r
.37982 .37775 .38654 .38839 .40894 .38754 .40237 .37699 Mtetra
.577 .767 .969 r
.40237 .37699 .40894 .38754 .43143 .3865 .42502 .37602 Mtetra
.58 .771 .97 r
.42502 .37602 .43143 .3865 .45403 .38529 .44777 .37487 Mtetra
.582 .774 .971 r
.44777 .37487 .45403 .38529 .47671 .38395 .47061 .37357 Mtetra
.584 .777 .971 r
.47061 .37357 .47671 .38395 .49949 .38249 .49355 .37214 Mtetra
.586 .779 .972 r
.49355 .37214 .49949 .38249 .52236 .38093 .51659 .3706 Mtetra
.587 .78 .972 r
.51659 .3706 .52236 .38093 .54532 .37929 .53971 .36897 Mtetra
.588 .782 .972 r
.53971 .36897 .54532 .37929 .56837 .37758 .56293 .36726 Mtetra
.589 .783 .973 r
.56293 .36726 .56837 .37758 .59151 .3758 .58624 .36548 Mtetra
.59 .784 .973 r
.58624 .36548 .59151 .3758 .61474 .37396 .60964 .36364 Mtetra
.59 .785 .973 r
.60964 .36364 .61474 .37396 .63807 .37208 .63314 .36174 Mtetra
.591 .786 .973 r
.63314 .36174 .63807 .37208 .66148 .37014 .65672 .3598 Mtetra
.591 .787 .974 r
.65672 .3598 .66148 .37014 .68498 .36816 .6804 .3578 Mtetra
.592 .788 .974 r
.6804 .3578 .68498 .36816 .70858 .36615 .70417 .35577 Mtetra
.592 .789 .974 r
.70417 .35577 .70858 .36615 .73226 .36409 .72803 .35369 Mtetra
.593 .789 .974 r
.72803 .35369 .73226 .36409 .75604 .36201 .75199 .35159 Mtetra
.593 .79 .974 r
.75199 .35159 .75604 .36201 .77991 .35989 .77604 .34945 Mtetra
.77604 .34945 .77991 .35989 .80387 .35774 .80018 .34728 Mtetra
.593 .791 .974 r
.80018 .34728 .80387 .35774 .82792 .35557 .82442 .34508 Mtetra
.594 .791 .974 r
.82442 .34508 .82792 .35557 .85207 .35337 .84875 .34285 Mtetra
.594 .791 .975 r
.84875 .34285 .85207 .35337 .8763 .35115 .87318 .3406 Mtetra
.594 .792 .975 r
.87318 .3406 .8763 .35115 .90064 .34891 .8977 .33833 Mtetra
.8977 .33833 .90064 .34891 .92506 .34664 .92231 .33603 Mtetra
.92231 .33603 .92506 .34664 .94958 .34436 .94703 .33371 Mtetra
.041 .23 .731 r
.15592 .30449 .16334 .32672 .18335 .34821 .17569 .33062 Mtetra
.261 .449 .857 r
.17569 .33062 .18335 .34821 .20416 .36042 .19645 .3453 Mtetra
.382 .569 .91 r
.19645 .3453 .20416 .36042 .22543 .36784 .21775 .35419 Mtetra
.451 .637 .935 r
.21775 .35419 .22543 .36784 .24699 .37249 .23938 .35977 Mtetra
.492 .678 .948 r
.23938 .35977 .24699 .37249 .26877 .37539 .26126 .3633 Mtetra
.519 .705 .955 r
.26126 .3633 .26877 .37539 .29072 .37713 .28333 .36547 Mtetra
.537 .724 .96 r
.28333 .36547 .29072 .37713 .31281 .37804 .30556 .3667 Mtetra
.549 .738 .963 r
.30556 .3667 .31281 .37804 .33503 .37836 .32792 .36725 Mtetra
.559 .748 .965 r
.32792 .36725 .33503 .37836 .35737 .37823 .3504 .36729 Mtetra
.565 .755 .967 r
.3504 .36729 .35737 .37823 .37982 .37775 .373 .36694 Mtetra
.571 .761 .968 r
.373 .36694 .37982 .37775 .40237 .37699 .3957 .36629 Mtetra
.575 .766 .969 r
.3957 .36629 .40237 .37699 .42502 .37602 .41851 .36539 Mtetra
.578 .77 .97 r
.41851 .36539 .42502 .37602 .44777 .37487 .44142 .36429 Mtetra
.58 .773 .971 r
.44142 .36429 .44777 .37487 .47061 .37357 .46442 .36303 Mtetra
.583 .776 .971 r
.46442 .36303 .47061 .37357 .49355 .37214 .48752 .36162 Mtetra
.584 .778 .972 r
.48752 .36162 .49355 .37214 .51659 .3706 .51072 .36011 Mtetra
.586 .78 .972 r
.51072 .36011 .51659 .3706 .53971 .36897 .53402 .35849 Mtetra
.587 .781 .972 r
.53402 .35849 .53971 .36897 .56293 .36726 .5574 .35678 Mtetra
.588 .783 .973 r
.5574 .35678 .56293 .36726 .58624 .36548 .58088 .355 Mtetra
.589 .784 .973 r
.58088 .355 .58624 .36548 .60964 .36364 .60446 .35316 Mtetra
.59 .785 .973 r
.60446 .35316 .60964 .36364 .63314 .36174 .62813 .35125 Mtetra
.59 .786 .973 r
.62813 .35125 .63314 .36174 .65672 .3598 .65189 .34929 Mtetra
.591 .787 .974 r
.65189 .34929 .65672 .3598 .6804 .3578 .67575 .34728 Mtetra
.591 .788 .974 r
.67575 .34728 .6804 .3578 .70417 .35577 .6997 .34523 Mtetra
.592 .788 .974 r
.6997 .34523 .70417 .35577 .72803 .35369 .72374 .34313 Mtetra
.592 .789 .974 r
.72374 .34313 .72803 .35369 .75199 .35159 .74788 .341 Mtetra
.593 .789 .974 r
.74788 .341 .75199 .35159 .77604 .34945 .77211 .33884 Mtetra
.593 .79 .974 r
.77211 .33884 .77604 .34945 .80018 .34728 .79644 .33664 Mtetra
.79644 .33664 .80018 .34728 .82442 .34508 .82086 .33442 Mtetra
.593 .791 .975 r
.82086 .33442 .82442 .34508 .84875 .34285 .84538 .33216 Mtetra
.594 .791 .975 r
.84538 .33216 .84875 .34285 .87318 .3406 .87 .32988 Mtetra
.87 .32988 .87318 .3406 .8977 .33833 .89471 .32758 Mtetra
.594 .792 .975 r
.89471 .32758 .8977 .33833 .92231 .33603 .91952 .32525 Mtetra
.91952 .32525 .92231 .33603 .94703 .33371 .94443 .32289 Mtetra
0 .115 .66 r
.14842 .28202 .15592 .30449 .17569 .33062 .16794 .31281 Mtetra
.177 .39 .833 r
.16794 .31281 .17569 .33062 .19645 .3453 .18863 .32998 Mtetra
.335 .538 .903 r
.18863 .32998 .19645 .3453 .21775 .35419 .20996 .34034 Mtetra
.422 .619 .933 r
.20996 .34034 .21775 .35419 .23938 .35977 .23167 .34687 Mtetra
.474 .667 .948 r
.23167 .34687 .23938 .35977 .26126 .3633 .25365 .35103 Mtetra
.506 .698 .956 r
.25365 .35103 .26126 .3633 .28333 .36547 .27584 .35365 Mtetra
.528 .719 .961 r
.27584 .35365 .28333 .36547 .30556 .3667 .2982 .35519 Mtetra
.543 .734 .964 r
.2982 .35519 .30556 .3667 .32792 .36725 .3207 .35598 Mtetra
.553 .745 .966 r
.3207 .35598 .32792 .36725 .3504 .36729 .34332 .35619 Mtetra
.561 .753 .967 r
.34332 .35619 .3504 .36729 .373 .36694 .36607 .35597 Mtetra
.567 .76 .969 r
.36607 .35597 .373 .36694 .3957 .36629 .38893 .35541 Mtetra
.572 .765 .969 r
.38893 .35541 .3957 .36629 .41851 .36539 .4119 .35459 Mtetra
.576 .769 .97 r
.4119 .35459 .41851 .36539 .44142 .36429 .43496 .35354 Mtetra
.579 .772 .971 r
.43496 .35354 .44142 .36429 .46442 .36303 .45813 .35232 Mtetra
.581 .775 .971 r
.45813 .35232 .46442 .36303 .48752 .36162 .4814 .35095 Mtetra
.583 .777 .972 r
.4814 .35095 .48752 .36162 .51072 .36011 .50477 .34945 Mtetra
.585 .779 .972 r
.50477 .34945 .51072 .36011 .53402 .35849 .52823 .34784 Mtetra
.586 .781 .972 r
.52823 .34784 .53402 .35849 .5574 .35678 .55179 .34614 Mtetra
.587 .782 .973 r
.55179 .34614 .5574 .35678 .58088 .355 .57545 .34436 Mtetra
.588 .784 .973 r
.57545 .34436 .58088 .355 .60446 .35316 .5992 .34251 Mtetra
.589 .785 .973 r
.5992 .34251 .60446 .35316 .62813 .35125 .62304 .34059 Mtetra
.59 .786 .973 r
.62304 .34059 .62813 .35125 .65189 .34929 .64698 .33861 Mtetra
.59 .787 .974 r
.64698 .33861 .65189 .34929 .67575 .34728 .67102 .33659 Mtetra
.591 .787 .974 r
.67102 .33659 .67575 .34728 .6997 .34523 .69515 .33452 Mtetra
.591 .788 .974 r
.69515 .33452 .6997 .34523 .72374 .34313 .71938 .3324 Mtetra
.592 .789 .974 r
.71938 .3324 .72374 .34313 .74788 .341 .7437 .33025 Mtetra
.7437 .33025 .74788 .341 .77211 .33884 .76812 .32806 Mtetra
.593 .79 .974 r
.76812 .32806 .77211 .33884 .79644 .33664 .79264 .32584 Mtetra
.79264 .32584 .79644 .33664 .82086 .33442 .81725 .32358 Mtetra
.593 .791 .975 r
.81725 .32358 .82086 .33442 .84538 .33216 .84196 .3213 Mtetra
.84196 .3213 .84538 .33216 .87 .32988 .86677 .31899 Mtetra
.594 .791 .975 r
.86677 .31899 .87 .32988 .89471 .32758 .89167 .31665 Mtetra
.594 .792 .975 r
.89167 .31665 .89471 .32758 .91952 .32525 .91668 .31429 Mtetra
.91668 .31429 .91952 .32525 .94443 .32289 .94179 .3119 Mtetra
0 0 .575 r
.14084 .25932 .14842 .28202 .16794 .31281 .16009 .29477 Mtetra
.088 .325 .801 r
.16009 .29477 .16794 .31281 .18863 .32998 .18071 .31445 Mtetra
.284 .504 .893 r
.18071 .31445 .18863 .32998 .20996 .34034 .20206 .3263 Mtetra
.392 .6 .93 r
.20206 .3263 .20996 .34034 .23167 .34687 .22385 .33378 Mtetra
.454 .656 .947 r
.22385 .33378 .23167 .34687 .25365 .35103 .24593 .33858 Mtetra
.493 .691 .956 r
.24593 .33858 .25365 .35103 .27584 .35365 .26824 .34164 Mtetra
.518 .714 .961 r
.26824 .34164 .27584 .35365 .2982 .35519 .29072 .34351 Mtetra
.536 .73 .964 r
.29072 .34351 .2982 .35519 .3207 .35598 .31336 .34453 Mtetra
.548 .742 .966 r
.31336 .34453 .3207 .35598 .34332 .35619 .33614 .34492 Mtetra
.557 .751 .968 r
.33614 .34492 .34332 .35619 .36607 .35597 .35904 .34483 Mtetra
.564 .758 .969 r
.35904 .34483 .36607 .35597 .38893 .35541 .38206 .34437 Mtetra
.569 .763 .97 r
.38206 .34437 .38893 .35541 .4119 .35459 .40518 .34362 Mtetra
.574 .768 .97 r
.40518 .34362 .4119 .35459 .43496 .35354 .42841 .34263 Mtetra
.577 .771 .971 r
.42841 .34263 .43496 .35354 .45813 .35232 .45175 .34145 Mtetra
.58 .774 .972 r
.45175 .34145 .45813 .35232 .4814 .35095 .47518 .34011 Mtetra
.582 .777 .972 r
.47518 .34011 .4814 .35095 .50477 .34945 .49872 .33863 Mtetra
.584 .779 .972 r
.49872 .33863 .50477 .34945 .52823 .34784 .52236 .33703 Mtetra
.585 .78 .973 r
.52236 .33703 .52823 .34784 .55179 .34614 .54609 .33533 Mtetra
.586 .782 .973 r
.54609 .33533 .55179 .34614 .57545 .34436 .56992 .33355 Mtetra
.588 .783 .973 r
.56992 .33355 .57545 .34436 .5992 .34251 .59385 .33169 Mtetra
.588 .784 .973 r
.59385 .33169 .5992 .34251 .62304 .34059 .61787 .32976 Mtetra
.589 .785 .974 r
.61787 .32976 .62304 .34059 .64698 .33861 .64199 .32777 Mtetra
.59 .786 .974 r
.64199 .32777 .64698 .33861 .67102 .33659 .66621 .32573 Mtetra
.591 .787 .974 r
.66621 .32573 .67102 .33659 .69515 .33452 .69053 .32363 Mtetra
.591 .788 .974 r
.69053 .32363 .69515 .33452 .71938 .3324 .71494 .3215 Mtetra
.592 .789 .974 r
.71494 .3215 .71938 .3324 .7437 .33025 .73945 .31932 Mtetra
.73945 .31932 .7437 .33025 .76812 .32806 .76406 .3171 Mtetra
.592 .79 .974 r
.76406 .3171 .76812 .32806 .79264 .32584 .78877 .31485 Mtetra
.593 .79 .974 r
.78877 .31485 .79264 .32584 .81725 .32358 .81358 .31257 Mtetra
.593 .79 .975 r
.81358 .31257 .81725 .32358 .84196 .3213 .83848 .31026 Mtetra
.593 .791 .975 r
.83848 .31026 .84196 .3213 .86677 .31899 .86349 .30791 Mtetra
.86349 .30791 .86677 .31899 .89167 .31665 .88859 .30554 Mtetra
.594 .792 .975 r
.88859 .30554 .89167 .31665 .91668 .31429 .91379 .30315 Mtetra
.91379 .30315 .91668 .31429 .94179 .3119 .9391 .30073 Mtetra
0 0 .458 r
.13287 .24047 .14084 .25932 .16009 .29477 .15214 .27651 Mtetra
0 .255 .762 r
.15214 .27651 .16009 .29477 .18071 .31445 .17269 .29871 Mtetra
.231 .468 .879 r
.17269 .29871 .18071 .31445 .20206 .3263 .19405 .31206 Mtetra
.361 .58 .926 r
.19405 .31206 .20206 .3263 .22385 .33378 .21591 .3205 Mtetra
.434 .644 .946 r
.21591 .3205 .22385 .33378 .24593 .33858 .23809 .32595 Mtetra
.48 .683 .956 r
.23809 .32595 .24593 .33858 .26824 .34164 .26052 .32946 Mtetra
.509 .709 .961 r
.26052 .32946 .26824 .34164 .29072 .34351 .28314 .33165 Mtetra
.529 .726 .964 r
.28314 .33165 .29072 .34351 .31336 .34453 .30592 .33291 Mtetra
.543 .739 .966 r
.30592 .33291 .31336 .34453 .33614 .34492 .32885 .33348 Mtetra
.553 .749 .968 r
.32885 .33348 .33614 .34492 .35904 .34483 .3519 .33352 Mtetra
.561 .756 .969 r
.3519 .33352 .35904 .34483 .38206 .34437 .37507 .33316 Mtetra
.567 .762 .97 r
.37507 .33316 .38206 .34437 .40518 .34362 .39836 .33249 Mtetra
.572 .766 .971 r
.39836 .33249 .40518 .34362 .42841 .34263 .42176 .33155 Mtetra
.575 .77 .971 r
.42176 .33155 .42841 .34263 .45175 .34145 .44526 .33041 Mtetra
.578 .773 .972 r
.44526 .33041 .45175 .34145 .47518 .34011 .46887 .32909 Mtetra
.581 .776 .972 r
.46887 .32909 .47518 .34011 .49872 .33863 .49258 .32763 Mtetra
.583 .778 .972 r
.49258 .32763 .49872 .33863 .52236 .33703 .51639 .32604 Mtetra
.584 .78 .973 r
.51639 .32604 .52236 .33703 .54609 .33533 .5403 .32435 Mtetra
.586 .782 .973 r
.5403 .32435 .54609 .33533 .56992 .33355 .56431 .32256 Mtetra
.587 .783 .973 r
.56431 .32256 .56992 .33355 .59385 .33169 .58841 .32069 Mtetra
.588 .784 .973 r
.58841 .32069 .59385 .33169 .61787 .32976 .61262 .31875 Mtetra
.589 .785 .974 r
.61262 .31875 .61787 .32976 .64199 .32777 .63693 .31675 Mtetra
.59 .786 .974 r
.63693 .31675 .64199 .32777 .66621 .32573 .66133 .31469 Mtetra
.59 .787 .974 r
.66133 .31469 .66621 .32573 .69053 .32363 .68583 .31258 Mtetra
.591 .788 .974 r
.68583 .31258 .69053 .32363 .71494 .3215 .71044 .31042 Mtetra
.71044 .31042 .71494 .3215 .73945 .31932 .73514 .30821 Mtetra
.592 .789 .974 r
.73514 .30821 .73945 .31932 .76406 .3171 .75994 .30597 Mtetra
.75994 .30597 .76406 .3171 .78877 .31485 .78484 .30369 Mtetra
.592 .79 .974 r
.78484 .30369 .78877 .31485 .81358 .31257 .80984 .30138 Mtetra
.593 .79 .975 r
.80984 .30138 .81358 .31257 .83848 .31026 .83494 .29903 Mtetra
.593 .791 .975 r
.83494 .29903 .83848 .31026 .86349 .30791 .86015 .29666 Mtetra
.86015 .29666 .86349 .30791 .88859 .30554 .88545 .29426 Mtetra
.88545 .29426 .88859 .30554 .91379 .30315 .91086 .29183 Mtetra
.594 .792 .975 r
.91086 .29183 .91379 .30315 .9391 .30073 .93637 .28937 Mtetra
.643 .187 0 r
.12419 .22967 .13287 .24047 .15214 .27651 .14409 .25802 Mtetra
0 .183 .715 r
.14409 .25802 .15214 .27651 .17269 .29871 .16455 .28275 Mtetra
.176 .428 .863 r
.16455 .28275 .17269 .29871 .19405 .31206 .18593 .29762 Mtetra
.328 .559 .92 r
.18593 .29762 .19405 .31206 .21591 .3205 .20785 .30702 Mtetra
.414 .631 .944 r
.20785 .30702 .21591 .3205 .23809 .32595 .23014 .31313 Mtetra
.466 .675 .955 r
.23014 .31313 .23809 .32595 .26052 .32946 .25269 .31709 Mtetra
.499 .703 .961 r
.25269 .31709 .26052 .32946 .28314 .33165 .27544 .31962 Mtetra
.522 .722 .965 r
.27544 .31962 .28314 .33165 .30592 .33291 .29836 .32111 Mtetra
.538 .736 .967 r
.29836 .32111 .30592 .33291 .32885 .33348 .32144 .32185 Mtetra
.549 .746 .968 r
.32144 .32185 .32885 .33348 .3519 .33352 .34465 .32203 Mtetra
.558 .754 .969 r
.34465 .32203 .3519 .33352 .37507 .33316 .36798 .32178 Mtetra
.564 .76 .97 r
.36798 .32178 .37507 .33316 .39836 .33249 .39144 .32117 Mtetra
.569 .765 .971 r
.39144 .32117 .39836 .33249 .42176 .33155 .415 .3203 Mtetra
.573 .769 .971 r
.415 .3203 .42176 .33155 .44526 .33041 .43867 .31919 Mtetra
.577 .772 .972 r
.43867 .31919 .44526 .33041 .46887 .32909 .46245 .3179 Mtetra
.579 .775 .972 r
.46245 .3179 .46887 .32909 .49258 .32763 .48634 .31646 Mtetra
.582 .777 .972 r
.48634 .31646 .49258 .32763 .51639 .32604 .51032 .31488 Mtetra
.583 .779 .973 r
.51032 .31488 .51639 .32604 .5403 .32435 .53441 .31319 Mtetra
.585 .781 .973 r
.53441 .31319 .5403 .32435 .56431 .32256 .5586 .3114 Mtetra
.586 .782 .973 r
.5586 .3114 .56431 .32256 .58841 .32069 .58289 .30952 Mtetra
.587 .784 .973 r
.58289 .30952 .58841 .32069 .61262 .31875 .60728 .30757 Mtetra
.588 .785 .974 r
.60728 .30757 .61262 .31875 .63693 .31675 .63178 .30555 Mtetra
.589 .786 .974 r
.63178 .30555 .63693 .31675 .66133 .31469 .65637 .30347 Mtetra
.59 .787 .974 r
.65637 .30347 .66133 .31469 .68583 .31258 .68106 .30134 Mtetra
.68106 .30134 .68583 .31258 .71044 .31042 .70586 .29915 Mtetra
.591 .788 .974 r
.70586 .29915 .71044 .31042 .73514 .30821 .73075 .29693 Mtetra
.591 .789 .974 r
.73075 .29693 .73514 .30821 .75994 .30597 .75575 .29466 Mtetra
.592 .789 .974 r
.75575 .29466 .75994 .30597 .78484 .30369 .78085 .29235 Mtetra
.592 .79 .974 r
.78085 .29235 .78484 .30369 .80984 .30138 .80605 .29 Mtetra
.592 .79 .975 r
.80605 .29 .80984 .30138 .83494 .29903 .83135 .28763 Mtetra
.593 .791 .975 r
.83135 .28763 .83494 .29903 .86015 .29666 .85676 .28522 Mtetra
.85676 .28522 .86015 .29666 .88545 .29426 .88227 .28278 Mtetra
.88227 .28278 .88545 .29426 .91086 .29183 .90788 .28031 Mtetra
.593 .792 .975 r
.90788 .28031 .91086 .29183 .93637 .28937 .9336 .27782 Mtetra
0 .077 .602 r
.11538 .21869 .12419 .22967 .14409 .25802 .13594 .23929 Mtetra
0 .109 .663 r
.13594 .23929 .14409 .25802 .16455 .28275 .1563 .26658 Mtetra
.118 .387 .843 r
.1563 .26658 .16455 .28275 .18593 .29762 .17769 .28297 Mtetra
.294 .536 .913 r
.17769 .28297 .18593 .29762 .20785 .30702 .19968 .29335 Mtetra
.392 .618 .942 r
.19968 .29335 .20785 .30702 .23014 .31313 .22206 .30011 Mtetra
.452 .666 .954 r
.22206 .30011 .23014 .31313 .25269 .31709 .24473 .30454 Mtetra
.489 .697 .961 r
.24473 .30454 .25269 .31709 .27544 .31962 .26762 .30739 Mtetra
.515 .718 .965 r
.26762 .30739 .27544 .31962 .29836 .32111 .29069 .30913 Mtetra
.532 .733 .967 r
.29069 .30913 .29836 .32111 .32144 .32185 .31392 .31005 Mtetra
.545 .744 .968 r
.31392 .31005 .32144 .32185 .34465 .32203 .33728 .31037 Mtetra
.554 .752 .97 r
.33728 .31037 .34465 .32203 .36798 .32178 .36078 .31021 Mtetra
.562 .759 .97 r
.36078 .31021 .36798 .32178 .39144 .32117 .3844 .30968 Mtetra
.567 .764 .971 r
.3844 .30968 .39144 .32117 .415 .3203 .40813 .30886 Mtetra
.572 .768 .971 r
.40813 .30886 .415 .3203 .43867 .31919 .43198 .3078 Mtetra
.575 .772 .972 r
.43198 .3078 .43867 .31919 .46245 .3179 .45593 .30653 Mtetra
.578 .774 .972 r
.45593 .30653 .46245 .3179 .48634 .31646 .47999 .30511 Mtetra
.58 .777 .973 r
.47999 .30511 .48634 .31646 .51032 .31488 .50416 .30354 Mtetra
.582 .779 .973 r
.50416 .30354 .51032 .31488 .53441 .31319 .52843 .30185 Mtetra
.584 .781 .973 r
.52843 .30185 .53441 .31319 .5586 .3114 .5528 .30005 Mtetra
.585 .782 .973 r
.5528 .30005 .5586 .3114 .58289 .30952 .57728 .29817 Mtetra
.587 .783 .973 r
.57728 .29817 .58289 .30952 .60728 .30757 .60186 .2962 Mtetra
.588 .785 .974 r
.60186 .2962 .60728 .30757 .63178 .30555 .62654 .29417 Mtetra
.589 .786 .974 r
.62654 .29417 .63178 .30555 .65637 .30347 .65133 .29207 Mtetra
.65133 .29207 .65637 .30347 .68106 .30134 .67621 .28991 Mtetra
.59 .787 .974 r
.67621 .28991 .68106 .30134 .70586 .29915 .7012 .28771 Mtetra
.591 .788 .974 r
.7012 .28771 .70586 .29915 .73075 .29693 .72629 .28545 Mtetra
.591 .789 .974 r
.72629 .28545 .73075 .29693 .75575 .29466 .75149 .28315 Mtetra
.592 .789 .974 r
.75149 .28315 .75575 .29466 .78085 .29235 .77679 .28081 Mtetra
.592 .79 .974 r
.77679 .28081 .78085 .29235 .80605 .29 .80219 .27844 Mtetra
.592 .79 .975 r
.80219 .27844 .80605 .29 .83135 .28763 .8277 .27603 Mtetra
.593 .79 .975 r
.8277 .27603 .83135 .28763 .85676 .28522 .85331 .27359 Mtetra
.593 .791 .975 r
.85331 .27359 .85676 .28522 .88227 .28278 .87902 .27111 Mtetra
.87902 .27111 .88227 .28278 .90788 .28031 .90485 .26861 Mtetra
.593 .792 .975 r
.90485 .26861 .90788 .28031 .9336 .27782 .93077 .26608 Mtetra
.003 .403 .852 r
.10642 .20755 .11538 .21869 .13594 .23929 .12768 .22032 Mtetra
0 .036 .606 r
.12768 .22032 .13594 .23929 .1563 .26658 .14794 .25018 Mtetra
.059 .343 .819 r
.14794 .25018 .1563 .26658 .17769 .28297 .16933 .26811 Mtetra
.258 .512 .905 r
.16933 .26811 .17769 .28297 .19968 .29335 .19139 .27948 Mtetra
.371 .604 .939 r
.19139 .27948 .19968 .29335 .22206 .30011 .21387 .2869 Mtetra
.437 .658 .953 r
.21387 .2869 .22206 .30011 .24473 .30454 .23666 .29179 Mtetra
.479 .691 .961 r
.23666 .29179 .24473 .30454 .26762 .30739 .25968 .29498 Mtetra
.507 .714 .965 r
.25968 .29498 .26762 .30739 .29069 .30913 .2829 .29696 Mtetra
.527 .73 .967 r
.2829 .29696 .29069 .30913 .31392 .31005 .30628 .29806 Mtetra
.541 .742 .969 r
.30628 .29806 .31392 .31005 .33728 .31037 .3298 .29851 Mtetra
.551 .751 .97 r
.3298 .29851 .33728 .31037 .36078 .31021 .35346 .29846 Mtetra
.559 .757 .971 r
.35346 .29846 .36078 .31021 .3844 .30968 .37725 .29801 Mtetra
.565 .763 .971 r
.37725 .29801 .3844 .30968 .40813 .30886 .40116 .29724 Mtetra
.57 .767 .972 r
.40116 .29724 .40813 .30886 .43198 .3078 .42518 .29622 Mtetra
.574 .771 .972 r
.42518 .29622 .43198 .3078 .45593 .30653 .44931 .29498 Mtetra
.577 .774 .972 r
.44931 .29498 .45593 .30653 .47999 .30511 .47355 .29357 Mtetra
.579 .776 .973 r
.47355 .29357 .47999 .30511 .50416 .30354 .4979 .29201 Mtetra
.582 .778 .973 r
.4979 .29201 .50416 .30354 .52843 .30185 .52235 .29032 Mtetra
.583 .78 .973 r
.52235 .29032 .52843 .30185 .5528 .30005 .54691 .28852 Mtetra
.585 .782 .973 r
.54691 .28852 .5528 .30005 .57728 .29817 .57158 .28663 Mtetra
.586 .783 .974 r
.57158 .28663 .57728 .29817 .60186 .2962 .59635 .28465 Mtetra
.587 .784 .974 r
.59635 .28465 .60186 .2962 .62654 .29417 .62122 .2826 Mtetra
.588 .785 .974 r
.62122 .2826 .62654 .29417 .65133 .29207 .6462 .28048 Mtetra
.589 .786 .974 r
.6462 .28048 .65133 .29207 .67621 .28991 .67128 .2783 Mtetra
.59 .787 .974 r
.67128 .2783 .67621 .28991 .7012 .28771 .69647 .27607 Mtetra
.59 .788 .974 r
.69647 .27607 .7012 .28771 .72629 .28545 .72176 .27379 Mtetra
.591 .788 .974 r
.72176 .27379 .72629 .28545 .75149 .28315 .74716 .27146 Mtetra
.591 .789 .974 r
.74716 .27146 .75149 .28315 .77679 .28081 .77266 .26909 Mtetra
.592 .789 .975 r
.77266 .26909 .77679 .28081 .80219 .27844 .79827 .26668 Mtetra
.592 .79 .975 r
.79827 .26668 .80219 .27844 .8277 .27603 .82398 .26423 Mtetra
.82398 .26423 .8277 .27603 .85331 .27359 .8498 .26176 Mtetra
.593 .791 .975 r
.8498 .26176 .85331 .27359 .87902 .27111 .87573 .25925 Mtetra
.87573 .25925 .87902 .27111 .90485 .26861 .90176 .25671 Mtetra
.90176 .25671 .90485 .26861 .93077 .26608 .9279 .25414 Mtetra
.378 .66 .968 r
.09733 .19623 .10642 .20755 .12768 .22032 .11932 .2011 Mtetra
0 0 .547 r
.11932 .2011 .12768 .22032 .14794 .25018 .13946 .23355 Mtetra
0 .297 .793 r
.13946 .23355 .14794 .25018 .16933 .26811 .16086 .25304 Mtetra
.222 .487 .895 r
.16086 .25304 .16933 .26811 .19139 .27948 .18297 .2654 Mtetra
.348 .59 .935 r
.18297 .2654 .19139 .27948 .21387 .2869 .20555 .27349 Mtetra
.422 .649 .952 r
.20555 .27349 .21387 .2869 .23666 .29179 .22846 .27885 Mtetra
.469 .685 .961 r
.22846 .27885 .23666 .29179 .25968 .29498 .25162 .28237 Mtetra
.5 .71 .965 r
.25162 .28237 .25968 .29498 .2829 .29696 .27498 .2846 Mtetra
.521 .727 .967 r
.27498 .2846 .2829 .29696 .30628 .29806 .29851 .28589 Mtetra
.536 .739 .969 r
.29851 .28589 .30628 .29806 .3298 .29851 .3222 .28647 Mtetra
.548 .749 .97 r
.3222 .28647 .3298 .29851 .35346 .29846 .34603 .28652 Mtetra
.556 .756 .971 r
.34603 .28652 .35346 .29846 .37725 .29801 .36999 .28614 Mtetra
.563 .762 .971 r
.36999 .28614 .37725 .29801 .40116 .29724 .39407 .28543 Mtetra
.568 .766 .972 r
.39407 .28543 .40116 .29724 .42518 .29622 .41826 .28445 Mtetra
.572 .77 .972 r
.41826 .28445 .42518 .29622 .44931 .29498 .44257 .28324 Mtetra
.576 .773 .972 r
.44257 .28324 .44931 .29498 .47355 .29357 .467 .28185 Mtetra
.578 .776 .973 r
.467 .28185 .47355 .29357 .4979 .29201 .49153 .28029 Mtetra
.581 .778 .973 r
.49153 .28029 .4979 .29201 .52235 .29032 .51617 .27861 Mtetra
.583 .78 .973 r
.51617 .27861 .52235 .29032 .54691 .28852 .54092 .2768 Mtetra
.584 .781 .973 r
.54092 .2768 .54691 .28852 .57158 .28663 .56578 .2749 Mtetra
.585 .783 .974 r
.56578 .2749 .57158 .28663 .59635 .28465 .59074 .27291 Mtetra
.587 .784 .974 r
.59074 .27291 .59635 .28465 .62122 .2826 .61581 .27084 Mtetra
.588 .785 .974 r
.61581 .27084 .62122 .2826 .6462 .28048 .64099 .2687 Mtetra
.588 .786 .974 r
.64099 .2687 .6462 .28048 .67128 .2783 .66627 .26649 Mtetra
.589 .787 .974 r
.66627 .26649 .67128 .2783 .69647 .27607 .69166 .26423 Mtetra
.59 .787 .974 r
.69166 .26423 .69647 .27607 .72176 .27379 .71715 .26192 Mtetra
.59 .788 .974 r
.71715 .26192 .72176 .27379 .74716 .27146 .74275 .25956 Mtetra
.591 .789 .974 r
.74275 .25956 .74716 .27146 .77266 .26909 .76846 .25716 Mtetra
.591 .789 .975 r
.76846 .25716 .77266 .26909 .79827 .26668 .79428 .25472 Mtetra
.592 .79 .975 r
.79428 .25472 .79827 .26668 .82398 .26423 .8202 .25224 Mtetra
.8202 .25224 .82398 .26423 .8498 .26176 .84623 .24973 Mtetra
.592 .791 .975 r
.84623 .24973 .8498 .26176 .87573 .25925 .87237 .24718 Mtetra
.593 .791 .975 r
.87237 .24718 .87573 .25925 .90176 .25671 .89863 .2446 Mtetra
.89863 .2446 .90176 .25671 .9279 .25414 .92499 .24199 Mtetra
.617 .786 .963 r
.0881 .18473 .09733 .19623 .11932 .2011 .11082 .18195 Mtetra
0 0 .485 r
.11082 .18195 .11932 .2011 .13946 .23355 .13087 .2167 Mtetra
0 .25 .763 r
.13087 .2167 .13946 .23355 .16086 .25304 .15225 .23774 Mtetra
.184 .461 .884 r
.15225 .23774 .16086 .25304 .18297 .2654 .17442 .2511 Mtetra
.325 .574 .931 r
.17442 .2511 .18297 .2654 .20555 .27349 .1971 .25987 Mtetra
.407 .639 .951 r
.1971 .25987 .20555 .27349 .22846 .27885 .22013 .2657 Mtetra
.459 .679 .96 r
.22013 .2657 .22846 .27885 .25162 .28237 .24343 .26956 Mtetra
.492 .706 .965 r
.24343 .26956 .25162 .28237 .27498 .2846 .26694 .27204 Mtetra
.516 .724 .967 r
.26694 .27204 .27498 .2846 .29851 .28589 .29063 .27351 Mtetra
.532 .737 .969 r
.29063 .27351 .29851 .28589 .3222 .28647 .31448 .27424 Mtetra
.544 .747 .97 r
.31448 .27424 .3222 .28647 .34603 .28652 .33847 .27438 Mtetra
.554 .754 .971 r
.33847 .27438 .34603 .28652 .36999 .28614 .3626 .27409 Mtetra
.561 .76 .971 r
.3626 .27409 .36999 .28614 .39407 .28543 .38686 .27343 Mtetra
.566 .765 .972 r
.38686 .27343 .39407 .28543 .41826 .28445 .41124 .27249 Mtetra
.571 .769 .972 r
.41124 .27249 .41826 .28445 .44257 .28324 .43573 .27131 Mtetra
.574 .772 .973 r
.43573 .27131 .44257 .28324 .467 .28185 .46034 .26993 Mtetra
.577 .775 .973 r
.46034 .26993 .467 .28185 .49153 .28029 .48506 .26838 Mtetra
.58 .777 .973 r
.48506 .26838 .49153 .28029 .51617 .27861 .50989 .2667 Mtetra
.582 .779 .973 r
.50989 .2667 .51617 .27861 .54092 .2768 .53483 .26489 Mtetra
.583 .781 .973 r
.53483 .26489 .54092 .2768 .56578 .2749 .55988 .26297 Mtetra
.585 .782 .974 r
.55988 .26297 .56578 .2749 .59074 .27291 .58504 .26097 Mtetra
.586 .784 .974 r
.58504 .26097 .59074 .27291 .61581 .27084 .61031 .25888 Mtetra
.587 .785 .974 r
.61031 .25888 .61581 .27084 .64099 .2687 .63569 .25672 Mtetra
.588 .786 .974 r
.63569 .25672 .64099 .2687 .66627 .26649 .66117 .25449 Mtetra
.589 .787 .974 r
.66117 .25449 .66627 .26649 .69166 .26423 .68676 .2522 Mtetra
.59 .787 .974 r
.68676 .2522 .69166 .26423 .71715 .26192 .71246 .24986 Mtetra
.59 .788 .974 r
.71246 .24986 .71715 .26192 .74275 .25956 .73827 .24747 Mtetra
.591 .789 .974 r
.73827 .24747 .74275 .25956 .76846 .25716 .76419 .24503 Mtetra
.591 .789 .975 r
.76419 .24503 .76846 .25716 .79428 .25472 .79022 .24256 Mtetra
.592 .79 .975 r
.79022 .24256 .79428 .25472 .8202 .25224 .81636 .24004 Mtetra
.81636 .24004 .8202 .25224 .84623 .24973 .84261 .23749 Mtetra
.592 .791 .975 r
.84261 .23749 .84623 .24973 .87237 .24718 .86896 .2349 Mtetra
.593 .791 .975 r
.86896 .2349 .87237 .24718 .89863 .2446 .89543 .23228 Mtetra
.89543 .23228 .89863 .2446 .92499 .24199 .92202 .22963 Mtetra
.617 .786 .963 r
.07871 .17305 .0881 .18473 .11082 .18195 .1016 .17022 Mtetra
.634 .181 0 r
.1016 .17022 .11082 .18195 .13087 .2167 .12215 .1996 Mtetra
0 .203 .731 r
.12215 .1996 .13087 .2167 .15225 .23774 .14352 .22222 Mtetra
.145 .433 .871 r
.14352 .22222 .15225 .23774 .17442 .2511 .16575 .23659 Mtetra
.301 .559 .926 r
.16575 .23659 .17442 .2511 .1971 .25987 .18852 .24604 Mtetra
.392 .63 .949 r
.18852 .24604 .1971 .25987 .22013 .2657 .21167 .25235 Mtetra
.448 .673 .959 r
.21167 .25235 .22013 .2657 .24343 .26956 .2351 .25656 Mtetra
.485 .701 .965 r
.2351 .25656 .24343 .26956 .26694 .27204 .25876 .25928 Mtetra
.51 .721 .968 r
.25876 .25928 .26694 .27204 .29063 .27351 .28261 .26094 Mtetra
.528 .735 .969 r
.28261 .26094 .29063 .27351 .31448 .27424 .30663 .2618 Mtetra
.541 .745 .97 r
.30663 .2618 .31448 .27424 .33847 .27438 .3308 .26205 Mtetra
.551 .753 .971 r
.3308 .26205 .33847 .27438 .3626 .27409 .3551 .26183 Mtetra
.559 .759 .972 r
.3551 .26183 .3626 .27409 .38686 .27343 .37953 .26123 Mtetra
.564 .764 .972 r
.37953 .26123 .38686 .27343 .41124 .27249 .40409 .26033 Mtetra
.569 .768 .972 r
.40409 .26033 .41124 .27249 .43573 .27131 .42877 .25917 Mtetra
.573 .772 .973 r
.42877 .25917 .43573 .27131 .46034 .26993 .45357 .25781 Mtetra
.576 .774 .973 r
.45357 .25781 .46034 .26993 .48506 .26838 .47848 .25627 Mtetra
.579 .777 .973 r
.47848 .25627 .48506 .26838 .50989 .2667 .50351 .25459 Mtetra
.581 .779 .973 r
.50351 .25459 .50989 .2667 .53483 .26489 .52864 .25277 Mtetra
.583 .78 .974 r
.52864 .25277 .53483 .26489 .55988 .26297 .55389 .25085 Mtetra
.584 .782 .974 r
.55389 .25085 .55988 .26297 .58504 .26097 .57925 .24882 Mtetra
.586 .783 .974 r
.57925 .24882 .58504 .26097 .61031 .25888 .60472 .24671 Mtetra
.587 .784 .974 r
.60472 .24671 .61031 .25888 .63569 .25672 .6303 .24453 Mtetra
.588 .785 .974 r
.6303 .24453 .63569 .25672 .66117 .25449 .65599 .24228 Mtetra
.589 .786 .974 r
.65599 .24228 .66117 .25449 .68676 .2522 .68179 .23996 Mtetra
.589 .787 .974 r
.68179 .23996 .68676 .2522 .71246 .24986 .7077 .23759 Mtetra
.59 .788 .974 r
.7077 .23759 .71246 .24986 .73827 .24747 .73372 .23517 Mtetra
.73372 .23517 .73827 .24747 .76419 .24503 .75985 .2327 Mtetra
.591 .789 .975 r
.75985 .2327 .76419 .24503 .79022 .24256 .78609 .23019 Mtetra
.591 .79 .975 r
.78609 .23019 .79022 .24256 .81636 .24004 .81245 .22763 Mtetra
.592 .79 .975 r
.81245 .22763 .81636 .24004 .84261 .23749 .83892 .22504 Mtetra
.83892 .22504 .84261 .23749 .86896 .2349 .86549 .22241 Mtetra
.592 .791 .975 r
.86549 .22241 .86896 .2349 .89543 .23228 .89219 .21975 Mtetra
.593 .791 .975 r
.89219 .21975 .89543 .23228 .92202 .22963 .91899 .21706 Mtetra
.617 .786 .963 r
.06918 .16119 .07871 .17305 .1016 .17022 .09223 .15831 Mtetra
0 0 .52 r
.09223 .15831 .1016 .17022 .12215 .1996 .1133 .18226 Mtetra
0 .155 .696 r
.1133 .18226 .12215 .1996 .14352 .22222 .13466 .20647 Mtetra
.106 .404 .856 r
.13466 .20647 .14352 .22222 .16575 .23659 .15694 .22186 Mtetra
.276 .542 .921 r
.15694 .22186 .16575 .23659 .18852 .24604 .17981 .232 Mtetra
.376 .62 .947 r
.17981 .232 .18852 .24604 .21167 .25235 .20308 .23879 Mtetra
.437 .666 .959 r
.20308 .23879 .21167 .25235 .2351 .25656 .22665 .24334 Mtetra
.477 .697 .964 r
.22665 .24334 .2351 .25656 .25876 .25928 .25046 .24632 Mtetra
.504 .717 .968 r
.25046 .24632 .25876 .25928 .28261 .26094 .27447 .24816 Mtetra
.524 .732 .969 r
.27447 .24816 .28261 .26094 .30663 .2618 .29865 .24916 Mtetra
.538 .743 .97 r
.29865 .24916 .30663 .2618 .3308 .26205 .32299 .24952 Mtetra
.548 .751 .971 r
.32299 .24952 .3308 .26205 .3551 .26183 .34747 .24938 Mtetra
.556 .758 .972 r
.34747 .24938 .3551 .26183 .37953 .26123 .37209 .24883 Mtetra
.563 .763 .972 r
.37209 .24883 .37953 .26123 .40409 .26033 .39683 .24797 Mtetra
.568 .767 .973 r
.39683 .24797 .40409 .26033 .42877 .25917 .4217 .24684 Mtetra
.572 .771 .973 r
.4217 .24684 .42877 .25917 .45357 .25781 .44669 .24549 Mtetra
.575 .774 .973 r
.44669 .24549 .45357 .25781 .47848 .25627 .47179 .24396 Mtetra
.578 .776 .973 r
.47179 .24396 .47848 .25627 .50351 .25459 .49701 .24227 Mtetra
.58 .778 .973 r
.49701 .24227 .50351 .25459 .52864 .25277 .52235 .24045 Mtetra
.582 .78 .974 r
.52235 .24045 .52864 .25277 .55389 .25085 .54779 .23851 Mtetra
.584 .782 .974 r
.54779 .23851 .55389 .25085 .57925 .24882 .57336 .23647 Mtetra
.585 .783 .974 r
.57336 .23647 .57925 .24882 .60472 .24671 .59903 .23434 Mtetra
.586 .784 .974 r
.59903 .23434 .60472 .24671 .6303 .24453 .62482 .23214 Mtetra
.587 .785 .974 r
.62482 .23214 .6303 .24453 .65599 .24228 .65071 .22986 Mtetra
.588 .786 .974 r
.65071 .22986 .65599 .24228 .68179 .23996 .67672 .22751 Mtetra
.589 .787 .974 r
.67672 .22751 .68179 .23996 .7077 .23759 .70285 .22511 Mtetra
.59 .788 .974 r
.70285 .22511 .7077 .23759 .73372 .23517 .72908 .22265 Mtetra
.72908 .22265 .73372 .23517 .75985 .2327 .75543 .22015 Mtetra
.591 .789 .975 r
.75543 .22015 .75985 .2327 .78609 .23019 .78189 .2176 Mtetra
.78189 .2176 .78609 .23019 .81245 .22763 .80847 .21501 Mtetra
.592 .79 .975 r
.80847 .21501 .81245 .22763 .83892 .22504 .83516 .21237 Mtetra
.83516 .21237 .83892 .22504 .86549 .22241 .86196 .20971 Mtetra
.592 .791 .975 r
.86196 .20971 .86549 .22241 .89219 .21975 .88888 .207 Mtetra
.593 .791 .975 r
.88888 .207 .89219 .21975 .91899 .21706 .91592 .20427 Mtetra
.617 .786 .963 r
.05949 .14913 .06918 .16119 .09223 .15831 .08271 .1462 Mtetra
0 .195 .703 r
.08271 .1462 .09223 .15831 .1133 .18226 .10433 .16467 Mtetra
0 .107 .66 r
.10433 .16467 .1133 .18226 .13466 .20647 .12567 .19048 Mtetra
.066 .375 .84 r
.12567 .19048 .13466 .20647 .15694 .22186 .148 .2069 Mtetra
.251 .525 .914 r
.148 .2069 .15694 .22186 .17981 .232 .17096 .21773 Mtetra
.36 .609 .944 r
.17096 .21773 .17981 .232 .20308 .23879 .19435 .22501 Mtetra
.426 .66 .958 r
.19435 .22501 .20308 .23879 .22665 .24334 .21806 .22991 Mtetra
.469 .692 .964 r
.21806 .22991 .22665 .24334 .25046 .24632 .24202 .23314 Mtetra
.498 .714 .968 r
.24202 .23314 .25046 .24632 .27447 .24816 .26619 .23518 Mtetra
.519 .73 .969 r
.26619 .23518 .27447 .24816 .29865 .24916 .29055 .23632 Mtetra
.534 .741 .971 r
.29055 .23632 .29865 .24916 .32299 .24952 .31506 .23678 Mtetra
.545 .75 .971 r
.31506 .23678 .32299 .24952 .34747 .24938 .33972 .23671 Mtetra
.554 .757 .972 r
.33972 .23671 .34747 .24938 .37209 .24883 .36452 .23622 Mtetra
.561 .762 .972 r
.36452 .23622 .37209 .24883 .39683 .24797 .38945 .2354 Mtetra
.566 .767 .973 r
.38945 .2354 .39683 .24797 .4217 .24684 .41451 .2343 Mtetra
.571 .77 .973 r
.41451 .2343 .4217 .24684 .44669 .24549 .43969 .23296 Mtetra
.574 .773 .973 r
.43969 .23296 .44669 .24549 .47179 .24396 .46499 .23144 Mtetra
.577 .776 .973 r
.46499 .23144 .47179 .24396 .49701 .24227 .49041 .22975 Mtetra
.579 .778 .973 r
.49041 .22975 .49701 .24227 .52235 .24045 .51594 .22792 Mtetra
.581 .78 .974 r
.51594 .22792 .52235 .24045 .54779 .23851 .54159 .22597 Mtetra
.583 .781 .974 r
.54159 .22597 .54779 .23851 .57336 .23647 .56736 .22391 Mtetra
.585 .783 .974 r
.56736 .22391 .57336 .23647 .59903 .23434 .59324 .22176 Mtetra
.586 .784 .974 r
.59324 .22176 .59903 .23434 .62482 .23214 .61924 .21953 Mtetra
.587 .785 .974 r
.61924 .21953 .62482 .23214 .65071 .22986 .64535 .21722 Mtetra
.588 .786 .974 r
.64535 .21722 .65071 .22986 .67672 .22751 .67157 .21485 Mtetra
.589 .787 .974 r
.67157 .21485 .67672 .22751 .70285 .22511 .69791 .21241 Mtetra
.69791 .21241 .70285 .22511 .72908 .22265 .72437 .20992 Mtetra
.59 .788 .975 r
.72437 .20992 .72908 .22265 .75543 .22015 .75094 .20738 Mtetra
.59 .789 .975 r
.75094 .20738 .75543 .22015 .78189 .2176 .77762 .20479 Mtetra
.591 .789 .975 r
.77762 .20479 .78189 .2176 .80847 .21501 .80442 .20216 Mtetra
.591 .79 .975 r
.80442 .20216 .80847 .21501 .83516 .21237 .83134 .19949 Mtetra
.592 .79 .975 r
.83134 .19949 .83516 .21237 .86196 .20971 .85837 .19677 Mtetra
.592 .791 .975 r
.85837 .19677 .86196 .20971 .88888 .207 .88552 .19403 Mtetra
.88552 .19403 .88888 .207 .91592 .20427 .91279 .19125 Mtetra
.617 .786 .963 r
.04964 .13687 .05949 .14913 .08271 .1462 .07304 .1339 Mtetra
.021 .414 .86 r
.07304 .1339 .08271 .1462 .10433 .16467 .09524 .14683 Mtetra
0 .06 .622 r
.09524 .14683 .10433 .16467 .12567 .19048 .11654 .17425 Mtetra
.026 .344 .823 r
.11654 .17425 .12567 .19048 .148 .2069 .13892 .19171 Mtetra
.226 .507 .907 r
.13892 .19171 .148 .2069 .17096 .21773 .16197 .20324 Mtetra
.343 .599 .942 r
.16197 .20324 .17096 .21773 .19435 .22501 .18548 .21101 Mtetra
.415 .653 .957 r
.18548 .21101 .19435 .22501 .21806 .22991 .20933 .21626 Mtetra
.461 .687 .964 r
.20933 .21626 .21806 .22991 .24202 .23314 .23345 .21975 Mtetra
.493 .711 .968 r
.23345 .21975 .24202 .23314 .26619 .23518 .25778 .22198 Mtetra
.515 .727 .97 r
.25778 .22198 .26619 .23518 .29055 .23632 .2823 .22326 Mtetra
.531 .739 .971 r
.2823 .22326 .29055 .23632 .31506 .23678 .30699 .22383 Mtetra
.543 .748 .972 r
.30699 .22383 .31506 .23678 .33972 .23671 .33183 .22383 Mtetra
.552 .756 .972 r
.33183 .22383 .33972 .23671 .36452 .23622 .35682 .2234 Mtetra
.559 .761 .972 r
.35682 .2234 .36452 .23622 .38945 .2354 .38194 .22262 Mtetra
.565 .766 .973 r
.38194 .22262 .38945 .2354 .41451 .2343 .40719 .22154 Mtetra
.569 .769 .973 r
.40719 .22154 .41451 .2343 .43969 .23296 .43257 .22022 Mtetra
.573 .773 .973 r
.43257 .22022 .43969 .23296 .46499 .23144 .45807 .2187 Mtetra
.576 .775 .973 r
.45807 .2187 .46499 .23144 .49041 .22975 .48369 .21701 Mtetra
.579 .777 .974 r
.48369 .21701 .49041 .22975 .51594 .22792 .50943 .21517 Mtetra
.581 .779 .974 r
.50943 .21517 .51594 .22792 .54159 .22597 .53529 .21321 Mtetra
.582 .781 .974 r
.53529 .21321 .54159 .22597 .56736 .22391 .56126 .21113 Mtetra
.584 .782 .974 r
.56126 .21113 .56736 .22391 .59324 .22176 .58736 .20896 Mtetra
.585 .784 .974 r
.58736 .20896 .59324 .22176 .61924 .21953 .61357 .2067 Mtetra
.586 .785 .974 r
.61357 .2067 .61924 .21953 .64535 .21722 .63989 .20436 Mtetra
.587 .786 .974 r
.63989 .20436 .64535 .21722 .67157 .21485 .66633 .20196 Mtetra
.588 .786 .974 r
.66633 .20196 .67157 .21485 .69791 .21241 .69289 .19949 Mtetra
.589 .787 .974 r
.69289 .19949 .69791 .21241 .72437 .20992 .71957 .19696 Mtetra
.59 .788 .975 r
.71957 .19696 .72437 .20992 .75094 .20738 .74636 .19438 Mtetra
.59 .789 .975 r
.74636 .19438 .75094 .20738 .77762 .20479 .77327 .19175 Mtetra
.591 .789 .975 r
.77327 .19175 .77762 .20479 .80442 .20216 .8003 .18908 Mtetra
.591 .79 .975 r
.8003 .18908 .80442 .20216 .83134 .19949 .82745 .18637 Mtetra
.592 .79 .975 r
.82745 .18637 .83134 .19949 .85837 .19677 .85472 .18361 Mtetra
.85472 .18361 .85837 .19677 .88552 .19403 .8821 .18082 Mtetra
.592 .791 .975 r
.8821 .18082 .88552 .19403 .91279 .19125 .90961 .178 Mtetra
.617 .786 .963 r
.03963 .12441 .04964 .13687 .07304 .1339 .0632 .12139 Mtetra
.282 .598 .95 r
.0632 .12139 .07304 .1339 .09524 .14683 .086 .12873 Mtetra
0 .014 .583 r
.086 .12873 .09524 .14683 .11654 .17425 .10728 .15777 Mtetra
0 .313 .804 r
.10728 .15777 .11654 .17425 .13892 .19171 .1297 .17628 Mtetra
.2 .489 .9 r
.1297 .17628 .13892 .19171 .16197 .20324 .15284 .18852 Mtetra
.326 .588 .939 r
.15284 .18852 .16197 .20324 .18548 .21101 .17647 .19679 Mtetra
.404 .646 .956 r
.17647 .19679 .18548 .21101 .20933 .21626 .20046 .20239 Mtetra
.453 .683 .963 r
.20046 .20239 .20933 .21626 .23345 .21975 .22473 .20614 Mtetra
.487 .707 .967 r
.22473 .20614 .23345 .21975 .25778 .22198 .24923 .20856 Mtetra
.51 .725 .97 r
.24923 .20856 .25778 .22198 .2823 .22326 .27392 .20998 Mtetra
.527 .737 .971 r
.27392 .20998 .2823 .22326 .30699 .22383 .29879 .21065 Mtetra
.54 .747 .972 r
.29879 .21065 .30699 .22383 .33183 .22383 .32382 .21074 Mtetra
.55 .754 .972 r
.32382 .21074 .33183 .22383 .35682 .2234 .34899 .21036 Mtetra
.557 .76 .973 r
.34899 .21036 .35682 .2234 .38194 .22262 .3743 .20962 Mtetra
.563 .765 .973 r
.3743 .20962 .38194 .22262 .40719 .22154 .39975 .20856 Mtetra
.568 .769 .973 r
.39975 .20856 .40719 .22154 .43257 .22022 .42533 .20726 Mtetra
.572 .772 .973 r
.42533 .20726 .43257 .22022 .45807 .2187 .45103 .20574 Mtetra
.575 .775 .973 r
.45103 .20574 .45807 .2187 .48369 .21701 .47685 .20405 Mtetra
.578 .777 .974 r
.47685 .20405 .48369 .21701 .50943 .21517 .5028 .2022 Mtetra
.58 .779 .974 r
.5028 .2022 .50943 .21517 .53529 .21321 .52887 .20022 Mtetra
.582 .781 .974 r
.52887 .20022 .53529 .21321 .56126 .21113 .55506 .19813 Mtetra
.583 .782 .974 r
.55506 .19813 .56126 .21113 .58736 .20896 .58137 .19593 Mtetra
.585 .783 .974 r
.58137 .19593 .58736 .20896 .61357 .2067 .60779 .19365 Mtetra
.586 .784 .974 r
.60779 .19365 .61357 .2067 .63989 .20436 .63434 .19128 Mtetra
.587 .785 .974 r
.63434 .19128 .63989 .20436 .66633 .20196 .661 .18884 Mtetra
.588 .786 .974 r
.661 .18884 .66633 .20196 .69289 .19949 .68778 .18634 Mtetra
.589 .787 .974 r
.68778 .18634 .69289 .19949 .71957 .19696 .71469 .18377 Mtetra
.589 .788 .975 r
.71469 .18377 .71957 .19696 .74636 .19438 .74171 .18116 Mtetra
.59 .788 .975 r
.74171 .18116 .74636 .19438 .77327 .19175 .76885 .17849 Mtetra
.591 .789 .975 r
.76885 .17849 .77327 .19175 .8003 .18908 .79611 .17577 Mtetra
.79611 .17577 .8003 .18908 .82745 .18637 .82349 .17301 Mtetra
.591 .79 .975 r
.82349 .17301 .82745 .18637 .85472 .18361 .85099 .17021 Mtetra
.592 .79 .975 r
.85099 .17021 .85472 .18361 .8821 .18082 .87862 .16738 Mtetra
.592 .791 .975 r
.87862 .16738 .8821 .18082 .90961 .178 .90636 .1645 Mtetra
.617 .786 .963 r
.02946 .11175 .03963 .12441 .0632 .12139 .0532 .10868 Mtetra
.49 .723 .975 r
.0532 .10868 .0632 .12139 .086 .12873 .07664 .11036 Mtetra
0 0 .544 r
.07664 .11036 .086 .12873 .10728 .15777 .09787 .14104 Mtetra
0 .282 .784 r
.09787 .14104 .10728 .15777 .1297 .17628 .12033 .16061 Mtetra
.173 .47 .891 r
.12033 .16061 .1297 .17628 .15284 .18852 .14356 .17356 Mtetra
.309 .576 .935 r
.14356 .17356 .15284 .18852 .17647 .19679 .16731 .18233 Mtetra
.392 .639 .954 r
.16731 .18233 .17647 .19679 .20046 .20239 .19144 .18829 Mtetra
.445 .678 .963 r
.19144 .18829 .20046 .20239 .22473 .20614 .21586 .1923 Mtetra
.481 .704 .967 r
.21586 .1923 .22473 .20614 .24923 .20856 .24053 .19491 Mtetra
.506 .722 .97 r
.24053 .19491 .24923 .20856 .27392 .20998 .2654 .19648 Mtetra
.524 .735 .971 r
.2654 .19648 .27392 .20998 .29879 .21065 .29045 .19726 Mtetra
.537 .745 .972 r
.29045 .19726 .29879 .21065 .32382 .21074 .31566 .19742 Mtetra
.547 .753 .972 r
.31566 .19742 .32382 .21074 .34899 .21036 .34103 .1971 Mtetra
.555 .759 .973 r
.34103 .1971 .34899 .21036 .3743 .20962 .36654 .19639 Mtetra
.562 .764 .973 r
.36654 .19639 .3743 .20962 .39975 .20856 .39218 .19536 Mtetra
.567 .768 .973 r
.39218 .19536 .39975 .20856 .42533 .20726 .41796 .19407 Mtetra
.571 .771 .973 r
.41796 .19407 .42533 .20726 .45103 .20574 .44387 .19256 Mtetra
.574 .774 .974 r
.44387 .19256 .45103 .20574 .47685 .20405 .4699 .19086 Mtetra
.577 .776 .974 r
.4699 .19086 .47685 .20405 .5028 .2022 .49606 .18901 Mtetra
.579 .778 .974 r
.49606 .18901 .5028 .2022 .52887 .20022 .52234 .18701 Mtetra
.581 .78 .974 r
.52234 .18701 .52887 .20022 .55506 .19813 .54874 .1849 Mtetra
.583 .782 .974 r
.54874 .1849 .55506 .19813 .58137 .19593 .57527 .18268 Mtetra
.584 .783 .974 r
.57527 .18268 .58137 .19593 .60779 .19365 .60192 .18036 Mtetra
.586 .784 .974 r
.60192 .18036 .60779 .19365 .63434 .19128 .62868 .17797 Mtetra
.587 .785 .974 r
.62868 .17797 .63434 .19128 .661 .18884 .65557 .17549 Mtetra
.588 .786 .974 r
.65557 .17549 .661 .18884 .68778 .18634 .68258 .17295 Mtetra
.588 .787 .974 r
.68258 .17295 .68778 .18634 .71469 .18377 .70971 .17035 Mtetra
.589 .788 .975 r
.70971 .17035 .71469 .18377 .74171 .18116 .73697 .16769 Mtetra
.59 .788 .975 r
.73697 .16769 .74171 .18116 .76885 .17849 .76434 .16498 Mtetra
.59 .789 .975 r
.76434 .16498 .76885 .17849 .79611 .17577 .79184 .16222 Mtetra
.591 .789 .975 r
.79184 .16222 .79611 .17577 .82349 .17301 .81946 .15942 Mtetra
.591 .79 .975 r
.81946 .15942 .82349 .17301 .85099 .17021 .8472 .15657 Mtetra
.592 .79 .975 r
.8472 .15657 .85099 .17021 .87862 .16738 .87507 .15369 Mtetra
.592 .791 .975 r
.87507 .15369 .87862 .16738 .90636 .1645 .90306 .15076 Mtetra
0 g
.89362 0 m
.98022 .38351 L
s
.98022 .38351 m
1 .65325 L
s
1 .65325 m
.91448 .33294 L
s
.91448 .33294 m
.89362 0 L
s
.02946 .11175 m
0 .4272 L
s
0 .4272 m
.91448 .33294 L
s
.91448 .33294 m
.89362 0 L
s
.89362 0 m
.02946 .11175 L
s
.02946 .11175 m
.89362 0 L
s
gsave
.44797 -0.02478 -65.9056 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(u) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
0 .4272 m
.29069 .70824 L
s
gsave
.15892 .66839 -66.3192 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(p) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{261.5, 185.063},
  ImageMargins->{{30.25, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.095767,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000450000^A000`40O003h00Oogoo1Woo003oOol6
Ool00?moo`Ioo`00ogoo1Woo003oOol6Ool00?moo`Ioo`00PWoo1000Ogoo0021Ool01000Oomoo`00
P7oo0021Ool01000Oomoo`00P7oo0020Ool200000goo00000020Ool00?moo`Ioo`00ogoo1Woo003o
Ool6Ool00?moo`Ioo`00ogoo1Woo003oOol6Ool00?moo`Ioo`00ogoo1Woo003oOol6Ool00?moo`Io
o`00ogoo1Woo003LOol4000UOol00=Aoo`P000=oo`03001oogoo02=oo`00c7oo20002goo00<007oo
Ool08goo0034Ool8000COol2000TOol00;aoo`P001]oo`8002Aoo`00]Goo1`008goo0P0097oo002]
Ool8000ZOol2000TOol00:Eoo`P0039oo`03001oo`0002=oo`00WGoo2000>Woo00<007oo00008goo
002FOol70013Ool2000SOol008ioo`P004Yoo`8002=oo`00QWoo2000DWoo00<007oo00008Woo001n
Ool8001JOol00`00Ool0000ROol007Ioo`P0069oo`03001oo`00029oo`00Kgoo1`00JWoo00<007oo
00008Woo001WOol8001aOol00`00Ool0000ROol005moo`P007Uoo`04001oogoo000QOol005Moo`P0
085oo`04001oogoo000QOol0051oo`L008Uoo`04001oogoo000QOol004Qoo`P0091oo`04001oogoo
000QOol0041oo`P009Qoo`05001oogooOol0000POol003Qoo`P00:1oo`05001oogooOol0000POol0
031oo`P00:Qoo`05001oogooOol0000POol002aoo`@00007Cci;7CkN>]hnoc[N?]h0ZGoo00D007oo
Oomoo`00021oo`00;7oo00H004lNCai?7T/NCah2?]h00c[N?]hngP2YOol01@00Oomoogoo000087oo
000/Ool03000Ool004/MCai;7Dln>]hngS[N?_ljgZQoo`03001oogoo009oo`03001oogoo01eoo`00
;7oo00@007oo001oo`9?7P04Bai?7R9M8Uh28Ud00`0@Oomoo`2VOol01@00Oomoogoo00007goo000/
Ool03P00Oomoo`00Cci;7DlNBae??R9M8UhRGB9n012WOol01@00Oomoogoo00007goo000/Ool01@00
Oomoogoo00000dlN00I;7TlN8UdRGR9M01:WOol01@00Oomoogoo00007goo000[Ool00`00Oomoo`03
Ool02P00Cci;7DlNBad5^`6J8UhRG@0bYWoo00<007ooOol00Woo00<007ooOol077oo000[Ool00`00
Oomoo`04Ool02P00Cai?7TlNBah5V`FJ1I/04@0@YGoo00<007ooOol00Woo00<007ooOol077oo000[
Ool00`00Oomoo`05Ool02P00Cci;7DlNBad5^`6J1I/04@4HY7oo00<007ooOol00Woo00<007ooOol0
77oo000[Ool00`00Oomoo`05Ool00`00Bai?7P02Cah01T/N1I/5VP0b014169Moo`a;7P03001oogoo
009oo`03001oogoo01aoo`00:goo00<007ooOol01Woo00/004/MCci;7DlNBad0eP6J0381>04H095o
o`0BBci77T/oBai;?TLNBcm;7T/nAai;?d/NBci77T/oBai;?P001Goo00<007ooOol06goo000[Ool0
0`00Oomoo`07Ool00`00Bai?7P02Cah01`0?0;D0<`0b0CP1617K08=ooae;7P03001oogoo00=oo`03
001oogoo01]oo`00:goo00<007ooOol027oo00h004/MCci;7DlN00l0eP0A0CT1>1GL4M/Eg17KMGoo
00Q77T/NAai;?dLNBai77T/o0T/N00I77T/oBai;7TLNBcl2Bah05dLNBcm;7T/NAai;?d/NBci77T/o
Bai;?TLNBcm;7T/nAai;?d/NBci77T/o00001Goo00<007ooOol06goo000[Ool00`00Oomoo`09Ool0
0`00Bai?7P02Cah02P0?05@1>@4i0CPEg17K5M`AfbHmJ7oo<d/N00<007ooOol00goo00<007ooOol0
6goo000[Ool00`00Oomoo`09Ool04P00Cai;7DlnBae?7P0?03<1>04i0CPEg17K5M`R?2IM9SdVGEYo
o`0PAai;7TLNBam77T/NAai;7dLNBai77T/oAai;7TLNBcm77T/NAai;?dLNBai77T/oAai;7TLNBcm7
7T/NAai;?`9;7P06Aai;?d/NBai77T/o0T/N01E77T/oBai;7TLNBcm;7T/nAai;?d/NBci77T/oBai;
?TLNBcm;7T/n00001Goo00<007ooOol06goo000[Ool00`00Oomoo`0:Ool00`00Cai;7P03Cah0200?
1ET5F@4i5M`Eo17K5M`39Sd01BIM;WdbORim<Yh0BWoo0T/N00E77T/NBai;7TLN00=;7P03Aai;7T/N
03a;7P03001;7Woo00Aoo`03001oogoo01Yoo`00:goo00<007ooOol02goo01X004lNBae??T/M0100
M@EJ0ET5FQGK6O`EfbIM8S`VGBHm<Yh^OC:N;WdbWSJM>[hfWCJn>Woo03A77T/NA_i;7dLNBai6oT/O
Aai;7TKnBam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBcm77T/N
Aai;?dLNBai77T/oAai;7TLNBcm77T/NAai;?`9;7P06Aai;?d/NBai77T/o0T/N01Q77T/oBai;?TLN
Bcm;7T/nAai;?d/NBci77T/oBai;?TLNBcm;7T/nAai;?`00Bch5Ool00`00Oomoo`0JOol002Yoo`03
001oogoo00eoo`9?7P05Bai?7TlN0100E0031ET011GL5O`Eo2YM0bIM00HbWRim<Wh^OCJn=Yh3=[h0
13Zn>]hj_SkN9Goo0dLN00=6oTLNAah024LN00i;7TLNAai77T/NAai;7TLNBai77T/NAai;7TLN0d/N
00E77T/NBai;7TLN041;7P03001;7Woo00Aoo`03001oogoo01Yoo`00:Woo00<007ooOol03Woo0RjN
00L^WBjNC800UPEI1GX1F@036O`04BHm:UdV?BYM9SdbWRim<YhbOCJn=Ydj_SJM?]hj_CkN>[h00SkN
0652gSkN?]hngT;n?]i2oSkN@_i2gT;n@]i6oT;NA_i2oTKn@_i6oT;nAam2oTLN@_i77dKnAai2oTLO
A_i77TKnBam6oTLNA_i;7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dKnBai6oT/OAai;7TKnBam77T/N
A_i;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/o
Aai;7TLNBcm77T/NAai;?`02Bah01TLNBcm;7T/NAai;?`9;7P06Aai;?d/NBai77T/o0T/N01M77T/o
Bai;?TLNBcm;7T/nAai;?d/NBci77T/oBai;?TLNBcm;7T/n001;?d/N00Aoo`03001oogoo01Yoo`00
:Woo00<007ooOol03Woo00<002jN;Yh00RjN00<0]P2E1GX00PEj0aWl00XVGBYM9UdVGC:M<YhbOC:N
<Ydj_P<f_P04?]hj_S[N>[h5?]h01D;N@_i2gT;n@]h01T;n00A6oT;nA_i2oPQ6oP0:Aai6oTKnA_i7
7TKnAai6oTLNA_h3Aah00dKnAai77P04Aah04T/NAai77TLNBai77T/NAai;7TLNBai77T/NAai;7TLN
Bai77P=;7P05Aai;7T/NBai77P0nBah00`00Bai;7P05Ool00`00Oomoo`0IOol002Yoo`03001oogoo
00moo`08000^WRjN;Ye@X02f09H5F@85NP8Io00B7Q`ZGBYM9UdZOS9m<Yh^OC:N=Ydj_SJM>[hfWCkN
>[dngSZn0SkN0652gSkN?]hngT;n?]i2oSkNA_i2gT;n@]i6oT;nA_i2oTKn@_i77T;nAam2oTLN@_i7
7dKnAai2oTLOA_i77TKnBam6oTLNA_i;7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dKnBai6oT/OAai;
7TKnBam77T/NA_i;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBcm77T/NAai;
?dLNBai77T/oAai;7TLNBcm77T/NAai;?`02Bah01TLNBcm;7T/NAai;?`9;7P0MAai;?d/NBai77T/o
Bai;?TLNBcm;7T/nAai;?d/NBci77T/oBai;?TLNBcm;7T/nAai;?d/N00177P05Ool00`00Oomoo`0I
Ool002Yoo`03001oogoo011oo`81VP8^WP80]P033I/9VPEj008N70036O`ZGBYM00<ZG@06<YdbWS:M
<Yhf_SZn0SJn00Dj_SkN>[hngSZn00DngP05@]i2oT;N@_i2gP06@_h014Kn@_i6oT;n24Kn00Y77TKn
A_i6oTLNA_i77TKnAai6oP=77P04A_i77TLNBah3Aah04T/NAai77TLNBai77T/NAai;7TLNBai77T/N
Aai;7TLNBai77P=;7P05Aai;7T/NBai77P0mBah00`00Baioo`04Ool00`00Oomoo`0IOol002Yoo`03
001oogoo015oo`0=0I/1VP6K00h0e`2f3I/9NPfK7O`N71gl:Wh00RYM00TVGCJN<YdfWS9m>[hf_CZn
=Yd00SZn06LngSZm?]hj_T;N?]i2oSkN@_hngT;n?]i2oT;NA_i2oTKn@]i77T;nA_i2oTLN@_i77T;n
Aam2oTLNA_i77dKnAai6oT/OA_i77TKnBam6oT/NA_i;7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dKn
Bai6oT/OAai;7TKnBam77T/NA_i;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLN
Bcm77T/NAai;?dLNBai77T/oAai;7TLNBcm77T/NAai;?`02Bah01TLNBcm;7T/NAai;?`9;7P0KAai;
?d/NBai77T/oBai;?TLNBcm;7T/nAai;?d/NBci77T/oBai;?TLNBcm;7T/nAah004/N00Eoo`03001o
ogoo01Uoo`00:Woo00<007ooOol04Woo0P6J00D0<`3g0;H0]PfK0089VP0;8Q`N71hL;UdZGBim:Udb
WS:M<YhbW@04>[h6?]h024;N?]hngSkN@_i2gT;n@]h6@_h014Kn@_i6oT;n1TKn00Y77TKnAai6oTLN
A_i77TKnAai6oP=77P03A_i77TLN00A77P0BBai77T/NAai;7TLNBai77T/NAai;7TLNBai77T/NAai;
7TLN0d/N00=77T/NBah0@D/N00<004/NBah017oo00<007ooOol06Goo000ZOol00`00Oomoo`0COol0
0`6K0IX03`020=L05`fJ4K/9NR8m7Q`R?AhL;WhZGBim<YdfWS:M=YhfWCZn=[dj_SJM?]hj_SkN>[d0
0SkN05]2oSkN@_hngT;n?]i2oT;N@_i2gTKn@_i6oT;NAai2oTKn@_i77TKnAai2oTLNA_i77TKnAam6
oTLNA_i;7dKnAai6oT/OA_i;7TKnBam6oT/NA_i;7dKnBai6oT/OA_i;7TKnBam77T/NA_i;7dLNBai6
oT/OAai;7TKnBam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/oAai;7TLNBcm7
7T/NAai;?`02Bah01TLNBcm;7T/NAai;?`9;7P06Aai;?d/NBai77T/o0T/N01Y77T/oBai;?TLNBcm;
7T/nAai;?d/NBci77T/oBai;?TLNBcm;7T/nAai;?d/N00177T/o1Goo00<007ooOol067oo000ZOol0
0`00Oomoo`0COol01P000IX0<P3h0?L0]P8A^`043K/R728L8Qd2;Wd00bYM;WdbW@03=Yh4>[h7?]h0
0d;N?]hngP02@_h014;N@_i2oTKn0d;n00=6oT;nA_h00TKn00=2oTKnA_h014Kn00Y77TKnAai6oTLN
A_i77TKnAai6oP=77P04A_i77TLNBah3Aah03T/NAai;7TLNBai77T/NAai;7TLNBai77T/NAah3Bah0
1DLNBai;7T/NAah0@D/N00<004/NBah01Goo00<007ooOol067oo000ZOol00`00Oomoo`0DOol0NP0b
03<0<P3h0=LA^`fJ4K/R72Hm7Q`R?BiM;Wh^GCJN<YdfWS:M>[hj_C[N>[dj_SZm?]hn_SkN>[e2oSkN
@_hngT;n@]i2oT;N@_i2gTKn@]i6oT;nA_i2oTLN@_i6oT;nAai6oTLN@_i77TKnAai6oTLOA_i;7TKn
Bam6oT/NA_i;7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dLNBai6oT/OAai;7TKnBam77T/NAai;7dLN
Bai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBcm77T/NAai;?dLNBai77T/oAai;7TLN
Bcl2Bah01TLNBcm;7T/NAai;?`9;7P0PAai;?d/NBai77T/oBai;?TLNBcm;7T/nAai;?d/NBci77T/o
Bai;?TLNBcm;7T/nAai;?d/NBci77P00Bai;?PEoo`03001oogoo01Qoo`00:Woo00<007ooOol05Goo
0P0b00@1603h0?LEf`8A^`038S`V?BHm00@^O@04=YhfWCJN=Yh5>[h5?]h014;N?]i2gSkN0d;n00A2
gT;n@_i6oP=2oP03A_i2oTKn0096oP04@_i6oTKnAah3A_h01TLNA_i77TKnAai6oP=77P05A_i77TLN
Aai6oP02Aah04T/NAai77TLNBai77T/NAai;7TLNBai77T/NAai;7TLNBai77P=;7P05Aai;7T/NBai7
7P0oBah00`00Bai;7P05Ool00`00Oomoo`0HOol002Uoo`03001oogoo01Moo`0J05@0<`4H0CTA^aGL
5K/V?B8L9SdR?39n;Ud^OSJM=[hbWCJn=YdngSZm?]hj_CkN?[e2gP<ngP08@_hngT;n?]i2oT;N@_i2
gP92oP1CA_i2gTKn@_i6oT;nAai2oTKn@_i77TKnAai2oTLOA_i77TKnAam6oT/NA_i;7dKnBai6oT/O
A_i;7TKnBam6oT/NA_i;7dKnBai6oT/OAai;7TKnBam77T/NA_i;7dLNBai77T/OAai;7TLNBam77T/N
Aai;7dLNBai77T/OAai;7TLNBam77T/NAai;?dLNBai77T/oAai;7TLNBcm77T/NAai;?`02Bah01TLN
Bcm;7T/NAai;?`9;7P0OAai;?d/NBci77T/oBai;?TLNBcm;7T/nAai;?d/NBci77T/oBai;?TLNBcm;
7T/nAai;?d/N00177T/oBah01Goo00<007ooOol05goo000YOol00`00Oomoo`0GOol01@1B05@0<P4H
0CT00aGK00LZ?B8l9Sd^OC9m;WdbO@02=Yh00cJM=Yhj_P04>[h5?]h3@]h00d;n@]i2oP05@_h014Kn
@_i6oT;n24Kn00I77TKnAai6oTLNA_h3Aah00dKnAai77P04Aah01D/NAai77TLNBah00dLN00I;7TLN
Bai77T/NAah3Bah01DLNBai;7T/NAah0AD/N00@004/NBai;7PEoo`03001oogoo01Moo`0057oo0`00
4Woo00<007ooOol05goo01`03@1d0385FP4H6O`IfaGL9S`ZGBHl:Ud^OC9n;WdbWSJM>[hfWCZn>[dn
gSZm?]hj_CkN?[e2gP<ngP1E@_hngT;n@]i6oT;N@_i2gTKn@_i6oT;nA_i2oTLN@_i77T;nAai6oTLN
A_i77TKnBam6oTLNA_i;7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dKnBai6oT/OAai;7TKnBam77T/N
A_i;7dLNBai6oT/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBcm77T/NAai;?dLNBai77T/o
Aai;7TLNBcl00T/N00I77T/oBai;7TLNBcl2Bah01TLNBcm;7T/NAai;?`9;7P0MAai;?d/NBci77T/o
Bai;?TLNBcm;7T/nAai;?d/NBci77T/oBai;?TLNBcm;7T/nAah004/NBci77P05Ool00`00Oomoo`0G
Ool001Eoo`03001oogoo015oo`03001oogoo01Moo`0;01403P1d0385F@4H6O`IfaWl9SdZ?@029Sd0
3C9m<YhbOC9m=Yhf_SJM=[hj_SkN>[hn_SZn00@ngP04@_i2gT;n@]h6@_h014Kn@_i6oT;n1TKn00Y7
7TKnA_i6oTLNA_i77TKnAai6oP=77P04A_i77TLNBah3Aah03T/NAai;7TLNBai77T/NAai;7TLNBai7
7T/NAah3Bah01DLNBai;7T/NAah0@d/N00<004/NBah00T/N17oo00<007ooOol05goo000COol3000C
Ool00`00Oomoo`0HOol02@0>09H0M0Di1EXIfaWl6M/Io002:Ud02BHl<YhbOC:N<WdbWSJM>[hfW@02
>[h05SkN>[dngSkN@]hngD;N?]i2oSkN@_i2gT;n@]i6oT;NA_i2gTKn@_i6oT;n0TKn04=77T;nAai6
oTLNA_i77TKnAai6oT/NA_i77TKnBam6oT/NA_i;7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dLNBai6
oT/OAai;7TKnBam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/oAai;7TLNBcm7
7T/NAai;?`02Bah01TLNBcm;7T/NAai;?`9;7P06Aai;?d/NBai77T/o0T/N02177T/oBai;7TLNBcm;
7T/nAai;?d/NBci77T/oBai;?TLNBcm;7T/nAai;?d/NBci77T/oBah004LNBcm;7T/n1Goo00<007oo
Ool05Woo000BOol01000Oomoo`004goo00<007ooOol067oo00@04@0>05@=VP85F@037O`Io1WK00@Z
G@8bO@03<YhbOCZn008j_P05=YdngSjn?]hj_P05?]h01D;N@_i2gT;n@]h01T;n0dKn00=2oTKnA_h0
14Kn00Y77TKnA_i6oTLNA_i77TKnAai6oP=77P04A_i77TLNBah3Aah02T/NAai;7TLNBai77T/NAai;
7TLN0d/N00E77T/NBai;7TLN04E;7P03001;7T/N009;7PEoo`03001oogoo01Ioo`004Woo00@007oo
Ool001=oo`03001oogoo01Uoo`0:00d0]P1D3IX9NB8L7O`R71gk;Ud2:Ud03BXl=YhbOCJN<Wdj_SJM
>[hfWCkN>[hngSZm008ngP1G@]hngD;n@]i2oT;N@_i2gTKn@]i6oT;nA_i2oTLN@_i6oT;nAai6oTLN
@_i77TKnAai6oTLNA_i;7TKnBai6oT/NA_i;7dKnBai6oT/OA_i;7TKnBam6oT/NA_i;7dKnBai6oT/O
Aai;7TKnBam77T/NA_i;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBcm77T/N
Aai;?dLNBai77T/o009;7P06Aai;?d/NBai77T/o0T/N00I77T/oBai;7TLNBcl2Bah07TLNBcm;7T/n
Aai;?d/NBci77T/oBai;?TLNBcm;7T/nAai;?d/NBci77T/oBai;?TLN001;7T/nAai;?`Eoo`03001o
ogoo01Ioo`004goo10004Woo00<007ooOol06Goo00H04P3g0;H=NPfJ3GX27O`00ahL7O`^G@02:Ud0
13:M=YdbWCJN1CZn00`ngSjn?]hj_T;N?]i2gSkN@_i2gT;n@]h2@_h01TKn@_i2oT;nA_i2oPY6oP0:
Aai6oTKnA_i77TKnAai6oTLNA_h3Aah014KnAai77T/N0dLN00I;7TLNBai77T/NAah3Bah01DLNBai;
7T/NAah00d/N00=77T/NBah0@D/N00<004/NBah00d/N17oo00<007ooOol05Woo000YOol00`00Oomo
o`0JOol08P0>0?L0]PUj3IX9NBHm7O`R72YM;WdZGBim<WdfWS9m=YhjWCZn>[dj_SZm?]hn_SkN>[e2
oSkN@_hngD;n@]i2oT;N0T;n04]6oT;NA_i2oTKn@_i77T;nA_i2oTLNA_i77T;nBai6oTLNA_i;7TKn
Bai6oT/NA_i;7TKnBai6oT/NA_i;7dKnBai6oT/OAai;7TKnBam77T/NA_i;7dLNBai6oT/OAai;7TKn
Bam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLNBai77T/oAai;7TLNBcl00T/N00I77T/o
Bai;7TLNBcl2Bah01TLNBcm;7T/NAai;?`9;7P0QAai;?d/NBci77T/oBai;?TLNBcm;7T/nAai;?d/N
Bci77T/oBai;?TLNBcm;7T/nAai;?d/N00177T/oBai;?TLN00Aoo`03001oogoo01Ioo`00:Goo00<0
07ooOol06Woo00H04@3h0?LE^aFj3IX38Q`01BHL;Ud^GBiM=Yh00cJM13Zn00<ngSjn?]h00ckN0d;N
00DngT;n@_i2oT;N0092oP04A_i2oTKn@_h8A_h01TLNA_i77TKnAai6oP=77P05A_i77TLNBai6oP02
Aah02T/NAai77TLNBai77T/NAai;7TLN0d/N00E77T/NBai;7TLN00=;7P03Aai;7T/N04A;7P03001;
7T/N009;7PEoo`03001oogoo01Eoo`00:7oo00<007ooOol077oo06`04@3h0?LE^a6J5K/R72Hm8Q`b
OBiM;WdZGCJN<YdfWSJM?[hj_Cjn>[dngSZm?]hn_SkN?]e2oSkN@_hngDKn@]i2oT;NA_i2oTKn@]i6
oT;nA_i2oTLN@_i77TKnAai6oTLNA_i;7TKnAai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/OA_i;
7TKnBam77T/NA_i;7dLNBai6oT/OAai;7TLNBam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/NAai;
?dLNBai77T/oAai;7TLNBcl2Bah01TLNBcm;7T/NAai;?`9;7P06Aai;?d/NBai77T/o0T/N02=77T/o
Bai;7TLNBcm;7T/nAai;?d/NBci77T/oBai;?TLNBcm;7T/nAai;?d/NBci77T/oBai;?TLNBcl004/n
Bai;?d/N00Eoo`03001oogoo01Eoo`00:7oo00<007ooOol077oo00P0M0Ti0?P0maFk5KXZ?BHl0R8L
00DbOBim<WdfWCJN00<fW@@j_PDngPE2gP=2oP05@]i6oTKnA_i2oP06A_h02TLNA_i6oTKnAai6oTLN
A_i77TKn0dLN00A6oTLNAai;7P=77P0:Bai77T/NAai;7TLNBai77T/NAah3Bah01DLNBai;7T/NAah0
B4/N00<004/NBah00T/N1Goo00<007ooOol05Goo000XOol00`00Oomoo`0LOol0:PCF0185>03h6K/M
g16J:SdV72Xm;UdbOBiM<WhfWCZn=Ydj_SJM?]hj_CkN>[dngSjm@]hn_T;n?]e2oSkN@_i2gTKn@]i6
oT;nA_i2oTKn@_i77P96oP0n@_i77TKnAai6oTLNA_i77TKnBai6oTLNA_i;7TKnBai6oT/NA_i;7TKn
Bai6oT/NA_i;7dKnBai6oT/OAai;7TKnBam77T/NA_i;7dLNBai77T/OAai;7TLNBam77T/NAai;7dLN
Bai77T/OAai;7TLNBcm77T/NAai;?`9;7P06Aai;?d/NBai77T/o0T/N00I77T/oBai;7TLNBcl2Bah0
9TLNBcm;7T/NAai;?d/NBci77T/oBai;?TLNBcm;7T/nAai;?d/NBci77T/oBai;?TLNBcm;7T/nBai;
?d/NBch004/oBai;?T/NBcl4Ool00`00Oomoo`0EOol002Qoo`03001oogoo01aoo`051=L0E0Ti2CT0
n0026M/012Hl:SdV?2Hl139m00@fWCZN=YdfWP8n_P04>[hn_SkN@]h3?]h01T;n@]i2gT;N@_i2gPA2
oP=6oP03@_i6oTKn00A6oP0:Aai6oTKnA_i77TKnAai6oTLNA_h2Aah01D/NA_i77TLNBah00dLN00Y;
7TLNBai77T/NAai;7TLNBai77P=;7P05Aai;7T/NBai77P16Bah00`00Bai;7P03Bah5Ool00`00Oomo
o`0DOol002Qoo`03001oogoo01eoo`0;1?L0E0UI1CPMfaVk7M`Z?2Xm9Q`fWP03<Wd023JN>Ydj_SJM
>[hj_CkN>[d2?]h0Cd;N?[e2gT;N@_i2gD;n@]i6oT;MA_i2gTKn@_i6oT;nA_i2oTLNA_i77T;nAai6
oTLNA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBam6oT/NA_i;7dLNBai6
oT/OAai;7TKnBam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/NAai;?dLNBai77T/o009;7P06Aai;
?d/NBai77T/o0T/N00I77T/oBai;7TLNBcl2Bah01TLNBcm;7T/NAai;?`9;7P0QAai;?d/NBci77T/o
Bai;?TLNBcm;7T/nAai;?d/NBci77T/oBai;?TLNBcm;7T/nBai;?`00Bci;7T/oBai;?T/N00Aoo`03
001oogoo01Aoo`00:7oo00<007ooOol07Goo00/4ePCG4GT9>B7k8O`IfbiM:Sd^GBXl00@bO@04>[hj
WCZn>Yd2?[h01CkN?[hngSkN@]h00SkN00=2gT;n@]h00T;N00I6oT;n@_i2oTKn@_h:A_h02TLNA_i6
oTKnAai6oTLNA_i;7TKn0TLN00i;7TLNBai77T/NAai;7TLNBai77T/NAai;7TLN0d/N00E77T/NBai;
7TLN04Q;7P03001;7T/N00A;7PAoo`03001oogoo01Aoo`00:7oo00<007ooOol07Goo01`4m`CF07@A
N@UI8O/Qo27k;UdZ?2iM:S`fWSIm=YhbOCZn>Ydj_SJM?]hn_CkN>[e2gSkN@]hng@92gP0<@_i2gDKn
@]i6oT;MA_i2gTKn@_i77T;n0TKn03U77TKnAai6oT/NA_i77TKnBai6oT/NA_i;7TKnBai6oT/NA_i;
7TKnBai6oT/NA_i;7TKnBai6oT/NAai;7TKnBam77T/NAai;7dLNBai77T/OAai;7TLNBam77T/NAai;
7dLNBai77T/OAai;7TLNBcl00T/N00I77T/oBai;7TLNBcl2Bah01TLNBcm;7T/NAai;?`9;7P0[Aai;
?d/NBai77T/oBai;?TLNBcm;7T/nAai;?d/NBci77T/oBai;?TLNBcm;7T/nAai;?d/NBci;7T/oBai;
?T/NBcm;7T/n001;?d/NBci;7T/oBah017oo00<007ooOol057oo000XOol00`00Oomoo`0MOol051EH
1=H4eQFJ4GTQo27k8O`Qnc9M:Sd^GCIm=YdfOCJM>[dj_SZm>[h3?[h00ckN?[i2gP02@]h01CkN@]i2
gT;n@]h00T;n00A6oT;nA_i2oPa6oP06Aai6oTKnA_i77TKn0TLN00Y;7TKnAai77T/NAai;7TLNBai7
7P=;7P05Aai;7T/NBai77P1:Bah50006Bah4Ool00`00Oomoo`0DOol002Qoo`03001oogoo01ioo`1V
4CP4mafj5IXANBXl8O/Qo2iL<Wd^G39M<WdfWSIm=YhjWCjn>Ydn_Sjm@]hn_D;N?]e2oT;M@]hngDKn
@]i6oT;MA_i2oTKn@]e6oT;nA_i2oTLNA_i77TKnBai6oTLNA_i;7TKnBai6oT/NA_i;7TKnBai6oT/N
A_i;7TKnBai6oT/NA_i;7TKnBai77T/NA_i;7dLNBai6oT/OAai;7TLNBam77T/NAai;7dLNBai77T/O
Aai;7TLNBam77T/NAai;7dLNBai77T/o0T/N00I77T/oBai;7TLNBcl2Bah01TLNBcm;7T/NAai;?`9;
7P0DAai;?d/NBai77T/oBai;?TLNBcm;7T/nAai;?d/NBci77T/oBai;?PX0000;Bai;?T/NBcl004/n
Bai;?d/NBci;7P05Ool00`00Oomoo`0COol002Qoo`03001oogoo01ioo`065EP4ePCF7KXM^bHL0bXL
00d^GC9M;UdbGCJM>YdfWCZn>[dj_SZm>[hn_P03?]h5@]h2@_h00dKn@]i6oP02A_h00d;nA_i6oP04
A_h02TLNA_i6oTKnAai6oTLNA_i77TKn0TLN00I;7TKnAai77T/NA_h2Aah01T/NAai;7TLNBai77P=;
7P05Aai;7T/NBai77P0eBah9000?Bah00`00Bai;7P04Bah4Ool00`00Oomoo`0COol002Qoo`03001o
ogoo01moo`0V5EP4eR7K7KXQfbHK:S`V73Im<U`fOC9L>YhfOCZN=Ydn_SZm?[hj_D;N?[e2gSjm@]hn
gD;n@]e2gT;MA_i2gTKn@]e6oT;nA_i2g@=6oP0f@_i77TKnAai6oT/NA_i;7TKnBai6oT/NA_i;7TKn
Bai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NAai;7TKnBam77T/NA_i;7dLNBai77T/OAai;7TLN
Bam77T/NAai;7dLNBai77T/o0T/N00I77T/oBai;7TLNBcl2Bah01TLNBcm;7T/NAai;?`9;7P07Aai;
?d/NBai77T/oBah02P0001m;?d/NBci77T/oBai;?T/NBcm;7T/nBai;?d/NBci;7T/oBai;?T/NBcm;
7T/nBah004/NBci;7T/oBai;?P04Ool00`00Oomoo`0COol002Moo`03001oogoo021oo`8EF0<M^P08
7K/^?2XL:Q`fOC9m=WdbO@@jW@08?[hn_Cjn?[e2gSkN@]hngPI2gP04A_i2oTKn@]h:A_h02TLNA_i6
oTKnAai6oTLNA_i77TKn0TLN00i;7TKnBai77T/NAai;7TLNBai77T/NAai;7TLN:4/N2@008T/N00<0
04/NBah014/N17oo00<007ooOol04goo000WOol00`00Oomoo`0POol01RFj5CPEF2Gj8M/M^P8^?08b
G01?=WdbG3Im>Ydj_SZM?[hn_CkN?[e2gSjm@]hn_D;N?[e2oT;MA_i2gD;n@]e6oT;NA_i2oDKn@_i6
oT;mAai6oTLNA_i77TKnAai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;
7TKnBai6oT/NAai;7TKnBai77T/NA_i;7dLNBai77T/OAai;7TLNBal00T/N00I77T/OBai;7TLNBcl2
Bah00dLNBcm;7P0900001TLNBcm;7T/NAai;?`9;7P0ZAai;?d/NBci77T/oBai;?TLNBcm;7T/nAai;
?d/NBci;7T/oBai;?T/NBcm;7T/nBai;?d/NBci;7T/oBai;?T/NBcm;7P00Bai;?d/NBci;7T/o1Goo
00<007ooOol04Woo000WOol00`00Oomoo`0QOol29KT4:O/3;S`013Im>YdfOCIm13ZM00@n_Cjn?[dn
_PE2gP06A_i2gT;N@]i6oT;n3TKn01977TKnA_i6oT/NA_i77TKnBai6oT/NAai;7TLNBai77T/NAah3
Bah01DLNBai;7T/NAah04d/N2P00=D/N00<004/NBah014/N17oo00<007ooOol04Woo000WOol00`00
Oomoo`0QOol09BFI9KXUVBWk9OXYnc9L=Ud^?3ZM=WdjWCIl?[hjWCjn>Ye2gSjm?]hn_D;N@]e2gSkM
@]i2gDKn@]e6oT;MA_i2gDKn@]i6oT;m00A6oP0YBai6oTLNA_i;7TKnBai6oT/NA_i;7TKnBai6oT/N
A_i;7TKnBai6oT/NA_i;7TKnBai77T/NA_i;7TLNBai6oT/NAai;7TKnBai77T/NAai;7`0900000d/N
Aai;7`02Bah01TLNBcm;7T/NAai;?`9;7P06Aai;?d/NBai77T/o0T/N00I77T/oBai;7TLNBcl2Bah0
:DLNBcm;7T/nAai;?d/NBci77T/oBai;?T/NBcm;7T/nBai;?d/NBci;7T/oBai;?T/NBcm;7T/nBai;
?d/NBci;7T/o001;?T/NBcm;7T/nBah017oo00<007ooOol04Woo000WOol00`00Oomoo`0QOol01BFi
9ITU^C8K<S/00RWk0SIL00DbG3Im=WdjWCIm00<n_@05>Ye2gSjm@]hn_@03@]h01d;M@]i2gTKn@]i6
oT;N00i6oP04Aai6oT/NA_h2Aah02T/NA_i77TLNBai6oT/NAai;7TLN0d/N00E77T/NBai;7TLN009;
7PX004Q;7P03001;7T/N00A;7PAoo`03001oogoo019oo`009goo00<007ooOol08Goo01lanBFi9ITU
^S8K<S`b6cIM<U`fGC9L?YdjWCjM>Ydn_SZM?[hjWD;N?[e2gSjmA_i2gD;N@]e6oT;MA_i2g@03A_h0
7D;MA_i6oTKnA_e77TKnBai6oD/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_h0
2@0001177T/NA_i;7TLNBai77T/NAai;7TLNBam77T/NAai;7`9;7P06Aai;?d/NBai77T/o0T/N00I7
7T/oBai;7TLNBcl2Bah01TLNBcm;7T/NAai;?`9;7P0_Aai;?d/NBci77T/oBai;?TLNBcm;7T/nBai;
?d/NBci;7T/oBai;?T/NBcm;7T/nBai;?d/NBci;7T/oBai;?T/NBcm;7T/nBai;?d/NBch004/oBai;
?T/NBcm;7P05Ool00`00Oomoo`0AOol002Moo`03001oogoo029oo`07<OXenRFI<S/b6c8k<Q/00SYl
00<jOCZM>Yd00SZM13jm00E2gD;N@]e2gT;M0092gP06A]i2gDKn@]i6oT;N2TKn00]77TKnA_i6oTLN
A_i77TKnBai6oT/N00X00003Aai;7T/N05U;7P04001;7T/NBch3Bah4Ool00`00Oomoo`0AOol002Mo
o`03001oogoo029oo`0>=QXanCGj<Q/b?38K<S`fG3Ym>W`jOCjL@[dnW@8n_@0@@[hn_D:n?[e2gT:m
@]i2gDKn@]e6oT;MA_i2gDKn@]d3A_h024KMA_i6oTKnA_e;7TKnBah9000074/NA_i;7TKnBai6oT/N
A_i;7TKnBai6oT/NA_i;7TKnBai77T/NA_i;7TLNBai6oT/NAai;7TLN0d/N00I77T/OBai;7TLNBal2
Bah01TLNBcm;7T/NAai;?`9;7P06Aai;?d/NBai77T/o0T/N00I77T/oBai;7TLNBcl2Bah0;TLNBcm;
7T/nAai;?d/NBci;7T/oBai;?T/NBcm;7T/nBai;?d/NBci;7T/oBai;?T/NBcm;7T/nBai;?d/NBci;
7T/oBai;?T/NBcm;7P00Bai;?d/NBci;7T/o1@004goo000WOol00`00Oomoo`0SOol00cGj<OXenP03
>U/01CYL>W`jO3Yl?[d00cjM14:m00I2gT;M@]i2gD;N@]d2@]h2A]h3A_h00dKN0000000800003TLN
A_i6oTKnBai6oT/NA_i;7TKnBai77T/NA_h3Bah00dLNBai;7P1KBah00`00Bai;7P02Bah00d/nBaio
o`03Ool00`00Oomoo`0AOol002Moo`03001oogoo02=oo`0G<OTf6S7i>U`j>ciL>S/nWCil@YdnO3jm
?Ya2_CjM@]hn_D;N?[e6gT;MA]i2g@090000;DKMB_i6oTKnA_e:oTKnBai6oD/NA_i;7TKmBai6oT/N
A_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NAai;7TKnBai77T/NAai;7TLNBai77P03
Bah01DLNBai;7T/NAah00d/N00I77T/OBai;7TLNBcl2Bah01TLNBcm;7T/NAai;?`9;7P06Aai;?d/N
Bai77T/o0T/N03177T/oBai;?T/NBcm;7T/nBai;?d/NBci;7T/oBai;?T/NBcm;7T/nBai;?d/NBci;
7T/oBai;?T/NBcm;7T/nBai;?d/NBci;7T/oBai;?T/N001;7T/nBai;?d/NBch4Ool00`00Oomoo`0A
Ool002Moo`03001oogoo02=oo`05@SXn>T8j?SXjG003>U/01CjM?W`nW3jL@[d02P0000=2gDKn@]d0
0TKN44Kn00Y;7TKnA_i6oT/NA_i;7TKnBai6oVA;7P03001;7T/n00=;7P05BcioogooOol0000COol0
02Ioo`03001oogoo02Eoo`03@SXn>D8j00T0000n@[dnW4:m@[e6gT:mA]i2_DKN@]e6oT;MA_i6gDKn
A]e6oTKMB_i6oDKnA_e;7TKmB_i6oD/NA_i;7TKmBai6oT/NA_e;7TKnBai6oD/NA_i;7TKnBai6oT/N
A_i;7TKnBai6oT/NAai;7TKnBai77T/NA_i;7TLNBai77P=;7P05Aai;7T/NBai77P03Bah01TLNBcm;
7T/NAai;?`9;7P06Aai;?d/NBai77T/o0T/N00I77T/oBai;7TLNBcl2Bah00dLNBcm;7P02Bah0;T/o
Bai;?T/NBcm;7T/nBai;?d/NBci;7T/oBai;?T/NBcm;7T/nBai;?d/NBci;7T/oBai;?T/NBcm;7T/n
Bai;?d/NBci;7T/oBai;?P00Bcm;7T/nBai;?d/N0goo00<007ooOol04Goo000VOol00`00Oomoo`0O
Ool900000d8j@W]2O002@W/014:L@Ye2W4:L1D:m00I6gD:m@]e6gDKNA]d2A]h014KnA]e6oTKN34Kn
00Y;7TKnBai6oT/NA_i;7TLNBai6oVI;7P05001;7T/NBai;?P02Bah3Ool00`00Oomoo`0AOol002Io
o`03001oogoo01Eoo`X000Ioo`0A@SXn>T8j?SU2O49k@W`nFdJm@Ya6_D:LA[e2_DJm@[a6gP02A]d0
<D:mA]i6gDKnA]e6oTKMA_i6gDKnA_e:oTKmB_i6oD/NA_e;7TKmBai6oD/NA_i;7TKmBai6oT/NA_e;
7TKnBai6oD/NA_i;7TKnBai6oT/NA_i;7TKnBai6oT/NAai;7TKn00=;7P05A_i;7T/NBai77P03Bah0
1DLNBai;7T/NAah00d/N00I77T/oBai;7TLNBcl2Bah01TLNBcm;7T/NAai;?`=;7P05Bcm;7T/NBai;
?`03Bah0<4/oBai;?T/NBcm;7T/nBai;?d/NBci;7T/oBai;?T/NBcm;7T/nBai;?d/NBci;7T/oBai;
?T/NBcm;7T/nBai;?d/NBci;7T/oBai;?T/NBcm;7P00Bai;?d/NBci;7P=oo`03001oogoo015oo`00
9Woo00<007ooOol037oo2@004Goo00=:NTYJBWX00d9k00I2O49k@Ya2W4:M@Y`3A[d00d:mA]e6g@04
A]d01TKnA]e6gDKmA_i6o@96oP05B_i6oTKnA_i:oP03A_h02T[nA_i:oTKnBai6oT/NB_i;7TKn0d/N
00=6oT/NBah0H4/N00E;?T/NBah004/n00=;7P03Bci;7Woo009oo`03001oogoo011oo`009Woo00<0
07ooOol00Woo2P006Woo0196FDYjBUY:NTIkBYa6NdZLAYa:_DJlB[e6W4[MA[a:gD:mA]h2A]d0;D:m
A_i6gDKnA]e:oTKMB_i6gD[nA_e:oTKmB_i6oD/NA_e;7TKmBai6oD/NA_i;7TKmBai6oT/NA_e;7TKn
Bai6oD/NA_i;7TKnBai77T/NA_i;7TLNBai6oP03Bah01DKnBai;7T/NAah00d/N00E77T/NBai;7TLN
00=;7P06Aai;?T/NBai77T/o0T/N00=77T/oBah00T/N00E;?d/NBai;7T/o00=;7P0gBcm;7T/NBai;
?d/NBci;7T/oBai;?T/NBcm;7T/nBai;?d/NBci;7T/oBai;?T/NBcm;7T/nBai;?d/NBci;7T/oBai;
?T/NBcm;7T/nBai;?d/NBci;7T/oBai;?T/N001;7T/nBai;?d/NBch00goo00<007ooOol047oo000V
Ool5000UOol014YJBWY:FTZL0dJK00=:W4JlA[`00TJl00=6_DKMA[d014KM00i:gDKMA_e6gD[nA]e:
oTKmB_i6oD[nA_i:oTKm0d[n00U6oT[nB_i;7TKnBai:oT/NB_h00d/N00E:oT/NBai;7T[n05i;7P06
Bci;7T/NBai;?P000T/N00A;?T/NBai;7P=oo`03001oogoo011oo`009goo00<007ooOol09Woo03Y:
NTIIBWY:FTZLAW]:W4IkB[e6W4ZmA[a:_DJlB]e6_4[MA]e:oTKMB]e6gD[nA]e:oTKMB_i6oD[nA]e;
7TKmB_i6oD/NA_e;7TKmBai6oT/NA_e;7TKnBai6oD/NA_i;7TKmBai:oT/NA_e;7T[nBai6oP=;7P05
A_i;7T/NBai6oP03Bah01DLNBai;7T/NAah00d/N00I77T/NBai;7TLNBch2Bah00dLNBci;7P02Bah0
1D/oBai;7T/NBcl00d/N00E;?d/NBai;7T/o00=;7P0eBcm;7T/nBai;?d/NBci;7T/oBai;?T/NBcm;
7T/nBai;?d/NBci;7T/oBai;?T/NBcm;7T/nBai;?d/NBci;7T/oBai;?T/NBcm;7T/nBai;?d/NBci;
7T/oBai;?P00Bcm;7T/nBai;?`03Ool00`00Oomoo`0@Ool002Qoo`03001oogoo02Eoo`9BVP05DYUB
VTjkC[]>V`02C[/014[LB[a:_4Zl14[M00A:oD[MB]e:g@A:o@06B_i:oD[nB_e:oT[m0d[n00A:oD[n
B_i;7P=:oP06Bai:oT/NB_i;7T[nHT/N00E;?T/NBai;7T/n00=;7P06001;7T/NBai;?T/N0goo00<0
07ooOol047oo000YOol00`00Oomoo`0TOol0>5:JDWUBVTiiDYY:VdjkBY]>_4ZlC]a:_4kMB[a:gDZl
B]e:g4[mA]e:oT[MB_e6gD[nA]e:oTKmB_i6oD[nA_e;7TKmBai6oD/NA_e;7TKmBai:oD/NA_e;7T[m
Bai6oD/NB_i;7TKmBai:oT/NA_d3Bah01DKmBai;7T/NA_h00d/N00=6oT/NBah02T/N00E;?T/NBai;
7T/n00=;7P05Bci;7T/NBai;?`03Bah01D/oBai;7T/NBcl00d/N03M;?d/NBai;7T/oBai;?T/NBcm;
7T/nBai;?d/NBci;7T/oBai;?T/NBcm;7T/nBai;?d/NBci;7T/oBai;?T/NBcm;7T/nBai;?d/NBci;
7T/oBai;?T/NBcm;7T/nBai;?`00Bci;7T/oBai;?P03Ool00`00Oomoo`0@Ool002Yoo`03001oogoo
02Aoo`=BVP08DYU>^djkC[]>VdjkB[a:g09:_0A:g@9:o@03B]e:oD[m00I:o@04B_i:oD[nB_d3B_h0
1D[mBai:oT/NB_h00d/N00E:oT/NBai;7T[n05i;7P05Bci;7T/NBai;?P03Bah01D/nBah004/NBch0
0d/N00A;?WooOol0019oo`00:goo00<007ooOol08goo03U>NE:JEYUJ^UJID]]B^e;KD[YBg4jlC]a>
_5;LB]a>oD[LC_e:gDkmB]e>oD[MB_i:gDknB_e:oT[mBai:oD[nB_e;7T[mBai6oD/NB_e;7TKmBai:
oD/NB_e;7T[nBai:oD/NB_i;7T[mBai:oT/NB_d00d/N00=:oT/NBah04T/N00E;?T/NBai;7T/n00=;
7P05Bci;7T/NBai;?`03Bah0?T/oBai;7T/NBcm;7T/nBai;?d/NBci;7T/oBai;?T/NBcm;7T/nBai;
?d/NBci;7T/oBai;?T/NBcm;7T/nBai;?d/NBci;7T/oBai;?T/NBcm;7T/nBai;?d/NBci;7T/oBai;
?T/NBcm;7T/nBah004/NBci;7T/oBah2Ool00`00Oomoo`0@Ool002aoo`03001oogoo029oo`05F[UF
VEZiE[UJ^@05D[/4C]`3C]d01D[LC]e:oD[mB]d00T[m00E>oD[mB_e:oD[n00=:o@0:B_i:oD[nB_i;
7T[nBai:oT/NB_h3Bah00d[nBai;7P1LBah01D/nBai;7T/NBch00d/N00I;?T/NBai;7T/n0002Bah0
0d/nBai;7P02Ool00`00Oomoo`0@Ool002eoo`03001oogoo025oo`0dEYUJ^UJIF[YFVEZjD[YBfe:k
D]]>fe;lD]]Bo4kKD_e>g4kmC]aBoD[mC_e:gDkmB_e>oT[mCai:oDlNB_e?7T[mBai:oDlNB_e;7T[m
Cai:oD/NB_e?7T[mBai:oDlNB_i;7T[mCah2Bah01D[mBai;7T/NB_d00d/N00=:oT/NBah02T/N00E;
?T/NBai;7T/n00=;7P05Bci;7T/NBai;?P03Bah01D/nBai;7T/NBcl00d/N03a;?d/NBai;7T/oBai;
?T/NBcm;7T/nBai;?d/NBci;7T/oBai;?T/NBcm;7T/nBai;?d/NBci;7T/oBai;?T/NBcm;7T/nBai;
?d/NBci;7T/oBai;?T/NBcm;7T/nBai;?d/NBci;7T/oBah004/NBcm;7T/nBah2Ool00`00Oomoo`0@
Ool002ioo`03001oogoo025oo`07E[UJ^EJIF[UF^EKKE]X00eKK15;L00E>g4kmC]a>oDkL00E>o@03
B_e>oD[m009:o@0:Cai:oDkmB_e?7T[mBai:oDlNB_iRBah01D/nBai;7T/NBch00d/N00E;?T/NBai;
7T/n00=;7P08001;7T/NBai;?T/NOol0019oo`00;goo00<007ooOol087oo01EJ^UJIF[YJ^5kIE]YF
feJjF]]FfU;lC]]Bo5;KD_a>g5;mC]aBoDkLD_d00Tkm01Y>o5;mB_e?7D[mCai:oDlNB_e?7T[mCai:
oDlNB_e?7T[mCai:oDlNB_e?7T[mCai:oDlN0T/N00I:oDlNBai;7T[mCah2Bah00d[mCai;7P02Bah0
1DlNBai;7T/NCah00d/N00E?7T/NBai;7T/n00=;7P05Bci;7T/NBai;?P03Bah01D/nBai;7T/NBch0
0d/N045;?d/NBci;7T/oBai;?T/NBcm;7T/nBai;?d/NBci;7T/oBai;?T/NBcm;7T/nBai;?d/NBci;
7T/oBai;?T/NBcm;7T/nBai;?d/NBci;7T/oBai;?T/NBcm;7T/nBai;?d/NBci;7T/oBai;?T/NBcl0
04/nBai;?d/NBcioo`00019oo`00<7oo00<007ooOol07goo0eji00=NfEjiG[T00UKK00EFfUKKE]]F
o5;K00=Fo0=Bo003D_e>oDkm00M>o@0<Cae>oDlNC_e?7DkmCai:oDlNBae?7T[mFT/N00E;?T/NBai;
7T/n00=;7P05Bci;7T/NBai;?P03Bah02D/nBai;7T/NBci;7P00Bai;?P03Bah00goo001oo`0AOol0
035oo`03001oogoo01moo`0jF[QNfEZiG]UJ^5[kF]YJne[JF_]JfUKlD]]Fo5;KD_e>g5;mC]aBoDkl
Dae>o5<MC_a?7TkmCae>oDlNB_e?7T[mCai:oDlNB_e?7T[mCai:oDlNB_e?7T[mCai:oDlNB_e?7T/M
Cai:oDlNBai?7T[mCah2Bah00d/MCai;7P02Bah01DlNBai;7T/NCah00d/N00E??T/NBai;7Tln00=;
7P05Cci;7T/NBai;?P03Bah0AdlnBai;7T/NCci;7T/nBai;?T/NBci;7T/oBai;?T/NBcm;7T/nBai;
?d/NBci;7T/oBai;?T/NBcm;7T/nBai;?d/NBci;7T/oBai;?T/NBcm;7T/nBai;?d/NBci;7T/oBai;
?T/NBcm;7T/nBai;?d/NBci;7T/oBai;?P00Bcm;7T/nBai;?d/N00004Woo000bOol00`00Oomoo`0N
Ool01UkIG[UN^EjiH]URf09JfP05F]]JfU[JE_]Fo003E_/5D_`014kmD_e>oE;m0dkm00I?7DkmCae?
7DlNC_d2Cad02DlNB_e?7T/NCai;7DlNBai?7P1GBah01D/nBai;7T/NBch00d/N00E;?T/NBai;7T/n
00=;7P06Bci;7T/NBai;?P000T/N00E;?T/NBaioo`00015oo`00<goo00<007ooOol07Woo03mNfEjh
H]UNf6;IF]YJne[JG_YJfU[lE_]Jo5KKF_aBo5KmD_aG7E;lDae>o5<MD_aC7DkmDai>oE<MC_e?7Tkm
Cai>oDlNB_e?7T[mCai:oDlNB_e?7T/MCai:oDlNBae?7T[mCai;7DlNBae?7T/NCai;7DlNBai?7T/M
Cah00T/N00=;7DlnBah00T/N00E??T/NBai;7Tln00=;7P05Cci;7T/NBai??P03Bah0BTlnBai;7T/N
Cci;7T/nBai??T/NBci;7TloBai;?T/NCcm;7T/nBai;?d/NBci;7TloBai;?T/NBcm;7T/nBai;?d/N
Bci;7T/oBai;?T/NBcm;7T/nBai;?d/NBci;7T/oBai;?T/NBcm;7T/nBai;?d/NBci;7T/oBai;?T/N
Bcm;7P00Bai;?d/NBci;7Woo000AOol003Aoo`03001oogoo01eoo`07H]QRfF;HH]URf6;IG]X00ekj
00ANfUKkE_]Fo09Fn`03E_aG75Kl009Fo009DaeBoE;mD_eC7DkmCae>oE<M00E?7@04Cai?7DlNCad3
Cah024/MCai;7TlNBai?7T/NCah3Bah01DlNBai;7T/NCah0Ad/N00E;?T/NBai;7T/n00=;7P05Bci;
7T/NBai;?P03Bah01D/nBai;7T/NBch00T/N00<004/nBah00T/N00=;?Woo00004Goo000eOol2000M
Ool0BF;IG]QRfEjhH]URf5kjF]YNne[JG_YJne/LF_]Jo5[kFaaBo5LLD_aG7E;lEaeBo5LMD_aC7Dkm
Dae>oE<MC_eC7TkmDai:oDlNC_e?7T[mCai;7DlNB_e?7T/MCai:oDlNBae?7T/MCai;7DlNBae?7T/N
Cai;7DlNBai?7T/MCci;7TlNBae??T/NCai;7Tln00=;7P05Cci;7T/NBai??P03Bah0C4lnBai;7T/N
Cci;7T/nBai??T/NBci;7TlnBai;?T/NCcm;7T/nBai??d/NBci;7TloBai;?T/NCcm;7T/nBai??d/N
Bci;7T/oBai;?T/NBcm;7T/nBai;?d/NBci;7T/oBai;?T/NBcm;7T/nBai;?d/NBci;7T/oBai;?T/N
Bcm;7T/nBah004/NBci;7T/oBaioo`004Goo000gOol00`00Oomoo`0KOol016;IH]QRfF;H0VKH00EN
nUkJG_YNnV;j00EJn`05EaaFo5LLE_aG7002Dad01E;lDaeC7E<MC_d00e<M0dlM00IC7DlMCae?7DlN
Cad3Cah034lMCai?7TlNBai?7T/NCai;7TlNBai?7P=;7P03Cai;7T/N03e;7P05Bci;7T/NBai;?P03
Bah01D/nBai;7T/NBch00d/N00E;?T/NBai;7T/n00=;7P09Bci;7T/NBai;?T/N001;7T/n00=;7P03
001oogoo00moo`00>7oo00<007ooOol06Woo04iN^6KhH]QVn6;HI_QJfV;jG_URnUkiF_aJne/LF_]O
6eKlFaaFo5/LE_aK75;lEaeBo5LMD_eC7DkmDaeBoE<NC_eC7TkmDai>oDlNCae?7T/MCai?7DlNBae?
7T/MCai;7DlNBae?7T/MCai;7TlNBae?7T/NCai;7DlnBai?7T/MCci;7TlNBai??T/NCai;7TlnBai?
7T/NCch3Bah0CTlnBai;7T/NCci;7T/nBai??T/NBci;7TlnBai;?T/NCci;7T/nBai??d/NBci;7Tlo
Bai;?T/NCcm;7T/nBai??d/NBci;7TloBai;?T/NCcm;7T/nBai??d/NBci;7TloBai;?T/NBcm;7T/n
Bai;?d/NBci;7T/oBai;?T/NBcm;7T/nBai;?d/NBch004/oBai;?T/NBcl0015oo`00>Goo00<007oo
Ool06Goo01]Vn6;HI]QVf6KhH]QRnUkjH_YNnV;jG_YO6e[kG_]JnelKE_aG75KlFaaG75LMEaaG7E<L
Ead01U<M00A?7E<MDaeC7@=?7@06Cai?7DlNCae?7TlM0dlN00a?7DlNCai?7T/NCai;7TlNBai?7T/N
Cah3Bah00dlNBai;7P0eBah01D/nBai;7T/NBch00d/N00E;?T/NBai;7T/n00=;7P05Bci;7T/NBai;
?P03Bah01D/nBai;7T/NBch00goo00<007ooOol00goo00<007ooOol03goo000jOol00`00Oomoo`0I
Ool06fKhH]QVn6;HJ_QNnF;jG_URnUkiIaYJnelKF_]O6e[kFaaFne/LE_aK75KkEaeBo5LMD_aG7@02
Dad0KU;lEae?7E<MC_eC7TlMDai>oE<NCae?7TlMDai?7DlNBae?7T/MCai;7DlNBae?7T/MCci;7TlN
Bae??T/NCai;7DlnBai?7T/MCci;7TlNBai??T/NCai;7TlnBai??T/NCci;7TlnBai??T/NCci;7Tln
Bai;?T/NCci;7T/nBai??T/NBci;7TlnBai;?T/NCci;7T/nBai??d/NBci;7TloBai;?T/NCcm;7T/n
Bai??d/NBci;7TloBai;?T/NCcm;7T/nBai??d/NBci;7TloBai;?T/NBcl<Ool00`00Oomoo`03Ool0
0`00Oomoo`0?Ool003]oo`03001oogoo01Qoo`03I]QVn6;H009Vn005J_QNnV;jH_URnP02H_T00e[k
Ga]Nn`02Ga/00e/LEaaK7002Fa`3Ea`00eLMEaaC7@09Dad02U<NCae?7DlMCai?7DlNCae?7TlM2dlN
00A;7TlNBai?7P=;7P05Cai;7T/NBai?7P0[Bah01D/nBai;7T/NBch00d/N00E;?T/NBai;7T/n01Yo
o`03001oogoo009oo`03001oogoo00moo`00?7oo00<007ooOol067oo021Rf6[hI]MZn6KGHaYRnFLJ
H_US6V;iGa]NnUlKG_YO6ekjFaaJnelLFa]K75KlEaeG75LMDaaG7E<LEaeC75LM0U<M04i?7E<NCaeC
7TlMDai?7E<NCaeC?TlMCai;7DlnCae?7T/MCci;7DlNBae??T/MCai;7DlnBai?7T/MCci;7TlNBae?
?T/NCai;7DlnBai??T/NCci;7TlnBai??T/NCci;7TlnBai??T/NCci;7TlnBai??T/NBci;7TlnBai;
?T/NCci;7T/nBai??d/NBci;7TloBai;?T/NCclWOol00`00Oomoo`02Ool00`00Oomoo`0?Ool003eo
o`03001oogoo01Moo`9Vn005J_QVef[gJ_MRnP03H_T00fLIH_UO6`02Ga/01ElJHa]O6U/LFa/00U/L
1ELL00AC7ELMDaeG7@IC7@0;CaeC7TlMDae?7DlNCae?7TlMCai?7@07Cah044/NCai?7TlNBai?7T/N
Cai;7TlNBai?7T/NCai;7TlN0d/N00=?7T/NBah06T/N<7oo00<007ooOol00Woo00<007ooOol03goo
000nOol00`00Oomoo`0FOol08VKGJ_QVef[hJ]MZn6;iHaYRnFLJH_UW6EkjHa]O6V<KG_YS6e/KGaaK
6elLFa]K7ELLFaeG75/MDaaG?E<LEaeC75<n0e<M03IC?TlMDai?7E<nCaeC7TlMDci?7DlNCae??TlM
Cai;7DlnBae?7T/MCci;7DlNBae??T/NCai;7DlnBai?7T/MCci;7TlnBae??T/NCci;7TlnBai??T/N
Cci;7TlnBai??T/NCci;7TlnBahmOol01@00Oomoogoo00004Goo000oOol00`00Oomoo`0EOol00f[h
I]MVn004J_L00fKiIaURn@03IaT03ElJHa]O6V<KHaYO75/KGaaK6elLFa]K75LL00=K70AG7@YC7@03
CaeC7TlM00=?7P03Cae?7TlN00U?7P0<Bai?7TlNCai;7TlNBai?7T/NCai;7TlN0d/N00=?7T/NOol0
BGoo00D007ooOomoo`00015oo`00@7oo00<007ooOol05Goo04EZn6[GJ_QZmf[hJ_IW6V;iIaUVn6/I
I_US6ekjHa]S6V<KGaYO75/KGaaK6ellFa]K75LLFceG75LmEaaG?ELLEceC7ELmDaeG?DlMDciC7E<n
CaeC?TlMDci?7E<nCae?7TlMDci?7DlnCae??TlMCci;7DlnBae??T/MCci;7TlnBae??T/NCch0DWoo
00D007ooOomoo`00015oo`00@Goo00<007ooOol057oo00=Vn6[gJ_L00V[g00=^mf[gIaT00VLI00=V
nFLIIaT01F<J0elK00EO75lKGa]K75/l00=K7009EaeG75LMEaeG?E<MEaeC7ELm00MC7@06Dai?7E<M
Cae?7TlM1DlNGgoo00<007ooOol00Woo00<007ooOol03Woo0012Ool00`00Oomoo`0COol0<6[hJ_MZ
n6[GKaMZmfkgI_Q[6FKiIaUVn6/IIaQS6elJIc]S6VLJFa]O?5/KGcaO6f<lFaaK?5LLFceG75/mEaaK
?ELLEceC7ELmDaeG?E<MDciC7E<nDaeC?TlMDci?7FQoo`05001oogooOol0000@Ool004=oo`03001o
ogoo019oo`=Zm`06K_MZmf[gJ_M_5fKi0VLI00E[6FLHJaUS6VLJ00=S6P0>IaYO6elKGa]O>elKFcaK
75/lFaaK?5LMEceG709G7@05EceC7ELMEaeG?@03Dad00e<mOomoo`1ZOol01@00Oomoogoo000047oo
0014Ool00`00Oomoo`0BOol08f[GKaMZmfkgJ_I_5fkfIaUVn6/IIaQ[6F/HIc]S6VLJHaYW>f<JIcYO
6f<lGa]S>elKGcaK75llFaaK?ELLFceG75/mEa`0M7oo00D007ooOomoo`00011oo`00AGoo00<007oo
Ool04Goo16[g00M^mfkfK_M^mV/IIaQ[6@03JaP2HaX04FLJHaYW6VLJHc]O6f<kGa]S>e/LGcaK75ll
FaaG?ELLFcd0MWoo00D007ooOomoo`00011oo`00AWoo00<007ooOol047oo01mZmfkgJ_I_5fkfKaMZ
mW<GIaQ[6FKhJaU[66/IHaUW>V<JIcYS6FLjIaUS>elKHc]O6f<kFa]O?5/LGcaK6`1iOol01000Oomo
o`0047oo0017Ool00`00Oomoo`0@Ool026[gK_MZmfkgK_I_5fkfKaH6JaP01V<JIaYW6VLjIaUW6P9S
>`04Ha]S>f<kHc]mOol01000Oomoo`0047oo0018Ool00`00Oomoo`0?Ool06FlGJ_M_5f[fKaM^mW<G
K_I[6F/HJaU[66lhJaQ_66LIIcYW6FLjIaUS>elKHc]O6V<k07ioo`04001oogoo000@Ool004Uoo`03
001oogoo00moo`07J_M^mVlGK_I_5VkfKaH01V/H00M_66LjIaUW6VLIJcYW6@02Hc^1Ool00`00Ool0
000@Ool004Yoo`03001oogoo00ioo`0DJ_I_5fkfLaM^mW<GK_Ic5V/HKcQ[66lHJaM_>6/GIcYW6F/j
IaU[>X=oo`03001oo`00011oo`00Bgoo00<007ooOol03Goo00Q_5fkfK_M^mVlFK_Ic5VlF16/H00M_
66/HKaQW6F/jIaUW>@24Ool00`00Ool0000@Ool004aoo`03001oogoo00eoo`0@KaM^mW<GK_Ic5Vkf
LaI[66lHJaQ_>6/GKaQ[5flhIaV6Ool00`00Ool0000@Ool004eoo`03001oogoo00aoo`03K_I_5Vkf
009_5P06LaIbmG<FJaQ_66/H0flH00=_5gooOol0QWoo0P0047oo001>Ool00`00Oomoo`0;Ool03W<G
K_Ic5fkfLaI^mW<FK_E_>6/GKaQ[5flhKaN9Ool2000@Ool004moo`03001oogoo00Yoo`05K_I_5Vkf
LaI^mP03LaH01W<EKaQ_66lHKaM_68Uoo`03001oo`0000moo`00D7oo00<007ooOol02Woo00a^mW<F
K_Ic5VkeLaIbmG<FJaM_>6lGKcR:Ool00`00Ool0000?Ool0055oo`03001oogoo00Uoo`06KaI^mW<F
KaIc5W;e0W<E00Ac5VlGKaQ_5h]oo`8000moo`00DWoo00<007ooOol027oo00]^mW<FK_Ic5VkeLaIb
mG<FL_E_>6/G08aoo`8000moo`00Dgoo0P002Goo00I_5W<FL_Ec5W<ELaH3LaD00flHOomoo`2:Ool2
000?Ool005Eoo`03001oogoo00Ioo`09LaI^mG<FK_Ec5W;eLaIbmGLF08eoo`8000moo`00EWoo00<0
07ooOol01Woo0g<F1G<ESWoo00<007ooOol03Goo001GOol00`00Oomoo`05Ool01fkeLaIbmG<FL_Eg
5W;e08Uoo`L000moo`00F7oo00<007ooOol01Goo00AbmG<ELaEc5P9c5G]oo`h001Ioo`00FGoo00<0
07ooOol017oo00Ec5W;eLaIbmGLE06moo`d002Aoo`00FWoo00<007ooOol00goo00=c5G<FLaD00W<E
HWoo3@00<Goo001KOol00`00Oomoo`02Ool01G<FL_Eg5G;eMaH0E7oo3P00?Woo001LOol00`00Oomo
o`02Ool3LaE8Ool=001<Ool004Aoo`<001Ioo`07001oogooOombmGLFL_D0>goo3@00FGoo0015Ool0
0`00Oomoo`0FOol00`00Oomoo`03LaD]Ool>001VOol004Eoo`<001Moo`04001oog;eMaDQOol=001d
Ool004Eoo`04001oogoo000GOol00`00Oomc5@0DOol=0021Ool004Eoo`04001oogoo000HOol20006
Ool>002>Ool004Aoo`@001Yoo`L009aoo`00ogoo1Woo003oOol6Ool00?moo`Ioo`00ogoo1Woo003o
Ool6Ool00?moo`Ioo`00ogoo1Woo001oOol200000goo00000002Ool40003Ool20004Ool20003Ool5
001XOol0081oo`03001oo`0000Uoo`04001oogoo000:Ool00`00Oomoo`1XOol0085oo`03001oogoo
009oo`@0009oo`04001oogoo000:Ool00`00Oomoo`1XOol007moo`800003Ool0000000Qoo`04001o
ogoo000:Ool00`00Oomoo`1XOol008aoo`04001oogoo000:Ool00`00Oomoo`1XOol008eoo`8000Yo
o`8006Yoo`00ogoo1Woo003oOol6Ool00?moo`Ioo`00ogoo1Woo0000\
\>"],
  ImageRangeCache->{{{0, 260.5}, {184.063, 0}} -> {-0.170612, 0.0461341, \
0.00439245, 0.00439245}}]
}, Closed]]
}, Open  ]],

Cell[TextData[{
  "On top of each picture, the specific ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  "-value is given. This allows us to locate the position along the ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  "-axis. The animation shows that the manifold along the ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  "-axis changes rapidly for small ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  "-values. For greater values of ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ", there are no dramatic changes in \[GothicCapitalM]. We again realize \
that the skeleton in the original coordinates represents a complicated \
manifold."
}], "Text",
  CellTags->{"animation", "manifold"}],

Cell[TextData[{
  "In ",
  ButtonBox["Section 4.4.1.1",
    ButtonData:>{"symmet2.nb", 
      "The skeleton of an ordinary differential equation"},
    ButtonStyle->"Hyperlink"],
  ", we remarked that the method of canonical variables allows us to simplify \
the skeleton. To demonstrate this behavior, let us calculate the canonical \
coordinates related to subgroups ",
  StyleBox["k1 ",
    FontSlant->"Italic"],
  "and ",
  StyleBox["k2",
    FontSlant->"Italic"],
  " for the above ODE. First, we carry out the calculation for subgroup",
  StyleBox[" k1 ",
    FontSlant->"Italic"],
  "representing the scaling group for this equation"
}], "Text",
  CellTags->{"method of canonical variables", "canonical coordinates"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(cck1 = CanonicalVariables[{u}, {x}, {x}, {u\/2}, \n\t\t{w}, {t}]; 
    cck1 // LTF\)], "Input"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\(t == Log[x]\)},
          {
            RowBox[{"w", "==", 
              StyleBox[\(u\/\@x\),
                ScriptLevel->0]}]}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {
        Equal[ t, 
          Log[ x]], 
        Equal[ w, 
          Times[ u, 
            Power[ x, 
              Rational[ -1, 2]]]]}]]], "Output"]
}, Open  ]],

Cell[TextData[{
  "The second set of canonical variables follows from the subgroup with ",
  Cell[BoxData[
      \(TraditionalForm\`k1 = 0\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`k2 = 1\)]],
  " by "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(cck2 = CanonicalVariables[{u}, {x}, {x\^2}, {x\ u}, \n\t\t{w}, {t}]; 
    cck2 // LTF\)], "Input"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {
            RowBox[{"t", "==", 
              StyleBox[\(-\(1\/x\)\),
                ScriptLevel->0]}]},
          {
            RowBox[{"w", "==", 
              StyleBox[\(u\/x\),
                ScriptLevel->0]}]}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {
        Equal[ t, 
          Times[ -1, 
            Power[ x, -1]]], 
        Equal[ w, 
          Times[ u, 
            Power[ x, -1]]]}]]], "Output"]
}, Open  ]],

Cell[TextData[{
  "For each set of canonical variables, there exists a representation of the \
original ODE. The equation in canonical variables for ",
  Cell[BoxData[
      \(TraditionalForm\`k1 = 1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`k2 = 0\)]],
  " reads"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ceqk1 = CanonicalRepresentation[firstExample, u, x, \n\t\tcck1, w, t]; 
    ceqk1 // LTF\)], "Input",
  CellTags->"first reduction"],

Cell[BoxData[
    TagBox[GridBox[{
          {\(2\ w - w\^3 - 4\ w\_t + 4\ w\^2\ w\_\(t, t\) == 0\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output"]
}, Open  ]],

Cell["\<\
The second representation related to the second set of canonical \
variables is\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ceqk2 = CanonicalRepresentation[firstExample, u, x, \n\t\tcck2, w, t]; 
    ceqk2 // LTF\)], "Input",
  CellTags->"second reduction"],

Cell[BoxData[
    TagBox[GridBox[{
          {
            RowBox[{
              RowBox[{\(t\^3\), " ", 
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(w\_t\/w\^2\),
                      ScriptLevel->0], "-", \(w\_\(t, t\)\)}], ")"}]}], "==", 
              "0"}]}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Both equations are embedded in the reduced manifold ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalM]\_c = {w, w', \(w'\)'}\)]],
  ". This manifold is free of the independent variable ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  " and thus simplifies the representation of the equation. The surface of \
the two manifolds in canonical coordinates is given in the following figure:"
}], "Text",
  CellTags->"reduced manifold"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[
      GraphicsArray[{
          Plot3D[\(-\(\(2\ w - w\^3 - 4\ p\)\/\(4\ w\^2\)\)\), {w,  .1, 2}, {
              p, \(-3\), 3}, AxesLabel \[Rule] {"\<w\>", "\<P\>", "\<Q\>"}, 
            PlotPoints \[Rule] 35, Mesh \[Rule] False, 
            ViewPoint -> {0.717, \ \(-2.988\), \ 1.417}, Ticks \[Rule] False, 
            DisplayFunction \[Rule] Identity], 
          Plot3D[p\/w\^2, {w,  .1, 2}, {p, \(-3\), 3}, 
            AxesLabel \[Rule] {"\<w\>", "\<P\>", "\<Q\>"}, 
            PlotPoints \[Rule] 35, Mesh \[Rule] False, 
            ViewPoint -> {0.717, \ \(-2.988\), \ 1.417}, Ticks \[Rule] False, 
            DisplayFunction \[Rule] Identity]}, 
        DisplayFunction \[Rule] $DisplayFunction]]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .33726 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.00802991 0.47619 [
[ 0 0 0 0 ]
[ 1 .33726 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .33726 L
0 .33726 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00802991 0.477324 0.329226 MathSubStart
%% SurfaceGraphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.66533e-016 1.10169 -0.148196 1.10169 [
[.44797 -0.02478 -5.39612 -15 ]
[.44797 -0.02478 5.60388 0 ]
[.15892 .66839 -5.31917 0 ]
[.15892 .66839 4.68083 15 ]
[-0.06694 .27471 -10 -6.62571 ]
[-0.06694 .27471 0 8.37429 ]
[ 0 0 0 0 ]
[ 1 .70824 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.02946 .11175 m
.89362 0 L
s
gsave
.44797 -0.02478 -66.3961 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(w) show
69.062500 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
0 .4272 m
.29069 .70824 L
s
gsave
.15892 .66839 -66.3192 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(P) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.02946 .11175 m
0 .4272 L
s
gsave
-0.06694 .27471 -71 -10.6257 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Q) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.02946 .11175 m
0 .4272 L
s
0 .4272 m
.29069 .70824 L
s
.29069 .70824 m
.30155 .45044 L
s
.30155 .45044 m
.02946 .11175 L
s
.89362 0 m
.98022 .38351 L
s
.98022 .38351 m
1 .65325 L
s
1 .65325 m
.91448 .33294 L
s
.91448 .33294 m
.89362 0 L
s
.02946 .11175 m
0 .4272 L
s
0 .4272 m
.91448 .33294 L
s
.91448 .33294 m
.89362 0 L
s
.89362 0 m
.02946 .11175 L
s
.30155 .45044 m
.98022 .38351 L
s
.98022 .38351 m
1 .65325 L
s
1 .65325 m
.29069 .70824 L
s
.29069 .70824 m
.30155 .45044 L
s
0 0 m
1 0 L
1 .70824 L
0 .70824 L
closepath
clip
newpath
.567 .808 .99 r
.28406 .70183 .29069 .70824 .31044 .70671 .30393 .70027 Mtetra
.30393 .70027 .31044 .70671 .33025 .70517 .32386 .69872 Mtetra
.32386 .69872 .33025 .70517 .35012 .70363 .34386 .69716 Mtetra
.34386 .69716 .35012 .70363 .37006 .70209 .36393 .69559 Mtetra
.36393 .69559 .37006 .70209 .39006 .70053 .38406 .69402 Mtetra
.38406 .69402 .39006 .70053 .41013 .69898 .40425 .69244 Mtetra
.40425 .69244 .41013 .69898 .43027 .69742 .42452 .69086 Mtetra
.828 .9 .891 r
.42452 .69086 .43027 .69742 .45056 .69036 .44508 .67582 Mtetra
.848 .79 .795 r
.44508 .67582 .45056 .69036 .4711 .66644 .46572 .65319 Mtetra
.823 .795 .825 r
.46572 .65319 .4711 .66644 .4915 .64814 .48624 .63584 Mtetra
.799 .798 .85 r
.48624 .63584 .4915 .64814 .51184 .63372 .5067 .62215 Mtetra
.776 .799 .871 r
.5067 .62215 .51184 .63372 .53215 .62206 .52713 .61106 Mtetra
.755 .8 .889 r
.52713 .61106 .53215 .62206 .55245 .61243 .54756 .60189 Mtetra
.737 .8 .903 r
.54756 .60189 .55245 .61243 .57278 .60432 .56801 .59414 Mtetra
.72 .8 .914 r
.56801 .59414 .57278 .60432 .59314 .59737 .5885 .58748 Mtetra
.705 .799 .924 r
.5885 .58748 .59314 .59737 .61354 .59132 .60903 .58167 Mtetra
.692 .799 .931 r
.60903 .58167 .61354 .59132 .63399 .58598 .62961 .57653 Mtetra
.681 .798 .937 r
.62961 .57653 .63399 .58598 .65449 .5812 .65025 .57192 Mtetra
.671 .797 .943 r
.65025 .57192 .65449 .5812 .67505 .57687 .67094 .56773 Mtetra
.662 .797 .947 r
.67094 .56773 .67505 .57687 .69567 .57292 .69169 .5639 Mtetra
.655 .796 .95 r
.69169 .5639 .69567 .57292 .71635 .56928 .7125 .56035 Mtetra
.648 .796 .953 r
.7125 .56035 .71635 .56928 .73709 .56588 .73338 .55704 Mtetra
.642 .795 .956 r
.73338 .55704 .73709 .56588 .7579 .5627 .75433 .55393 Mtetra
.637 .795 .958 r
.75433 .55393 .7579 .5627 .77877 .55969 .77534 .55098 Mtetra
.633 .795 .96 r
.77534 .55098 .77877 .55969 .79971 .55684 .79642 .54818 Mtetra
.629 .794 .962 r
.79642 .54818 .79971 .55684 .82072 .55411 .81757 .54549 Mtetra
.625 .794 .963 r
.81757 .54549 .82072 .55411 .8418 .55149 .83879 .54291 Mtetra
.622 .794 .964 r
.83879 .54291 .8418 .55149 .86295 .54897 .86008 .54041 Mtetra
.62 .794 .965 r
.86008 .54041 .86295 .54897 .88417 .54653 .88145 .538 Mtetra
.617 .794 .966 r
.88145 .538 .88417 .54653 .90546 .54415 .90288 .53564 Mtetra
.615 .794 .967 r
.90288 .53564 .90546 .54415 .92682 .54184 .92439 .53334 Mtetra
.613 .794 .968 r
.92439 .53334 .92682 .54184 .94825 .53958 .94597 .53109 Mtetra
.611 .793 .969 r
.94597 .53109 .94825 .53958 .96976 .53736 .96763 .52889 Mtetra
.61 .793 .969 r
.96763 .52889 .96976 .53736 .99134 .53519 .98936 .52672 Mtetra
.567 .808 .99 r
.27734 .69533 .28406 .70183 .30393 .70027 .29733 .69375 Mtetra
.29733 .69375 .30393 .70027 .32386 .69872 .31739 .69218 Mtetra
.31739 .69218 .32386 .69872 .34386 .69716 .33752 .69059 Mtetra
.33752 .69059 .34386 .69716 .36393 .69559 .35771 .689 Mtetra
.35771 .689 .36393 .69559 .38406 .69402 .37797 .68741 Mtetra
.37797 .68741 .38406 .69402 .40425 .69244 .39829 .68581 Mtetra
.39829 .68581 .40425 .69244 .42452 .69086 .41869 .68421 Mtetra
.891 .903 .829 r
.41869 .68421 .42452 .69086 .44508 .67582 .43954 .66112 Mtetra
.84 .787 .8 r
.43954 .66112 .44508 .67582 .46572 .65319 .46029 .63978 Mtetra
.816 .792 .83 r
.46029 .63978 .46572 .65319 .48624 .63584 .48092 .6234 Mtetra
.792 .795 .854 r
.48092 .6234 .48624 .63584 .5067 .62215 .50149 .61044 Mtetra
.769 .796 .875 r
.50149 .61044 .5067 .62215 .52713 .61106 .52204 .59993 Mtetra
.749 .797 .892 r
.52204 .59993 .52713 .61106 .54756 .60189 .5426 .59121 Mtetra
.731 .797 .905 r
.5426 .59121 .54756 .60189 .56801 .59414 .56318 .58382 Mtetra
.714 .797 .916 r
.56318 .58382 .56801 .59414 .5885 .58748 .5838 .57746 Mtetra
.7 .797 .925 r
.5838 .57746 .5885 .58748 .60903 .58167 .60446 .5719 Mtetra
.688 .796 .932 r
.60446 .5719 .60903 .58167 .62961 .57653 .62517 .56695 Mtetra
.677 .796 .938 r
.62517 .56695 .62961 .57653 .65025 .57192 .64594 .56251 Mtetra
.667 .795 .943 r
.64594 .56251 .65025 .57192 .67094 .56773 .66677 .55847 Mtetra
.659 .795 .947 r
.66677 .55847 .67094 .56773 .69169 .5639 .68766 .55475 Mtetra
.652 .795 .951 r
.68766 .55475 .69169 .5639 .7125 .56035 .70861 .5513 Mtetra
.646 .794 .954 r
.70861 .5513 .7125 .56035 .73338 .55704 .72963 .54807 Mtetra
.64 .794 .956 r
.72963 .54807 .73338 .55704 .75433 .55393 .75071 .54503 Mtetra
.635 .794 .958 r
.75071 .54503 .75433 .55393 .77534 .55098 .77186 .54215 Mtetra
.631 .794 .96 r
.77186 .54215 .77534 .55098 .79642 .54818 .79309 .53939 Mtetra
.627 .793 .962 r
.79309 .53939 .79642 .54818 .81757 .54549 .81438 .53675 Mtetra
.624 .793 .963 r
.81438 .53675 .81757 .54549 .83879 .54291 .83574 .53421 Mtetra
.621 .793 .965 r
.83574 .53421 .83879 .54291 .86008 .54041 .85718 .53174 Mtetra
.618 .793 .966 r
.85718 .53174 .86008 .54041 .88145 .538 .87869 .52935 Mtetra
.616 .793 .967 r
.87869 .52935 .88145 .538 .90288 .53564 .90027 .52701 Mtetra
.614 .793 .967 r
.90027 .52701 .90288 .53564 .92439 .53334 .92193 .52473 Mtetra
.612 .793 .968 r
.92193 .52473 .92439 .53334 .94597 .53109 .94366 .52249 Mtetra
.61 .793 .969 r
.94366 .52249 .94597 .53109 .96763 .52889 .96546 .52029 Mtetra
.609 .793 .97 r
.96546 .52029 .96763 .52889 .98936 .52672 .98734 .51813 Mtetra
.567 .808 .99 r
.27052 .68874 .27734 .69533 .29733 .69375 .29064 .68714 Mtetra
.29064 .68714 .29733 .69375 .31739 .69218 .31083 .68554 Mtetra
.31083 .68554 .31739 .69218 .33752 .69059 .33108 .68394 Mtetra
.33108 .68394 .33752 .69059 .35771 .689 .3514 .68233 Mtetra
.3514 .68233 .35771 .689 .37797 .68741 .37179 .68071 Mtetra
.37179 .68071 .37797 .68741 .39829 .68581 .39225 .67909 Mtetra
.681 .858 .966 r
.39225 .67909 .39829 .68581 .41869 .68421 .41287 .67322 Mtetra
.888 .842 .793 r
.41287 .67322 .41869 .68421 .43954 .66112 .43394 .64625 Mtetra
.832 .784 .806 r
.43394 .64625 .43954 .66112 .46029 .63978 .45479 .62622 Mtetra
.808 .788 .834 r
.45479 .62622 .46029 .63978 .48092 .6234 .47553 .61081 Mtetra
.784 .791 .858 r
.47553 .61081 .48092 .6234 .50149 .61044 .49622 .59859 Mtetra
.762 .793 .878 r
.49622 .59859 .50149 .61044 .52204 .59993 .5169 .58866 Mtetra
.742 .794 .894 r
.5169 .58866 .52204 .59993 .5426 .59121 .53758 .58039 Mtetra
.724 .794 .907 r
.53758 .58039 .5426 .59121 .56318 .58382 .55829 .57338 Mtetra
.709 .795 .918 r
.55829 .57338 .56318 .58382 .5838 .57746 .57904 .56731 Mtetra
.695 .794 .926 r
.57904 .56731 .5838 .57746 .60446 .5719 .59983 .56199 Mtetra
.683 .794 .933 r
.59983 .56199 .60446 .5719 .62517 .56695 .62068 .55725 Mtetra
.673 .794 .939 r
.62068 .55725 .62517 .56695 .64594 .56251 .64158 .55298 Mtetra
.664 .794 .944 r
.64158 .55298 .64594 .56251 .66677 .55847 .66254 .54908 Mtetra
.656 .793 .948 r
.66254 .54908 .66677 .55847 .68766 .55475 .68357 .54548 Mtetra
.649 .793 .951 r
.68357 .54548 .68766 .55475 .70861 .5513 .70466 .54213 Mtetra
.643 .793 .954 r
.70466 .54213 .70861 .5513 .72963 .54807 .72582 .53899 Mtetra
.638 .793 .957 r
.72582 .53899 .72963 .54807 .75071 .54503 .74704 .53602 Mtetra
.633 .793 .959 r
.74704 .53602 .75071 .54503 .77186 .54215 .76834 .5332 Mtetra
.629 .792 .961 r
.76834 .5332 .77186 .54215 .79309 .53939 .78971 .53049 Mtetra
.626 .792 .962 r
.78971 .53049 .79309 .53939 .81438 .53675 .81114 .52789 Mtetra
.623 .792 .963 r
.81114 .52789 .81438 .53675 .83574 .53421 .83265 .52538 Mtetra
.62 .792 .965 r
.83265 .52538 .83574 .53421 .85718 .53174 .85424 .52295 Mtetra
.617 .792 .966 r
.85424 .52295 .85718 .53174 .87869 .52935 .87589 .52058 Mtetra
.615 .792 .967 r
.87589 .52058 .87869 .52935 .90027 .52701 .89762 .51826 Mtetra
.613 .792 .968 r
.89762 .51826 .90027 .52701 .92193 .52473 .91943 .51599 Mtetra
.611 .792 .968 r
.91943 .51599 .92193 .52473 .94366 .52249 .94131 .51377 Mtetra
.61 .792 .969 r
.94131 .51377 .94366 .52249 .96546 .52029 .96327 .51158 Mtetra
.608 .792 .97 r
.96327 .51158 .96546 .52029 .98734 .51813 .9853 .50942 Mtetra
.567 .808 .99 r
.26361 .68206 .27052 .68874 .29064 .68714 .28386 .68044 Mtetra
.28386 .68044 .29064 .68714 .31083 .68554 .30418 .67882 Mtetra
.30418 .67882 .31083 .68554 .33108 .68394 .32456 .67719 Mtetra
.32456 .67719 .33108 .68394 .3514 .68233 .34501 .67556 Mtetra
.34501 .67556 .3514 .68233 .37179 .68071 .36553 .67392 Mtetra
.36553 .67392 .37179 .68071 .39225 .67909 .38612 .67227 Mtetra
.834 .899 .885 r
.38612 .67227 .39225 .67909 .41287 .67322 .40712 .65637 Mtetra
.848 .774 .779 r
.40712 .65637 .41287 .67322 .43394 .64625 .42827 .63121 Mtetra
.824 .78 .811 r
.42827 .63121 .43394 .64625 .45479 .62622 .44923 .61249 Mtetra
.799 .784 .839 r
.44923 .61249 .45479 .62622 .47553 .61081 .47008 .59806 Mtetra
.776 .788 .862 r
.47008 .59806 .47553 .61081 .49622 .59859 .49089 .58659 Mtetra
.755 .79 .881 r
.49089 .58659 .49622 .59859 .5169 .58866 .51169 .57724 Mtetra
.735 .791 .897 r
.51169 .57724 .5169 .58866 .53758 .58039 .5325 .56943 Mtetra
.718 .791 .909 r
.5325 .56943 .53758 .58039 .55829 .57338 .55333 .56279 Mtetra
.703 .792 .92 r
.55333 .56279 .55829 .57338 .57904 .56731 .57421 .55703 Mtetra
.69 .792 .928 r
.57421 .55703 .57904 .56731 .59983 .56199 .59514 .55196 Mtetra
.679 .792 .935 r
.59514 .55196 .59983 .56199 .62068 .55725 .61612 .54742 Mtetra
.669 .792 .94 r
.61612 .54742 .62068 .55725 .64158 .55298 .63716 .54332 Mtetra
.66 .792 .945 r
.63716 .54332 .64158 .55298 .66254 .54908 .65826 .53956 Mtetra
.653 .792 .949 r
.65826 .53956 .66254 .54908 .68357 .54548 .67943 .53608 Mtetra
.646 .792 .952 r
.67943 .53608 .68357 .54548 .70466 .54213 .70066 .53283 Mtetra
.641 .791 .955 r
.70066 .53283 .70466 .54213 .72582 .53899 .72196 .52978 Mtetra
.636 .791 .957 r
.72196 .52978 .72582 .53899 .74704 .53602 .74333 .52688 Mtetra
.631 .791 .959 r
.74333 .52688 .74704 .53602 .76834 .5332 .76477 .52412 Mtetra
.627 .791 .961 r
.76477 .52412 .76834 .5332 .78971 .53049 .78628 .52147 Mtetra
.624 .791 .962 r
.78628 .52147 .78971 .53049 .81114 .52789 .80786 .51891 Mtetra
.621 .791 .964 r
.80786 .51891 .81114 .52789 .83265 .52538 .82952 .51644 Mtetra
.618 .792 .965 r
.82952 .51644 .83265 .52538 .85424 .52295 .85125 .51403 Mtetra
.616 .792 .966 r
.85125 .51403 .85424 .52295 .87589 .52058 .87306 .51168 Mtetra
.614 .792 .967 r
.87306 .51168 .87589 .52058 .89762 .51826 .89494 .50939 Mtetra
.612 .792 .968 r
.89494 .50939 .89762 .51826 .91943 .51599 .9169 .50713 Mtetra
.61 .792 .968 r
.9169 .50713 .91943 .51599 .94131 .51377 .93893 .50492 Mtetra
.609 .792 .969 r
.93893 .50492 .94131 .51377 .96327 .51158 .96104 .50274 Mtetra
.607 .792 .97 r
.96104 .50274 .96327 .51158 .9853 .50942 .98323 .50058 Mtetra
.567 .808 .99 r
.2566 .67528 .26361 .68206 .28386 .68044 .27698 .67364 Mtetra
.27698 .67364 .28386 .68044 .30418 .67882 .29743 .672 Mtetra
.29743 .672 .30418 .67882 .32456 .67719 .31795 .67035 Mtetra
.31795 .67035 .32456 .67719 .34501 .67556 .33853 .66869 Mtetra
.33853 .66869 .34501 .67556 .36553 .67392 .35919 .66703 Mtetra
.35919 .66703 .36553 .67392 .38612 .67227 .37991 .66536 Mtetra
.903 .899 .812 r
.37991 .66536 .38612 .67227 .40712 .65637 .4013 .63933 Mtetra
.839 .77 .785 r
.4013 .63933 .40712 .65637 .42827 .63121 .42254 .616 Mtetra
.814 .776 .817 r
.42254 .616 .42827 .63121 .44923 .61249 .4436 .5986 Mtetra
.79 .781 .844 r
.4436 .5986 .44923 .61249 .47008 .59806 .46456 .58516 Mtetra
.767 .784 .866 r
.46456 .58516 .47008 .59806 .49089 .58659 .48549 .57444 Mtetra
.747 .786 .885 r
.48549 .57444 .49089 .58659 .51169 .57724 .50641 .56568 Mtetra
.728 .787 .9 r
.50641 .56568 .51169 .57724 .5325 .56943 .52735 .55834 Mtetra
.712 .788 .912 r
.52735 .55834 .5325 .56943 .55333 .56279 .54831 .55207 Mtetra
.697 .789 .921 r
.54831 .55207 .55333 .56279 .57421 .55703 .56933 .54661 Mtetra
.685 .789 .929 r
.56933 .54661 .57421 .55703 .59514 .55196 .59039 .54179 Mtetra
.674 .789 .936 r
.59039 .54179 .59514 .55196 .61612 .54742 .6115 .53746 Mtetra
.665 .79 .941 r
.6115 .53746 .61612 .54742 .63716 .54332 .63268 .53353 Mtetra
.657 .79 .945 r
.63268 .53353 .63716 .54332 .65826 .53956 .65392 .52991 Mtetra
.649 .79 .949 r
.65392 .52991 .65826 .53956 .67943 .53608 .67523 .52656 Mtetra
.643 .79 .952 r
.67523 .52656 .67943 .53608 .70066 .53283 .6966 .52341 Mtetra
.638 .79 .955 r
.6966 .52341 .70066 .53283 .72196 .52978 .71804 .52044 Mtetra
.633 .79 .957 r
.71804 .52044 .72196 .52978 .74333 .52688 .73956 .51762 Mtetra
.629 .79 .959 r
.73956 .51762 .74333 .52688 .76477 .52412 .76114 .51492 Mtetra
.626 .79 .961 r
.76114 .51492 .76477 .52412 .78628 .52147 .7828 .51232 Mtetra
.622 .79 .962 r
.7828 .51232 .78628 .52147 .80786 .51891 .80453 .5098 Mtetra
.62 .791 .964 r
.80453 .5098 .80786 .51891 .82952 .51644 .82634 .50736 Mtetra
.617 .791 .965 r
.82634 .50736 .82952 .51644 .85125 .51403 .84822 .50499 Mtetra
.615 .791 .966 r
.84822 .50499 .85125 .51403 .87306 .51168 .87018 .50266 Mtetra
.613 .791 .967 r
.87018 .50266 .87306 .51168 .89494 .50939 .89222 .50039 Mtetra
.611 .791 .968 r
.89222 .50039 .89494 .50939 .9169 .50713 .91433 .49815 Mtetra
.609 .791 .968 r
.91433 .49815 .9169 .50713 .93893 .50492 .93652 .49595 Mtetra
.608 .791 .969 r
.93652 .49595 .93893 .50492 .96104 .50274 .95878 .49377 Mtetra
.607 .791 .97 r
.95878 .49377 .96104 .50274 .98323 .50058 .98113 .49162 Mtetra
.567 .808 .99 r
.2495 .66841 .2566 .67528 .27698 .67364 .27001 .66675 Mtetra
.27001 .66675 .27698 .67364 .29743 .672 .29059 .66508 Mtetra
.29059 .66508 .29743 .672 .31795 .67035 .31124 .66341 Mtetra
.31124 .66341 .31795 .67035 .33853 .66869 .33196 .66173 Mtetra
.33196 .66173 .33853 .66869 .35919 .66703 .35275 .66004 Mtetra
.722 .871 .951 r
.35275 .66004 .35919 .66703 .37991 .66536 .37379 .6521 Mtetra
.887 .82 .776 r
.37379 .6521 .37991 .66536 .4013 .63933 .39542 .6221 Mtetra
.829 .766 .792 r
.39542 .6221 .4013 .63933 .42254 .616 .41675 .60062 Mtetra
.804 .772 .823 r
.41675 .60062 .42254 .616 .4436 .5986 .4379 .58455 Mtetra
.781 .776 .849 r
.4379 .58455 .4436 .5986 .46456 .58516 .45898 .5721 Mtetra
.759 .78 .87 r
.45898 .5721 .46456 .58516 .48549 .57444 .48002 .56214 Mtetra
.739 .782 .888 r
.48002 .56214 .48549 .57444 .50641 .56568 .50106 .55397 Mtetra
.721 .784 .902 r
.50106 .55397 .50641 .56568 .52735 .55834 .52213 .5471 Mtetra
.705 .785 .914 r
.52213 .5471 .52735 .55834 .54831 .55207 .54323 .54121 Mtetra
.691 .786 .923 r
.54323 .54121 .54831 .55207 .56933 .54661 .56437 .53606 Mtetra
.68 .787 .931 r
.56437 .53606 .56933 .54661 .59039 .54179 .58557 .53148 Mtetra
.669 .787 .937 r
.58557 .53148 .59039 .54179 .6115 .53746 .60682 .52737 Mtetra
.661 .787 .942 r
.60682 .52737 .6115 .53746 .63268 .53353 .62814 .52361 Mtetra
.653 .788 .946 r
.62814 .52361 .63268 .53353 .65392 .52991 .64952 .52014 Mtetra
.646 .788 .95 r
.64952 .52014 .65392 .52991 .67523 .52656 .67097 .5169 Mtetra
.64 .788 .953 r
.67097 .5169 .67523 .52656 .6966 .52341 .69249 .51386 Mtetra
.635 .789 .955 r
.69249 .51386 .6966 .52341 .71804 .52044 .71408 .51098 Mtetra
.631 .789 .958 r
.71408 .51098 .71804 .52044 .73956 .51762 .73574 .50823 Mtetra
.627 .789 .96 r
.73574 .50823 .73956 .51762 .76114 .51492 .75747 .50559 Mtetra
.624 .789 .961 r
.75747 .50559 .76114 .51492 .7828 .51232 .77928 .50304 Mtetra
.621 .789 .963 r
.77928 .50304 .7828 .51232 .80453 .5098 .80116 .50057 Mtetra
.618 .79 .964 r
.80116 .50057 .80453 .5098 .82634 .50736 .82312 .49816 Mtetra
.616 .79 .965 r
.82312 .49816 .82634 .50736 .84822 .50499 .84515 .49582 Mtetra
.614 .79 .966 r
.84515 .49582 .84822 .50499 .87018 .50266 .86727 .49352 Mtetra
.612 .79 .967 r
.86727 .49352 .87018 .50266 .89222 .50039 .88945 .49126 Mtetra
.61 .79 .968 r
.88945 .49126 .89222 .50039 .91433 .49815 .91172 .48904 Mtetra
.609 .791 .968 r
.91172 .48904 .91433 .49815 .93652 .49595 .93407 .48684 Mtetra
.607 .791 .969 r
.93407 .48684 .93652 .49595 .95878 .49377 .95649 .48468 Mtetra
.606 .791 .97 r
.95649 .48468 .95878 .49377 .98113 .49162 .979 .48253 Mtetra
.567 .808 .99 r
.24229 .66145 .2495 .66841 .27001 .66675 .26294 .65976 Mtetra
.26294 .65976 .27001 .66675 .29059 .66508 .28365 .65807 Mtetra
.28365 .65807 .29059 .66508 .31124 .66341 .30443 .65637 Mtetra
.30443 .65637 .31124 .66341 .33196 .66173 .32529 .65467 Mtetra
.32529 .65467 .33196 .66173 .35275 .66004 .34622 .65296 Mtetra
.872 .899 .849 r
.34622 .65296 .35275 .66004 .37379 .6521 .36779 .63203 Mtetra
.843 .753 .764 r
.36779 .63203 .37379 .6521 .39542 .6221 .38948 .60469 Mtetra
.818 .761 .798 r
.38948 .60469 .39542 .6221 .41675 .60062 .41088 .58506 Mtetra
.794 .767 .828 r
.41088 .58506 .41675 .60062 .4379 .58455 .43214 .57033 Mtetra
.771 .772 .853 r
.43214 .57033 .4379 .58455 .45898 .5721 .45332 .55887 Mtetra
.749 .775 .874 r
.45332 .55887 .45898 .5721 .48002 .56214 .47448 .54968 Mtetra
.73 .778 .891 r
.47448 .54968 .48002 .56214 .50106 .55397 .49565 .5421 Mtetra
.713 .78 .905 r
.49565 .5421 .50106 .55397 .52213 .5471 .51684 .53571 Mtetra
.698 .782 .916 r
.51684 .53571 .52213 .5471 .54323 .54121 .53807 .5302 Mtetra
.685 .783 .925 r
.53807 .5302 .54323 .54121 .56437 .53606 .55935 .52536 Mtetra
.674 .784 .932 r
.55935 .52536 .56437 .53606 .58557 .53148 .58069 .52104 Mtetra
.665 .785 .938 r
.58069 .52104 .58557 .53148 .60682 .52737 .60208 .51713 Mtetra
.656 .785 .943 r
.60208 .51713 .60682 .52737 .62814 .52361 .62354 .51355 Mtetra
.649 .786 .947 r
.62354 .51355 .62814 .52361 .64952 .52014 .64506 .51022 Mtetra
.643 .786 .95 r
.64506 .51022 .64952 .52014 .67097 .5169 .66665 .50711 Mtetra
.638 .787 .953 r
.66665 .50711 .67097 .5169 .69249 .51386 .68832 .50417 Mtetra
.633 .787 .956 r
.68832 .50417 .69249 .51386 .71408 .51098 .71005 .50138 Mtetra
.629 .787 .958 r
.71005 .50138 .71408 .51098 .73574 .50823 .73186 .4987 Mtetra
.625 .788 .96 r
.73186 .4987 .73574 .50823 .75747 .50559 .75375 .49612 Mtetra
.622 .788 .961 r
.75375 .49612 .75747 .50559 .77928 .50304 .7757 .49363 Mtetra
.619 .788 .963 r
.7757 .49363 .77928 .50304 .80116 .50057 .79774 .4912 Mtetra
.617 .789 .964 r
.79774 .4912 .80116 .50057 .82312 .49816 .81985 .48883 Mtetra
.614 .789 .965 r
.81985 .48883 .82312 .49816 .84515 .49582 .84204 .48652 Mtetra
.612 .789 .966 r
.84204 .48652 .84515 .49582 .86727 .49352 .86431 .48424 Mtetra
.611 .79 .967 r
.86431 .48424 .86727 .49352 .88945 .49126 .88665 .482 Mtetra
.609 .79 .968 r
.88665 .482 .88945 .49126 .91172 .48904 .90908 .47979 Mtetra
.608 .79 .969 r
.90908 .47979 .91172 .48904 .93407 .48684 .93159 .47761 Mtetra
.606 .79 .969 r
.93159 .47761 .93407 .48684 .95649 .48468 .95417 .47545 Mtetra
.605 .79 .97 r
.95417 .47545 .95649 .48468 .979 .48253 .97684 .47331 Mtetra
.567 .808 .99 r
.23498 .65438 .24229 .66145 .26294 .65976 .25576 .65267 Mtetra
.25576 .65267 .26294 .65976 .28365 .65807 .27661 .65095 Mtetra
.27661 .65095 .28365 .65807 .30443 .65637 .29753 .64923 Mtetra
.29753 .64923 .30443 .65637 .32529 .65467 .31853 .6475 Mtetra
.31853 .6475 .32529 .65467 .34622 .65296 .33959 .64577 Mtetra
.93 .89 .77 r
.33959 .64577 .34622 .65296 .36779 .63203 .36174 .61176 Mtetra
.831 .748 .771 r
.36174 .61176 .36779 .63203 .38948 .60469 .38347 .58709 Mtetra
.807 .755 .805 r
.38347 .58709 .38948 .60469 .41088 .58506 .40495 .56931 Mtetra
.783 .761 .834 r
.40495 .56931 .41088 .58506 .43214 .57033 .4263 .55593 Mtetra
.76 .767 .858 r
.4263 .55593 .43214 .57033 .45332 .55887 .4476 .54549 Mtetra
.74 .771 .878 r
.4476 .54549 .45332 .55887 .47448 .54968 .46888 .53706 Mtetra
.721 .774 .894 r
.46888 .53706 .47448 .54968 .49565 .5421 .49017 .53009 Mtetra
.705 .776 .907 r
.49017 .53009 .49565 .5421 .51684 .53571 .51149 .52417 Mtetra
.691 .778 .918 r
.51149 .52417 .51684 .53571 .53807 .5302 .53285 .51904 Mtetra
.679 .78 .926 r
.53285 .51904 .53807 .5302 .55935 .52536 .55427 .51452 Mtetra
.669 .781 .933 r
.55427 .51452 .55935 .52536 .58069 .52104 .57574 .51046 Mtetra
.66 .782 .939 r
.57574 .51046 .58069 .52104 .60208 .51713 .59727 .50676 Mtetra
.652 .783 .944 r
.59727 .50676 .60208 .51713 .62354 .51355 .61887 .50335 Mtetra
.646 .784 .948 r
.61887 .50335 .62354 .51355 .64506 .51022 .64054 .50017 Mtetra
.64 .784 .951 r
.64054 .50017 .64506 .51022 .66665 .50711 .66228 .49719 Mtetra
.635 .785 .954 r
.66228 .49719 .66665 .50711 .68832 .50417 .68409 .49435 Mtetra
.63 .786 .956 r
.68409 .49435 .68832 .50417 .71005 .50138 .70597 .49165 Mtetra
.626 .786 .958 r
.70597 .49165 .71005 .50138 .73186 .4987 .72793 .48904 Mtetra
.623 .787 .96 r
.72793 .48904 .73186 .4987 .75375 .49612 .74997 .48653 Mtetra
.62 .787 .962 r
.74997 .48653 .75375 .49612 .7757 .49363 .77208 .48408 Mtetra
.617 .787 .963 r
.77208 .48408 .7757 .49363 .79774 .4912 .79427 .4817 Mtetra
.615 .788 .964 r
.79427 .4817 .79774 .4912 .81985 .48883 .81654 .47937 Mtetra
.613 .788 .965 r
.81654 .47937 .81985 .48883 .84204 .48652 .83888 .47708 Mtetra
.611 .788 .966 r
.83888 .47708 .84204 .48652 .86431 .48424 .86131 .47483 Mtetra
.61 .789 .967 r
.86131 .47483 .86431 .48424 .88665 .482 .88381 .47261 Mtetra
.608 .789 .968 r
.88381 .47261 .88665 .482 .90908 .47979 .9064 .47042 Mtetra
.607 .789 .969 r
.9064 .47042 .90908 .47979 .93159 .47761 .92907 .46824 Mtetra
.606 .79 .969 r
.92907 .46824 .93159 .47761 .95417 .47545 .95181 .46609 Mtetra
.604 .79 .97 r
.95181 .46609 .95417 .47545 .97684 .47331 .97465 .46395 Mtetra
.567 .808 .99 r
.22757 .64721 .23498 .65438 .25576 .65267 .24848 .64548 Mtetra
.24848 .64548 .25576 .65267 .27661 .65095 .26947 .64374 Mtetra
.26947 .64374 .27661 .65095 .29753 .64923 .29053 .64199 Mtetra
.29053 .64199 .29753 .64923 .31853 .6475 .31167 .64023 Mtetra
.838 .896 .881 r
.31167 .64023 .31853 .6475 .33959 .64577 .33341 .62341 Mtetra
.851 .747 .747 r
.33341 .62341 .33959 .64577 .36174 .61176 .35562 .59129 Mtetra
.818 .741 .779 r
.35562 .59129 .36174 .61176 .38347 .58709 .3774 .56929 Mtetra
.794 .749 .812 r
.3774 .56929 .38347 .58709 .40495 .56931 .39895 .55338 Mtetra
.77 .756 .84 r
.39895 .55338 .40495 .56931 .4263 .55593 .4204 .54136 Mtetra
.749 .761 .863 r
.4204 .54136 .4263 .55593 .4476 .54549 .4418 .53193 Mtetra
.729 .766 .882 r
.4418 .53193 .4476 .54549 .46888 .53706 .4632 .52429 Mtetra
.712 .769 .897 r
.4632 .52429 .46888 .53706 .49017 .53009 .48461 .51792 Mtetra
.697 .772 .909 r
.48461 .51792 .49017 .53009 .51149 .52417 .50606 .51248 Mtetra
.684 .774 .919 r
.50606 .51248 .51149 .52417 .53285 .51904 .52756 .50774 Mtetra
.673 .776 .928 r
.52756 .50774 .53285 .51904 .55427 .51452 .54911 .50353 Mtetra
.664 .778 .934 r
.54911 .50353 .55427 .51452 .57574 .51046 .57072 .49973 Mtetra
.655 .779 .94 r
.57072 .49973 .57574 .51046 .59727 .50676 .5924 .49624 Mtetra
.648 .781 .944 r
.5924 .49624 .59727 .50676 .61887 .50335 .61414 .49301 Mtetra
.642 .782 .948 r
.61414 .49301 .61887 .50335 .64054 .50017 .63596 .48999 Mtetra
.636 .783 .951 r
.63596 .48999 .64054 .50017 .66228 .49719 .65784 .48712 Mtetra
.632 .783 .954 r
.65784 .48712 .66228 .49719 .68409 .49435 .6798 .48439 Mtetra
.628 .784 .957 r
.6798 .48439 .68409 .49435 .70597 .49165 .70184 .48177 Mtetra
.624 .785 .959 r
.70184 .48177 .70597 .49165 .72793 .48904 .72395 .47925 Mtetra
.621 .785 .96 r
.72395 .47925 .72793 .48904 .74997 .48653 .74614 .47679 Mtetra
.618 .786 .962 r
.74614 .47679 .74997 .48653 .77208 .48408 .7684 .4744 Mtetra
.616 .786 .963 r
.7684 .4744 .77208 .48408 .79427 .4817 .79075 .47206 Mtetra
.614 .787 .964 r
.79075 .47206 .79427 .4817 .81654 .47937 .81317 .46977 Mtetra
.612 .787 .965 r
.81317 .46977 .81654 .47937 .83888 .47708 .83568 .46751 Mtetra
.61 .788 .966 r
.83568 .46751 .83888 .47708 .86131 .47483 .85826 .46528 Mtetra
.608 .788 .967 r
.85826 .46528 .86131 .47483 .88381 .47261 .88093 .46308 Mtetra
.607 .788 .968 r
.88093 .46308 .88381 .47261 .9064 .47042 .90368 .4609 Mtetra
.606 .789 .969 r
.90368 .4609 .9064 .47042 .92907 .46824 .92651 .45874 Mtetra
.605 .789 .969 r
.92651 .45874 .92907 .46824 .95181 .46609 .94942 .45659 Mtetra
.604 .789 .97 r
.94942 .45659 .95181 .46609 .97465 .46395 .97242 .45446 Mtetra
.567 .808 .99 r
.22005 .63994 .22757 .64721 .24848 .64548 .2411 .63818 Mtetra
.2411 .63818 .24848 .64548 .26947 .64374 .26223 .63641 Mtetra
.26223 .63641 .26947 .64374 .29053 .64199 .28343 .63464 Mtetra
.28343 .63464 .29053 .64199 .31167 .64023 .30471 .63286 Mtetra
.928 .888 .772 r
.30471 .63286 .31167 .64023 .33341 .62341 .32725 .59869 Mtetra
.828 .724 .751 r
.32725 .59869 .33341 .62341 .35562 .59129 .34944 .5706 Mtetra
.803 .733 .787 r
.34944 .5706 .35562 .59129 .3774 .56929 .37125 .55129 Mtetra
.78 .742 .818 r
.37125 .55129 .3774 .56929 .39895 .55338 .39288 .53727 Mtetra
.757 .749 .845 r
.39288 .53727 .39895 .55338 .4204 .54136 .41442 .52662 Mtetra
.737 .755 .867 r
.41442 .52662 .4204 .54136 .4418 .53193 .43593 .5182 Mtetra
.719 .76 .885 r
.43593 .5182 .4418 .53193 .4632 .52429 .45744 .51134 Mtetra
.703 .764 .9 r
.45744 .51134 .4632 .52429 .48461 .51792 .47898 .50559 Mtetra
.689 .768 .912 r
.47898 .50559 .48461 .51792 .50606 .51248 .50056 .50064 Mtetra
.677 .771 .921 r
.50056 .50064 .50606 .51248 .52756 .50774 .52219 .49628 Mtetra
.667 .773 .929 r
.52219 .49628 .52756 .50774 .54911 .50353 .54388 .49239 Mtetra
.658 .775 .935 r
.54388 .49239 .54911 .50353 .57072 .49973 .56564 .48885 Mtetra
.65 .777 .941 r
.56564 .48885 .57072 .49973 .5924 .49624 .58746 .48558 Mtetra
.644 .778 .945 r
.58746 .48558 .5924 .49624 .61414 .49301 .60935 .48253 Mtetra
.638 .779 .949 r
.60935 .48253 .61414 .49301 .63596 .48999 .63131 .47965 Mtetra
.633 .781 .952 r
.63131 .47965 .63596 .48999 .65784 .48712 .65334 .47692 Mtetra
.629 .782 .955 r
.65334 .47692 .65784 .48712 .6798 .48439 .67545 .47429 Mtetra
.625 .783 .957 r
.67545 .47429 .6798 .48439 .70184 .48177 .69764 .47176 Mtetra
.622 .783 .959 r
.69764 .47176 .70184 .48177 .72395 .47925 .71991 .46931 Mtetra
.619 .784 .961 r
.71991 .46931 .72395 .47925 .74614 .47679 .74225 .46692 Mtetra
.616 .785 .962 r
.74225 .46692 .74614 .47679 .7684 .4744 .76467 .46458 Mtetra
.614 .785 .963 r
.76467 .46458 .7684 .4744 .79075 .47206 .78718 .46228 Mtetra
.612 .786 .965 r
.78718 .46228 .79075 .47206 .81317 .46977 .80976 .46003 Mtetra
.61 .786 .966 r
.80976 .46003 .81317 .46977 .83568 .46751 .83243 .4578 Mtetra
.609 .787 .967 r
.83243 .4578 .83568 .46751 .85826 .46528 .85517 .45559 Mtetra
.607 .787 .967 r
.85517 .45559 .85826 .46528 .88093 .46308 .878 .45341 Mtetra
.606 .788 .968 r
.878 .45341 .88093 .46308 .90368 .4609 .90092 .45124 Mtetra
.605 .788 .969 r
.90092 .45124 .90368 .4609 .92651 .45874 .92391 .44909 Mtetra
.604 .788 .969 r
.92391 .44909 .92651 .45874 .94942 .45659 .947 .44695 Mtetra
.603 .789 .97 r
.947 .44695 .94942 .45659 .97242 .45446 .97016 .44482 Mtetra
.567 .808 .99 r
.21242 .63256 .22005 .63994 .2411 .63818 .23361 .63078 Mtetra
.23361 .63078 .2411 .63818 .26223 .63641 .25488 .62898 Mtetra
.25488 .62898 .26223 .63641 .28343 .63464 .27622 .62719 Mtetra
.829 .893 .887 r
.27622 .62719 .28343 .63464 .30471 .63286 .29824 .6111 Mtetra
.87 .76 .738 r
.29824 .6111 .30471 .63286 .32725 .59869 .32103 .57375 Mtetra
.811 .715 .759 r
.32103 .57375 .32725 .59869 .34944 .5706 .34319 .54971 Mtetra
.787 .725 .794 r
.34319 .54971 .34944 .5706 .37125 .55129 .36504 .5331 Mtetra
.764 .734 .825 r
.36504 .5331 .37125 .55129 .39288 .53727 .38674 .52097 Mtetra
.743 .742 .85 r
.38674 .52097 .39288 .53727 .41442 .52662 .40837 .51169 Mtetra
.724 .749 .872 r
.40837 .51169 .41442 .52662 .43593 .5182 .42998 .5043 Mtetra
.708 .755 .889 r
.42998 .5043 .43593 .5182 .45744 .51134 .45161 .49823 Mtetra
.693 .759 .903 r
.45161 .49823 .45744 .51134 .47898 .50559 .47328 .49309 Mtetra
.68 .763 .914 r
.47328 .49309 .47898 .50559 .50056 .50064 .49499 .48863 Mtetra
.67 .767 .923 r
.49499 .48863 .50056 .50064 .52219 .49628 .51676 .48467 Mtetra
.66 .77 .93 r
.51676 .48467 .52219 .49628 .54388 .49239 .53859 .4811 Mtetra
.652 .772 .937 r
.53859 .4811 .54388 .49239 .56564 .48885 .56048 .47782 Mtetra
.645 .774 .942 r
.56048 .47782 .56564 .48885 .58746 .48558 .58244 .47477 Mtetra
.639 .776 .946 r
.58244 .47477 .58746 .48558 .60935 .48253 .60448 .4719 Mtetra
.634 .777 .949 r
.60448 .4719 .60935 .48253 .63131 .47965 .62659 .46917 Mtetra
.63 .779 .952 r
.62659 .46917 .63131 .47965 .65334 .47692 .64878 .46656 Mtetra
.626 .78 .955 r
.64878 .46656 .65334 .47692 .67545 .47429 .67104 .46405 Mtetra
.623 .781 .957 r
.67104 .46405 .67545 .47429 .69764 .47176 .69338 .46161 Mtetra
.62 .782 .959 r
.69338 .46161 .69764 .47176 .71991 .46931 .71581 .45923 Mtetra
.617 .783 .961 r
.71581 .45923 .71991 .46931 .74225 .46692 .73831 .4569 Mtetra
.615 .784 .962 r
.73831 .4569 .74225 .46692 .76467 .46458 .76089 .45462 Mtetra
.613 .784 .964 r
.76089 .45462 .76467 .46458 .78718 .46228 .78355 .45236 Mtetra
.611 .785 .965 r
.78355 .45236 .78718 .46228 .80976 .46003 .8063 .45014 Mtetra
.609 .786 .966 r
.8063 .45014 .80976 .46003 .83243 .4578 .82913 .44794 Mtetra
.608 .786 .967 r
.82913 .44794 .83243 .4578 .85517 .45559 .85204 .44576 Mtetra
.606 .787 .967 r
.85204 .44576 .85517 .45559 .878 .45341 .87503 .4436 Mtetra
.605 .787 .968 r
.87503 .4436 .878 .45341 .90092 .45124 .89812 .44145 Mtetra
.604 .788 .969 r
.89812 .44145 .90092 .45124 .92391 .44909 .92128 .4393 Mtetra
.603 .788 .969 r
.92128 .4393 .92391 .44909 .947 .44695 .94453 .43717 Mtetra
.602 .788 .97 r
.94453 .43717 .947 .44695 .97016 .44482 .96787 .43504 Mtetra
.567 .808 .99 r
.20467 .62508 .21242 .63256 .23361 .63078 .22601 .62326 Mtetra
.22601 .62326 .23361 .63078 .25488 .62898 .24742 .62145 Mtetra
.24742 .62145 .25488 .62898 .27622 .62719 .26891 .61962 Mtetra
.94 .879 .748 r
.26891 .61962 .27622 .62719 .29824 .6111 .29211 .57949 Mtetra
.815 .693 .731 r
.29211 .57949 .29824 .6111 .32103 .57375 .31476 .54859 Mtetra
.791 .704 .768 r
.31476 .54859 .32103 .57375 .34319 .54971 .33688 .5286 Mtetra
.769 .715 .802 r
.33688 .5286 .34319 .54971 .36504 .5331 .35876 .5147 Mtetra
.748 .725 .831 r
.35876 .5147 .36504 .5331 .38674 .52097 .38052 .50447 Mtetra
.728 .734 .856 r
.38052 .50447 .38674 .52097 .40837 .51169 .40224 .49657 Mtetra
.711 .742 .876 r
.40224 .49657 .40837 .51169 .42998 .5043 .42396 .49023 Mtetra
.696 .749 .892 r
.42396 .49023 .42998 .5043 .45161 .49823 .44571 .48495 Mtetra
.683 .754 .905 r
.44571 .48495 .45161 .49823 .47328 .49309 .4675 .48043 Mtetra
.672 .759 .916 r
.4675 .48043 .47328 .49309 .49499 .48863 .48934 .47646 Mtetra
.662 .763 .925 r
.48934 .47646 .49499 .48863 .51676 .48467 .51125 .4729 Mtetra
.654 .766 .932 r
.51125 .4729 .51676 .48467 .53859 .4811 .53321 .46965 Mtetra
.647 .769 .938 r
.53321 .46965 .53859 .4811 .56048 .47782 .55525 .46664 Mtetra
.64 .771 .943 r
.55525 .46664 .56048 .47782 .58244 .47477 .57736 .46381 Mtetra
.635 .773 .947 r
.57736 .46381 .58244 .47477 .60448 .4719 .59955 .46112 Mtetra
.63 .775 .95 r
.59955 .46112 .60448 .4719 .62659 .46917 .62181 .45854 Mtetra
.626 .777 .953 r
.62181 .45854 .62659 .46917 .64878 .46656 .64415 .45606 Mtetra
.623 .778 .955 r
.64415 .45606 .64878 .46656 .67104 .46405 .66657 .45365 Mtetra
.62 .779 .958 r
.66657 .45365 .67104 .46405 .69338 .46161 .68907 .4513 Mtetra
.617 .781 .959 r
.68907 .4513 .69338 .46161 .71581 .45923 .71165 .449 Mtetra
.615 .782 .961 r
.71165 .449 .71581 .45923 .73831 .4569 .73431 .44674 Mtetra
.613 .783 .963 r
.73431 .44674 .73831 .4569 .76089 .45462 .75705 .44451 Mtetra
.611 .783 .964 r
.75705 .44451 .76089 .45462 .78355 .45236 .77988 .4423 Mtetra
.609 .784 .965 r
.77988 .4423 .78355 .45236 .8063 .45014 .80279 .44011 Mtetra
.608 .785 .966 r
.80279 .44011 .8063 .45014 .82913 .44794 .82578 .43794 Mtetra
.606 .785 .967 r
.82578 .43794 .82913 .44794 .85204 .44576 .84886 .43579 Mtetra
.605 .786 .968 r
.84886 .43579 .85204 .44576 .87503 .4436 .87202 .43364 Mtetra
.604 .786 .968 r
.87202 .43364 .87503 .4436 .89812 .44145 .89527 .4315 Mtetra
.603 .787 .969 r
.89527 .4315 .89812 .44145 .92128 .4393 .91861 .42937 Mtetra
.602 .787 .969 r
.91861 .42937 .92128 .4393 .94453 .43717 .94203 .42724 Mtetra
.601 .788 .97 r
.94203 .42724 .94453 .43717 .96787 .43504 .96554 .42511 Mtetra
.567 .808 .99 r
.19682 .61748 .20467 .62508 .22601 .62326 .2183 .61564 Mtetra
.2183 .61564 .22601 .62326 .24742 .62145 .23985 .61379 Mtetra
.888 .891 .827 r
.23985 .61379 .24742 .62145 .26891 .61962 .26258 .58895 Mtetra
.848 .717 .718 r
.26258 .58895 .26891 .61962 .29211 .57949 .28595 .54767 Mtetra
.791 .679 .74 r
.28595 .54767 .29211 .57949 .31476 .54859 .30843 .52321 Mtetra
.769 .691 .777 r
.30843 .52321 .31476 .54859 .33688 .5286 .33051 .50727 Mtetra
.748 .703 .809 r
.33051 .50727 .33688 .5286 .35876 .5147 .35241 .49609 Mtetra
.729 .715 .837 r
.35241 .49609 .35876 .5147 .38052 .50447 .37423 .48777 Mtetra
.712 .726 .861 r
.37423 .48777 .38052 .50447 .40224 .49657 .39604 .48127 Mtetra
.697 .735 .88 r
.39604 .48127 .40224 .49657 .42396 .49023 .41787 .47597 Mtetra
.684 .742 .895 r
.41787 .47597 .42396 .49023 .44571 .48495 .43973 .47149 Mtetra
.672 .749 .908 r
.43973 .47149 .44571 .48495 .4675 .48043 .46164 .4676 Mtetra
.663 .754 .918 r
.46164 .4676 .4675 .48043 .48934 .47646 .48362 .46413 Mtetra
.654 .759 .926 r
.48362 .46413 .48934 .47646 .51125 .4729 .50566 .46097 Mtetra
.647 .762 .933 r
.50566 .46097 .51125 .4729 .53321 .46965 .52777 .45804 Mtetra
.641 .766 .939 r
.52777 .45804 .53321 .46965 .55525 .46664 .54995 .4553 Mtetra
.635 .768 .943 r
.54995 .4553 .55525 .46664 .57736 .46381 .57221 .45269 Mtetra
.631 .771 .947 r
.57221 .45269 .57736 .46381 .59955 .46112 .59454 .45018 Mtetra
.627 .773 .951 r
.59454 .45018 .59955 .46112 .62181 .45854 .61696 .44776 Mtetra
.623 .775 .953 r
.61696 .44776 .62181 .45854 .64415 .45606 .63945 .44541 Mtetra
.62 .776 .956 r
.63945 .44541 .64415 .45606 .66657 .45365 .66203 .44311 Mtetra
.617 .778 .958 r
.66203 .44311 .66657 .45365 .68907 .4513 .68468 .44085 Mtetra
.615 .779 .96 r
.68468 .44085 .68907 .4513 .71165 .449 .70742 .43862 Mtetra
.613 .78 .961 r
.70742 .43862 .71165 .449 .73431 .44674 .73025 .43642 Mtetra
.611 .781 .963 r
.73025 .43642 .73431 .44674 .75705 .44451 .75315 .43425 Mtetra
.609 .782 .964 r
.75315 .43425 .75705 .44451 .77988 .4423 .77614 .43208 Mtetra
.608 .783 .965 r
.77614 .43208 .77988 .4423 .80279 .44011 .79922 .42993 Mtetra
.606 .784 .966 r
.79922 .42993 .80279 .44011 .82578 .43794 .82238 .42779 Mtetra
.605 .785 .967 r
.82238 .42779 .82578 .43794 .84886 .43579 .84563 .42566 Mtetra
.604 .785 .968 r
.84563 .42566 .84886 .43579 .87202 .43364 .86896 .42353 Mtetra
.603 .786 .968 r
.86896 .42353 .87202 .43364 .89527 .4315 .89239 .42141 Mtetra
.602 .786 .969 r
.89239 .42141 .89527 .4315 .91861 .42937 .9159 .41928 Mtetra
.601 .787 .97 r
.9159 .41928 .91861 .42937 .94203 .42724 .93949 .41716 Mtetra
.93949 .41716 .94203 .42724 .96554 .42511 .96318 .41504 Mtetra
.567 .808 .99 r
.18884 .60977 .19682 .61748 .2183 .61564 .21047 .6079 Mtetra
.632 .836 .979 r
.21047 .6079 .2183 .61564 .23985 .61379 .23229 .60373 Mtetra
.954 .846 .697 r
.23229 .60373 .23985 .61379 .26258 .58895 .2568 .54584 Mtetra
.784 .648 .712 r
.2568 .54584 .26258 .58895 .28595 .54767 .27974 .51563 Mtetra
.763 .661 .75 r
.27974 .51563 .28595 .54767 .30843 .52321 .30204 .49759 Mtetra
.743 .676 .785 r
.30204 .49759 .30843 .52321 .33051 .50727 .32407 .48571 Mtetra
.725 .69 .817 r
.32407 .48571 .33051 .50727 .35241 .49609 .34598 .47727 Mtetra
.709 .704 .843 r
.34598 .47727 .35241 .49609 .37423 .48777 .36787 .47087 Mtetra
.695 .716 .866 r
.36787 .47087 .37423 .48777 .39604 .48127 .38976 .46577 Mtetra
.682 .727 .884 r
.38976 .46577 .39604 .48127 .41787 .47597 .41169 .46152 Mtetra
.671 .735 .898 r
.41169 .46152 .41787 .47597 .43973 .47149 .43367 .45786 Mtetra
.662 .743 .91 r
.43367 .45786 .43973 .47149 .46164 .4676 .45571 .4546 Mtetra
.653 .749 .92 r
.45571 .4546 .46164 .4676 .48362 .46413 .47781 .45163 Mtetra
.646 .754 .928 r
.47781 .45163 .48362 .46413 .50566 .46097 .49999 .44887 Mtetra
.64 .759 .934 r
.49999 .44887 .50566 .46097 .52777 .45804 .52224 .44627 Mtetra
.635 .762 .94 r
.52224 .44627 .52777 .45804 .54995 .4553 .54457 .4438 Mtetra
.63 .766 .944 r
.54457 .4438 .54995 .4553 .57221 .45269 .56698 .44141 Mtetra
.626 .768 .948 r
.56698 .44141 .57221 .45269 .59454 .45018 .58947 .43909 Mtetra
.623 .771 .951 r
.58947 .43909 .59454 .45018 .61696 .44776 .61204 .43683 Mtetra
.62 .773 .954 r
.61204 .43683 .61696 .44776 .63945 .44541 .63469 .4346 Mtetra
.617 .775 .956 r
.63469 .4346 .63945 .44541 .66203 .44311 .65742 .43241 Mtetra
.615 .776 .958 r
.65742 .43241 .66203 .44311 .68468 .44085 .68024 .43024 Mtetra
.612 .778 .96 r
.68024 .43024 .68468 .44085 .70742 .43862 .70314 .42809 Mtetra
.611 .779 .962 r
.70314 .42809 .70742 .43862 .73025 .43642 .72613 .42596 Mtetra
.609 .78 .963 r
.72613 .42596 .73025 .43642 .75315 .43425 .7492 .42383 Mtetra
.608 .781 .964 r
.7492 .42383 .75315 .43425 .77614 .43208 .77236 .42172 Mtetra
.606 .782 .965 r
.77236 .42172 .77614 .43208 .79922 .42993 .7956 .4196 Mtetra
.605 .783 .966 r
.7956 .4196 .79922 .42993 .82238 .42779 .81893 .41749 Mtetra
.604 .784 .967 r
.81893 .41749 .82238 .42779 .84563 .42566 .84235 .41538 Mtetra
.603 .784 .968 r
.84235 .41538 .84563 .42566 .86896 .42353 .86586 .41327 Mtetra
.602 .785 .968 r
.86586 .41327 .86896 .42353 .89239 .42141 .88946 .41116 Mtetra
.601 .786 .969 r
.88946 .41116 .89239 .42141 .9159 .41928 .91314 .40905 Mtetra
.601 .786 .97 r
.91314 .40905 .9159 .41928 .93949 .41716 .93692 .40693 Mtetra
.6 .787 .97 r
.93692 .40693 .93949 .41716 .96318 .41504 .96078 .40481 Mtetra
.567 .808 .99 r
.18075 .60195 .18884 .60977 .21047 .6079 .20252 .60005 Mtetra
.962 .856 .689 r
.20252 .60005 .21047 .6079 .23229 .60373 .22755 .53918 Mtetra
.765 .608 .684 r
.22755 .53918 .23229 .60373 .2568 .54584 .25101 .50259 Mtetra
.745 .621 .721 r
.25101 .50259 .2568 .54584 .27974 .51563 .27349 .48336 Mtetra
.728 .638 .758 r
.27349 .48336 .27974 .51563 .30204 .49759 .2956 .47174 Mtetra
.713 .657 .793 r
.2956 .47174 .30204 .49759 .32407 .48571 .31756 .46393 Mtetra
.7 .675 .823 r
.31756 .46393 .32407 .48571 .34598 .47727 .33949 .45823 Mtetra
.687 .692 .849 r
.33949 .45823 .34598 .47727 .36787 .47087 .36142 .45377 Mtetra
.676 .706 .87 r
.36142 .45377 .36787 .47087 .38976 .46577 .3834 .45008 Mtetra
.666 .718 .887 r
.3834 .45008 .38976 .46577 .41169 .46152 .40543 .44689 Mtetra
.658 .728 .901 r
.40543 .44689 .41169 .46152 .43367 .45786 .42753 .44404 Mtetra
.65 .737 .913 r
.42753 .44404 .43367 .45786 .45571 .4546 .44969 .44141 Mtetra
.644 .744 .922 r
.44969 .44141 .45571 .4546 .47781 .45163 .47193 .43895 Mtetra
.638 .75 .929 r
.47193 .43895 .47781 .45163 .49999 .44887 .49425 .4366 Mtetra
.633 .755 .936 r
.49425 .4366 .49999 .44887 .52224 .44627 .51664 .43434 Mtetra
.629 .759 .941 r
.51664 .43434 .52224 .44627 .54457 .4438 .53912 .43213 Mtetra
.625 .763 .945 r
.53912 .43213 .54457 .4438 .56698 .44141 .56168 .42997 Mtetra
.622 .766 .949 r
.56168 .42997 .56698 .44141 .58947 .43909 .58432 .42784 Mtetra
.619 .769 .952 r
.58432 .42784 .58947 .43909 .61204 .43683 .60705 .42573 Mtetra
.616 .771 .954 r
.60705 .42573 .61204 .43683 .63469 .4346 .62985 .42364 Mtetra
.614 .773 .957 r
.62985 .42364 .63469 .4346 .65742 .43241 .65275 .42156 Mtetra
.612 .775 .959 r
.65275 .42156 .65742 .43241 .68024 .43024 .67573 .41948 Mtetra
.61 .776 .96 r
.67573 .41948 .68024 .43024 .70314 .42809 .69879 .41741 Mtetra
.609 .778 .962 r
.69879 .41741 .70314 .42809 .72613 .42596 .72195 .41534 Mtetra
.607 .779 .963 r
.72195 .41534 .72613 .42596 .7492 .42383 .74519 .41327 Mtetra
.606 .78 .964 r
.74519 .41327 .7492 .42383 .77236 .42172 .76851 .41119 Mtetra
.605 .781 .965 r
.76851 .41119 .77236 .42172 .7956 .4196 .79193 .40912 Mtetra
.604 .782 .966 r
.79193 .40912 .7956 .4196 .81893 .41749 .81543 .40703 Mtetra
.603 .783 .967 r
.81543 .40703 .81893 .41749 .84235 .41538 .83902 .40495 Mtetra
.602 .784 .968 r
.83902 .40495 .84235 .41538 .86586 .41327 .86271 .40285 Mtetra
.601 .784 .968 r
.86271 .40285 .86586 .41327 .88946 .41116 .88648 .40076 Mtetra
.6 .785 .969 r
.88648 .40076 .88946 .41116 .91314 .40905 .91035 .39865 Mtetra
.6 .786 .97 r
.91035 .39865 .91314 .40905 .93692 .40693 .9343 .39654 Mtetra
.599 .786 .97 r
.9343 .39654 .93692 .40693 .96078 .40481 .95835 .39442 Mtetra
.972 .84 .653 r
.17253 .594 .18075 .60195 .20252 .60005 .19917 .51187 Mtetra
.741 .574 .668 r
.19917 .51187 .20252 .60005 .22755 .53918 .22282 .47488 Mtetra
.708 .565 .691 r
.22282 .47488 .22755 .53918 .25101 .50259 .24519 .4592 Mtetra
.696 .586 .728 r
.24519 .4592 .25101 .50259 .27349 .48336 .2672 .45088 Mtetra
.687 .611 .766 r
.2672 .45088 .27349 .48336 .2956 .47174 .28909 .44566 Mtetra
.679 .636 .8 r
.28909 .44566 .2956 .47174 .31756 .46393 .31098 .44193 Mtetra
.671 .658 .829 r
.31098 .44193 .31756 .46393 .33949 .45823 .33291 .43898 Mtetra
.663 .678 .854 r
.33291 .43898 .33949 .45823 .36142 .45377 .3549 .43646 Mtetra
.656 .695 .874 r
.3549 .43646 .36142 .45377 .3834 .45008 .37696 .43419 Mtetra
.65 .709 .89 r
.37696 .43419 .3834 .45008 .40543 .44689 .39909 .43207 Mtetra
.644 .721 .904 r
.39909 .43207 .40543 .44689 .42753 .44404 .4213 .43004 Mtetra
.639 .73 .915 r
.4213 .43004 .42753 .44404 .44969 .44141 .44359 .42805 Mtetra
.634 .738 .923 r
.44359 .42805 .44969 .44141 .47193 .43895 .46597 .4261 Mtetra
.63 .745 .931 r
.46597 .4261 .47193 .43895 .49425 .4366 .48842 .42416 Mtetra
.626 .751 .937 r
.48842 .42416 .49425 .4366 .51664 .43434 .51096 .42223 Mtetra
.623 .756 .942 r
.51096 .42223 .51664 .43434 .53912 .43213 .53359 .4203 Mtetra
.62 .76 .946 r
.53359 .4203 .53912 .43213 .56168 .42997 .5563 .41837 Mtetra
.617 .763 .949 r
.5563 .41837 .56168 .42997 .58432 .42784 .5791 .41642 Mtetra
.615 .766 .952 r
.5791 .41642 .58432 .42784 .60705 .42573 .60198 .41447 Mtetra
.613 .769 .955 r
.60198 .41447 .60705 .42573 .62985 .42364 .62495 .41251 Mtetra
.611 .771 .957 r
.62495 .41251 .62985 .42364 .65275 .42156 .64801 .41054 Mtetra
.609 .773 .959 r
.64801 .41054 .65275 .42156 .67573 .41948 .67115 .40856 Mtetra
.608 .775 .961 r
.67115 .40856 .67573 .41948 .69879 .41741 .69438 .40656 Mtetra
.606 .777 .962 r
.69438 .40656 .69879 .41741 .72195 .41534 .7177 .40456 Mtetra
.605 .778 .963 r
.7177 .40456 .72195 .41534 .74519 .41327 .74111 .40254 Mtetra
.604 .779 .964 r
.74111 .40254 .74519 .41327 .76851 .41119 .76461 .40051 Mtetra
.603 .78 .965 r
.76461 .40051 .76851 .41119 .79193 .40912 .7882 .39847 Mtetra
.602 .781 .966 r
.7882 .39847 .79193 .40912 .81543 .40703 .81188 .39642 Mtetra
.601 .782 .967 r
.81188 .39642 .81543 .40703 .83902 .40495 .83565 .39435 Mtetra
.601 .783 .968 r
.83565 .39435 .83902 .40495 .86271 .40285 .85951 .39228 Mtetra
.6 .784 .969 r
.85951 .39228 .86271 .40285 .88648 .40076 .88346 .39019 Mtetra
.599 .784 .969 r
.88346 .39019 .88648 .40076 .91035 .39865 .90751 .38809 Mtetra
.599 .785 .97 r
.90751 .38809 .91035 .39865 .9343 .39654 .93164 .38598 Mtetra
.598 .786 .97 r
.93164 .38598 .9343 .39654 .95835 .39442 .95587 .38386 Mtetra
.616 .445 .628 r
.17743 .37849 .17253 .594 .19917 .51187 .19727 .40111 Mtetra
.624 .471 .655 r
.19727 .40111 .19917 .51187 .22282 .47488 .21811 .41082 Mtetra
.629 .505 .693 r
.21811 .41082 .22282 .47488 .24519 .4592 .23936 .41567 Mtetra
.634 .542 .733 r
.23936 .41567 .24519 .4592 .2672 .45088 .26086 .41816 Mtetra
.637 .577 .771 r
.26086 .41816 .2672 .45088 .28909 .44566 .28253 .41933 Mtetra
.639 .61 .805 r
.28253 .41933 .28909 .44566 .31098 .44193 .30434 .41969 Mtetra
.639 .639 .834 r
.30434 .41969 .31098 .44193 .33291 .43898 .32627 .4195 Mtetra
.637 .663 .858 r
.32627 .4195 .33291 .43898 .3549 .43646 .3483 .41894 Mtetra
.635 .682 .878 r
.3483 .41894 .3549 .43646 .37696 .43419 .37044 .4181 Mtetra
.632 .699 .893 r
.37044 .4181 .37696 .43419 .39909 .43207 .39267 .41705 Mtetra
.629 .712 .906 r
.39267 .41705 .39909 .43207 .4213 .43004 .41499 .41584 Mtetra
.627 .723 .917 r
.41499 .41584 .4213 .43004 .44359 .42805 .43741 .41451 Mtetra
.624 .733 .925 r
.43741 .41451 .44359 .42805 .46597 .4261 .45992 .41307 Mtetra
.621 .74 .932 r
.45992 .41307 .46597 .4261 .48842 .42416 .48252 .41155 Mtetra
.619 .747 .938 r
.48252 .41155 .48842 .42416 .51096 .42223 .5052 .40995 Mtetra
.616 .752 .942 r
.5052 .40995 .51096 .42223 .53359 .4203 .52798 .4083 Mtetra
.614 .757 .946 r
.52798 .4083 .53359 .4203 .5563 .41837 .55084 .40659 Mtetra
.612 .761 .95 r
.55084 .40659 .5563 .41837 .5791 .41642 .5738 .40484 Mtetra
.611 .764 .953 r
.5738 .40484 .5791 .41642 .60198 .41447 .59684 .40305 Mtetra
.609 .767 .955 r
.59684 .40305 .60198 .41447 .62495 .41251 .61997 .40122 Mtetra
.608 .769 .957 r
.61997 .40122 .62495 .41251 .64801 .41054 .64319 .39936 Mtetra
.607 .772 .959 r
.64319 .39936 .64801 .41054 .67115 .40856 .6665 .39747 Mtetra
.605 .774 .961 r
.6665 .39747 .67115 .40856 .69438 .40656 .6899 .39555 Mtetra
.604 .775 .962 r
.6899 .39555 .69438 .40656 .7177 .40456 .71339 .39361 Mtetra
.603 .777 .963 r
.71339 .39361 .7177 .40456 .74111 .40254 .73697 .39165 Mtetra
.602 .778 .965 r
.73697 .39165 .74111 .40254 .76461 .40051 .76065 .38966 Mtetra
.602 .779 .966 r
.76065 .38966 .76461 .40051 .7882 .39847 .78441 .38766 Mtetra
.601 .78 .966 r
.78441 .38766 .7882 .39847 .81188 .39642 .80827 .38564 Mtetra
.6 .781 .967 r
.80827 .38564 .81188 .39642 .83565 .39435 .83222 .38359 Mtetra
.6 .782 .968 r
.83222 .38359 .83565 .39435 .85951 .39228 .85626 .38154 Mtetra
.599 .783 .969 r
.85626 .38154 .85951 .39228 .88346 .39019 .88039 .37946 Mtetra
.598 .784 .969 r
.88039 .37946 .88346 .39019 .90751 .38809 .90462 .37737 Mtetra
.598 .785 .97 r
.90462 .37737 .90751 .38809 .93164 .38598 .92895 .37527 Mtetra
.92895 .37527 .93164 .38598 .95587 .38386 .95336 .37315 Mtetra
.647 .5 .669 r
.17437 .29213 .17743 .37849 .19727 .40111 .19542 .29248 Mtetra
.469 .348 .633 r
.19542 .29248 .19727 .40111 .21811 .41082 .21341 .347 Mtetra
.519 .421 .684 r
.21341 .347 .21811 .41082 .23936 .41567 .23351 .372 Mtetra
.553 .483 .731 r
.23351 .372 .23936 .41567 .26086 .41816 .25448 .38522 Mtetra
.577 .536 .773 r
.25448 .38522 .26086 .41816 .28253 .41933 .27591 .39277 Mtetra
.592 .58 .808 r
.27591 .39277 .28253 .41933 .30434 .41969 .29762 .39721 Mtetra
.602 .616 .837 r
.29762 .39721 .30434 .41969 .32627 .4195 .31954 .3998 Mtetra
.609 .645 .861 r
.31954 .3998 .32627 .4195 .3483 .41894 .34162 .4012 Mtetra
.612 .669 .881 r
.34162 .4012 .3483 .41894 .37044 .4181 .36383 .4018 Mtetra
.614 .688 .896 r
.36383 .4018 .37044 .4181 .39267 .41705 .38616 .40183 Mtetra
.614 .704 .908 r
.38616 .40183 .39267 .41705 .41499 .41584 .4086 .40146 Mtetra
.614 .716 .918 r
.4086 .40146 .41499 .41584 .43741 .41451 .43114 .40077 Mtetra
.613 .727 .926 r
.43114 .40077 .43741 .41451 .45992 .41307 .45378 .39986 Mtetra
.612 .735 .933 r
.45378 .39986 .45992 .41307 .48252 .41155 .47652 .39875 Mtetra
.611 .742 .939 r
.47652 .39875 .48252 .41155 .5052 .40995 .49936 .3975 Mtetra
.61 .748 .943 r
.49936 .3975 .5052 .40995 .52798 .4083 .52229 .39612 Mtetra
.609 .754 .947 r
.52229 .39612 .52798 .4083 .55084 .40659 .54531 .39464 Mtetra
.608 .758 .95 r
.54531 .39464 .55084 .40659 .5738 .40484 .56842 .39308 Mtetra
.607 .762 .953 r
.56842 .39308 .5738 .40484 .59684 .40305 .59162 .39145 Mtetra
.606 .765 .956 r
.59162 .39145 .59684 .40305 .61997 .40122 .61492 .38976 Mtetra
.605 .768 .958 r
.61492 .38976 .61997 .40122 .64319 .39936 .6383 .38801 Mtetra
.604 .77 .959 r
.6383 .38801 .64319 .39936 .6665 .39747 .66178 .38621 Mtetra
.603 .772 .961 r
.66178 .38621 .6665 .39747 .6899 .39555 .68536 .38438 Mtetra
.602 .774 .962 r
.68536 .38438 .6899 .39555 .71339 .39361 .70902 .3825 Mtetra
.601 .776 .964 r
.70902 .3825 .71339 .39361 .73697 .39165 .73278 .38059 Mtetra
.601 .777 .965 r
.73278 .38059 .73697 .39165 .76065 .38966 .75662 .37865 Mtetra
.6 .778 .966 r
.75662 .37865 .76065 .38966 .78441 .38766 .78057 .37668 Mtetra
.6 .78 .967 r
.78057 .37668 .78441 .38766 .80827 .38564 .8046 .37469 Mtetra
.599 .781 .967 r
.8046 .37469 .80827 .38564 .83222 .38359 .82873 .37267 Mtetra
.598 .782 .968 r
.82873 .37267 .83222 .38359 .85626 .38154 .85296 .37063 Mtetra
.598 .782 .969 r
.85296 .37063 .85626 .38154 .88039 .37946 .87728 .36857 Mtetra
.598 .783 .969 r
.87728 .36857 .88039 .37946 .90462 .37737 .90169 .36648 Mtetra
.597 .784 .97 r
.90169 .36648 .90462 .37737 .92895 .37527 .9262 .36438 Mtetra
.597 .785 .97 r
.9262 .36438 .92895 .37527 .95336 .37315 .95081 .36226 Mtetra
.617 .786 .963 r
.16632 .28211 .17437 .29213 .19542 .29248 .18767 .27968 Mtetra
.492 .67 .942 r
.18767 .27968 .19542 .29248 .21341 .347 .20874 .28341 Mtetra
.37 .307 .655 r
.20874 .28341 .21341 .347 .23351 .372 .22764 .32818 Mtetra
.451 .408 .719 r
.22764 .32818 .23351 .372 .25448 .38522 .24805 .35205 Mtetra
.504 .485 .769 r
.24805 .35205 .25448 .38522 .27591 .39277 .26922 .36596 Mtetra
.539 .544 .808 r
.26922 .36596 .27591 .39277 .29762 .39721 .29083 .3745 Mtetra
.562 .59 .839 r
.29083 .3745 .29762 .39721 .31954 .3998 .31274 .37987 Mtetra
.577 .626 .864 r
.31274 .37987 .31954 .3998 .34162 .4012 .33485 .38324 Mtetra
.588 .654 .883 r
.33485 .38324 .34162 .4012 .36383 .4018 .35714 .38528 Mtetra
.594 .677 .898 r
.35714 .38528 .36383 .4018 .38616 .40183 .37956 .38641 Mtetra
.598 .695 .91 r
.37956 .38641 .38616 .40183 .4086 .40146 .40212 .38687 Mtetra
.601 .709 .92 r
.40212 .38687 .4086 .40146 .43114 .40077 .42479 .38685 Mtetra
.603 .721 .928 r
.42479 .38685 .43114 .40077 .45378 .39986 .44756 .38645 Mtetra
.603 .73 .934 r
.44756 .38645 .45378 .39986 .47652 .39875 .47045 .38577 Mtetra
.604 .738 .94 r
.47045 .38577 .47652 .39875 .49936 .3975 .49343 .38486 Mtetra
.604 .745 .944 r
.49343 .38486 .49936 .3975 .52229 .39612 .51651 .38377 Mtetra
.603 .75 .948 r
.51651 .38377 .52229 .39612 .54531 .39464 .53969 .38252 Mtetra
.603 .755 .951 r
.53969 .38252 .54531 .39464 .56842 .39308 .56296 .38115 Mtetra
.603 .759 .954 r
.56296 .38115 .56842 .39308 .59162 .39145 .58633 .37968 Mtetra
.602 .763 .956 r
.58633 .37968 .59162 .39145 .61492 .38976 .60979 .37812 Mtetra
.602 .766 .958 r
.60979 .37812 .61492 .38976 .6383 .38801 .63334 .37649 Mtetra
.601 .768 .96 r
.63334 .37649 .6383 .38801 .66178 .38621 .65699 .37479 Mtetra
.601 .771 .961 r
.65699 .37479 .66178 .38621 .68536 .38438 .68074 .37303 Mtetra
.6 .773 .963 r
.68074 .37303 .68536 .38438 .70902 .3825 .70458 .37122 Mtetra
.6 .774 .964 r
.70458 .37122 .70902 .3825 .73278 .38059 .72851 .36936 Mtetra
.599 .776 .965 r
.72851 .36936 .73278 .38059 .75662 .37865 .75254 .36747 Mtetra
.599 .777 .966 r
.75254 .36747 .75662 .37865 .78057 .37668 .77666 .36554 Mtetra
.598 .779 .967 r
.77666 .36554 .78057 .37668 .8046 .37469 .80088 .36357 Mtetra
.598 .78 .967 r
.80088 .36357 .8046 .37469 .82873 .37267 .8252 .36157 Mtetra
.597 .781 .968 r
.8252 .36157 .82873 .37267 .85296 .37063 .84961 .35955 Mtetra
.597 .782 .969 r
.84961 .35955 .85296 .37063 .87728 .36857 .87411 .3575 Mtetra
.597 .783 .969 r
.87411 .3575 .87728 .36857 .90169 .36648 .89872 .35542 Mtetra
.596 .783 .97 r
.89872 .35542 .90169 .36648 .9262 .36438 .92342 .35333 Mtetra
.596 .784 .97 r
.92342 .35333 .9262 .36438 .95081 .36226 .94822 .35121 Mtetra
.617 .786 .963 r
.15814 .27193 .16632 .28211 .18767 .27968 .17964 .26947 Mtetra
.17964 .26947 .18767 .27968 .20874 .28341 .20122 .26699 Mtetra
.136 .375 .83 r
.20122 .26699 .20874 .28341 .22764 .32818 .22175 .28423 Mtetra
.324 .314 .693 r
.22175 .28423 .22764 .32818 .24805 .35205 .24158 .31865 Mtetra
.417 .423 .758 r
.24158 .31865 .24805 .35205 .26922 .36596 .26248 .3389 Mtetra
.478 .502 .805 r
.26248 .3389 .26922 .36596 .29083 .3745 .28397 .35153 Mtetra
.517 .561 .839 r
.28397 .35153 .29083 .3745 .31274 .37987 .30585 .3597 Mtetra
.544 .605 .865 r
.30585 .3597 .31274 .37987 .33485 .38324 .328 .36506 Mtetra
.561 .638 .884 r
.328 .36506 .33485 .38324 .35714 .38528 .35036 .36856 Mtetra
.574 .664 .9 r
.35036 .36856 .35714 .38528 .37956 .38641 .37288 .37078 Mtetra
.582 .685 .912 r
.37288 .37078 .37956 .38641 .40212 .38687 .39555 .37209 Mtetra
.588 .701 .921 r
.39555 .37209 .40212 .38687 .42479 .38685 .41834 .37273 Mtetra
.592 .714 .929 r
.41834 .37273 .42479 .38685 .44756 .38645 .44125 .37286 Mtetra
.594 .725 .935 r
.44125 .37286 .44756 .38645 .47045 .38577 .46428 .3726 Mtetra
.596 .734 .94 r
.46428 .3726 .47045 .38577 .49343 .38486 .48741 .37204 Mtetra
.597 .741 .945 r
.48741 .37204 .49343 .38486 .51651 .38377 .51065 .37123 Mtetra
.598 .747 .948 r
.51065 .37123 .51651 .38377 .53969 .38252 .53398 .37022 Mtetra
.598 .752 .951 r
.53398 .37022 .53969 .38252 .56296 .38115 .55742 .36904 Mtetra
.598 .757 .954 r
.55742 .36904 .56296 .38115 .58633 .37968 .58095 .36773 Mtetra
.598 .761 .956 r
.58095 .36773 .58633 .37968 .60979 .37812 .60458 .36631 Mtetra
.598 .764 .958 r
.60458 .36631 .60979 .37812 .63334 .37649 .62831 .36479 Mtetra
.598 .767 .96 r
.62831 .36479 .63334 .37649 .65699 .37479 .65213 .36318 Mtetra
.598 .769 .961 r
.65213 .36318 .65699 .37479 .68074 .37303 .67605 .3615 Mtetra
.598 .771 .963 r
.67605 .3615 .68074 .37303 .70458 .37122 .70007 .35976 Mtetra
.598 .773 .964 r
.70007 .35976 .70458 .37122 .72851 .36936 .72418 .35796 Mtetra
.597 .775 .965 r
.72418 .35796 .72851 .36936 .75254 .36747 .74839 .35611 Mtetra
.597 .776 .966 r
.74839 .35611 .75254 .36747 .77666 .36554 .7727 .35421 Mtetra
.597 .778 .967 r
.7727 .35421 .77666 .36554 .80088 .36357 .7971 .35228 Mtetra
.597 .779 .967 r
.7971 .35228 .80088 .36357 .8252 .36157 .8216 .3503 Mtetra
.596 .78 .968 r
.8216 .3503 .8252 .36157 .84961 .35955 .8462 .34829 Mtetra
.596 .781 .969 r
.8462 .34829 .84961 .35955 .87411 .3575 .8709 .34625 Mtetra
.596 .782 .969 r
.8709 .34625 .87411 .3575 .89872 .35542 .8957 .34419 Mtetra
.595 .783 .97 r
.8957 .34419 .89872 .35542 .92342 .35333 .92059 .34209 Mtetra
.595 .784 .97 r
.92059 .34209 .92342 .35333 .94822 .35121 .94559 .33997 Mtetra
.617 .786 .963 r
.14985 .2616 .15814 .27193 .17964 .26947 .17149 .2591 Mtetra
.17149 .2591 .17964 .26947 .20122 .26699 .19322 .25659 Mtetra
.19322 .25659 .20122 .26699 .22175 .28423 .21502 .25407 Mtetra
.166 .257 .713 r
.21502 .25407 .22175 .28423 .24158 .31865 .23506 .28501 Mtetra
.317 .35 .738 r
.23506 .28501 .24158 .31865 .26248 .3389 .25567 .31159 Mtetra
.408 .454 .796 r
.25567 .31159 .26248 .3389 .28397 .35153 .27704 .32833 Mtetra
.467 .527 .836 r
.27704 .32833 .28397 .35153 .30585 .3597 .29889 .33929 Mtetra
.507 .581 .864 r
.29889 .33929 .30585 .3597 .328 .36506 .32106 .34664 Mtetra
.534 .621 .885 r
.32106 .34664 .328 .36506 .35036 .36856 .34349 .35161 Mtetra
.552 .651 .901 r
.34349 .35161 .35036 .36856 .37288 .37078 .3661 .35494 Mtetra
.565 .675 .913 r
.3661 .35494 .37288 .37078 .39555 .37209 .38888 .3571 Mtetra
.574 .693 .922 r
.38888 .3571 .39555 .37209 .41834 .37273 .4118 .35841 Mtetra
.58 .708 .93 r
.4118 .35841 .41834 .37273 .44125 .37286 .43485 .35907 Mtetra
.585 .72 .936 r
.43485 .35907 .44125 .37286 .46428 .3726 .45802 .35924 Mtetra
.588 .729 .941 r
.45802 .35924 .46428 .3726 .48741 .37204 .48131 .35903 Mtetra
.59 .737 .945 r
.48131 .35903 .48741 .37204 .51065 .37123 .5047 .3585 Mtetra
.592 .744 .949 r
.5047 .3585 .51065 .37123 .53398 .37022 .52819 .35773 Mtetra
.593 .75 .952 r
.52819 .35773 .53398 .37022 .55742 .36904 .55179 .35675 Mtetra
.594 .754 .954 r
.55179 .35675 .55742 .36904 .58095 .36773 .57549 .35561 Mtetra
.595 .758 .957 r
.57549 .35561 .58095 .36773 .60458 .36631 .59929 .35432 Mtetra
.595 .762 .959 r
.59929 .35432 .60458 .36631 .62831 .36479 .62319 .35291 Mtetra
.596 .765 .96 r
.62319 .35291 .62831 .36479 .65213 .36318 .64719 .3514 Mtetra
.596 .768 .962 r
.64719 .3514 .65213 .36318 .67605 .3615 .67129 .3498 Mtetra
.596 .77 .963 r
.67129 .3498 .67605 .3615 .70007 .35976 .69549 .34812 Mtetra
.596 .772 .964 r
.69549 .34812 .70007 .35976 .72418 .35796 .71978 .34638 Mtetra
.596 .774 .965 r
.71978 .34638 .72418 .35796 .74839 .35611 .74418 .34457 Mtetra
.596 .775 .966 r
.74418 .34457 .74839 .35611 .7727 .35421 .76867 .34271 Mtetra
.595 .777 .967 r
.76867 .34271 .7727 .35421 .7971 .35228 .79326 .3408 Mtetra
.595 .778 .968 r
.79326 .3408 .7971 .35228 .8216 .3503 .81795 .33885 Mtetra
.595 .779 .968 r
.81795 .33885 .8216 .3503 .8462 .34829 .84274 .33686 Mtetra
.595 .78 .969 r
.84274 .33686 .8462 .34829 .8709 .34625 .86763 .33483 Mtetra
.595 .781 .969 r
.86763 .33483 .8709 .34625 .8957 .34419 .89262 .33277 Mtetra
.595 .782 .97 r
.89262 .33277 .8957 .34419 .92059 .34209 .91772 .33068 Mtetra
.594 .783 .97 r
.91772 .33068 .92059 .34209 .94559 .33997 .94291 .32855 Mtetra
.617 .786 .963 r
.14142 .25112 .14985 .2616 .17149 .2591 .16322 .24858 Mtetra
.16322 .24858 .17149 .2591 .19322 .25659 .18509 .24603 Mtetra
.18509 .24603 .19322 .25659 .21502 .25407 .20704 .24347 Mtetra
.27 .587 .946 r
.20704 .24347 .21502 .25407 .23506 .28501 .2285 .25113 Mtetra
.202 .265 .705 r
.2285 .25113 .23506 .28501 .25567 .31159 .24879 .28402 Mtetra
.33 .398 .781 r
.24879 .28402 .25567 .31159 .27704 .32833 .27003 .30486 Mtetra
.413 .49 .83 r
.27003 .30486 .27704 .32833 .29889 .33929 .29184 .31864 Mtetra
.467 .555 .862 r
.29184 .31864 .29889 .33929 .32106 .34664 .31404 .328 Mtetra
.504 .602 .885 r
.31404 .328 .32106 .34664 .34349 .35161 .33653 .33444 Mtetra
.529 .637 .901 r
.33653 .33444 .34349 .35161 .3661 .35494 .35924 .33888 Mtetra
.547 .664 .914 r
.35924 .33888 .3661 .35494 .38888 .3571 .38213 .3419 Mtetra
.559 .684 .923 r
.38213 .3419 .38888 .3571 .4118 .35841 .40517 .34388 Mtetra
.569 .701 .931 r
.40517 .34388 .4118 .35841 .43485 .35907 .42836 .34508 Mtetra
.575 .714 .937 r
.42836 .34508 .43485 .35907 .45802 .35924 .45168 .34569 Mtetra
.58 .725 .942 r
.45168 .34569 .45802 .35924 .48131 .35903 .47511 .34582 Mtetra
.584 .733 .946 r
.47511 .34582 .48131 .35903 .5047 .3585 .49866 .34558 Mtetra
.587 .741 .949 r
.49866 .34558 .5047 .3585 .52819 .35773 .52232 .34505 Mtetra
.589 .747 .952 r
.52232 .34505 .52819 .35773 .55179 .35675 .54608 .34427 Mtetra
.59 .752 .955 r
.54608 .34427 .55179 .35675 .57549 .35561 .56995 .34329 Mtetra
.591 .756 .957 r
.56995 .34329 .57549 .35561 .59929 .35432 .59393 .34214 Mtetra
.592 .76 .959 r
.59393 .34214 .59929 .35432 .62319 .35291 .618 .34085 Mtetra
.593 .763 .96 r
.618 .34085 .62319 .35291 .64719 .3514 .64218 .33943 Mtetra
.593 .766 .962 r
.64218 .33943 .64719 .3514 .67129 .3498 .66646 .33791 Mtetra
.594 .769 .963 r
.66646 .33791 .67129 .3498 .69549 .34812 .69083 .3363 Mtetra
.594 .771 .964 r
.69083 .3363 .69549 .34812 .71978 .34638 .71531 .33461 Mtetra
.594 .773 .965 r
.71531 .33461 .71978 .34638 .74418 .34457 .73989 .33285 Mtetra
.594 .774 .966 r
.73989 .33285 .74418 .34457 .76867 .34271 .76458 .33103 Mtetra
.594 .776 .967 r
.76458 .33103 .76867 .34271 .79326 .3408 .78936 .32915 Mtetra
.594 .777 .968 r
.78936 .32915 .79326 .3408 .81795 .33885 .81424 .32722 Mtetra
.594 .779 .968 r
.81424 .32722 .81795 .33885 .84274 .33686 .83923 .32524 Mtetra
.594 .78 .969 r
.83923 .32524 .84274 .33686 .86763 .33483 .86431 .32322 Mtetra
.594 .781 .969 r
.86431 .32322 .86763 .33483 .89262 .33277 .8895 .32117 Mtetra
.594 .782 .97 r
.8895 .32117 .89262 .33277 .91772 .33068 .9148 .31907 Mtetra
.594 .783 .97 r
.9148 .31907 .91772 .33068 .94291 .32855 .94019 .31695 Mtetra
.617 .786 .963 r
.13287 .24047 .14142 .25112 .16322 .24858 .15482 .2379 Mtetra
.15482 .2379 .16322 .24858 .18509 .24603 .17684 .23531 Mtetra
.17684 .23531 .18509 .24603 .20704 .24347 .19895 .23271 Mtetra
.19895 .23271 .20704 .24347 .2285 .25113 .22114 .2301 Mtetra
.013 .226 .734 r
.22114 .2301 .2285 .25113 .24879 .28402 .24186 .2562 Mtetra
.244 .336 .759 r
.24186 .2562 .24879 .28402 .27003 .30486 .26294 .28115 Mtetra
.353 .448 .82 r
.26294 .28115 .27003 .30486 .29184 .31864 .2847 .29775 Mtetra
.425 .526 .858 r
.2847 .29775 .29184 .31864 .31404 .328 .30693 .30912 Mtetra
.472 .582 .883 r
.30693 .30912 .31404 .328 .33653 .33444 .32948 .31704 Mtetra
.505 .622 .901 r
.32948 .31704 .33653 .33444 .35924 .33888 .35227 .32261 Mtetra
.528 .652 .914 r
.35227 .32261 .35924 .33888 .38213 .3419 .37528 .32649 Mtetra
.545 .676 .924 r
.37528 .32649 .38213 .3419 .40517 .34388 .39845 .32915 Mtetra
.557 .694 .931 r
.39845 .32915 .40517 .34388 .42836 .34508 .42177 .33089 Mtetra
.565 .708 .937 r
.42177 .33089 .42836 .34508 .45168 .34569 .44523 .33193 Mtetra
.572 .72 .942 r
.44523 .33193 .45168 .34569 .47511 .34582 .46882 .33242 Mtetra
.577 .729 .946 r
.46882 .33242 .47511 .34582 .49866 .34558 .49253 .33247 Mtetra
.581 .737 .95 r
.49253 .33247 .49866 .34558 .52232 .34505 .51635 .33218 Mtetra
.584 .744 .953 r
.51635 .33218 .52232 .34505 .54608 .34427 .54028 .3316 Mtetra
.586 .749 .955 r
.54028 .3316 .54608 .34427 .56995 .34329 .56433 .33078 Mtetra
.588 .754 .957 r
.56433 .33078 .56995 .34329 .59393 .34214 .58847 .32977 Mtetra
.589 .758 .959 r
.58847 .32977 .59393 .34214 .618 .34085 .61273 .3286 Mtetra
.59 .762 .961 r
.61273 .3286 .618 .34085 .64218 .33943 .63708 .32728 Mtetra
.591 .765 .962 r
.63708 .32728 .64218 .33943 .66646 .33791 .66154 .32584 Mtetra
.591 .767 .963 r
.66154 .32584 .66646 .33791 .69083 .3363 .68611 .3243 Mtetra
.592 .77 .964 r
.68611 .3243 .69083 .3363 .71531 .33461 .71077 .32266 Mtetra
.592 .772 .965 r
.71077 .32266 .71531 .33461 .73989 .33285 .73554 .32094 Mtetra
.592 .774 .966 r
.73554 .32094 .73989 .33285 .76458 .33103 .76042 .31916 Mtetra
.593 .775 .967 r
.76042 .31916 .76458 .33103 .78936 .32915 .78539 .3173 Mtetra
.593 .777 .968 r
.78539 .3173 .78936 .32915 .81424 .32722 .81047 .31539 Mtetra
.593 .778 .968 r
.81047 .31539 .81424 .32722 .83923 .32524 .83565 .31343 Mtetra
.593 .779 .969 r
.83565 .31343 .83923 .32524 .86431 .32322 .86094 .31143 Mtetra
.593 .78 .969 r
.86094 .31143 .86431 .32322 .8895 .32117 .88633 .30937 Mtetra
.593 .781 .97 r
.88633 .30937 .8895 .32117 .9148 .31907 .91183 .30728 Mtetra
.593 .782 .97 r
.91183 .30728 .9148 .31907 .94019 .31695 .93743 .30516 Mtetra
.617 .786 .963 r
.12419 .22967 .13287 .24047 .15482 .2379 .14629 .22705 Mtetra
.14629 .22705 .15482 .2379 .17684 .23531 .16847 .22442 Mtetra
.16847 .22442 .17684 .23531 .19895 .23271 .19073 .22178 Mtetra
.19073 .22178 .19895 .23271 .22114 .2301 .21307 .21914 Mtetra
.22 .552 .932 r
.21307 .21914 .22114 .2301 .24186 .2562 .23485 .22811 Mtetra
.151 .267 .729 r
.23485 .22811 .24186 .2562 .26294 .28115 .25577 .25717 Mtetra
.289 .403 .805 r
.25577 .25717 .26294 .28115 .2847 .29775 .27749 .2766 Mtetra
.379 .495 .851 r
.27749 .2766 .2847 .29775 .30693 .30912 .29972 .28999 Mtetra
.439 .56 .88 r
.29972 .28999 .30693 .30912 .32948 .31704 .32233 .29941 Mtetra
.48 .606 .9 r
.32233 .29941 .32948 .31704 .35227 .32261 .34522 .3061 Mtetra
.509 .64 .914 r
.34522 .3061 .35227 .32261 .37528 .32649 .36833 .31086 Mtetra
.529 .666 .924 r
.36833 .31086 .37528 .32649 .39845 .32915 .39163 .3142 Mtetra
.544 .686 .932 r
.39163 .3142 .39845 .32915 .42177 .33089 .41509 .31649 Mtetra
.555 .702 .938 r
.41509 .31649 .42177 .33089 .44523 .33193 .4387 .31797 Mtetra
.564 .715 .943 r
.4387 .31797 .44523 .33193 .46882 .33242 .46244 .31881 Mtetra
.57 .725 .947 r
.46244 .31881 .46882 .33242 .49253 .33247 .48631 .31916 Mtetra
.575 .734 .95 r
.48631 .31916 .49253 .33247 .51635 .33218 .51029 .31911 Mtetra
.579 .741 .953 r
.51029 .31911 .51635 .33218 .54028 .3316 .5344 .31873 Mtetra
.582 .747 .955 r
.5344 .31873 .54028 .3316 .56433 .33078 .55861 .31808 Mtetra
.584 .752 .958 r
.55861 .31808 .56433 .33078 .58847 .32977 .58294 .31721 Mtetra
.586 .756 .959 r
.58294 .31721 .58847 .32977 .61273 .3286 .60737 .31615 Mtetra
.587 .76 .961 r
.60737 .31615 .61273 .3286 .63708 .32728 .63191 .31493 Mtetra
.588 .763 .962 r
.63191 .31493 .63708 .32728 .66154 .32584 .65655 .31357 Mtetra
.589 .766 .963 r
.65655 .31357 .66154 .32584 .68611 .3243 .68131 .3121 Mtetra
.59 .768 .964 r
.68131 .3121 .68611 .3243 .71077 .32266 .70616 .31052 Mtetra
.59 .771 .965 r
.70616 .31052 .71077 .32266 .73554 .32094 .73112 .30884 Mtetra
.591 .773 .966 r
.73112 .30884 .73554 .32094 .76042 .31916 .75619 .30709 Mtetra
.591 .774 .967 r
.75619 .30709 .76042 .31916 .78539 .3173 .78136 .30527 Mtetra
.592 .776 .968 r
.78136 .30527 .78539 .3173 .81047 .31539 .80664 .30338 Mtetra
.592 .777 .968 r
.80664 .30338 .81047 .31539 .83565 .31343 .83202 .30143 Mtetra
.592 .778 .969 r
.83202 .30143 .83565 .31343 .86094 .31143 .85751 .29943 Mtetra
.592 .78 .97 r
.85751 .29943 .86094 .31143 .88633 .30937 .88311 .29739 Mtetra
.592 .781 .97 r
.88311 .29739 .88633 .30937 .91183 .30728 .90881 .2953 Mtetra
.90881 .2953 .91183 .30728 .93743 .30516 .93462 .29317 Mtetra
.617 .786 .963 r
.11538 .21869 .12419 .22967 .14629 .22705 .13763 .21604 Mtetra
.13763 .21604 .14629 .22705 .16847 .22442 .15996 .21337 Mtetra
.15996 .21337 .16847 .22442 .19073 .22178 .18238 .21069 Mtetra
.18238 .21069 .19073 .22178 .21307 .21914 .20488 .208 Mtetra
.20488 .208 .21307 .21914 .23485 .22811 .22747 .2053 Mtetra
.025 .221 .727 r
.22747 .2053 .23485 .22811 .25577 .25717 .24853 .23293 Mtetra
.22 .353 .786 r
.24853 .23293 .25577 .25717 .27749 .2766 .27018 .25519 Mtetra
.33 .461 .842 r
.27018 .25519 .27749 .2766 .29972 .28999 .29242 .27062 Mtetra
.404 .536 .876 r
.29242 .27062 .29972 .28999 .32233 .29941 .31509 .28154 Mtetra
.454 .589 .898 r
.31509 .28154 .32233 .29941 .34522 .3061 .33806 .28937 Mtetra
.489 .628 .913 r
.33806 .28937 .34522 .3061 .36833 .31086 .36128 .295 Mtetra
.514 .657 .924 r
.36128 .295 .36833 .31086 .39163 .3142 .38471 .29904 Mtetra
.532 .679 .932 r
.38471 .29904 .39163 .3142 .41509 .31649 .40831 .30187 Mtetra
.545 .696 .938 r
.40831 .30187 .41509 .31649 .4387 .31797 .43206 .30379 Mtetra
.555 .71 .943 r
.43206 .30379 .4387 .31797 .46244 .31881 .45596 .305 Mtetra
.563 .721 .947 r
.45596 .305 .46244 .31881 .48631 .31916 .47999 .30565 Mtetra
.569 .73 .951 r
.47999 .30565 .48631 .31916 .51029 .31911 .50414 .30584 Mtetra
.574 .738 .953 r
.50414 .30584 .51029 .31911 .5344 .31873 .52842 .30566 Mtetra
.577 .744 .956 r
.52842 .30566 .5344 .31873 .55861 .31808 .55281 .30518 Mtetra
.58 .75 .958 r
.55281 .30518 .55861 .31808 .58294 .31721 .57731 .30445 Mtetra
.582 .754 .96 r
.57731 .30445 .58294 .31721 .60737 .31615 .60193 .30351 Mtetra
.584 .758 .961 r
.60193 .30351 .60737 .31615 .63191 .31493 .62665 .30239 Mtetra
.586 .762 .962 r
.62665 .30239 .63191 .31493 .65655 .31357 .65148 .30111 Mtetra
.587 .765 .964 r
.65148 .30111 .65655 .31357 .68131 .3121 .67643 .2997 Mtetra
.588 .767 .965 r
.67643 .2997 .68131 .3121 .70616 .31052 .70148 .29817 Mtetra
.589 .769 .966 r
.70148 .29817 .70616 .31052 .73112 .30884 .72663 .29655 Mtetra
.589 .772 .966 r
.72663 .29655 .73112 .30884 .75619 .30709 .7519 .29483 Mtetra
.59 .773 .967 r
.7519 .29483 .75619 .30709 .78136 .30527 .77727 .29303 Mtetra
.59 .775 .968 r
.77727 .29303 .78136 .30527 .80664 .30338 .80275 .29117 Mtetra
.591 .776 .968 r
.80275 .29117 .80664 .30338 .83202 .30143 .82833 .28923 Mtetra
.591 .778 .969 r
.82833 .28923 .83202 .30143 .85751 .29943 .85403 .28724 Mtetra
.591 .779 .97 r
.85403 .28724 .85751 .29943 .88311 .29739 .87983 .2852 Mtetra
.591 .78 .97 r
.87983 .2852 .88311 .29739 .90881 .2953 .90574 .28311 Mtetra
.591 .781 .97 r
.90574 .28311 .90881 .2953 .93462 .29317 .93176 .28098 Mtetra
.617 .786 .963 r
.10642 .20755 .11538 .21869 .13763 .21604 .12883 .20485 Mtetra
.12883 .20485 .13763 .21604 .15996 .21337 .15132 .20214 Mtetra
.15132 .20214 .15996 .21337 .18238 .21069 .1739 .19942 Mtetra
.1739 .19942 .18238 .21069 .20488 .208 .19656 .19669 Mtetra
.19656 .19669 .20488 .208 .22747 .2053 .21931 .19395 Mtetra
0 .371 .835 r
.21931 .19395 .22747 .2053 .24853 .23293 .2412 .20841 Mtetra
.147 .299 .762 r
.2412 .20841 .24853 .23293 .27018 .25519 .26278 .23353 Mtetra
.279 .425 .83 r
.26278 .23353 .27018 .25519 .29242 .27062 .28503 .251 Mtetra
.367 .511 .87 r
.28503 .251 .29242 .27062 .31509 .28154 .30774 .26343 Mtetra
.426 .571 .895 r
.30774 .26343 .31509 .28154 .33806 .28937 .3308 .2724 Mtetra
.468 .614 .912 r
.3308 .2724 .33806 .28937 .36128 .295 .35413 .27892 Mtetra
.497 .646 .924 r
.35413 .27892 .36128 .295 .38471 .29904 .37768 .28365 Mtetra
.519 .671 .932 r
.37768 .28365 .38471 .29904 .40831 .30187 .40142 .28704 Mtetra
.535 .69 .939 r
.40142 .28704 .40831 .30187 .43206 .30379 .42532 .28941 Mtetra
.547 .705 .944 r
.42532 .28941 .43206 .30379 .45596 .305 .44938 .29098 Mtetra
.556 .717 .948 r
.44938 .29098 .45596 .305 .47999 .30565 .47357 .29192 Mtetra
.563 .727 .951 r
.47357 .29192 .47999 .30565 .50414 .30584 .49789 .29236 Mtetra
.569 .735 .954 r
.49789 .29236 .50414 .30584 .52842 .30566 .52234 .29239 Mtetra
.573 .742 .956 r
.52234 .29239 .52842 .30566 .55281 .30518 .54691 .29208 Mtetra
.576 .747 .958 r
.54691 .29208 .55281 .30518 .57731 .30445 .5716 .29149 Mtetra
.579 .752 .96 r
.5716 .29149 .57731 .30445 .60193 .30351 .5964 .29066 Mtetra
.581 .756 .961 r
.5964 .29066 .60193 .30351 .62665 .30239 .62131 .28964 Mtetra
.583 .76 .963 r
.62131 .28964 .62665 .30239 .65148 .30111 .64633 .28844 Mtetra
.585 .763 .964 r
.64633 .28844 .65148 .30111 .67643 .2997 .67147 .2871 Mtetra
.586 .766 .965 r
.67147 .2871 .67643 .2997 .70148 .29817 .69671 .28563 Mtetra
.587 .768 .966 r
.69671 .28563 .70148 .29817 .72663 .29655 .72207 .28405 Mtetra
.588 .771 .967 r
.72207 .28405 .72663 .29655 .7519 .29483 .74753 .28237 Mtetra
.588 .772 .967 r
.74753 .28237 .7519 .29483 .77727 .29303 .7731 .2806 Mtetra
.589 .774 .968 r
.7731 .2806 .77727 .29303 .80275 .29117 .79879 .27875 Mtetra
.589 .776 .969 r
.79879 .27875 .80275 .29117 .82833 .28923 .82458 .27683 Mtetra
.59 .777 .969 r
.82458 .27683 .82833 .28923 .85403 .28724 .85048 .27485 Mtetra
.59 .778 .97 r
.85048 .27485 .85403 .28724 .87983 .2852 .8765 .27281 Mtetra
.59 .779 .97 r
.8765 .27281 .87983 .2852 .90574 .28311 .90262 .27072 Mtetra
.591 .78 .971 r
.90262 .27072 .90574 .28311 .93176 .28098 .92886 .26858 Mtetra
.617 .786 .963 r
.09733 .19623 .10642 .20755 .12883 .20485 .1199 .19349 Mtetra
.1199 .19349 .12883 .20485 .15132 .20214 .14255 .19074 Mtetra
.14255 .19074 .15132 .20214 .1739 .19942 .16529 .18797 Mtetra
.16529 .18797 .1739 .19942 .19656 .19669 .18811 .1852 Mtetra
.18811 .1852 .19656 .19669 .21931 .19395 .21102 .18242 Mtetra
.512 .732 .973 r
.21102 .18242 .21931 .19395 .2412 .20841 .2338 .18363 Mtetra
.072 .243 .734 r
.2338 .18363 .2412 .20841 .26278 .23353 .2553 .2116 Mtetra
.225 .386 .815 r
.2553 .2116 .26278 .23353 .28503 .251 .27754 .23112 Mtetra
.328 .484 .863 r
.27754 .23112 .28503 .251 .30774 .26343 .3003 .24507 Mtetra
.398 .552 .892 r
.3003 .24507 .30774 .26343 .3308 .2724 .32344 .2552 Mtetra
.446 .6 .91 r
.32344 .2552 .3308 .2724 .35413 .27892 .34688 .26261 Mtetra
.481 .636 .923 r
.34688 .26261 .35413 .27892 .37768 .28365 .37055 .26803 Mtetra
.506 .663 .932 r
.37055 .26803 .37768 .28365 .40142 .28704 .39443 .27198 Mtetra
.524 .683 .939 r
.39443 .27198 .40142 .28704 .42532 .28941 .41848 .2748 Mtetra
.538 .699 .944 r
.41848 .2748 .42532 .28941 .44938 .29098 .4427 .27674 Mtetra
.549 .712 .948 r
.4427 .27674 .44938 .29098 .47357 .29192 .46705 .27798 Mtetra
.557 .723 .951 r
.46705 .27798 .47357 .29192 .49789 .29236 .49155 .27867 Mtetra
.563 .732 .954 r
.49155 .27867 .49789 .29236 .52234 .29239 .51617 .2789 Mtetra
.569 .739 .956 r
.51617 .2789 .52234 .29239 .54691 .29208 .54092 .27877 Mtetra
.573 .745 .958 r
.54092 .27877 .54691 .29208 .5716 .29149 .56579 .27832 Mtetra
.576 .75 .96 r
.56579 .27832 .5716 .29149 .5964 .29066 .59078 .27761 Mtetra
.579 .755 .961 r
.59078 .27761 .5964 .29066 .62131 .28964 .61588 .27669 Mtetra
.581 .758 .963 r
.61588 .27669 .62131 .28964 .64633 .28844 .6411 .27557 Mtetra
.583 .762 .964 r
.6411 .27557 .64633 .28844 .67147 .2871 .66643 .2743 Mtetra
.584 .765 .965 r
.66643 .2743 .67147 .2871 .69671 .28563 .69187 .27288 Mtetra
.585 .767 .966 r
.69187 .27288 .69671 .28563 .72207 .28405 .71743 .27134 Mtetra
.586 .77 .967 r
.71743 .27134 .72207 .28405 .74753 .28237 .74309 .2697 Mtetra
.587 .772 .967 r
.74309 .2697 .74753 .28237 .7731 .2806 .76887 .26796 Mtetra
.588 .773 .968 r
.76887 .26796 .7731 .2806 .79879 .27875 .79476 .26613 Mtetra
.588 .775 .969 r
.79476 .26613 .79879 .27875 .82458 .27683 .82077 .26422 Mtetra
.589 .776 .969 r
.82077 .26422 .82458 .27683 .85048 .27485 .84688 .26225 Mtetra
.589 .778 .97 r
.84688 .26225 .85048 .27485 .8765 .27281 .87311 .26022 Mtetra
.59 .779 .97 r
.87311 .26022 .8765 .27281 .90262 .27072 .89945 .25812 Mtetra
.59 .78 .971 r
.89945 .25812 .90262 .27072 .92886 .26858 .9259 .25598 Mtetra
.617 .786 .963 r
.0881 .18473 .09733 .19623 .1199 .19349 .11082 .18195 Mtetra
.11082 .18195 .1199 .19349 .14255 .19074 .13364 .17915 Mtetra
.13364 .17915 .14255 .19074 .16529 .18797 .15654 .17634 Mtetra
.15654 .17634 .16529 .18797 .18811 .1852 .17953 .17353 Mtetra
.17953 .17353 .18811 .1852 .21102 .18242 .2026 .1707 Mtetra
.2026 .1707 .21102 .18242 .2338 .18363 .22577 .16786 Mtetra
0 .241 .757 r
.22577 .16786 .2338 .18363 .2553 .2116 .24772 .1894 Mtetra
.169 .345 .797 r
.24772 .1894 .2553 .2116 .27754 .23112 .26995 .21098 Mtetra
.288 .456 .853 r
.26995 .21098 .27754 .23112 .3003 .24507 .29276 .22646 Mtetra
.368 .532 .887 r
.29276 .22646 .3003 .24507 .32344 .2552 .31598 .23774 Mtetra
.424 .586 .908 r
.31598 .23774 .32344 .2552 .34688 .26261 .33952 .24605 Mtetra
.464 .625 .922 r
.33952 .24605 .34688 .26261 .37055 .26803 .36332 .25219 Mtetra
.492 .654 .931 r
.36332 .25219 .37055 .26803 .39443 .27198 .38734 .2567 Mtetra
.513 .676 .939 r
.38734 .2567 .39443 .27198 .41848 .2748 .41154 .25997 Mtetra
.529 .694 .944 r
.41154 .25997 .41848 .2748 .4427 .27674 .43591 .26228 Mtetra
.541 .708 .948 r
.43591 .26228 .4427 .27674 .46705 .27798 .46044 .26382 Mtetra
.551 .719 .951 r
.46044 .26382 .46705 .27798 .49155 .27867 .4851 .26476 Mtetra
.558 .729 .954 r
.4851 .26476 .49155 .27867 .51617 .2789 .5099 .2652 Mtetra
.564 .736 .956 r
.5099 .2652 .51617 .2789 .54092 .27877 .53483 .26524 Mtetra
.569 .743 .958 r
.53483 .26524 .54092 .27877 .56579 .27832 .55989 .26493 Mtetra
.573 .748 .96 r
.55989 .26493 .56579 .27832 .59078 .27761 .58506 .26435 Mtetra
.576 .753 .962 r
.58506 .26435 .59078 .27761 .61588 .27669 .61036 .26352 Mtetra
.578 .757 .963 r
.61036 .26352 .61588 .27669 .6411 .27557 .63577 .26249 Mtetra
.58 .76 .964 r
.63577 .26249 .6411 .27557 .66643 .2743 .6613 .26128 Mtetra
.582 .763 .965 r
.6613 .26128 .66643 .2743 .69187 .27288 .68695 .25992 Mtetra
.583 .766 .966 r
.68695 .25992 .69187 .27288 .71743 .27134 .71271 .25843 Mtetra
.585 .769 .967 r
.71271 .25843 .71743 .27134 .74309 .2697 .73858 .25682 Mtetra
.586 .771 .967 r
.73858 .25682 .74309 .2697 .76887 .26796 .76457 .2551 Mtetra
.586 .773 .968 r
.76457 .2551 .76887 .26796 .79476 .26613 .79067 .25329 Mtetra
.587 .774 .969 r
.79067 .25329 .79476 .26613 .82077 .26422 .81689 .2514 Mtetra
.588 .776 .969 r
.81689 .2514 .82077 .26422 .84688 .26225 .84322 .24944 Mtetra
.588 .777 .97 r
.84322 .24944 .84688 .26225 .87311 .26022 .86966 .2474 Mtetra
.589 .778 .97 r
.86966 .2474 .87311 .26022 .89945 .25812 .89622 .24531 Mtetra
.589 .779 .971 r
.89622 .24531 .89945 .25812 .9259 .25598 .9229 .24316 Mtetra
.617 .786 .963 r
.07871 .17305 .0881 .18473 .11082 .18195 .1016 .17022 Mtetra
.1016 .17022 .11082 .18195 .13364 .17915 .12458 .16738 Mtetra
.12458 .16738 .13364 .17915 .15654 .17634 .14765 .16453 Mtetra
.14765 .16453 .15654 .17634 .17953 .17353 .17081 .16167 Mtetra
.17081 .16167 .17953 .17353 .2026 .1707 .19405 .15879 Mtetra
.19405 .15879 .2026 .1707 .22577 .16786 .21739 .15591 Mtetra
.151 .499 .908 r
.21739 .15591 .22577 .16786 .24772 .1894 .24005 .16692 Mtetra
.111 .302 .776 r
.24005 .16692 .24772 .1894 .26995 .21098 .26227 .19057 Mtetra
.246 .426 .842 r
.26227 .19057 .26995 .21098 .29276 .22646 .28511 .20759 Mtetra
.338 .511 .881 r
.28511 .20759 .29276 .22646 .31598 .23774 .30841 .22004 Mtetra
.401 .57 .905 r
.30841 .22004 .31598 .23774 .33952 .24605 .33206 .22925 Mtetra
.446 .613 .92 r
.33206 .22925 .33952 .24605 .36332 .25219 .35598 .2361 Mtetra
.478 .645 .931 r
.35598 .2361 .36332 .25219 .38734 .2567 .38013 .24118 Mtetra
.502 .67 .938 r
.38013 .24118 .38734 .2567 .41154 .25997 .40449 .24491 Mtetra
.52 .688 .944 r
.40449 .24491 .41154 .25997 .43591 .26228 .42902 .24759 Mtetra
.534 .703 .948 r
.42902 .24759 .43591 .26228 .46044 .26382 .45371 .24944 Mtetra
.545 .715 .952 r
.45371 .24944 .46044 .26382 .4851 .26476 .47855 .25063 Mtetra
.553 .725 .954 r
.47855 .25063 .4851 .26476 .5099 .2652 .50353 .25128 Mtetra
.56 .734 .957 r
.50353 .25128 .5099 .2652 .53483 .26524 .52865 .25149 Mtetra
.565 .74 .959 r
.52865 .25149 .53483 .26524 .55989 .26493 .55389 .25133 Mtetra
.569 .746 .96 r
.55389 .25133 .55989 .26493 .58506 .26435 .57926 .25086 Mtetra
.573 .751 .962 r
.57926 .25086 .58506 .26435 .61036 .26352 .60475 .25014 Mtetra
.576 .755 .963 r
.60475 .25014 .61036 .26352 .63577 .26249 .63036 .24919 Mtetra
.578 .759 .964 r
.63036 .24919 .63577 .26249 .6613 .26128 .65609 .24805 Mtetra
.58 .762 .965 r
.65609 .24805 .6613 .26128 .68695 .25992 .68194 .24674 Mtetra
.582 .765 .966 r
.68194 .24674 .68695 .25992 .71271 .25843 .70791 .24529 Mtetra
.583 .768 .967 r
.70791 .24529 .71271 .25843 .73858 .25682 .73399 .24372 Mtetra
.584 .77 .967 r
.73399 .24372 .73858 .25682 .76457 .2551 .76019 .24203 Mtetra
.585 .772 .968 r
.76019 .24203 .76457 .2551 .79067 .25329 .78651 .24024 Mtetra
.586 .773 .969 r
.78651 .24024 .79067 .25329 .81689 .2514 .81294 .23836 Mtetra
.587 .775 .969 r
.81294 .23836 .81689 .2514 .84322 .24944 .83949 .2364 Mtetra
.587 .776 .97 r
.83949 .2364 .84322 .24944 .86966 .2474 .86616 .23437 Mtetra
.588 .778 .97 r
.86616 .23437 .86966 .2474 .89622 .24531 .89294 .23227 Mtetra
.588 .779 .971 r
.89294 .23227 .89622 .24531 .9229 .24316 .91984 .23012 Mtetra
.617 .786 .963 r
.06918 .16119 .07871 .17305 .1016 .17022 .09223 .15831 Mtetra
.09223 .15831 .1016 .17022 .12458 .16738 .11538 .15542 Mtetra
.11538 .15542 .12458 .16738 .14765 .16453 .13862 .15252 Mtetra
.13862 .15252 .14765 .16453 .17081 .16167 .16194 .14961 Mtetra
.16194 .14961 .17081 .16167 .19405 .15879 .18536 .14669 Mtetra
.18536 .14669 .19405 .15879 .21739 .15591 .20887 .14376 Mtetra
.534 .744 .972 r
.20887 .14376 .21739 .15591 .24005 .16692 .23228 .14416 Mtetra
.053 .258 .752 r
.23228 .14416 .24005 .16692 .26227 .19057 .25448 .16989 Mtetra
.202 .394 .83 r
.25448 .16989 .26227 .19057 .28511 .20759 .27736 .18846 Mtetra
.306 .489 .874 r
.27736 .18846 .28511 .20759 .30841 .22004 .30073 .20208 Mtetra
.377 .554 .901 r
.30073 .20208 .30841 .22004 .33206 .22925 .32448 .21221 Mtetra
.428 .602 .918 r
.32448 .21221 .33206 .22925 .35598 .2361 .34853 .21977 Mtetra
.464 .636 .93 r
.34853 .21977 .35598 .2361 .38013 .24118 .37282 .22542 Mtetra
.491 .662 .938 r
.37282 .22542 .38013 .24118 .40449 .24491 .39733 .22961 Mtetra
.511 .683 .944 r
.39733 .22961 .40449 .24491 .42902 .24759 .42202 .23267 Mtetra
.526 .699 .948 r
.42202 .23267 .42902 .24759 .45371 .24944 .44688 .23483 Mtetra
.538 .712 .952 r
.44688 .23483 .45371 .24944 .47855 .25063 .4719 .23627 Mtetra
.548 .722 .955 r
.4719 .23627 .47855 .25063 .50353 .25128 .49706 .23714 Mtetra
.555 .731 .957 r
.49706 .23714 .50353 .25128 .52865 .25149 .52236 .23752 Mtetra
.561 .738 .959 r
.52236 .23752 .52865 .25149 .55389 .25133 .5478 .2375 Mtetra
.566 .744 .96 r
.5478 .2375 .55389 .25133 .57926 .25086 .57336 .23716 Mtetra
.57 .749 .962 r
.57336 .23716 .57926 .25086 .60475 .25014 .59905 .23653 Mtetra
.573 .754 .963 r
.59905 .23653 .60475 .25014 .63036 .24919 .62486 .23567 Mtetra
.576 .758 .964 r
.62486 .23567 .63036 .24919 .65609 .24805 .6508 .23459 Mtetra
.578 .761 .965 r
.6508 .23459 .65609 .24805 .68194 .24674 .67685 .23334 Mtetra
.58 .764 .966 r
.67685 .23334 .68194 .24674 .70791 .24529 .70303 .23194 Mtetra
.582 .767 .967 r
.70303 .23194 .70791 .24529 .73399 .24372 .72933 .23039 Mtetra
.583 .769 .968 r
.72933 .23039 .73399 .24372 .76019 .24203 .75574 .22873 Mtetra
.584 .771 .968 r
.75574 .22873 .76019 .24203 .78651 .24024 .78227 .22696 Mtetra
.585 .773 .969 r
.78227 .22696 .78651 .24024 .81294 .23836 .80893 .22509 Mtetra
.586 .774 .969 r
.80893 .22509 .81294 .23836 .83949 .2364 .8357 .22314 Mtetra
.586 .776 .97 r
.8357 .22314 .83949 .2364 .86616 .23437 .86259 .22111 Mtetra
.587 .777 .97 r
.86259 .22111 .86616 .23437 .89294 .23227 .8896 .21901 Mtetra
.588 .778 .971 r
.8896 .21901 .89294 .23227 .91984 .23012 .91673 .21685 Mtetra
.617 .786 .963 r
.05949 .14913 .06918 .16119 .09223 .15831 .08271 .1462 Mtetra
.08271 .1462 .09223 .15831 .11538 .15542 .10603 .14327 Mtetra
.10603 .14327 .11538 .15542 .13862 .15252 .12944 .14032 Mtetra
.12944 .14032 .13862 .15252 .16194 .14961 .15293 .13737 Mtetra
.15293 .13737 .16194 .14961 .18536 .14669 .17653 .1344 Mtetra
.17653 .1344 .18536 .14669 .20887 .14376 .20021 .13142 Mtetra
.20021 .13142 .20887 .14376 .23228 .14416 .22398 .12842 Mtetra
0 .269 .776 r
.22398 .12842 .23228 .14416 .25448 .16989 .24658 .14894 Mtetra
.158 .362 .815 r
.24658 .14894 .25448 .16989 .27736 .18846 .26949 .16905 Mtetra
.273 .466 .866 r
.26949 .16905 .27736 .18846 .30073 .20208 .29294 .18387 Mtetra
.353 .538 .897 r
.29294 .18387 .30073 .20208 .32448 .21221 .31679 .19491 Mtetra
.409 .589 .916 r
.31679 .19491 .32448 .21221 .34853 .21977 .34096 .20319 Mtetra
.45 .627 .929 r
.34096 .20319 .34853 .21977 .37282 .22542 .36539 .20942 Mtetra
.479 .655 .937 r
.36539 .20942 .37282 .22542 .39733 .22961 .39005 .21408 Mtetra
.502 .677 .944 r
.39005 .21408 .39733 .22961 .42202 .23267 .41491 .21751 Mtetra
.519 .694 .948 r
.41491 .21751 .42202 .23267 .44688 .23483 .43994 .21998 Mtetra
.532 .708 .952 r
.43994 .21998 .44688 .23483 .4719 .23627 .46513 .22168 Mtetra
.542 .719 .955 r
.46513 .22168 .4719 .23627 .49706 .23714 .49048 .22276 Mtetra
.551 .728 .957 r
.49048 .22276 .49706 .23714 .52236 .23752 .51597 .22332 Mtetra
.557 .736 .959 r
.51597 .22332 .52236 .23752 .5478 .2375 .5416 .22345 Mtetra
.563 .742 .961 r
.5416 .22345 .5478 .2375 .57336 .23716 .56736 .22322 Mtetra
.567 .748 .962 r
.56736 .22322 .57336 .23716 .59905 .23653 .59325 .2227 Mtetra
.571 .752 .963 r
.59325 .2227 .59905 .23653 .62486 .23567 .61927 .22192 Mtetra
.574 .756 .964 r
.61927 .22192 .62486 .23567 .6508 .23459 .64541 .22091 Mtetra
.576 .76 .965 r
.64541 .22091 .6508 .23459 .67685 .23334 .67168 .21972 Mtetra
.578 .763 .966 r
.67168 .21972 .67685 .23334 .70303 .23194 .69807 .21835 Mtetra
.58 .766 .967 r
.69807 .21835 .70303 .23194 .72933 .23039 .72458 .21684 Mtetra
.581 .768 .968 r
.72458 .21684 .72933 .23039 .75574 .22873 .75121 .21521 Mtetra
.583 .77 .968 r
.75121 .21521 .75574 .22873 .78227 .22696 .77797 .21345 Mtetra
.584 .772 .969 r
.77797 .21345 .78227 .22696 .80893 .22509 .80484 .2116 Mtetra
.585 .774 .969 r
.80484 .2116 .80893 .22509 .8357 .22314 .83184 .20965 Mtetra
.585 .775 .97 r
.83184 .20965 .8357 .22314 .86259 .22111 .85896 .20762 Mtetra
.586 .776 .97 r
.85896 .20762 .86259 .22111 .8896 .21901 .8862 .20552 Mtetra
.587 .778 .971 r
.8862 .20552 .8896 .21901 .91673 .21685 .91356 .20334 Mtetra
.617 .786 .963 r
.04964 .13687 .05949 .14913 .08271 .1462 .07304 .1339 Mtetra
.07304 .1339 .08271 .1462 .10603 .14327 .09653 .13092 Mtetra
.09653 .13092 .10603 .14327 .12944 .14032 .12011 .12792 Mtetra
.12011 .12792 .12944 .14032 .15293 .13737 .14378 .12492 Mtetra
.14378 .12492 .15293 .13737 .17653 .1344 .16755 .1219 Mtetra
.16755 .1219 .17653 .1344 .20021 .13142 .19141 .11887 Mtetra
.19141 .11887 .20021 .13142 .22398 .12842 .21536 .11582 Mtetra
.128 .479 .898 r
.21536 .11582 .22398 .12842 .24658 .14894 .23858 .1277 Mtetra
.113 .328 .798 r
.23858 .1277 .24658 .14894 .26949 .16905 .26152 .14938 Mtetra
.239 .442 .857 r
.26152 .14938 .26949 .16905 .29294 .18387 .28503 .16538 Mtetra
.328 .521 .892 r
.28503 .16538 .29294 .18387 .31679 .19491 .30898 .17735 Mtetra
.39 .577 .914 r
.30898 .17735 .31679 .19491 .34096 .20319 .33328 .18636 Mtetra
.435 .617 .927 r
.33328 .18636 .34096 .20319 .36539 .20942 .35785 .19317 Mtetra
.468 .648 .937 r
.35785 .19317 .36539 .20942 .39005 .21408 .38266 .1983 Mtetra
.492 .671 .943 r
.38266 .1983 .39005 .21408 .41491 .21751 .40768 .20211 Mtetra
.511 .689 .948 r
.40768 .20211 .41491 .21751 .43994 .21998 .43289 .2049 Mtetra
.526 .704 .952 r
.43289 .2049 .43994 .21998 .46513 .22168 .45826 .20685 Mtetra
.537 .715 .955 r
.45826 .20685 .46513 .22168 .49048 .22276 .48379 .20814 Mtetra
.546 .725 .957 r
.48379 .20814 .49048 .22276 .51597 .22332 .50947 .20888 Mtetra
.553 .733 .959 r
.50947 .20888 .51597 .22332 .5416 .22345 .5353 .20916 Mtetra
.559 .74 .961 r
.5353 .20916 .5416 .22345 .56736 .22322 .56126 .20906 Mtetra
.564 .746 .962 r
.56126 .20906 .56736 .22322 .59325 .2227 .58735 .20863 Mtetra
.568 .751 .963 r
.58735 .20863 .59325 .2227 .61927 .22192 .61358 .20793 Mtetra
.571 .755 .964 r
.61358 .20793 .61927 .22192 .64541 .22091 .63993 .20699 Mtetra
.574 .758 .965 r
.63993 .20699 .64541 .22091 .67168 .21972 .66641 .20585 Mtetra
.576 .762 .966 r
.66641 .20585 .67168 .21972 .69807 .21835 .69302 .20453 Mtetra
.578 .764 .967 r
.69302 .20453 .69807 .21835 .72458 .21684 .71975 .20306 Mtetra
.58 .767 .968 r
.71975 .20306 .72458 .21684 .75121 .21521 .74661 .20145 Mtetra
.581 .769 .968 r
.74661 .20145 .75121 .21521 .77797 .21345 .77359 .19971 Mtetra
.583 .771 .969 r
.77359 .19971 .77797 .21345 .80484 .2116 .80069 .19787 Mtetra
.584 .773 .969 r
.80069 .19787 .80484 .2116 .83184 .20965 .82792 .19593 Mtetra
.585 .774 .97 r
.82792 .19593 .83184 .20965 .85896 .20762 .85527 .19389 Mtetra
.585 .776 .97 r
.85527 .19389 .85896 .20762 .8862 .20552 .88274 .19178 Mtetra
.586 .777 .971 r
.88274 .19178 .8862 .20552 .91356 .20334 .91034 .1896 Mtetra
.617 .786 .963 r
.03963 .12441 .04964 .13687 .07304 .1339 .0632 .12139 Mtetra
.0632 .12139 .07304 .1339 .09653 .13092 .08686 .11836 Mtetra
.08686 .11836 .09653 .13092 .12011 .12792 .11062 .11531 Mtetra
.11062 .11531 .12011 .12792 .14378 .12492 .13447 .11226 Mtetra
.13447 .11226 .14378 .12492 .16755 .1219 .15842 .10919 Mtetra
.15842 .10919 .16755 .1219 .19141 .11887 .18246 .10611 Mtetra
.18246 .10611 .19141 .11887 .21536 .11582 .2066 .10302 Mtetra
.452 .697 .971 r
.2066 .10302 .21536 .11582 .23858 .1277 .23047 .10617 Mtetra
.067 .293 .78 r
.23047 .10617 .23858 .1277 .26152 .14938 .25343 .12942 Mtetra
.205 .417 .847 r
.25343 .12942 .26152 .14938 .28503 .16538 .27701 .14662 Mtetra
.302 .503 .886 r
.27701 .14662 .28503 .16538 .30898 .17735 .30106 .15952 Mtetra
.371 .563 .91 r
.30106 .15952 .30898 .17735 .33328 .18636 .32547 .16927 Mtetra
.42 .607 .926 r
.32547 .16927 .33328 .18636 .35785 .19317 .35019 .17666 Mtetra
.456 .64 .936 r
.35019 .17666 .35785 .19317 .38266 .1983 .37515 .18226 Mtetra
.483 .665 .943 r
.37515 .18226 .38266 .1983 .40768 .20211 .40034 .18646 Mtetra
.503 .684 .948 r
.40034 .18646 .40768 .20211 .43289 .2049 .42572 .18956 Mtetra
.519 .7 .952 r
.42572 .18956 .43289 .2049 .45826 .20685 .45127 .19178 Mtetra
.531 .712 .955 r
.45127 .19178 .45826 .20685 .48379 .20814 .47699 .19328 Mtetra
.541 .722 .957 r
.47699 .19328 .48379 .20814 .50947 .20888 .50287 .1942 Mtetra
.549 .731 .959 r
.50287 .1942 .50947 .20888 .5353 .20916 .52889 .19463 Mtetra
.556 .738 .961 r
.52889 .19463 .5353 .20916 .56126 .20906 .55506 .19465 Mtetra
.561 .744 .962 r
.55506 .19465 .56126 .20906 .58735 .20863 .58136 .19432 Mtetra
.565 .749 .963 r
.58136 .19432 .58735 .20863 .61358 .20793 .60779 .19371 Mtetra
.569 .753 .965 r
.60779 .19371 .61358 .20793 .63993 .20699 .63436 .19284 Mtetra
.572 .757 .965 r
.63436 .19284 .63993 .20699 .66641 .20585 .66106 .19175 Mtetra
.575 .761 .966 r
.66106 .19175 .66641 .20585 .69302 .20453 .68788 .19047 Mtetra
.577 .763 .967 r
.68788 .19047 .69302 .20453 .71975 .20306 .71484 .18903 Mtetra
.579 .766 .968 r
.71484 .18903 .71975 .20306 .74661 .20145 .74192 .18744 Mtetra
.58 .768 .968 r
.74192 .18744 .74661 .20145 .77359 .19971 .76913 .18573 Mtetra
.581 .77 .969 r
.76913 .18573 .77359 .19971 .80069 .19787 .79646 .18389 Mtetra
.583 .772 .969 r
.79646 .18389 .80069 .19787 .82792 .19593 .82392 .18195 Mtetra
.584 .774 .97 r
.82392 .18195 .82792 .19593 .85527 .19389 .85151 .17992 Mtetra
.584 .775 .97 r
.85151 .17992 .85527 .19389 .88274 .19178 .87922 .17781 Mtetra
.585 .777 .971 r
.87922 .17781 .88274 .19178 .91034 .1896 .90707 .17561 Mtetra
.617 .786 .963 r
.02946 .11175 .03963 .12441 .0632 .12139 .0532 .10868 Mtetra
.0532 .10868 .0632 .12139 .08686 .11836 .07704 .10559 Mtetra
.07704 .10559 .08686 .11836 .11062 .11531 .10098 .1025 Mtetra
.10098 .1025 .11062 .11531 .13447 .11226 .12501 .09939 Mtetra
.12501 .09939 .13447 .11226 .15842 .10919 .14914 .09627 Mtetra
.14914 .09627 .15842 .10919 .18246 .10611 .17336 .09314 Mtetra
.17336 .09314 .18246 .10611 .2066 .10302 .19768 .08999 Mtetra
.19768 .08999 .2066 .10302 .23047 .10617 .2221 .08683 Mtetra
.009 .281 .78 r
.2221 .08683 .23047 .10617 .25343 .12942 .24522 .10918 Mtetra
.17 .391 .835 r
.24522 .10918 .25343 .12942 .27701 .14662 .26887 .12759 Mtetra
.276 .484 .88 r
.26887 .12759 .27701 .14662 .30106 .15952 .29301 .14142 Mtetra
.351 .55 .907 r
.29301 .14142 .30106 .15952 .32547 .16927 .31755 .15191 Mtetra
.404 .597 .924 r
.31755 .15191 .32547 .16927 .35019 .17666 .3424 .15989 Mtetra
.444 .632 .935 r
.3424 .15989 .35019 .17666 .37515 .18226 .36752 .16597 Mtetra
.473 .659 .942 r
.36752 .16597 .37515 .18226 .40034 .18646 .39288 .17056 Mtetra
.495 .679 .948 r
.39288 .17056 .40034 .18646 .42572 .18956 .41843 .17398 Mtetra
.512 .696 .952 r
.41843 .17398 .42572 .18956 .45127 .19178 .44417 .17646 Mtetra
.526 .709 .955 r
.44417 .17646 .45127 .19178 .47699 .19328 .47008 .17817 Mtetra
.537 .719 .957 r
.47008 .17817 .47699 .19328 .50287 .1942 .49615 .17927 Mtetra
.545 .728 .959 r
.49615 .17927 .50287 .1942 .52889 .19463 .52238 .17985 Mtetra
.552 .736 .961 r
.52238 .17985 .52889 .19463 .55506 .19465 .54875 .17999 Mtetra
.558 .742 .962 r
.54875 .17999 .55506 .19465 .58136 .19432 .57526 .17977 Mtetra
.563 .747 .964 r
.57526 .17977 .58136 .19432 .60779 .19371 .60191 .17923 Mtetra
.567 .752 .965 r
.60191 .17923 .60779 .19371 .63436 .19284 .62869 .17843 Mtetra
.57 .756 .966 r
.62869 .17843 .63436 .19284 .66106 .19175 .65561 .1774 Mtetra
.573 .759 .966 r
.65561 .1774 .66106 .19175 .68788 .19047 .68266 .17617 Mtetra
.575 .762 .967 r
.68266 .17617 .68788 .19047 .71484 .18903 .70984 .17476 Mtetra
.577 .765 .968 r
.70984 .17476 .71484 .18903 .74192 .18744 .73715 .1732 Mtetra
.579 .768 .968 r
.73715 .1732 .74192 .18744 .76913 .18573 .76459 .17149 Mtetra
.58 .77 .969 r
.76459 .17149 .76913 .18573 .79646 .18389 .79216 .16967 Mtetra
.582 .772 .969 r
.79216 .16967 .79646 .18389 .82392 .18195 .81986 .16773 Mtetra
.583 .773 .97 r
.81986 .16773 .82392 .18195 .85151 .17992 .84768 .1657 Mtetra
.584 .775 .97 r
.84768 .1657 .85151 .17992 .87922 .17781 .87564 .16358 Mtetra
.584 .776 .971 r
.87564 .16358 .87922 .17781 .90707 .17561 .90373 .16137 Mtetra
0 g
.89362 0 m
.98022 .38351 L
s
.98022 .38351 m
1 .65325 L
s
1 .65325 m
.91448 .33294 L
s
.91448 .33294 m
.89362 0 L
s
.02946 .11175 m
0 .4272 L
s
0 .4272 m
.91448 .33294 L
s
.91448 .33294 m
.89362 0 L
s
.89362 0 m
.02946 .11175 L
s
.02946 .11175 m
.89362 0 L
s
gsave
.44797 -0.02478 -66.3961 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(w) show
69.062500 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
0 .4272 m
.29069 .70824 L
s
gsave
.15892 .66839 -66.3192 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(P) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.00802991 0.97619 0.329226 MathSubStart
%% SurfaceGraphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1.10169 -0.148196 1.10169 [
[.44797 -0.02478 -5.39612 -15 ]
[.44797 -0.02478 5.60388 0 ]
[.15892 .66839 -5.31917 0 ]
[.15892 .66839 4.68083 15 ]
[-0.06694 .27471 -10 -6.62571 ]
[-0.06694 .27471 0 8.37429 ]
[ 0 0 0 0 ]
[ 1 .70824 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.02946 .11175 m
.89362 0 L
s
gsave
.44797 -0.02478 -66.3961 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(w) show
69.062500 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
0 .4272 m
.29069 .70824 L
s
gsave
.15892 .66839 -66.3192 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(P) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.02946 .11175 m
0 .4272 L
s
gsave
-0.06694 .27471 -71 -10.6257 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Q) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.02946 .11175 m
0 .4272 L
s
0 .4272 m
.29069 .70824 L
s
.29069 .70824 m
.30155 .45044 L
s
.30155 .45044 m
.02946 .11175 L
s
.89362 0 m
.98022 .38351 L
s
.98022 .38351 m
1 .65325 L
s
1 .65325 m
.91448 .33294 L
s
.91448 .33294 m
.89362 0 L
s
.02946 .11175 m
0 .4272 L
s
0 .4272 m
.91448 .33294 L
s
.91448 .33294 m
.89362 0 L
s
.89362 0 m
.02946 .11175 L
s
.30155 .45044 m
.98022 .38351 L
s
.98022 .38351 m
1 .65325 L
s
1 .65325 m
.29069 .70824 L
s
.29069 .70824 m
.30155 .45044 L
s
0 0 m
1 0 L
1 .70824 L
0 .70824 L
closepath
clip
newpath
.567 .808 .99 r
.28406 .70183 .29069 .70824 .31044 .70671 .30393 .70027 Mtetra
.30393 .70027 .31044 .70671 .33025 .70517 .32386 .69872 Mtetra
.32386 .69872 .33025 .70517 .35012 .70363 .34386 .69716 Mtetra
.34386 .69716 .35012 .70363 .37006 .70209 .36393 .69559 Mtetra
.36393 .69559 .37006 .70209 .39006 .70053 .38406 .69402 Mtetra
.38406 .69402 .39006 .70053 .41013 .69898 .40425 .69244 Mtetra
.40425 .69244 .41013 .69898 .43027 .69742 .42452 .69086 Mtetra
.772 .889 .928 r
.42452 .69086 .43027 .69742 .45048 .69478 .445 .68022 Mtetra
.855 .793 .789 r
.445 .68022 .45048 .69478 .47106 .66942 .46568 .65616 Mtetra
.831 .798 .819 r
.46568 .65616 .47106 .66942 .49148 .64992 .48622 .6376 Mtetra
.808 .801 .845 r
.48622 .6376 .49148 .64992 .51183 .63446 .50669 .62288 Mtetra
.786 .803 .867 r
.50669 .62288 .51183 .63446 .53215 .62191 .52713 .61089 Mtetra
.765 .804 .884 r
.52713 .61089 .53215 .62191 .55245 .61148 .54756 .60092 Mtetra
.746 .804 .899 r
.54756 .60092 .55245 .61148 .57278 .60266 .56801 .59245 Mtetra
.73 .804 .911 r
.56801 .59245 .57278 .60266 .59313 .59506 .58849 .58514 Mtetra
.715 .804 .92 r
.58849 .58514 .59313 .59506 .61351 .58841 .609 .57873 Mtetra
.702 .803 .928 r
.609 .57873 .61351 .58841 .63394 .58251 .62957 .57303 Mtetra
.69 .802 .934 r
.62957 .57303 .63394 .58251 .65443 .57721 .65018 .5679 Mtetra
.68 .802 .94 r
.65018 .5679 .65443 .57721 .67496 .57241 .67085 .56323 Mtetra
.671 .801 .944 r
.67085 .56323 .67496 .57241 .69555 .568 .69157 .55894 Mtetra
.664 .8 .948 r
.69157 .55894 .69555 .568 .7162 .56392 .71236 .55495 Mtetra
.657 .8 .951 r
.71236 .55495 .7162 .56392 .73691 .56011 .73321 .55123 Mtetra
.651 .799 .954 r
.73321 .55123 .73691 .56011 .75768 .55653 .75412 .54772 Mtetra
.646 .799 .956 r
.75412 .54772 .75768 .55653 .77852 .55314 .77509 .54439 Mtetra
.641 .799 .958 r
.77509 .54439 .77852 .55314 .79943 .54992 .79614 .54121 Mtetra
.637 .798 .96 r
.79614 .54121 .79943 .54992 .82039 .54684 .81725 .53817 Mtetra
.634 .798 .961 r
.81725 .53817 .82039 .54684 .84143 .54387 .83843 .53524 Mtetra
.631 .798 .963 r
.83843 .53524 .84143 .54387 .86254 .54101 .85967 .53241 Mtetra
.628 .797 .964 r
.85967 .53241 .86254 .54101 .88371 .53824 .88099 .52966 Mtetra
.625 .797 .965 r
.88099 .52966 .88371 .53824 .90495 .53555 .90238 .52699 Mtetra
.623 .797 .966 r
.90238 .52699 .90495 .53555 .92626 .53292 .92383 .52437 Mtetra
.621 .797 .967 r
.92383 .52437 .92626 .53292 .94764 .53035 .94536 .52181 Mtetra
.619 .797 .967 r
.94536 .52181 .94764 .53035 .9691 .52784 .96696 .5193 Mtetra
.617 .797 .968 r
.96696 .5193 .9691 .52784 .99062 .52536 .98863 .51684 Mtetra
.567 .808 .99 r
.27734 .69533 .28406 .70183 .30393 .70027 .29733 .69375 Mtetra
.29733 .69375 .30393 .70027 .32386 .69872 .31739 .69218 Mtetra
.31739 .69218 .32386 .69872 .34386 .69716 .33752 .69059 Mtetra
.33752 .69059 .34386 .69716 .36393 .69559 .35771 .689 Mtetra
.35771 .689 .36393 .69559 .38406 .69402 .37797 .68741 Mtetra
.37797 .68741 .38406 .69402 .40425 .69244 .39829 .68581 Mtetra
.39829 .68581 .40425 .69244 .42452 .69086 .41869 .68421 Mtetra
.861 .903 .862 r
.41869 .68421 .42452 .69086 .445 .68022 .43946 .6655 Mtetra
.848 .79 .795 r
.43946 .6655 .445 .68022 .46568 .65616 .46025 .64273 Mtetra
.824 .795 .824 r
.46025 .64273 .46568 .65616 .48622 .6376 .4809 .62515 Mtetra
.801 .798 .849 r
.4809 .62515 .48622 .6376 .50669 .62288 .50149 .61116 Mtetra
.779 .8 .87 r
.50149 .61116 .50669 .62288 .52713 .61089 .52204 .59974 Mtetra
.759 .801 .887 r
.52204 .59974 .52713 .61089 .54756 .60092 .5426 .59022 Mtetra
.741 .802 .901 r
.5426 .59022 .54756 .60092 .56801 .59245 .56318 .58212 Mtetra
.724 .802 .912 r
.56318 .58212 .56801 .59245 .58849 .58514 .58379 .5751 Mtetra
.71 .801 .922 r
.58379 .5751 .58849 .58514 .609 .57873 .60444 .56893 Mtetra
.697 .801 .929 r
.60444 .56893 .609 .57873 .62957 .57303 .62513 .56343 Mtetra
.686 .8 .935 r
.62513 .56343 .62957 .57303 .65018 .5679 .64588 .55847 Mtetra
.677 .8 .941 r
.64588 .55847 .65018 .5679 .67085 .56323 .66668 .55394 Mtetra
.668 .799 .945 r
.66668 .55394 .67085 .56323 .69157 .55894 .68754 .54976 Mtetra
.661 .799 .949 r
.68754 .54976 .69157 .55894 .71236 .55495 .70847 .54587 Mtetra
.655 .798 .952 r
.70847 .54587 .71236 .55495 .73321 .55123 .72945 .54223 Mtetra
.649 .798 .954 r
.72945 .54223 .73321 .55123 .75412 .54772 .7505 .53879 Mtetra
.644 .798 .956 r
.7505 .53879 .75412 .54772 .77509 .54439 .77162 .53552 Mtetra
.64 .797 .958 r
.77162 .53552 .77509 .54439 .79614 .54121 .7928 .53239 Mtetra
.636 .797 .96 r
.7928 .53239 .79614 .54121 .81725 .53817 .81406 .52939 Mtetra
.632 .797 .962 r
.81406 .52939 .81725 .53817 .83843 .53524 .83538 .52649 Mtetra
.629 .797 .963 r
.83538 .52649 .83843 .53524 .85967 .53241 .85677 .52369 Mtetra
.627 .797 .964 r
.85677 .52369 .85967 .53241 .88099 .52966 .87823 .52096 Mtetra
.624 .797 .965 r
.87823 .52096 .88099 .52966 .90238 .52699 .89976 .51831 Mtetra
.622 .796 .966 r
.89976 .51831 .90238 .52699 .92383 .52437 .92137 .51571 Mtetra
.62 .796 .967 r
.92137 .51571 .92383 .52437 .94536 .52181 .94305 .51316 Mtetra
.618 .796 .967 r
.94305 .51316 .94536 .52181 .96696 .5193 .9648 .51065 Mtetra
.617 .796 .968 r
.9648 .51065 .96696 .5193 .98863 .51684 .98662 .50819 Mtetra
.567 .808 .99 r
.27052 .68874 .27734 .69533 .29733 .69375 .29064 .68714 Mtetra
.29064 .68714 .29733 .69375 .31739 .69218 .31083 .68554 Mtetra
.31083 .68554 .31739 .69218 .33752 .69059 .33108 .68394 Mtetra
.33108 .68394 .33752 .69059 .35771 .689 .3514 .68233 Mtetra
.3514 .68233 .35771 .689 .37797 .68741 .37179 .68071 Mtetra
.37179 .68071 .37797 .68741 .39829 .68581 .39225 .67909 Mtetra
.39225 .67909 .39829 .68581 .41869 .68421 .41278 .67746 Mtetra
.909 .901 .805 r
.41278 .67746 .41869 .68421 .43946 .6655 .43385 .65061 Mtetra
.84 .787 .8 r
.43385 .65061 .43946 .6655 .46025 .64273 .45475 .62915 Mtetra
.817 .792 .829 r
.45475 .62915 .46025 .64273 .4809 .62515 .47551 .61254 Mtetra
.794 .795 .853 r
.47551 .61254 .4809 .62515 .50149 .61116 .49622 .59929 Mtetra
.772 .797 .873 r
.49622 .59929 .50149 .61116 .52204 .59974 .5169 .58845 Mtetra
.752 .798 .89 r
.5169 .58845 .52204 .59974 .5426 .59022 .53758 .57938 Mtetra
.735 .799 .903 r
.53758 .57938 .5426 .59022 .56318 .58212 .55829 .57165 Mtetra
.719 .799 .914 r
.55829 .57165 .56318 .58212 .58379 .5751 .57903 .56493 Mtetra
.705 .799 .923 r
.57903 .56493 .58379 .5751 .60444 .56893 .59981 .559 Mtetra
.693 .799 .93 r
.59981 .559 .60444 .56893 .62513 .56343 .62064 .55371 Mtetra
.683 .798 .936 r
.62064 .55371 .62513 .56343 .64588 .55847 .64152 .54891 Mtetra
.673 .798 .941 r
.64152 .54891 .64588 .55847 .66668 .55394 .66246 .54452 Mtetra
.665 .798 .946 r
.66246 .54452 .66668 .55394 .68754 .54976 .68346 .54046 Mtetra
.658 .797 .949 r
.68346 .54046 .68754 .54976 .70847 .54587 .70452 .53667 Mtetra
.652 .797 .952 r
.70452 .53667 .70847 .54587 .72945 .54223 .72565 .53311 Mtetra
.647 .797 .955 r
.72565 .53311 .72945 .54223 .7505 .53879 .74684 .52973 Mtetra
.642 .797 .957 r
.74684 .52973 .7505 .53879 .77162 .53552 .7681 .52652 Mtetra
.638 .796 .959 r
.7681 .52652 .77162 .53552 .7928 .53239 .78943 .52345 Mtetra
.634 .796 .96 r
.78943 .52345 .7928 .53239 .81406 .52939 .81082 .52049 Mtetra
.631 .796 .962 r
.81082 .52049 .81406 .52939 .83538 .52649 .83229 .51763 Mtetra
.628 .796 .963 r
.83229 .51763 .83538 .52649 .85677 .52369 .85383 .51485 Mtetra
.625 .796 .964 r
.85383 .51485 .85677 .52369 .87823 .52096 .87544 .51214 Mtetra
.623 .796 .965 r
.87544 .51214 .87823 .52096 .89976 .51831 .89712 .5095 Mtetra
.621 .796 .966 r
.89712 .5095 .89976 .51831 .92137 .51571 .91887 .50692 Mtetra
.619 .796 .967 r
.91887 .50692 .92137 .51571 .94305 .51316 .9407 .50438 Mtetra
.617 .796 .967 r
.9407 .50438 .94305 .51316 .9648 .51065 .9626 .50188 Mtetra
.616 .796 .968 r
.9626 .50188 .9648 .51065 .98662 .50819 .98458 .49942 Mtetra
.567 .808 .99 r
.26361 .68206 .27052 .68874 .29064 .68714 .28386 .68044 Mtetra
.28386 .68044 .29064 .68714 .31083 .68554 .30418 .67882 Mtetra
.30418 .67882 .31083 .68554 .33108 .68394 .32456 .67719 Mtetra
.32456 .67719 .33108 .68394 .3514 .68233 .34501 .67556 Mtetra
.34501 .67556 .3514 .68233 .37179 .68071 .36553 .67392 Mtetra
.36553 .67392 .37179 .68071 .39225 .67909 .38612 .67227 Mtetra
.756 .883 .936 r
.38612 .67227 .39225 .67909 .41278 .67746 .40698 .66245 Mtetra
.866 .796 .78 r
.40698 .66245 .41278 .67746 .43385 .65061 .42818 .63556 Mtetra
.832 .784 .806 r
.42818 .63556 .43385 .65061 .45475 .62915 .44918 .61541 Mtetra
.809 .788 .834 r
.44918 .61541 .45475 .62915 .47551 .61254 .47006 .59977 Mtetra
.786 .792 .857 r
.47006 .59977 .47551 .61254 .49622 .59929 .49088 .58727 Mtetra
.765 .794 .877 r
.49088 .58727 .49622 .59929 .5169 .58845 .51169 .57702 Mtetra
.746 .795 .893 r
.51169 .57702 .5169 .58845 .53758 .57938 .5325 .56841 Mtetra
.729 .796 .905 r
.5325 .56841 .53758 .57938 .55829 .57165 .55333 .56104 Mtetra
.714 .797 .916 r
.55333 .56104 .55829 .57165 .57903 .56493 .5742 .55462 Mtetra
.7 .797 .925 r
.5742 .55462 .57903 .56493 .59981 .559 .59512 .54894 Mtetra
.689 .797 .932 r
.59512 .54894 .59981 .559 .62064 .55371 .61608 .54385 Mtetra
.679 .796 .937 r
.61608 .54385 .62064 .55371 .64152 .54891 .6371 .53922 Mtetra
.67 .796 .942 r
.6371 .53922 .64152 .54891 .66246 .54452 .65818 .53497 Mtetra
.662 .796 .946 r
.65818 .53497 .66246 .54452 .68346 .54046 .67932 .53103 Mtetra
.656 .796 .95 r
.67932 .53103 .68346 .54046 .70452 .53667 .70052 .52734 Mtetra
.65 .796 .952 r
.70052 .52734 .70452 .53667 .72565 .53311 .72179 .52386 Mtetra
.645 .796 .955 r
.72179 .52386 .72565 .53311 .74684 .52973 .74312 .52056 Mtetra
.64 .795 .957 r
.74312 .52056 .74684 .52973 .7681 .52652 .76453 .51741 Mtetra
.636 .795 .959 r
.76453 .51741 .7681 .52652 .78943 .52345 .786 .51438 Mtetra
.633 .795 .96 r
.786 .51438 .78943 .52345 .81082 .52049 .80754 .51146 Mtetra
.629 .795 .962 r
.80754 .51146 .81082 .52049 .83229 .51763 .82916 .50863 Mtetra
.627 .795 .963 r
.82916 .50863 .83229 .51763 .85383 .51485 .85084 .50588 Mtetra
.624 .795 .964 r
.85084 .50588 .85383 .51485 .87544 .51214 .8726 .5032 Mtetra
.622 .795 .965 r
.8726 .5032 .87544 .51214 .89712 .5095 .89443 .50058 Mtetra
.62 .795 .966 r
.89443 .50058 .89712 .5095 .91887 .50692 .91634 .49801 Mtetra
.618 .795 .967 r
.91634 .49801 .91887 .50692 .9407 .50438 .93832 .49548 Mtetra
.617 .795 .967 r
.93832 .49548 .9407 .50438 .9626 .50188 .96037 .49299 Mtetra
.615 .795 .968 r
.96037 .49299 .9626 .50188 .98458 .49942 .9825 .49053 Mtetra
.567 .808 .99 r
.2566 .67528 .26361 .68206 .28386 .68044 .27698 .67364 Mtetra
.27698 .67364 .28386 .68044 .30418 .67882 .29743 .672 Mtetra
.29743 .672 .30418 .67882 .32456 .67719 .31795 .67035 Mtetra
.31795 .67035 .32456 .67719 .34501 .67556 .33853 .66869 Mtetra
.33853 .66869 .34501 .67556 .36553 .67392 .35919 .66703 Mtetra
.35919 .66703 .36553 .67392 .38612 .67227 .37991 .66536 Mtetra
.868 .901 .854 r
.37991 .66536 .38612 .67227 .40698 .66245 .40115 .64539 Mtetra
.847 .774 .78 r
.40115 .64539 .40698 .66245 .42818 .63556 .42245 .62033 Mtetra
.824 .78 .811 r
.42245 .62033 .42818 .63556 .44918 .61541 .44355 .6015 Mtetra
.8 .785 .839 r
.44355 .6015 .44918 .61541 .47006 .59977 .46454 .58686 Mtetra
.778 .788 .861 r
.46454 .58686 .47006 .59977 .49088 .58727 .48548 .57511 Mtetra
.758 .791 .88 r
.48548 .57511 .49088 .58727 .51169 .57702 .50641 .56544 Mtetra
.739 .792 .895 r
.50641 .56544 .51169 .57702 .5325 .56841 .52735 .55729 Mtetra
.723 .793 .908 r
.52735 .55729 .5325 .56841 .55333 .56104 .54831 .5503 Mtetra
.708 .794 .918 r
.54831 .5503 .55333 .56104 .5742 .55462 .56932 .54418 Mtetra
.695 .794 .926 r
.56932 .54418 .5742 .55462 .59512 .54894 .59037 .53875 Mtetra
.684 .794 .933 r
.59037 .53875 .59512 .54894 .61608 .54385 .61147 .53386 Mtetra
.675 .794 .938 r
.61147 .53386 .61608 .54385 .6371 .53922 .63262 .5294 Mtetra
.666 .794 .943 r
.63262 .5294 .6371 .53922 .65818 .53497 .65384 .52529 Mtetra
.659 .794 .947 r
.65384 .52529 .65818 .53497 .67932 .53103 .67512 .52147 Mtetra
.653 .794 .95 r
.67512 .52147 .67932 .53103 .70052 .52734 .69647 .51788 Mtetra
.647 .794 .953 r
.69647 .51788 .70052 .52734 .72179 .52386 .71788 .51449 Mtetra
.642 .794 .955 r
.71788 .51449 .72179 .52386 .74312 .52056 .73936 .51126 Mtetra
.638 .794 .957 r
.73936 .51126 .74312 .52056 .76453 .51741 .76091 .50816 Mtetra
.634 .794 .959 r
.76091 .50816 .76453 .51741 .786 .51438 .78253 .50519 Mtetra
.631 .794 .961 r
.78253 .50519 .786 .51438 .80754 .51146 .80422 .50231 Mtetra
.628 .794 .962 r
.80422 .50231 .80754 .51146 .82916 .50863 .82598 .49951 Mtetra
.625 .794 .963 r
.82598 .49951 .82916 .50863 .85084 .50588 .84782 .49679 Mtetra
.623 .794 .964 r
.84782 .49679 .85084 .50588 .8726 .5032 .86973 .49413 Mtetra
.621 .794 .965 r
.86973 .49413 .8726 .5032 .89443 .50058 .89171 .49153 Mtetra
.619 .795 .966 r
.89171 .49153 .89443 .50058 .91634 .49801 .91377 .48897 Mtetra
.617 .795 .967 r
.91377 .48897 .91634 .49801 .93832 .49548 .9359 .48645 Mtetra
.616 .795 .968 r
.9359 .48645 .93832 .49548 .96037 .49299 .95811 .48396 Mtetra
.614 .795 .968 r
.95811 .48396 .96037 .49299 .9825 .49053 .9804 .48151 Mtetra
.567 .808 .99 r
.2495 .66841 .2566 .67528 .27698 .67364 .27001 .66675 Mtetra
.27001 .66675 .27698 .67364 .29743 .672 .29059 .66508 Mtetra
.29059 .66508 .29743 .672 .31795 .67035 .31124 .66341 Mtetra
.31124 .66341 .31795 .67035 .33853 .66869 .33196 .66173 Mtetra
.33196 .66173 .33853 .66869 .35919 .66703 .35275 .66004 Mtetra
.35275 .66004 .35919 .66703 .37991 .66536 .37361 .65835 Mtetra
.92 .896 .788 r
.37361 .65835 .37991 .66536 .40115 .64539 .39527 .62814 Mtetra
.838 .769 .786 r
.39527 .62814 .40115 .64539 .42245 .62033 .41665 .60492 Mtetra
.814 .776 .817 r
.41665 .60492 .42245 .62033 .44355 .6015 .43785 .58743 Mtetra
.791 .781 .843 r
.43785 .58743 .44355 .6015 .46454 .58686 .45895 .57378 Mtetra
.77 .784 .865 r
.45895 .57378 .46454 .58686 .48548 .57511 .48001 .56279 Mtetra
.75 .787 .883 r
.48001 .56279 .48548 .57511 .50641 .56544 .50107 .55371 Mtetra
.732 .789 .898 r
.50107 .55371 .50641 .56544 .52735 .55729 .52213 .54603 Mtetra
.716 .79 .91 r
.52213 .54603 .52735 .55729 .54831 .5503 .54323 .53941 Mtetra
.702 .791 .919 r
.54323 .53941 .54831 .5503 .56932 .54418 .56437 .5336 Mtetra
.69 .792 .927 r
.56437 .5336 .56932 .54418 .59037 .53875 .58555 .52842 Mtetra
.68 .792 .934 r
.58555 .52842 .59037 .53875 .61147 .53386 .60679 .52374 Mtetra
.671 .792 .939 r
.60679 .52374 .61147 .53386 .63262 .5294 .62809 .51945 Mtetra
.663 .792 .944 r
.62809 .51945 .63262 .5294 .65384 .52529 .64945 .51548 Mtetra
.656 .793 .947 r
.64945 .51548 .65384 .52529 .67512 .52147 .67087 .51178 Mtetra
.65 .793 .951 r
.67087 .51178 .67512 .52147 .69647 .51788 .69236 .50829 Mtetra
.645 .793 .953 r
.69236 .50829 .69647 .51788 .71788 .51449 .71391 .50498 Mtetra
.64 .793 .956 r
.71391 .50498 .71788 .51449 .73936 .51126 .73554 .50182 Mtetra
.636 .793 .958 r
.73554 .50182 .73936 .51126 .76091 .50816 .75724 .49879 Mtetra
.633 .793 .959 r
.75724 .49879 .76091 .50816 .78253 .50519 .779 .49586 Mtetra
.629 .793 .961 r
.779 .49586 .78253 .50519 .80422 .50231 .80084 .49303 Mtetra
.627 .793 .962 r
.80084 .49303 .80422 .50231 .82598 .49951 .82276 .49027 Mtetra
.624 .794 .963 r
.82276 .49027 .82598 .49951 .84782 .49679 .84475 .48757 Mtetra
.622 .794 .964 r
.84475 .48757 .84782 .49679 .86973 .49413 .86681 .48494 Mtetra
.62 .794 .965 r
.86681 .48494 .86973 .49413 .89171 .49153 .88895 .48235 Mtetra
.618 .794 .966 r
.88895 .48235 .89171 .49153 .91377 .48897 .91116 .4798 Mtetra
.616 .794 .967 r
.91116 .4798 .91377 .48897 .9359 .48645 .93345 .47729 Mtetra
.615 .794 .968 r
.93345 .47729 .9359 .48645 .95811 .48396 .95582 .47481 Mtetra
.614 .794 .968 r
.95582 .47481 .95811 .48396 .9804 .48151 .97827 .47236 Mtetra
.567 .808 .99 r
.24229 .66145 .2495 .66841 .27001 .66675 .26294 .65976 Mtetra
.26294 .65976 .27001 .66675 .29059 .66508 .28365 .65807 Mtetra
.28365 .65807 .29059 .66508 .31124 .66341 .30443 .65637 Mtetra
.30443 .65637 .31124 .66341 .33196 .66173 .32529 .65467 Mtetra
.32529 .65467 .33196 .66173 .35275 .66004 .34622 .65296 Mtetra
.796 .891 .913 r
.34622 .65296 .35275 .66004 .37361 .65835 .36755 .64021 Mtetra
.861 .773 .764 r
.36755 .64021 .37361 .65835 .39527 .62814 .38932 .6107 Mtetra
.828 .765 .793 r
.38932 .6107 .39527 .62814 .41665 .60492 .41078 .58934 Mtetra
.804 .771 .823 r
.41078 .58934 .41665 .60492 .43785 .58743 .43208 .57319 Mtetra
.782 .777 .848 r
.43208 .57319 .43785 .58743 .45895 .57378 .4533 .56054 Mtetra
.761 .78 .869 r
.4533 .56054 .45895 .57378 .48001 .56279 .47448 .55031 Mtetra
.742 .783 .886 r
.47448 .55031 .48001 .56279 .50107 .55371 .49565 .54183 Mtetra
.725 .785 .9 r
.49565 .54183 .50107 .55371 .52213 .54603 .51685 .53463 Mtetra
.71 .787 .912 r
.51685 .53463 .52213 .54603 .54323 .53941 .53808 .52839 Mtetra
.697 .788 .921 r
.53808 .52839 .54323 .53941 .56437 .5336 .55935 .52288 Mtetra
.685 .789 .929 r
.55935 .52288 .56437 .5336 .58555 .52842 .58067 .51795 Mtetra
.675 .79 .935 r
.58067 .51795 .58555 .52842 .60679 .52374 .60205 .51348 Mtetra
.667 .79 .94 r
.60205 .51348 .60679 .52374 .62809 .51945 .62349 .50936 Mtetra
.659 .79 .944 r
.62349 .50936 .62809 .51945 .64945 .51548 .64499 .50554 Mtetra
.653 .791 .948 r
.64499 .50554 .64945 .51548 .67087 .51178 .66656 .50196 Mtetra
.647 .791 .951 r
.66656 .50196 .67087 .51178 .69236 .50829 .68819 .49857 Mtetra
.642 .791 .954 r
.68819 .49857 .69236 .50829 .71391 .50498 .70989 .49535 Mtetra
.638 .792 .956 r
.70989 .49535 .71391 .50498 .73554 .50182 .73167 .49226 Mtetra
.634 .792 .958 r
.73167 .49226 .73554 .50182 .75724 .49879 .75351 .48929 Mtetra
.631 .792 .96 r
.75351 .48929 .75724 .49879 .779 .49586 .77543 .48641 Mtetra
.628 .792 .961 r
.77543 .48641 .779 .49586 .80084 .49303 .79742 .48361 Mtetra
.625 .793 .962 r
.79742 .48361 .80084 .49303 .82276 .49027 .81949 .48089 Mtetra
.623 .793 .964 r
.81949 .48089 .82276 .49027 .84475 .48757 .84163 .47822 Mtetra
.621 .793 .965 r
.84163 .47822 .84475 .48757 .86681 .48494 .86385 .47561 Mtetra
.619 .793 .965 r
.86385 .47561 .86681 .48494 .88895 .48235 .88615 .47304 Mtetra
.617 .793 .966 r
.88615 .47304 .88895 .48235 .91116 .4798 .90852 .4705 Mtetra
.616 .793 .967 r
.90852 .4705 .91116 .4798 .93345 .47729 .93097 .468 Mtetra
.614 .794 .968 r
.93097 .468 .93345 .47729 .95582 .47481 .9535 .46553 Mtetra
.613 .794 .968 r
.9535 .46553 .95582 .47481 .97827 .47236 .97611 .46308 Mtetra
.567 .808 .99 r
.23498 .65438 .24229 .66145 .26294 .65976 .25576 .65267 Mtetra
.25576 .65267 .26294 .65976 .28365 .65807 .27661 .65095 Mtetra
.27661 .65095 .28365 .65807 .30443 .65637 .29753 .64923 Mtetra
.29753 .64923 .30443 .65637 .32529 .65467 .31853 .6475 Mtetra
.31853 .6475 .32529 .65467 .34622 .65296 .33959 .64577 Mtetra
.899 .897 .816 r
.33959 .64577 .34622 .65296 .36755 .64021 .36148 .6199 Mtetra
.84 .752 .766 r
.36148 .6199 .36755 .64021 .38932 .6107 .38331 .59307 Mtetra
.817 .76 .799 r
.38331 .59307 .38932 .6107 .41078 .58934 .40485 .57358 Mtetra
.794 .767 .828 r
.40485 .57358 .41078 .58934 .43208 .57319 .42625 .55878 Mtetra
.772 .772 .853 r
.42625 .55878 .43208 .57319 .4533 .56054 .44757 .54714 Mtetra
.752 .776 .873 r
.44757 .54714 .4533 .56054 .47448 .55031 .46887 .53768 Mtetra
.733 .779 .89 r
.46887 .53768 .47448 .55031 .49565 .54183 .49017 .5298 Mtetra
.717 .782 .903 r
.49017 .5298 .49565 .54183 .51685 .53463 .51149 .52307 Mtetra
.703 .784 .914 r
.51149 .52307 .51685 .53463 .53808 .52839 .53286 .51721 Mtetra
.691 .785 .923 r
.53286 .51721 .53808 .52839 .55935 .52288 .55426 .51202 Mtetra
.68 .786 .93 r
.55426 .51202 .55935 .52288 .58067 .51795 .57572 .50734 Mtetra
.671 .787 .936 r
.57572 .50734 .58067 .51795 .60205 .51348 .59724 .50307 Mtetra
.663 .788 .941 r
.59724 .50307 .60205 .51348 .62349 .50936 .61882 .49913 Mtetra
.656 .789 .945 r
.61882 .49913 .62349 .50936 .64499 .50554 .64047 .49546 Mtetra
.65 .789 .949 r
.64047 .49546 .64499 .50554 .66656 .50196 .66218 .492 Mtetra
.644 .79 .952 r
.66218 .492 .66656 .50196 .68819 .49857 .68396 .48871 Mtetra
.64 .79 .954 r
.68396 .48871 .68819 .49857 .70989 .49535 .70582 .48558 Mtetra
.636 .79 .956 r
.70582 .48558 .70989 .49535 .73167 .49226 .72774 .48256 Mtetra
.632 .791 .958 r
.72774 .48256 .73167 .49226 .75351 .48929 .74974 .47965 Mtetra
.629 .791 .96 r
.74974 .47965 .75351 .48929 .77543 .48641 .77181 .47682 Mtetra
.626 .791 .961 r
.77181 .47682 .77543 .48641 .79742 .48361 .79396 .47407 Mtetra
.624 .792 .963 r
.79396 .47407 .79742 .48361 .81949 .48089 .81618 .47138 Mtetra
.621 .792 .964 r
.81618 .47138 .81949 .48089 .84163 .47822 .83848 .46874 Mtetra
.619 .792 .965 r
.83848 .46874 .84163 .47822 .86385 .47561 .86085 .46614 Mtetra
.618 .792 .966 r
.86085 .46614 .86385 .47561 .88615 .47304 .88331 .46359 Mtetra
.616 .793 .966 r
.88331 .46359 .88615 .47304 .90852 .4705 .90584 .46107 Mtetra
.615 .793 .967 r
.90584 .46107 .90852 .4705 .93097 .468 .92845 .45857 Mtetra
.613 .793 .968 r
.92845 .45857 .93097 .468 .9535 .46553 .95114 .45611 Mtetra
.612 .793 .968 r
.95114 .45611 .9535 .46553 .97611 .46308 .97391 .45366 Mtetra
.567 .808 .99 r
.22757 .64721 .23498 .65438 .25576 .65267 .24848 .64548 Mtetra
.24848 .64548 .25576 .65267 .27661 .65095 .26947 .64374 Mtetra
.26947 .64374 .27661 .65095 .29753 .64923 .29053 .64199 Mtetra
.29053 .64199 .29753 .64923 .31853 .6475 .31167 .64023 Mtetra
.678 .855 .967 r
.31167 .64023 .31853 .6475 .33959 .64577 .33302 .63429 Mtetra
.912 .844 .763 r
.33302 .63429 .33959 .64577 .36148 .6199 .35536 .59938 Mtetra
.828 .746 .773 r
.35536 .59938 .36148 .6199 .38331 .59307 .37722 .57525 Mtetra
.805 .754 .806 r
.37722 .57525 .38331 .59307 .40485 .57358 .39884 .55763 Mtetra
.782 .761 .834 r
.39884 .55763 .40485 .57358 .42625 .55878 .42034 .54419 Mtetra
.761 .767 .858 r
.42034 .54419 .42625 .55878 .44757 .54714 .44177 .53356 Mtetra
.742 .772 .877 r
.44177 .53356 .44757 .54714 .46887 .53768 .46319 .52488 Mtetra
.725 .775 .893 r
.46319 .52488 .46887 .53768 .49017 .5298 .48461 .51761 Mtetra
.71 .778 .905 r
.48461 .51761 .49017 .5298 .51149 .52307 .50607 .51136 Mtetra
.696 .78 .916 r
.50607 .51136 .51149 .52307 .53286 .51721 .52757 .50589 Mtetra
.685 .782 .924 r
.52757 .50589 .53286 .51721 .55426 .51202 .54911 .501 Mtetra
.675 .783 .931 r
.54911 .501 .55426 .51202 .57572 .50734 .57071 .49659 Mtetra
.666 .785 .937 r
.57071 .49659 .57572 .50734 .59724 .50307 .59237 .49253 Mtetra
.659 .786 .942 r
.59237 .49253 .59724 .50307 .61882 .49913 .6141 .48877 Mtetra
.652 .787 .946 r
.6141 .48877 .61882 .49913 .64047 .49546 .63589 .48524 Mtetra
.647 .787 .949 r
.63589 .48524 .64047 .49546 .66218 .492 .65775 .4819 Mtetra
.642 .788 .952 r
.65775 .4819 .66218 .492 .68396 .48871 .67968 .47872 Mtetra
.637 .789 .955 r
.67968 .47872 .68396 .48871 .70582 .48558 .70168 .47567 Mtetra
.633 .789 .957 r
.70168 .47567 .70582 .48558 .72774 .48256 .72376 .47272 Mtetra
.63 .79 .959 r
.72376 .47272 .72774 .48256 .74974 .47965 .74591 .46987 Mtetra
.627 .79 .96 r
.74591 .46987 .74974 .47965 .77181 .47682 .76814 .46709 Mtetra
.625 .79 .962 r
.76814 .46709 .77181 .47682 .79396 .47407 .79044 .46438 Mtetra
.622 .791 .963 r
.79044 .46438 .79396 .47407 .81618 .47138 .81282 .46173 Mtetra
.62 .791 .964 r
.81282 .46173 .81618 .47138 .83848 .46874 .83527 .45911 Mtetra
.618 .791 .965 r
.83527 .45911 .83848 .46874 .86085 .46614 .85781 .45654 Mtetra
.617 .792 .966 r
.85781 .45654 .86085 .46614 .88331 .46359 .88042 .45401 Mtetra
.615 .792 .966 r
.88042 .45401 .88331 .46359 .90584 .46107 .90312 .4515 Mtetra
.614 .792 .967 r
.90312 .4515 .90584 .46107 .92845 .45857 .92589 .44901 Mtetra
.613 .792 .968 r
.92589 .44901 .92845 .45857 .95114 .45611 .94875 .44655 Mtetra
.611 .793 .968 r
.94875 .44655 .95114 .45611 .97391 .45366 .97168 .4441 Mtetra
.567 .808 .99 r
.22005 .63994 .22757 .64721 .24848 .64548 .2411 .63818 Mtetra
.2411 .63818 .24848 .64548 .26947 .64374 .26223 .63641 Mtetra
.26223 .63641 .26947 .64374 .29053 .64199 .28343 .63464 Mtetra
.28343 .63464 .29053 .64199 .31167 .64023 .30471 .63286 Mtetra
.884 .896 .834 r
.30471 .63286 .31167 .64023 .33302 .63429 .32685 .6095 Mtetra
.838 .73 .745 r
.32685 .6095 .33302 .63429 .35536 .59938 .34917 .57866 Mtetra
.815 .739 .781 r
.34917 .57866 .35536 .59938 .37722 .57525 .37108 .55722 Mtetra
.792 .748 .813 r
.37108 .55722 .37722 .57525 .39884 .55763 .39277 .5415 Mtetra
.77 .755 .84 r
.39277 .5415 .39884 .55763 .42034 .54419 .41436 .52943 Mtetra
.75 .762 .862 r
.41436 .52943 .42034 .54419 .44177 .53356 .4359 .51982 Mtetra
.732 .767 .881 r
.4359 .51982 .44177 .53356 .46319 .52488 .45743 .51192 Mtetra
.716 .771 .896 r
.45743 .51192 .46319 .52488 .48461 .51761 .47899 .50526 Mtetra
.702 .774 .908 r
.47899 .50526 .48461 .51761 .50607 .51136 .50057 .49949 Mtetra
.689 .777 .918 r
.50057 .49949 .50607 .51136 .52757 .50589 .5222 .49441 Mtetra
.679 .779 .926 r
.5222 .49441 .52757 .50589 .54911 .501 .54389 .48984 Mtetra
.669 .781 .933 r
.54389 .48984 .54911 .501 .57071 .49659 .56563 .48568 Mtetra
.661 .782 .938 r
.56563 .48568 .57071 .49659 .59237 .49253 .58743 .48184 Mtetra
.655 .783 .943 r
.58743 .48184 .59237 .49253 .6141 .48877 .6093 .47825 Mtetra
.649 .785 .947 r
.6093 .47825 .6141 .48877 .63589 .48524 .63124 .47487 Mtetra
.643 .785 .95 r
.63124 .47487 .63589 .48524 .65775 .4819 .65325 .47166 Mtetra
.639 .786 .953 r
.65325 .47166 .65775 .4819 .67968 .47872 .67533 .46858 Mtetra
.635 .787 .955 r
.67533 .46858 .67968 .47872 .70168 .47567 .69749 .46561 Mtetra
.631 .788 .957 r
.69749 .46561 .70168 .47567 .72376 .47272 .71972 .46274 Mtetra
.628 .788 .959 r
.71972 .46274 .72376 .47272 .74591 .46987 .74203 .45995 Mtetra
.625 .789 .96 r
.74203 .45995 .74591 .46987 .76814 .46709 .76441 .45723 Mtetra
.623 .789 .962 r
.76441 .45723 .76814 .46709 .79044 .46438 .78687 .45456 Mtetra
.621 .79 .963 r
.78687 .45456 .79044 .46438 .81282 .46173 .80941 .45194 Mtetra
.619 .79 .964 r
.80941 .45194 .81282 .46173 .83527 .45911 .83202 .44935 Mtetra
.617 .791 .965 r
.83202 .44935 .83527 .45911 .85781 .45654 .85472 .4468 Mtetra
.616 .791 .966 r
.85472 .4468 .85781 .45654 .88042 .45401 .8775 .44428 Mtetra
.614 .791 .967 r
.8775 .44428 .88042 .45401 .90312 .4515 .90036 .44178 Mtetra
.613 .792 .967 r
.90036 .44178 .90312 .4515 .92589 .44901 .9233 .43931 Mtetra
.612 .792 .968 r
.9233 .43931 .92589 .44901 .94875 .44655 .94632 .43685 Mtetra
.611 .792 .968 r
.94632 .43685 .94875 .44655 .97168 .4441 .96942 .4344 Mtetra
.567 .808 .99 r
.21242 .63256 .22005 .63994 .2411 .63818 .23361 .63078 Mtetra
.23361 .63078 .2411 .63818 .26223 .63641 .25488 .62898 Mtetra
.25488 .62898 .26223 .63641 .28343 .63464 .27622 .62719 Mtetra
.27622 .62719 .28343 .63464 .30471 .63286 .29764 .62538 Mtetra
.943 .881 .743 r
.29764 .62538 .30471 .63286 .32685 .6095 .32062 .58449 Mtetra
.822 .721 .754 r
.32062 .58449 .32685 .6095 .34917 .57866 .34292 .55772 Mtetra
.799 .731 .789 r
.34292 .55772 .34917 .57866 .37108 .55722 .36486 .539 Mtetra
.777 .741 .819 r
.36486 .539 .37108 .55722 .39277 .5415 .38662 .52517 Mtetra
.757 .749 .845 r
.38662 .52517 .39277 .5415 .41436 .52943 .4083 .51448 Mtetra
.738 .756 .867 r
.4083 .51448 .41436 .52943 .4359 .51982 .42995 .5059 Mtetra
.721 .761 .884 r
.42995 .5059 .4359 .51982 .45743 .51192 .45161 .4988 Mtetra
.706 .766 .899 r
.45161 .4988 .45743 .51192 .47899 .50526 .47328 .49274 Mtetra
.693 .77 .91 r
.47328 .49274 .47899 .50526 .50057 .49949 .495 .48747 Mtetra
.682 .773 .92 r
.495 .48747 .50057 .49949 .5222 .49441 .51677 .48277 Mtetra
.672 .775 .927 r
.51677 .48277 .5222 .49441 .54389 .48984 .53859 .47853 Mtetra
.664 .778 .934 r
.53859 .47853 .54389 .48984 .56563 .48568 .56047 .47463 Mtetra
.657 .78 .939 r
.56047 .47463 .56563 .48568 .58743 .48184 .58242 .471 Mtetra
.65 .781 .944 r
.58242 .471 .58743 .48184 .6093 .47825 .60444 .46759 Mtetra
.645 .782 .947 r
.60444 .46759 .6093 .47825 .63124 .47487 .62653 .46436 Mtetra
.64 .784 .95 r
.62653 .46436 .63124 .47487 .65325 .47166 .64869 .46127 Mtetra
.636 .785 .953 r
.64869 .46127 .65325 .47166 .67533 .46858 .67093 .4583 Mtetra
.632 .786 .955 r
.67093 .4583 .67533 .46858 .69749 .46561 .69324 .45542 Mtetra
.629 .786 .957 r
.69324 .45542 .69749 .46561 .71972 .46274 .71562 .45262 Mtetra
.626 .787 .959 r
.71562 .45262 .71972 .46274 .74203 .45995 .73808 .44989 Mtetra
.624 .788 .961 r
.73808 .44989 .74203 .45995 .76441 .45723 .76063 .44722 Mtetra
.621 .788 .962 r
.76063 .44722 .76441 .45723 .78687 .45456 .78325 .44459 Mtetra
.619 .789 .963 r
.78325 .44459 .78687 .45456 .80941 .45194 .80595 .442 Mtetra
.617 .789 .964 r
.80595 .442 .80941 .45194 .83202 .44935 .82873 .43945 Mtetra
.616 .79 .965 r
.82873 .43945 .83202 .44935 .85472 .4468 .85159 .43692 Mtetra
.614 .79 .966 r
.85159 .43692 .85472 .4468 .8775 .44428 .87453 .43441 Mtetra
.613 .791 .967 r
.87453 .43441 .8775 .44428 .90036 .44178 .89756 .43193 Mtetra
.612 .791 .967 r
.89756 .43193 .90036 .44178 .9233 .43931 .92066 .42946 Mtetra
.611 .791 .968 r
.92066 .42946 .9233 .43931 .94632 .43685 .94385 .427 Mtetra
.61 .792 .968 r
.94385 .427 .94632 .43685 .96942 .4344 .96713 .42456 Mtetra
.567 .808 .99 r
.20467 .62508 .21242 .63256 .23361 .63078 .22601 .62326 Mtetra
.22601 .62326 .23361 .63078 .25488 .62898 .24742 .62145 Mtetra
.24742 .62145 .25488 .62898 .27622 .62719 .26891 .61962 Mtetra
.894 .893 .82 r
.26891 .61962 .27622 .62719 .29764 .62538 .2915 .59382 Mtetra
.827 .701 .726 r
.2915 .59382 .29764 .62538 .32062 .58449 .31434 .55926 Mtetra
.804 .711 .762 r
.31434 .55926 .32062 .58449 .34292 .55772 .3366 .53657 Mtetra
.782 .722 .796 r
.3366 .53657 .34292 .55772 .36486 .539 .35857 .52057 Mtetra
.762 .733 .826 r
.35857 .52057 .36486 .539 .38662 .52517 .3804 .50865 Mtetra
.743 .742 .851 r
.3804 .50865 .38662 .52517 .4083 .51448 .40217 .49935 Mtetra
.726 .749 .871 r
.40217 .49935 .4083 .51448 .42995 .5059 .42393 .49181 Mtetra
.71 .756 .888 r
.42393 .49181 .42995 .5059 .45161 .4988 .4457 .4855 Mtetra
.697 .761 .901 r
.4457 .4855 .45161 .4988 .47328 .49274 .4675 .48006 Mtetra
.685 .765 .913 r
.4675 .48006 .47328 .49274 .495 .48747 .48935 .47528 Mtetra
.675 .769 .922 r
.48935 .47528 .495 .48747 .51677 .48277 .51126 .47098 Mtetra
.666 .772 .929 r
.51126 .47098 .51677 .48277 .53859 .47853 .53322 .46705 Mtetra
.658 .775 .935 r
.53322 .46705 .53859 .47853 .56047 .47463 .55525 .46342 Mtetra
.652 .777 .94 r
.55525 .46342 .56047 .47463 .58242 .471 .57735 .46001 Mtetra
.646 .779 .944 r
.57735 .46001 .58242 .471 .60444 .46759 .59951 .45678 Mtetra
.641 .78 .948 r
.59951 .45678 .60444 .46759 .62653 .46436 .62175 .4537 Mtetra
.637 .782 .951 r
.62175 .4537 .62653 .46436 .64869 .46127 .64407 .45073 Mtetra
.633 .783 .953 r
.64407 .45073 .64869 .46127 .67093 .4583 .66645 .44787 Mtetra
.63 .784 .956 r
.66645 .44787 .67093 .4583 .69324 .45542 .68892 .44508 Mtetra
.627 .785 .958 r
.68892 .44508 .69324 .45542 .71562 .45262 .71146 .44235 Mtetra
.624 .786 .959 r
.71146 .44235 .71562 .45262 .73808 .44989 .73409 .43969 Mtetra
.622 .787 .961 r
.73409 .43969 .73808 .44989 .76063 .44722 .75679 .43706 Mtetra
.62 .787 .962 r
.75679 .43706 .76063 .44722 .78325 .44459 .77957 .43448 Mtetra
.618 .788 .963 r
.77957 .43448 .78325 .44459 .80595 .442 .80244 .43192 Mtetra
.616 .789 .964 r
.80244 .43192 .80595 .442 .82873 .43945 .82538 .42939 Mtetra
.615 .789 .965 r
.82538 .42939 .82873 .43945 .85159 .43692 .84841 .42689 Mtetra
.613 .79 .966 r
.84841 .42689 .85159 .43692 .87453 .43441 .87152 .4244 Mtetra
.612 .79 .967 r
.87152 .4244 .87453 .43441 .89756 .43193 .89471 .42193 Mtetra
.611 .79 .967 r
.89471 .42193 .89756 .43193 .92066 .42946 .91799 .41946 Mtetra
.61 .791 .968 r
.91799 .41946 .92066 .42946 .94385 .427 .94135 .41701 Mtetra
.609 .791 .969 r
.94135 .41701 .94385 .427 .96713 .42456 .9648 .41457 Mtetra
.567 .808 .99 r
.19682 .61748 .20467 .62508 .22601 .62326 .2183 .61564 Mtetra
.2183 .61564 .22601 .62326 .24742 .62145 .23985 .61379 Mtetra
.664 .849 .971 r
.23985 .61379 .24742 .62145 .26891 .61962 .26166 .60834 Mtetra
.936 .844 .727 r
.26166 .60834 .26891 .61962 .2915 .59382 .28532 .56187 Mtetra
.804 .687 .735 r
.28532 .56187 .2915 .59382 .31434 .55926 .308 .53381 Mtetra
.784 .699 .771 r
.308 .53381 .31434 .55926 .3366 .53657 .33022 .5152 Mtetra
.764 .712 .804 r
.33022 .5152 .3366 .53657 .35857 .52057 .35221 .50193 Mtetra
.745 .724 .832 r
.35221 .50193 .35857 .52057 .3804 .50865 .37411 .49193 Mtetra
.728 .734 .856 r
.37411 .49193 .3804 .50865 .40217 .49935 .39597 .48403 Mtetra
.712 .742 .875 r
.39597 .48403 .40217 .49935 .42393 .49181 .41783 .47753 Mtetra
.699 .75 .891 r
.41783 .47753 .42393 .49181 .4457 .4855 .43972 .47202 Mtetra
.687 .756 .904 r
.43972 .47202 .4457 .4855 .4675 .48006 .46165 .46721 Mtetra
.676 .761 .915 r
.46165 .46721 .4675 .48006 .48935 .47528 .48363 .46292 Mtetra
.667 .765 .923 r
.48363 .46292 .48935 .47528 .51126 .47098 .50567 .45902 Mtetra
.659 .769 .93 r
.50567 .45902 .51126 .47098 .53322 .46705 .52778 .45542 Mtetra
.653 .772 .936 r
.52778 .45542 .53322 .46705 .55525 .46342 .54995 .45205 Mtetra
.647 .774 .941 r
.54995 .45205 .55525 .46342 .57735 .46001 .5722 .44886 Mtetra
.642 .776 .945 r
.5722 .44886 .57735 .46001 .59951 .45678 .59451 .44581 Mtetra
.637 .778 .948 r
.59451 .44581 .59951 .45678 .62175 .4537 .6169 .44288 Mtetra
.633 .78 .951 r
.6169 .44288 .62175 .4537 .64407 .45073 .63937 .44005 Mtetra
.63 .781 .954 r
.63937 .44005 .64407 .45073 .66645 .44787 .66192 .43728 Mtetra
.627 .783 .956 r
.66192 .43728 .66645 .44787 .68892 .44508 .68454 .43458 Mtetra
.624 .784 .958 r
.68454 .43458 .68892 .44508 .71146 .44235 .70725 .43194 Mtetra
.622 .785 .96 r
.70725 .43194 .71146 .44235 .73409 .43969 .73003 .42933 Mtetra
.62 .786 .961 r
.73003 .42933 .73409 .43969 .75679 .43706 .7529 .42676 Mtetra
.618 .786 .962 r
.7529 .42676 .75679 .43706 .77957 .43448 .77584 .42421 Mtetra
.616 .787 .963 r
.77584 .42421 .77957 .43448 .80244 .43192 .79887 .42169 Mtetra
.615 .788 .964 r
.79887 .42169 .80244 .43192 .82538 .42939 .82199 .41919 Mtetra
.613 .788 .965 r
.82199 .41919 .82538 .42939 .84841 .42689 .84518 .41671 Mtetra
.612 .789 .966 r
.84518 .41671 .84841 .42689 .87152 .4244 .86846 .41423 Mtetra
.611 .789 .967 r
.86846 .41423 .87152 .4244 .89471 .42193 .89183 .41177 Mtetra
.61 .79 .967 r
.89183 .41177 .89471 .42193 .91799 .41946 .91528 .40932 Mtetra
.609 .79 .968 r
.91528 .40932 .91799 .41946 .94135 .41701 .93881 .40687 Mtetra
.608 .791 .969 r
.93881 .40687 .94135 .41701 .9648 .41457 .96244 .40443 Mtetra
.567 .808 .99 r
.18884 .60977 .19682 .61748 .2183 .61564 .21047 .6079 Mtetra
.21047 .6079 .2183 .61564 .23985 .61379 .23217 .60603 Mtetra
.939 .876 .747 r
.23217 .60603 .23985 .61379 .26166 .60834 .25587 .56497 Mtetra
.798 .657 .707 r
.25587 .56497 .26166 .60834 .28532 .56187 .2791 .5297 Mtetra
.778 .671 .744 r
.2791 .5297 .28532 .56187 .308 .53381 .3016 .50812 Mtetra
.76 .685 .78 r
.3016 .50812 .308 .53381 .33022 .5152 .32377 .4936 Mtetra
.742 .7 .811 r
.32377 .4936 .33022 .5152 .35221 .50193 .34578 .48309 Mtetra
.726 .713 .838 r
.34578 .48309 .35221 .50193 .37411 .49193 .36774 .47501 Mtetra
.711 .725 .861 r
.36774 .47501 .37411 .49193 .39597 .48403 .38968 .46851 Mtetra
.698 .735 .879 r
.38968 .46851 .39597 .48403 .41783 .47753 .41165 .46307 Mtetra
.687 .743 .895 r
.41165 .46307 .41783 .47753 .43972 .47202 .43366 .45837 Mtetra
.676 .75 .907 r
.43366 .45837 .43972 .47202 .46165 .46721 .45571 .45419 Mtetra
.667 .756 .917 r
.45571 .45419 .46165 .46721 .48363 .46292 .47783 .4504 Mtetra
.66 .761 .925 r
.47783 .4504 .48363 .46292 .50567 .45902 .50001 .4469 Mtetra
.653 .765 .932 r
.50001 .4469 .50567 .45902 .52778 .45542 .52226 .44363 Mtetra
.647 .769 .937 r
.52226 .44363 .52778 .45542 .54995 .45205 .54458 .44052 Mtetra
.642 .771 .942 r
.54458 .44052 .54995 .45205 .5722 .44886 .56697 .43755 Mtetra
.637 .774 .946 r
.56697 .43755 .5722 .44886 .59451 .44581 .58944 .43469 Mtetra
.633 .776 .949 r
.58944 .43469 .59451 .44581 .6169 .44288 .61199 .43191 Mtetra
.63 .778 .952 r
.61199 .43191 .6169 .44288 .63937 .44005 .63461 .4292 Mtetra
.627 .78 .954 r
.63461 .4292 .63937 .44005 .66192 .43728 .65732 .42655 Mtetra
.624 .781 .956 r
.65732 .42655 .66192 .43728 .68454 .43458 .6801 .42394 Mtetra
.622 .782 .958 r
.6801 .42394 .68454 .43458 .70725 .43194 .70297 .42136 Mtetra
.62 .783 .96 r
.70297 .42136 .70725 .43194 .73003 .42933 .72591 .41882 Mtetra
.618 .784 .961 r
.72591 .41882 .73003 .42933 .7529 .42676 .74894 .4163 Mtetra
.616 .785 .962 r
.74894 .4163 .7529 .42676 .77584 .42421 .77206 .4138 Mtetra
.615 .786 .964 r
.77206 .4138 .77584 .42421 .79887 .42169 .79526 .41131 Mtetra
.613 .787 .965 r
.79526 .41131 .79887 .42169 .82199 .41919 .81854 .40884 Mtetra
.612 .788 .965 r
.81854 .40884 .82199 .41919 .84518 .41671 .84191 .40637 Mtetra
.611 .788 .966 r
.84191 .40637 .84518 .41671 .86846 .41423 .86536 .40392 Mtetra
.61 .789 .967 r
.86536 .40392 .86846 .41423 .89183 .41177 .8889 .40147 Mtetra
.609 .789 .968 r
.8889 .40147 .89183 .41177 .91528 .40932 .91252 .39902 Mtetra
.608 .79 .968 r
.91252 .39902 .91528 .40932 .93881 .40687 .93624 .39657 Mtetra
.608 .79 .969 r
.93624 .39657 .93881 .40687 .96244 .40443 .96004 .39413 Mtetra
.567 .808 .99 r
.18075 .60195 .18884 .60977 .21047 .6079 .20252 .60005 Mtetra
.922 .881 .777 r
.20252 .60005 .21047 .6079 .23217 .60603 .22612 .56571 Mtetra
.829 .684 .703 r
.22612 .56571 .23217 .60603 .25587 .56497 .25006 .52147 Mtetra
.763 .633 .717 r
.25006 .52147 .25587 .56497 .2791 .5297 .27284 .49731 Mtetra
.747 .651 .754 r
.27284 .49731 .2791 .5297 .3016 .50812 .29515 .4822 Mtetra
.732 .669 .788 r
.29515 .4822 .3016 .50812 .32377 .4936 .31725 .47178 Mtetra
.719 .686 .818 r
.31725 .47178 .32377 .4936 .34578 .48309 .33928 .46402 Mtetra
.706 .702 .844 r
.33928 .46402 .34578 .48309 .36774 .47501 .36129 .45789 Mtetra
.694 .716 .866 r
.36129 .45789 .36774 .47501 .38968 .46851 .38332 .4528 Mtetra
.683 .727 .883 r
.38332 .4528 .38968 .46851 .41165 .46307 .40539 .44842 Mtetra
.674 .737 .898 r
.40539 .44842 .41165 .46307 .43366 .45837 .42752 .44453 Mtetra
.665 .745 .909 r
.42752 .44453 .43366 .45837 .45571 .45419 .4497 .44099 Mtetra
.658 .751 .919 r
.4497 .44099 .45571 .45419 .47783 .4504 .47195 .43771 Mtetra
.652 .757 .927 r
.47195 .43771 .47783 .4504 .50001 .4469 .49427 .43461 Mtetra
.646 .761 .933 r
.49427 .43461 .50001 .4469 .52226 .44363 .51666 .43167 Mtetra
.641 .765 .938 r
.51666 .43167 .52226 .44363 .54458 .44052 .53913 .42883 Mtetra
.637 .769 .943 r
.53913 .42883 .54458 .44052 .56697 .43755 .56167 .42609 Mtetra
.633 .771 .947 r
.56167 .42609 .56697 .43755 .58944 .43469 .5843 .42341 Mtetra
.63 .774 .95 r
.5843 .42341 .58944 .43469 .61199 .43191 .607 .42078 Mtetra
.627 .776 .952 r
.607 .42078 .61199 .43191 .63461 .4292 .62978 .4182 Mtetra
.624 .778 .955 r
.62978 .4182 .63461 .4292 .65732 .42655 .65265 .41565 Mtetra
.622 .78 .957 r
.65265 .41565 .65732 .42655 .6801 .42394 .67559 .41313 Mtetra
.62 .781 .959 r
.67559 .41313 .6801 .42394 .70297 .42136 .69862 .41063 Mtetra
.618 .782 .96 r
.69862 .41063 .70297 .42136 .72591 .41882 .72174 .40815 Mtetra
.616 .783 .961 r
.72174 .40815 .72591 .41882 .74894 .4163 .74493 .40568 Mtetra
.615 .784 .963 r
.74493 .40568 .74894 .4163 .77206 .4138 .76822 .40322 Mtetra
.613 .785 .964 r
.76822 .40322 .77206 .4138 .79526 .41131 .79159 .40077 Mtetra
.612 .786 .965 r
.79159 .40077 .79526 .41131 .81854 .40884 .81504 .39833 Mtetra
.611 .787 .966 r
.81504 .39833 .81854 .40884 .84191 .40637 .83858 .39588 Mtetra
.61 .788 .966 r
.83858 .39588 .84191 .40637 .86536 .40392 .86221 .39344 Mtetra
.609 .788 .967 r
.86221 .39344 .86536 .40392 .8889 .40147 .88592 .391 Mtetra
.608 .789 .968 r
.88592 .391 .8889 .40147 .91252 .39902 .90973 .38856 Mtetra
.90973 .38856 .91252 .39902 .93624 .39657 .93362 .38612 Mtetra
.607 .79 .969 r
.93362 .38612 .93624 .39657 .96004 .39413 .9576 .38368 Mtetra
.94 .87 .742 r
.17253 .594 .18075 .60195 .20252 .60005 .19689 .55068 Mtetra
.82 .665 .69 r
.19689 .55068 .20252 .60005 .22612 .56571 .22139 .50084 Mtetra
.73 .581 .688 r
.22139 .50084 .22612 .56571 .25006 .52147 .24423 .47783 Mtetra
.719 .602 .725 r
.24423 .47783 .25006 .52147 .27284 .49731 .26653 .46469 Mtetra
.71 .626 .762 r
.26653 .46469 .27284 .49731 .29515 .4822 .28863 .45605 Mtetra
.701 .649 .795 r
.28863 .45605 .29515 .4822 .31725 .47178 .31067 .44973 Mtetra
.692 .671 .825 r
.31067 .44973 .31725 .47178 .33928 .46402 .3327 .44474 Mtetra
.683 .69 .85 r
.3327 .44474 .33928 .46402 .36129 .45789 .35477 .44056 Mtetra
.675 .705 .87 r
.35477 .44056 .36129 .45789 .38332 .4528 .37688 .4369 Mtetra
.668 .719 .887 r
.37688 .4369 .38332 .4528 .40539 .44842 .39905 .43358 Mtetra
.661 .73 .9 r
.39905 .43358 .40539 .44842 .42752 .44453 .42129 .43051 Mtetra
.654 .739 .912 r
.42129 .43051 .42752 .44453 .4497 .44099 .4436 .42761 Mtetra
.649 .746 .921 r
.4436 .42761 .4497 .44099 .47195 .43771 .46598 .42483 Mtetra
.644 .752 .928 r
.46598 .42483 .47195 .43771 .49427 .43461 .48844 .42215 Mtetra
.639 .758 .934 r
.48844 .42215 .49427 .43461 .51666 .43167 .51098 .41954 Mtetra
.635 .762 .939 r
.51098 .41954 .51666 .43167 .53913 .42883 .5336 .41697 Mtetra
.632 .766 .944 r
.5336 .41697 .53913 .42883 .56167 .42609 .5563 .41445 Mtetra
.629 .769 .947 r
.5563 .41445 .56167 .42609 .5843 .42341 .57908 .41196 Mtetra
.626 .772 .95 r
.57908 .41196 .5843 .42341 .607 .42078 .60194 .40949 Mtetra
.623 .774 .953 r
.60194 .40949 .607 .42078 .62978 .4182 .62488 .40704 Mtetra
.621 .776 .955 r
.62488 .40704 .62978 .4182 .65265 .41565 .64791 .4046 Mtetra
.619 .778 .957 r
.64791 .4046 .65265 .41565 .67559 .41313 .67102 .40217 Mtetra
.617 .78 .959 r
.67102 .40217 .67559 .41313 .69862 .41063 .69421 .39974 Mtetra
.616 .781 .96 r
.69421 .39974 .69862 .41063 .72174 .40815 .7175 .39732 Mtetra
.614 .782 .962 r
.7175 .39732 .72174 .40815 .74493 .40568 .74086 .39491 Mtetra
.613 .783 .963 r
.74086 .39491 .74493 .40568 .76822 .40322 .76432 .39249 Mtetra
.612 .784 .964 r
.76432 .39249 .76822 .40322 .79159 .40077 .78786 .39007 Mtetra
.611 .785 .965 r
.78786 .39007 .79159 .40077 .81504 .39833 .81149 .38765 Mtetra
.61 .786 .966 r
.81149 .38765 .81504 .39833 .83858 .39588 .8352 .38523 Mtetra
.609 .787 .966 r
.8352 .38523 .83858 .39588 .86221 .39344 .85901 .38281 Mtetra
.608 .787 .967 r
.85901 .38281 .86221 .39344 .88592 .391 .8829 .38038 Mtetra
.607 .788 .968 r
.8829 .38038 .88592 .391 .90973 .38856 .90689 .37794 Mtetra
.607 .789 .968 r
.90689 .37794 .90973 .38856 .93362 .38612 .93096 .3755 Mtetra
.606 .789 .969 r
.93096 .3755 .93362 .38612 .9576 .38368 .95513 .37306 Mtetra
.651 .483 .643 r
.17347 .44057 .17253 .594 .19689 .55068 .19503 .4384 Mtetra
.654 .495 .656 r
.19503 .4384 .19689 .55068 .22139 .50084 .21667 .43623 Mtetra
.659 .527 .693 r
.21667 .43623 .22139 .50084 .24423 .47783 .23839 .43404 Mtetra
.663 .562 .731 r
.23839 .43404 .24423 .47783 .26653 .46469 .26018 .43185 Mtetra
.664 .596 .768 r
.26018 .43185 .26653 .46469 .28863 .45605 .28206 .42966 Mtetra
.664 .626 .802 r
.28206 .42966 .28863 .45605 .31067 .44973 .30401 .42745 Mtetra
.662 .653 .83 r
.30401 .42745 .31067 .44973 .3327 .44474 .32605 .42524 Mtetra
.659 .675 .854 r
.32605 .42524 .3327 .44474 .35477 .44056 .34816 .42301 Mtetra
.655 .694 .874 r
.34816 .42301 .35477 .44056 .37688 .4369 .37035 .42078 Mtetra
.651 .709 .89 r
.37035 .42078 .37688 .4369 .39905 .43358 .39263 .41855 Mtetra
.647 .722 .903 r
.39263 .41855 .39905 .43358 .42129 .43051 .41498 .4163 Mtetra
.643 .732 .914 r
.41498 .4163 .42129 .43051 .4436 .42761 .43742 .41404 Mtetra
.639 .741 .922 r
.43742 .41404 .4436 .42761 .46598 .42483 .45994 .41178 Mtetra
.635 .748 .929 r
.45994 .41178 .46598 .42483 .48844 .42215 .48254 .40951 Mtetra
.632 .754 .935 r
.48254 .40951 .48844 .42215 .51098 .41954 .50522 .40723 Mtetra
.629 .759 .94 r
.50522 .40723 .51098 .41954 .5336 .41697 .52799 .40494 Mtetra
.626 .763 .944 r
.52799 .40494 .5336 .41697 .5563 .41445 .55084 .40265 Mtetra
.624 .766 .948 r
.55084 .40265 .5563 .41445 .57908 .41196 .57378 .40034 Mtetra
.622 .769 .951 r
.57378 .40034 .57908 .41196 .60194 .40949 .5968 .39803 Mtetra
.62 .772 .953 r
.5968 .39803 .60194 .40949 .62488 .40704 .61991 .39571 Mtetra
.618 .774 .956 r
.61991 .39571 .62488 .40704 .64791 .4046 .6431 .39338 Mtetra
.616 .776 .957 r
.6431 .39338 .64791 .4046 .67102 .40217 .66638 .39104 Mtetra
.615 .778 .959 r
.66638 .39104 .67102 .40217 .69421 .39974 .68974 .38869 Mtetra
.614 .78 .961 r
.68974 .38869 .69421 .39974 .7175 .39732 .71319 .38633 Mtetra
.612 .781 .962 r
.71319 .38633 .7175 .39732 .74086 .39491 .73673 .38397 Mtetra
.611 .782 .963 r
.73673 .38397 .74086 .39491 .76432 .39249 .76036 .38159 Mtetra
.61 .783 .964 r
.76036 .38159 .76432 .39249 .78786 .39007 .78408 .37921 Mtetra
.609 .784 .965 r
.78408 .37921 .78786 .39007 .81149 .38765 .80788 .37682 Mtetra
.609 .785 .966 r
.80788 .37682 .81149 .38765 .8352 .38523 .83178 .37442 Mtetra
.608 .786 .966 r
.83178 .37442 .8352 .38523 .85901 .38281 .85576 .37201 Mtetra
.607 .787 .967 r
.85576 .37201 .85901 .38281 .8829 .38038 .87984 .36959 Mtetra
.607 .787 .968 r
.87984 .36959 .8829 .38038 .90689 .37794 .904 .36716 Mtetra
.606 .788 .968 r
.904 .36716 .90689 .37794 .93096 .3755 .92826 .36472 Mtetra
.605 .789 .969 r
.92826 .36472 .93096 .3755 .95513 .37306 .95261 .36227 Mtetra
.571 .417 .634 r
.17437 .29213 .17347 .44057 .19503 .4384 .19321 .32831 Mtetra
.515 .384 .641 r
.19321 .32831 .19503 .4384 .21667 .43623 .21197 .37185 Mtetra
.56 .452 .688 r
.21197 .37185 .21667 .43623 .23839 .43404 .23252 .39012 Mtetra
.59 .51 .732 r
.23252 .39012 .23839 .43404 .26018 .43185 .25379 .39879 Mtetra
.609 .558 .772 r
.25379 .39879 .26018 .43185 .28206 .42966 .27543 .40302 Mtetra
.621 .599 .806 r
.27543 .40302 .28206 .42966 .30401 .42745 .29729 .40493 Mtetra
.629 .632 .835 r
.29729 .40493 .30401 .42745 .32605 .42524 .31931 .4055 Mtetra
.632 .66 .859 r
.31931 .4055 .32605 .42524 .34816 .42301 .34147 .40525 Mtetra
.634 .682 .878 r
.34147 .40525 .34816 .42301 .37035 .42078 .36374 .40446 Mtetra
.633 .699 .893 r
.36374 .40446 .37035 .42078 .39263 .41855 .38612 .40331 Mtetra
.632 .714 .906 r
.38612 .40331 .39263 .41855 .41498 .4163 .40859 .40189 Mtetra
.631 .726 .916 r
.40859 .40189 .41498 .4163 .43742 .41404 .43115 .40029 Mtetra
.629 .735 .924 r
.43115 .40029 .43742 .41404 .45994 .41178 .45381 .39855 Mtetra
.627 .743 .931 r
.45381 .39855 .45994 .41178 .48254 .40951 .47655 .39669 Mtetra
.625 .75 .936 r
.47655 .39669 .48254 .40951 .50522 .40723 .49938 .39475 Mtetra
.623 .755 .941 r
.49938 .39475 .50522 .40723 .52799 .40494 .5223 .39274 Mtetra
.621 .76 .945 r
.5223 .39274 .52799 .40494 .55084 .40265 .54531 .39067 Mtetra
.619 .764 .948 r
.54531 .39067 .55084 .40265 .57378 .40034 .5684 .38855 Mtetra
.618 .767 .951 r
.5684 .38855 .57378 .40034 .5968 .39803 .59159 .3864 Mtetra
.616 .77 .954 r
.59159 .3864 .5968 .39803 .61991 .39571 .61486 .38421 Mtetra
.615 .773 .956 r
.61486 .38421 .61991 .39571 .6431 .39338 .63822 .38199 Mtetra
.614 .775 .958 r
.63822 .38199 .6431 .39338 .66638 .39104 .66166 .37974 Mtetra
.613 .777 .959 r
.66166 .37974 .66638 .39104 .68974 .38869 .6852 .37747 Mtetra
.612 .778 .961 r
.6852 .37747 .68974 .38869 .71319 .38633 .70882 .37517 Mtetra
.611 .78 .962 r
.70882 .37517 .71319 .38633 .73673 .38397 .73254 .37286 Mtetra
.61 .781 .963 r
.73254 .37286 .73673 .38397 .76036 .38159 .75634 .37053 Mtetra
.609 .782 .964 r
.75634 .37053 .76036 .38159 .78408 .37921 .78023 .36818 Mtetra
.608 .784 .965 r
.78023 .36818 .78408 .37921 .80788 .37682 .80422 .36582 Mtetra
.607 .785 .966 r
.80422 .36582 .80788 .37682 .83178 .37442 .82829 .36343 Mtetra
.607 .785 .967 r
.82829 .36343 .83178 .37442 .85576 .37201 .85246 .36104 Mtetra
.606 .786 .967 r
.85246 .36104 .85576 .37201 .87984 .36959 .87672 .35863 Mtetra
.606 .787 .968 r
.87672 .35863 .87984 .36959 .904 .36716 .90108 .35621 Mtetra
.605 .787 .968 r
.90108 .35621 .904 .36716 .92826 .36472 .92552 .35377 Mtetra
.605 .788 .969 r
.92552 .35377 .92826 .36472 .95261 .36227 .95006 .35132 Mtetra
.617 .786 .963 r
.16632 .28211 .17437 .29213 .19321 .32831 .18767 .27968 Mtetra
.432 .381 .7 r
.18767 .27968 .19321 .32831 .21197 .37185 .20729 .30773 Mtetra
.425 .348 .667 r
.20729 .30773 .21197 .37185 .23252 .39012 .22664 .34606 Mtetra
.497 .442 .725 r
.22664 .34606 .23252 .39012 .25379 .39879 .24735 .36549 Mtetra
.543 .512 .771 r
.24735 .36549 .25379 .39879 .27543 .40302 .26873 .37614 Mtetra
.572 .566 .808 r
.26873 .37614 .27543 .40302 .29729 .40493 .29049 .38217 Mtetra
.591 .609 .838 r
.29049 .38217 .29729 .40493 .31931 .4055 .3125 .38554 Mtetra
.603 .642 .862 r
.3125 .38554 .31931 .4055 .34147 .40525 .3347 .38727 Mtetra
.611 .668 .881 r
.3347 .38727 .34147 .40525 .36374 .40446 .35705 .38793 Mtetra
.615 .689 .896 r
.35705 .38793 .36374 .40446 .38612 .40331 .37952 .38787 Mtetra
.617 .705 .908 r
.37952 .38787 .38612 .40331 .40859 .40189 .40211 .38729 Mtetra
.618 .719 .918 r
.40211 .38729 .40859 .40189 .43115 .40029 .4248 .38635 Mtetra
.619 .729 .926 r
.4248 .38635 .43115 .40029 .45381 .39855 .44759 .38512 Mtetra
.618 .738 .932 r
.44759 .38512 .45381 .39855 .47655 .39669 .47047 .38369 Mtetra
.618 .746 .938 r
.47047 .38369 .47655 .39669 .49938 .39475 .49346 .38208 Mtetra
.617 .752 .942 r
.49346 .38208 .49938 .39475 .5223 .39274 .51653 .38035 Mtetra
.616 .757 .946 r
.51653 .38035 .5223 .39274 .54531 .39067 .53969 .37851 Mtetra
.615 .761 .949 r
.53969 .37851 .54531 .39067 .5684 .38855 .56295 .37659 Mtetra
.614 .765 .952 r
.56295 .37659 .5684 .38855 .59159 .3864 .5863 .37459 Mtetra
.613 .768 .954 r
.5863 .37459 .59159 .3864 .61486 .38421 .60973 .37254 Mtetra
.612 .771 .956 r
.60973 .37254 .61486 .38421 .63822 .38199 .63326 .37042 Mtetra
.611 .773 .958 r
.63326 .37042 .63822 .38199 .66166 .37974 .65688 .36827 Mtetra
.61 .775 .96 r
.65688 .36827 .66166 .37974 .6852 .37747 .68058 .36607 Mtetra
.609 .777 .961 r
.68058 .36607 .6852 .37747 .70882 .37517 .70438 .36384 Mtetra
.609 .779 .962 r
.70438 .36384 .70882 .37517 .73254 .37286 .72827 .36158 Mtetra
.608 .78 .963 r
.72827 .36158 .73254 .37286 .75634 .37053 .75226 .35929 Mtetra
.607 .782 .964 r
.75226 .35929 .75634 .37053 .78023 .36818 .77633 .35698 Mtetra
.607 .783 .965 r
.77633 .35698 .78023 .36818 .80422 .36582 .8005 .35464 Mtetra
.606 .784 .966 r
.8005 .35464 .80422 .36582 .82829 .36343 .82476 .35228 Mtetra
.606 .785 .967 r
.82476 .35228 .82829 .36343 .85246 .36104 .84911 .3499 Mtetra
.605 .785 .967 r
.84911 .3499 .85246 .36104 .87672 .35863 .87356 .3475 Mtetra
.605 .786 .968 r
.87356 .3475 .87672 .35863 .90108 .35621 .8981 .34508 Mtetra
.604 .787 .968 r
.8981 .34508 .90108 .35621 .92552 .35377 .92274 .34265 Mtetra
.604 .788 .969 r
.92274 .34265 .92552 .35377 .95006 .35132 .94747 .34019 Mtetra
.617 .786 .963 r
.15814 .27193 .16632 .28211 .18767 .27968 .17964 .26947 Mtetra
.17964 .26947 .18767 .27968 .20729 .30773 .20122 .26699 Mtetra
.277 .288 .691 r
.20122 .26699 .20729 .30773 .22664 .34606 .22074 .30185 Mtetra
.38 .355 .706 r
.22074 .30185 .22664 .34606 .24735 .36549 .24087 .33195 Mtetra
.463 .456 .765 r
.24087 .33195 .24735 .36549 .26873 .37614 .26197 .34901 Mtetra
.515 .528 .807 r
.26197 .34901 .26873 .37614 .29049 .38217 .28362 .35917 Mtetra
.549 .582 .839 r
.28362 .35917 .29049 .38217 .3125 .38554 .30561 .36534 Mtetra
.571 .622 .864 r
.30561 .36534 .3125 .38554 .3347 .38727 .32785 .36906 Mtetra
.586 .653 .883 r
.32785 .36906 .3347 .38727 .35705 .38793 .35027 .37119 Mtetra
.595 .677 .898 r
.35027 .37119 .35705 .38793 .37952 .38787 .37283 .37222 Mtetra
.601 .696 .91 r
.37283 .37222 .37952 .38787 .40211 .38729 .39553 .37249 Mtetra
.605 .711 .919 r
.39553 .37249 .40211 .38729 .4248 .38635 .41835 .37221 Mtetra
.608 .723 .927 r
.41835 .37221 .4248 .38635 .44759 .38512 .44128 .37151 Mtetra
.609 .733 .933 r
.44128 .37151 .44759 .38512 .47047 .38369 .46431 .37049 Mtetra
.61 .741 .938 r
.46431 .37049 .47047 .38369 .49346 .38208 .48744 .36924 Mtetra
.61 .748 .943 r
.48744 .36924 .49346 .38208 .51653 .38035 .51067 .36779 Mtetra
.61 .754 .947 r
.51067 .36779 .51653 .38035 .53969 .37851 .53399 .36618 Mtetra
.61 .759 .95 r
.53399 .36618 .53969 .37851 .56295 .37659 .55741 .36445 Mtetra
.61 .763 .952 r
.55741 .36445 .56295 .37659 .5863 .37459 .58092 .36261 Mtetra
.609 .766 .955 r
.58092 .36261 .5863 .37459 .60973 .37254 .60453 .36069 Mtetra
.609 .769 .957 r
.60453 .36069 .60973 .37254 .63326 .37042 .62823 .35869 Mtetra
.608 .772 .958 r
.62823 .35869 .63326 .37042 .65688 .36827 .65202 .35662 Mtetra
.608 .774 .96 r
.65202 .35662 .65688 .36827 .68058 .36607 .6759 .35451 Mtetra
.607 .776 .961 r
.6759 .35451 .68058 .36607 .70438 .36384 .69988 .35234 Mtetra
.607 .778 .962 r
.69988 .35234 .70438 .36384 .72827 .36158 .72395 .35013 Mtetra
.606 .779 .963 r
.72395 .35013 .72827 .36158 .75226 .35929 .74811 .34788 Mtetra
.606 .781 .964 r
.74811 .34788 .75226 .35929 .77633 .35698 .77237 .3456 Mtetra
.605 .782 .965 r
.77237 .3456 .77633 .35698 .8005 .35464 .79672 .34329 Mtetra
.605 .783 .966 r
.79672 .34329 .8005 .35464 .82476 .35228 .82117 .34095 Mtetra
.605 .784 .967 r
.82117 .34095 .82476 .35228 .84911 .3499 .84571 .33858 Mtetra
.604 .785 .967 r
.84571 .33858 .84911 .3499 .87356 .3475 .87034 .33619 Mtetra
.604 .786 .968 r
.87034 .33619 .87356 .3475 .8981 .34508 .89508 .33378 Mtetra
.603 .786 .968 r
.89508 .33378 .8981 .34508 .92274 .34265 .91991 .33134 Mtetra
.603 .787 .969 r
.91991 .33134 .92274 .34265 .94747 .34019 .94483 .32889 Mtetra
.617 .786 .963 r
.14985 .2616 .15814 .27193 .17964 .26947 .17149 .2591 Mtetra
.17149 .2591 .17964 .26947 .20122 .26699 .19322 .25659 Mtetra
.522 .74 .974 r
.19322 .25659 .20122 .26699 .22074 .30185 .21482 .25751 Mtetra
.238 .248 .668 r
.21482 .25751 .22074 .30185 .24087 .33195 .23434 .29819 Mtetra
.369 .388 .749 r
.23434 .29819 .24087 .33195 .26197 .34901 .25515 .32162 Mtetra
.451 .483 .802 r
.25515 .32162 .26197 .34901 .28362 .35917 .27668 .33591 Mtetra
.503 .551 .838 r
.27668 .33591 .28362 .35917 .30561 .36534 .29864 .34491 Mtetra
.537 .6 .865 r
.29864 .34491 .30561 .36534 .32785 .36906 .32091 .35063 Mtetra
.559 .637 .884 r
.32091 .35063 .32785 .36906 .35027 .37119 .34339 .35422 Mtetra
.575 .665 .899 r
.34339 .35422 .35027 .37119 .37283 .37222 .36606 .35636 Mtetra
.585 .687 .911 r
.36606 .35636 .37283 .37222 .39553 .37249 .38887 .35748 Mtetra
.592 .704 .921 r
.38887 .35748 .39553 .37249 .41835 .37221 .41182 .35786 Mtetra
.597 .717 .928 r
.41182 .35786 .41835 .37221 .44128 .37151 .43488 .3577 Mtetra
.6 .728 .934 r
.43488 .3577 .44128 .37151 .46431 .37049 .45806 .35711 Mtetra
.603 .737 .939 r
.45806 .35711 .46431 .37049 .48744 .36924 .48134 .3562 Mtetra
.604 .744 .944 r
.48134 .3562 .48744 .36924 .51067 .36779 .50472 .35503 Mtetra
.605 .751 .947 r
.50472 .35503 .51067 .36779 .53399 .36618 .52821 .35366 Mtetra
.605 .756 .95 r
.52821 .35366 .53399 .36618 .55741 .36445 .55179 .35212 Mtetra
.606 .76 .953 r
.55179 .35212 .55741 .36445 .58092 .36261 .57547 .35044 Mtetra
.606 .764 .955 r
.57547 .35044 .58092 .36261 .60453 .36069 .59925 .34865 Mtetra
.606 .767 .957 r
.59925 .34865 .60453 .36069 .62823 .35869 .62312 .34677 Mtetra
.606 .77 .959 r
.62312 .34677 .62823 .35869 .65202 .35662 .64708 .3448 Mtetra
.605 .772 .96 r
.64708 .3448 .65202 .35662 .6759 .35451 .67115 .34276 Mtetra
.605 .775 .961 r
.67115 .34276 .6759 .35451 .69988 .35234 .6953 .34065 Mtetra
.605 .777 .963 r
.6953 .34065 .69988 .35234 .72395 .35013 .71955 .3385 Mtetra
.605 .778 .964 r
.71955 .3385 .72395 .35013 .74811 .34788 .7439 .33629 Mtetra
.604 .78 .965 r
.7439 .33629 .74811 .34788 .77237 .3456 .76834 .33405 Mtetra
.604 .781 .965 r
.76834 .33405 .77237 .3456 .79672 .34329 .79288 .33176 Mtetra
.604 .782 .966 r
.79288 .33176 .79672 .34329 .82117 .34095 .81752 .32944 Mtetra
.603 .783 .967 r
.81752 .32944 .82117 .34095 .84571 .33858 .84225 .32709 Mtetra
.603 .784 .967 r
.84225 .32709 .84571 .33858 .87034 .33619 .86708 .3247 Mtetra
.603 .785 .968 r
.86708 .3247 .87034 .33619 .89508 .33378 .89201 .3223 Mtetra
.603 .786 .969 r
.89201 .3223 .89508 .33378 .91991 .33134 .91703 .31986 Mtetra
.602 .787 .969 r
.91703 .31986 .91991 .33134 .94483 .32889 .94216 .3174 Mtetra
.617 .786 .963 r
.14142 .25112 .14985 .2616 .17149 .2591 .16322 .24858 Mtetra
.16322 .24858 .17149 .2591 .19322 .25659 .18509 .24603 Mtetra
.18509 .24603 .19322 .25659 .21482 .25751 .20704 .24347 Mtetra
0 .218 .74 r
.20704 .24347 .21482 .25751 .23434 .29819 .22777 .26418 Mtetra
.261 .308 .722 r
.22777 .26418 .23434 .29819 .25515 .32162 .24827 .29398 Mtetra
.377 .432 .791 r
.24827 .29398 .25515 .32162 .27668 .33591 .26966 .31241 Mtetra
.451 .516 .834 r
.26966 .31241 .27668 .33591 .29864 .34491 .29159 .32423 Mtetra
.499 .576 .864 r
.29159 .32423 .29864 .34491 .32091 .35063 .31388 .33196 Mtetra
.531 .619 .885 r
.31388 .33196 .32091 .35063 .34339 .35422 .33643 .33703 Mtetra
.553 .652 .9 r
.33643 .33703 .34339 .35422 .36606 .35636 .35919 .34029 Mtetra
.568 .676 .912 r
.35919 .34029 .36606 .35636 .38887 .35748 .38212 .34227 Mtetra
.578 .695 .922 r
.38212 .34227 .38887 .35748 .41182 .35786 .40519 .34332 Mtetra
.586 .711 .929 r
.40519 .34332 .41182 .35786 .43488 .3577 .42839 .34368 Mtetra
.591 .723 .935 r
.42839 .34368 .43488 .3577 .45806 .35711 .45171 .34353 Mtetra
.595 .733 .94 r
.45171 .34353 .45806 .35711 .48134 .3562 .47515 .34297 Mtetra
.597 .741 .944 r
.47515 .34297 .48134 .3562 .50472 .35503 .49869 .34209 Mtetra
.599 .747 .948 r
.49869 .34209 .50472 .35503 .52821 .35366 .52234 .34095 Mtetra
.601 .753 .951 r
.52234 .34095 .52821 .35366 .55179 .35212 .54609 .33961 Mtetra
.602 .758 .953 r
.54609 .33961 .55179 .35212 .57547 .35044 .56993 .33809 Mtetra
.602 .762 .955 r
.56993 .33809 .57547 .35044 .59925 .34865 .59388 .33644 Mtetra
.603 .765 .957 r
.59388 .33644 .59925 .34865 .62312 .34677 .61793 .33466 Mtetra
.603 .768 .959 r
.61793 .33466 .62312 .34677 .64708 .3448 .64207 .33279 Mtetra
.603 .771 .96 r
.64207 .33279 .64708 .3448 .67115 .34276 .66631 .33082 Mtetra
.603 .773 .962 r
.66631 .33082 .67115 .34276 .6953 .34065 .69065 .32879 Mtetra
.603 .775 .963 r
.69065 .32879 .6953 .34065 .71955 .3385 .71509 .32668 Mtetra
.603 .777 .964 r
.71509 .32668 .71955 .3385 .7439 .33629 .73962 .32452 Mtetra
.603 .779 .965 r
.73962 .32452 .7439 .33629 .76834 .33405 .76425 .32231 Mtetra
.603 .78 .965 r
.76425 .32231 .76834 .33405 .79288 .33176 .78898 .32005 Mtetra
.603 .781 .966 r
.78898 .32005 .79288 .33176 .81752 .32944 .81381 .31774 Mtetra
.602 .782 .967 r
.81381 .31774 .81752 .32944 .84225 .32709 .83874 .31541 Mtetra
.602 .784 .967 r
.83874 .31541 .84225 .32709 .86708 .3247 .86376 .31303 Mtetra
.602 .784 .968 r
.86376 .31303 .86708 .3247 .89201 .3223 .88889 .31063 Mtetra
.602 .785 .969 r
.88889 .31063 .89201 .3223 .91703 .31986 .91411 .30819 Mtetra
.602 .786 .969 r
.91411 .30819 .91703 .31986 .94216 .3174 .93944 .30573 Mtetra
.617 .786 .963 r
.13287 .24047 .14142 .25112 .16322 .24858 .15482 .2379 Mtetra
.15482 .2379 .16322 .24858 .18509 .24603 .17684 .23531 Mtetra
.17684 .23531 .18509 .24603 .20704 .24347 .19895 .23271 Mtetra
.19895 .23271 .20704 .24347 .22777 .26418 .22114 .2301 Mtetra
.139 .218 .684 r
.22114 .2301 .22777 .26418 .24827 .29398 .24132 .26608 Mtetra
.295 .373 .773 r
.24132 .26608 .24827 .29398 .26966 .31241 .26256 .28864 Mtetra
.395 .478 .827 r
.26256 .28864 .26966 .31241 .29159 .32423 .28445 .3033 Mtetra
.459 .549 .861 r
.28445 .3033 .29159 .32423 .31388 .33196 .30676 .31306 Mtetra
.501 .6 .884 r
.30676 .31306 .31388 .33196 .33643 .33703 .32938 .31961 Mtetra
.53 .638 .901 r
.32938 .31961 .33643 .33703 .35919 .34029 .35223 .32399 Mtetra
.55 .666 .913 r
.35223 .32399 .35919 .34029 .38212 .34227 .37527 .32683 Mtetra
.564 .687 .923 r
.37527 .32683 .38212 .34227 .40519 .34332 .39847 .32856 Mtetra
.574 .704 .93 r
.39847 .32856 .40519 .34332 .42839 .34368 .42181 .32947 Mtetra
.582 .717 .936 r
.42181 .32947 .42839 .34368 .45171 .34353 .44527 .32975 Mtetra
.587 .728 .941 r
.44527 .32975 .45171 .34353 .47515 .34297 .46886 .32954 Mtetra
.591 .737 .945 r
.46886 .32954 .47515 .34297 .49869 .34209 .49256 .32894 Mtetra
.594 .744 .948 r
.49256 .32894 .49869 .34209 .52234 .34095 .51638 .32805 Mtetra
.596 .75 .951 r
.51638 .32805 .52234 .34095 .54609 .33961 .54029 .3269 Mtetra
.598 .755 .954 r
.54029 .3269 .54609 .33961 .56993 .33809 .56431 .32555 Mtetra
.599 .76 .956 r
.56431 .32555 .56993 .33809 .59388 .33644 .58844 .32403 Mtetra
.6 .764 .958 r
.58844 .32403 .59388 .33644 .61793 .33466 .61266 .32237 Mtetra
.6 .767 .959 r
.61266 .32237 .61793 .33466 .64207 .33279 .63698 .32059 Mtetra
.601 .77 .961 r
.63698 .32059 .64207 .33279 .66631 .33082 .66141 .3187 Mtetra
.601 .772 .962 r
.66141 .3187 .66631 .33082 .69065 .32879 .68593 .31673 Mtetra
.601 .774 .963 r
.68593 .31673 .69065 .32879 .71509 .32668 .71055 .31468 Mtetra
.601 .776 .964 r
.71055 .31468 .71509 .32668 .73962 .32452 .73528 .31256 Mtetra
.601 .778 .965 r
.73528 .31256 .73962 .32452 .76425 .32231 .7601 .31038 Mtetra
.601 .779 .966 r
.7601 .31038 .76425 .32231 .78898 .32005 .78502 .30814 Mtetra
.601 .781 .966 r
.78502 .30814 .78898 .32005 .81381 .31774 .81004 .30586 Mtetra
.601 .782 .967 r
.81004 .30586 .81381 .31774 .83874 .31541 .83517 .30354 Mtetra
.601 .783 .968 r
.83517 .30354 .83874 .31541 .86376 .31303 .86039 .30117 Mtetra
.601 .784 .968 r
.86039 .30117 .86376 .31303 .88889 .31063 .88572 .29877 Mtetra
.601 .785 .969 r
.88572 .29877 .88889 .31063 .91411 .30819 .91114 .29633 Mtetra
.91114 .29633 .91411 .30819 .93944 .30573 .93667 .29386 Mtetra
.617 .786 .963 r
.12419 .22967 .13287 .24047 .15482 .2379 .14629 .22705 Mtetra
.14629 .22705 .15482 .2379 .17684 .23531 .16847 .22442 Mtetra
.16847 .22442 .17684 .23531 .19895 .23271 .19073 .22178 Mtetra
.19073 .22178 .19895 .23271 .22114 .2301 .21307 .21914 Mtetra
0 .193 .707 r
.21307 .21914 .22114 .2301 .24132 .26608 .23431 .23792 Mtetra
.206 .307 .748 r
.23431 .23792 .24132 .26608 .26256 .28864 .25539 .26462 Mtetra
.333 .434 .815 r
.25539 .26462 .26256 .28864 .28445 .3033 .27722 .28212 Mtetra
.415 .52 .856 r
.27722 .28212 .28445 .3033 .30676 .31306 .29955 .29391 Mtetra
.47 .58 .883 r
.29955 .29391 .30676 .31306 .32938 .31961 .32223 .30196 Mtetra
.506 .623 .901 r
.32223 .30196 .32938 .31961 .35223 .32399 .34517 .30747 Mtetra
.531 .654 .914 r
.34517 .30747 .35223 .32399 .37527 .32683 .36832 .31118 Mtetra
.549 .678 .923 r
.36832 .31118 .37527 .32683 .39847 .32856 .39164 .3136 Mtetra
.562 .697 .931 r
.39164 .3136 .39847 .32856 .42181 .32947 .41512 .31504 Mtetra
.572 .712 .937 r
.41512 .31504 .42181 .32947 .44527 .32975 .43874 .31576 Mtetra
.579 .723 .942 r
.43874 .31576 .44527 .32975 .46886 .32954 .46248 .3159 Mtetra
.584 .733 .946 r
.46248 .3159 .46886 .32954 .49256 .32894 .48635 .3156 Mtetra
.588 .741 .949 r
.48635 .3156 .49256 .32894 .51638 .32805 .51032 .31494 Mtetra
.591 .747 .952 r
.51032 .31494 .51638 .32805 .54029 .3269 .53441 .314 Mtetra
.593 .753 .954 r
.53441 .314 .54029 .3269 .56431 .32555 .5586 .31281 Mtetra
.595 .758 .956 r
.5586 .31281 .56431 .32555 .58844 .32403 .5829 .31143 Mtetra
.596 .762 .958 r
.5829 .31143 .58844 .32403 .61266 .32237 .60731 .30988 Mtetra
.597 .765 .959 r
.60731 .30988 .61266 .32237 .63698 .32059 .63181 .3082 Mtetra
.598 .768 .961 r
.63181 .3082 .63698 .32059 .66141 .3187 .65642 .30639 Mtetra
.599 .771 .962 r
.65642 .30639 .66141 .3187 .68593 .31673 .68113 .30448 Mtetra
.599 .773 .963 r
.68113 .30448 .68593 .31673 .71055 .31468 .70595 .30248 Mtetra
.6 .775 .964 r
.70595 .30248 .71055 .31468 .73528 .31256 .73086 .3004 Mtetra
.6 .777 .965 r
.73086 .3004 .73528 .31256 .7601 .31038 .75588 .29826 Mtetra
.6 .778 .966 r
.75588 .29826 .7601 .31038 .78502 .30814 .78099 .29605 Mtetra
.6 .78 .966 r
.78099 .29605 .78502 .30814 .81004 .30586 .80622 .29378 Mtetra
.6 .781 .967 r
.80622 .29378 .81004 .30586 .83517 .30354 .83154 .29147 Mtetra
.6 .782 .968 r
.83154 .29147 .83517 .30354 .86039 .30117 .85696 .28911 Mtetra
.6 .783 .968 r
.85696 .28911 .86039 .30117 .88572 .29877 .88249 .28671 Mtetra
.6 .784 .969 r
.88249 .28671 .88572 .29877 .91114 .29633 .90812 .28427 Mtetra
.6 .785 .969 r
.90812 .28427 .91114 .29633 .93667 .29386 .93386 .2818 Mtetra
.617 .786 .963 r
.11538 .21869 .12419 .22967 .14629 .22705 .13763 .21604 Mtetra
.13763 .21604 .14629 .22705 .16847 .22442 .15996 .21337 Mtetra
.15996 .21337 .16847 .22442 .19073 .22178 .18238 .21069 Mtetra
.18238 .21069 .19073 .22178 .21307 .21914 .20488 .208 Mtetra
.504 .729 .974 r
.20488 .208 .21307 .21914 .23431 .23792 .22723 .20949 Mtetra
.111 .236 .714 r
.22723 .20949 .23431 .23792 .25539 .26462 .24814 .24033 Mtetra
.267 .387 .8 r
.24814 .24033 .25539 .26462 .27722 .28212 .26991 .26069 Mtetra
.369 .488 .849 r
.26991 .26069 .27722 .28212 .29955 .29391 .29225 .27451 Mtetra
.436 .558 .88 r
.29225 .27451 .29955 .29391 .32223 .30196 .31498 .28407 Mtetra
.481 .607 .9 r
.31498 .28407 .32223 .30196 .34517 .30747 .33801 .29072 Mtetra
.512 .642 .914 r
.33801 .29072 .34517 .30747 .36832 .31118 .36127 .29531 Mtetra
.534 .669 .924 r
.36127 .29531 .36832 .31118 .39164 .3136 .38472 .29841 Mtetra
.55 .69 .931 r
.38472 .29841 .39164 .3136 .41512 .31504 .40834 .30041 Mtetra
.562 .706 .937 r
.40834 .30041 .41512 .31504 .43874 .31576 .43211 .30156 Mtetra
.571 .718 .942 r
.43211 .30156 .43874 .31576 .46248 .3159 .45601 .30207 Mtetra
.577 .729 .946 r
.45601 .30207 .46248 .3159 .48635 .3156 .48003 .30206 Mtetra
.582 .737 .949 r
.48003 .30206 .48635 .3156 .51032 .31494 .50418 .30164 Mtetra
.586 .745 .952 r
.50418 .30164 .51032 .31494 .53441 .314 .52843 .30089 Mtetra
.589 .75 .954 r
.52843 .30089 .53441 .314 .5586 .31281 .5528 .29987 Mtetra
.591 .755 .956 r
.5528 .29987 .5586 .31281 .5829 .31143 .57728 .29863 Mtetra
.593 .76 .958 r
.57728 .29863 .5829 .31143 .60731 .30988 .60187 .2972 Mtetra
.595 .763 .96 r
.60187 .2972 .60731 .30988 .63181 .3082 .62656 .29561 Mtetra
.596 .767 .961 r
.62656 .29561 .63181 .3082 .65642 .30639 .65136 .29388 Mtetra
.597 .769 .962 r
.65136 .29388 .65642 .30639 .68113 .30448 .67626 .29203 Mtetra
.597 .772 .963 r
.67626 .29203 .68113 .30448 .70595 .30248 .70126 .29009 Mtetra
.598 .774 .964 r
.70126 .29009 .70595 .30248 .73086 .3004 .72637 .28805 Mtetra
.598 .776 .965 r
.72637 .28805 .73086 .3004 .75588 .29826 .75159 .28594 Mtetra
.599 .777 .966 r
.75159 .28594 .75588 .29826 .78099 .29605 .7769 .28376 Mtetra
.599 .779 .966 r
.7769 .28376 .78099 .29605 .80622 .29378 .80232 .28151 Mtetra
.599 .78 .967 r
.80232 .28151 .80622 .29378 .83154 .29147 .82785 .27921 Mtetra
.599 .782 .968 r
.82785 .27921 .83154 .29147 .85696 .28911 .85348 .27686 Mtetra
.599 .783 .968 r
.85348 .27686 .85696 .28911 .88249 .28671 .87922 .27446 Mtetra
.599 .784 .969 r
.87922 .27446 .88249 .28671 .90812 .28427 .90506 .27202 Mtetra
.90506 .27202 .90812 .28427 .93386 .2818 .931 .26954 Mtetra
.617 .786 .963 r
.10642 .20755 .11538 .21869 .13763 .21604 .12883 .20485 Mtetra
.12883 .20485 .13763 .21604 .15996 .21337 .15132 .20214 Mtetra
.15132 .20214 .15996 .21337 .18238 .21069 .1739 .19942 Mtetra
.1739 .19942 .18238 .21069 .20488 .208 .19656 .19669 Mtetra
.19656 .19669 .20488 .208 .22723 .20949 .21931 .19395 Mtetra
0 .225 .746 r
.21931 .19395 .22723 .20949 .24814 .24033 .2408 .21577 Mtetra
.197 .336 .779 r
.2408 .21577 .24814 .24033 .26991 .26069 .26251 .23899 Mtetra
.319 .454 .839 r
.26251 .23899 .26991 .26069 .29225 .27451 .28485 .25487 Mtetra
.4 .534 .875 r
.28485 .25487 .29225 .27451 .31498 .28407 .30764 .26594 Mtetra
.455 .589 .898 r
.30764 .26594 .31498 .28407 .33801 .29072 .33075 .27373 Mtetra
.492 .63 .913 r
.33075 .27373 .33801 .29072 .36127 .29531 .35412 .2792 Mtetra
.519 .659 .924 r
.35412 .2792 .36127 .29531 .38472 .29841 .3777 .283 Mtetra
.538 .682 .932 r
.3777 .283 .38472 .29841 .40834 .30041 .40146 .28555 Mtetra
.552 .7 .938 r
.40146 .28555 .40834 .30041 .43211 .30156 .42537 .28715 Mtetra
.562 .714 .943 r
.42537 .28715 .43211 .30156 .45601 .30207 .44943 .28801 Mtetra
.57 .725 .946 r
.44943 .28801 .45601 .30207 .48003 .30206 .47362 .2883 Mtetra
.576 .734 .95 r
.47362 .2883 .48003 .30206 .50418 .30164 .49793 .28813 Mtetra
.581 .742 .952 r
.49793 .28813 .50418 .30164 .52843 .30089 .52237 .28758 Mtetra
.585 .748 .955 r
.52237 .28758 .52843 .30089 .5528 .29987 .54691 .28673 Mtetra
.588 .753 .957 r
.54691 .28673 .5528 .29987 .57728 .29863 .57157 .28563 Mtetra
.59 .758 .958 r
.57157 .28563 .57728 .29863 .60187 .2972 .59634 .28431 Mtetra
.592 .762 .96 r
.59634 .28431 .60187 .2972 .62656 .29561 .62122 .28281 Mtetra
.593 .765 .961 r
.62122 .28281 .62656 .29561 .65136 .29388 .64621 .28116 Mtetra
.594 .768 .962 r
.64621 .28116 .65136 .29388 .67626 .29203 .67131 .27939 Mtetra
.595 .771 .963 r
.67131 .27939 .67626 .29203 .70126 .29009 .69651 .27749 Mtetra
.596 .773 .964 r
.69651 .27749 .70126 .29009 .72637 .28805 .72181 .2755 Mtetra
.597 .775 .965 r
.72181 .2755 .72637 .28805 .75159 .28594 .74722 .27342 Mtetra
.597 .777 .966 r
.74722 .27342 .75159 .28594 .7769 .28376 .77274 .27126 Mtetra
.598 .778 .967 r
.77274 .27126 .7769 .28376 .80232 .28151 .79837 .26903 Mtetra
.598 .78 .967 r
.79837 .26903 .80232 .28151 .82785 .27921 .8241 .26674 Mtetra
.598 .781 .968 r
.8241 .26674 .82785 .27921 .85348 .27686 .84994 .2644 Mtetra
.598 .782 .968 r
.84994 .2644 .85348 .27686 .87922 .27446 .87588 .262 Mtetra
.598 .783 .969 r
.87588 .262 .87922 .27446 .90506 .27202 .90194 .25956 Mtetra
.599 .784 .969 r
.90194 .25956 .90506 .27202 .931 .26954 .9281 .25707 Mtetra
.617 .786 .963 r
.09733 .19623 .10642 .20755 .12883 .20485 .1199 .19349 Mtetra
.1199 .19349 .12883 .20485 .15132 .20214 .14255 .19074 Mtetra
.14255 .19074 .15132 .20214 .1739 .19942 .16529 .18797 Mtetra
.16529 .18797 .1739 .19942 .19656 .19669 .18811 .1852 Mtetra
.18811 .1852 .19656 .19669 .21931 .19395 .21102 .18242 Mtetra
.248 .569 .939 r
.21102 .18242 .21931 .19395 .2408 .21577 .23339 .19094 Mtetra
.123 .281 .753 r
.23339 .19094 .2408 .21577 .26251 .23899 .25501 .21703 Mtetra
.267 .417 .827 r
.25501 .21703 .26251 .23899 .28485 .25487 .27736 .23497 Mtetra
.363 .508 .869 r
.27736 .23497 .28485 .25487 .30764 .26594 .30019 .24756 Mtetra
.427 .571 .895 r
.30019 .24756 .30764 .26594 .33075 .27373 .32339 .2565 Mtetra
.471 .616 .912 r
.32339 .2565 .33075 .27373 .35412 .2792 .34687 .26287 Mtetra
.503 .649 .923 r
.34687 .26287 .35412 .2792 .3777 .283 .37058 .26736 Mtetra
.525 .674 .932 r
.37058 .26736 .3777 .283 .40146 .28555 .39447 .27047 Mtetra
.542 .693 .938 r
.39447 .27047 .40146 .28555 .42537 .28715 .41854 .27252 Mtetra
.554 .708 .943 r
.41854 .27252 .42537 .28715 .44943 .28801 .44275 .27375 Mtetra
.563 .721 .947 r
.44275 .27375 .44943 .28801 .47362 .2883 .46711 .27433 Mtetra
.571 .73 .95 r
.46711 .27433 .47362 .2883 .49793 .28813 .49159 .27441 Mtetra
.576 .739 .953 r
.49159 .27441 .49793 .28813 .52237 .28758 .5162 .27406 Mtetra
.581 .745 .955 r
.5162 .27406 .52237 .28758 .54691 .28673 .54093 .27338 Mtetra
.584 .751 .957 r
.54093 .27338 .54691 .28673 .57157 .28563 .56577 .27241 Mtetra
.587 .756 .959 r
.56577 .27241 .57157 .28563 .59634 .28431 .59073 .27121 Mtetra
.589 .76 .96 r
.59073 .27121 .59634 .28431 .62122 .28281 .6158 .26981 Mtetra
.591 .764 .961 r
.6158 .26981 .62122 .28281 .64621 .28116 .64098 .26824 Mtetra
.592 .767 .963 r
.64098 .26824 .64621 .28116 .67131 .27939 .66627 .26653 Mtetra
.593 .769 .964 r
.66627 .26653 .67131 .27939 .69651 .27749 .69167 .26469 Mtetra
.594 .772 .964 r
.69167 .26469 .69651 .27749 .72181 .2755 .71718 .26274 Mtetra
.595 .774 .965 r
.71718 .26274 .72181 .2755 .74722 .27342 .74279 .26069 Mtetra
.596 .776 .966 r
.74279 .26069 .74722 .27342 .77274 .27126 .76851 .25856 Mtetra
.596 .777 .967 r
.76851 .25856 .77274 .27126 .79837 .26903 .79435 .25635 Mtetra
.597 .779 .967 r
.79435 .25635 .79837 .26903 .8241 .26674 .82029 .25407 Mtetra
.597 .78 .968 r
.82029 .25407 .8241 .26674 .84994 .2644 .84634 .25173 Mtetra
.597 .781 .968 r
.84634 .25173 .84994 .2644 .87588 .262 .8725 .24933 Mtetra
.598 .782 .969 r
.8725 .24933 .87588 .262 .90194 .25956 .89876 .24688 Mtetra
.598 .783 .969 r
.89876 .24688 .90194 .25956 .9281 .25707 .92514 .24439 Mtetra
.617 .786 .963 r
.0881 .18473 .09733 .19623 .1199 .19349 .11082 .18195 Mtetra
.11082 .18195 .1199 .19349 .14255 .19074 .13364 .17915 Mtetra
.13364 .17915 .14255 .19074 .16529 .18797 .15654 .17634 Mtetra
.15654 .17634 .16529 .18797 .18811 .1852 .17953 .17353 Mtetra
.17953 .17353 .18811 .1852 .21102 .18242 .2026 .1707 Mtetra
.2026 .1707 .21102 .18242 .23339 .19094 .22577 .16786 Mtetra
.037 .236 .737 r
.22577 .16786 .23339 .19094 .25501 .21703 .24743 .19479 Mtetra
.213 .377 .811 r
.24743 .19479 .25501 .21703 .27736 .23497 .26977 .2148 Mtetra
.324 .481 .862 r
.26977 .2148 .27736 .23497 .30019 .24756 .29265 .22893 Mtetra
.399 .552 .892 r
.29265 .22893 .30019 .24756 .32339 .2565 .31593 .23903 Mtetra
.45 .602 .91 r
.31593 .23903 .32339 .2565 .34687 .26287 .33951 .24629 Mtetra
.486 .639 .923 r
.33951 .24629 .34687 .26287 .37058 .26736 .36334 .2515 Mtetra
.512 .666 .932 r
.36334 .2515 .37058 .26736 .39447 .27047 .38738 .25516 Mtetra
.531 .687 .938 r
.38738 .25516 .39447 .27047 .41854 .27252 .4116 .25766 Mtetra
.545 .703 .943 r
.4116 .25766 .41854 .27252 .44275 .27375 .43597 .25926 Mtetra
.556 .716 .947 r
.43597 .25926 .44275 .27375 .46711 .27433 .46049 .26014 Mtetra
.565 .727 .95 r
.46049 .26014 .46711 .27433 .49159 .27441 .48515 .26046 Mtetra
.571 .736 .953 r
.48515 .26046 .49159 .27441 .5162 .27406 .50994 .26033 Mtetra
.576 .743 .955 r
.50994 .26033 .5162 .27406 .54093 .27338 .53485 .25981 Mtetra
.58 .749 .957 r
.53485 .25981 .54093 .27338 .56577 .27241 .55988 .25899 Mtetra
.584 .754 .959 r
.55988 .25899 .56577 .27241 .59073 .27121 .58503 .2579 Mtetra
.586 .758 .96 r
.58503 .2579 .59073 .27121 .6158 .26981 .61029 .2566 Mtetra
.588 .762 .962 r
.61029 .2566 .6158 .26981 .64098 .26824 .63566 .25511 Mtetra
.59 .765 .963 r
.63566 .25511 .64098 .26824 .66627 .26653 .66115 .25346 Mtetra
.592 .768 .964 r
.66115 .25346 .66627 .26653 .69167 .26469 .68675 .25167 Mtetra
.593 .771 .965 r
.68675 .25167 .69167 .26469 .71718 .26274 .71246 .24976 Mtetra
.594 .773 .965 r
.71246 .24976 .71718 .26274 .74279 .26069 .73828 .24775 Mtetra
.594 .775 .966 r
.73828 .24775 .74279 .26069 .76851 .25856 .76422 .24564 Mtetra
.595 .777 .967 r
.76422 .24564 .76851 .25856 .79435 .25635 .79026 .24345 Mtetra
.596 .778 .967 r
.79026 .24345 .79435 .25635 .82029 .25407 .81641 .24118 Mtetra
.596 .779 .968 r
.81641 .24118 .82029 .25407 .84634 .25173 .84268 .23884 Mtetra
.596 .781 .968 r
.84268 .23884 .84634 .25173 .8725 .24933 .86905 .23645 Mtetra
.597 .782 .969 r
.86905 .23645 .8725 .24933 .89876 .24688 .89554 .234 Mtetra
.597 .783 .969 r
.89554 .234 .89876 .24688 .92514 .24439 .92214 .23149 Mtetra
.617 .786 .963 r
.07871 .17305 .0881 .18473 .11082 .18195 .1016 .17022 Mtetra
.1016 .17022 .11082 .18195 .13364 .17915 .12458 .16738 Mtetra
.12458 .16738 .13364 .17915 .15654 .17634 .14765 .16453 Mtetra
.14765 .16453 .15654 .17634 .17953 .17353 .17081 .16167 Mtetra
.17081 .16167 .17953 .17353 .2026 .1707 .19405 .15879 Mtetra
.19405 .15879 .2026 .1707 .22577 .16786 .21739 .15591 Mtetra
0 .316 .799 r
.21739 .15591 .22577 .16786 .24743 .19479 .23975 .17228 Mtetra
.156 .335 .793 r
.23975 .17228 .24743 .19479 .26977 .2148 .26207 .19437 Mtetra
.283 .452 .852 r
.26207 .19437 .26977 .2148 .29265 .22893 .285 .21004 Mtetra
.369 .532 .887 r
.285 .21004 .29265 .22893 .31593 .23903 .30836 .22131 Mtetra
.428 .588 .908 r
.30836 .22131 .31593 .23903 .33951 .24629 .33205 .22948 Mtetra
.469 .628 .922 r
.33205 .22948 .33951 .24629 .36334 .2515 .356 .23539 Mtetra
.499 .658 .931 r
.356 .23539 .36334 .2515 .38738 .25516 .38018 .23962 Mtetra
.52 .68 .938 r
.38018 .23962 .38738 .25516 .4116 .25766 .40455 .24257 Mtetra
.537 .698 .943 r
.40455 .24257 .4116 .25766 .43597 .25926 .42908 .24454 Mtetra
.549 .712 .947 r
.42908 .24454 .43597 .25926 .46049 .26014 .45377 .24573 Mtetra
.559 .723 .951 r
.45377 .24573 .46049 .26014 .48515 .26046 .47861 .2463 Mtetra
.566 .732 .953 r
.47861 .2463 .48515 .26046 .50994 .26033 .50357 .24637 Mtetra
.572 .74 .956 r
.50357 .24637 .50994 .26033 .53485 .25981 .52867 .24603 Mtetra
.577 .747 .957 r
.52867 .24603 .53485 .25981 .55988 .25899 .55389 .24534 Mtetra
.58 .752 .959 r
.55389 .24534 .55988 .25899 .58503 .2579 .57923 .24438 Mtetra
.583 .757 .961 r
.57923 .24438 .58503 .2579 .61029 .2566 .60469 .24317 Mtetra
.586 .761 .962 r
.60469 .24317 .61029 .2566 .63566 .25511 .63026 .24176 Mtetra
.588 .764 .963 r
.63026 .24176 .63566 .25511 .66115 .25346 .65595 .24018 Mtetra
.59 .767 .964 r
.65595 .24018 .66115 .25346 .68675 .25167 .68175 .23844 Mtetra
.591 .77 .965 r
.68175 .23844 .68675 .25167 .71246 .24976 .70767 .23657 Mtetra
.592 .772 .965 r
.70767 .23657 .71246 .24976 .73828 .24775 .7337 .23459 Mtetra
.593 .774 .966 r
.7337 .23459 .73828 .24775 .76422 .24564 .75984 .2325 Mtetra
.594 .776 .967 r
.75984 .2325 .76422 .24564 .79026 .24345 .7861 .23033 Mtetra
.595 .777 .967 r
.7861 .23033 .79026 .24345 .81641 .24118 .81247 .22807 Mtetra
.595 .779 .968 r
.81247 .22807 .81641 .24118 .84268 .23884 .83895 .22574 Mtetra
.596 .78 .968 r
.83895 .22574 .84268 .23884 .86905 .23645 .86555 .22334 Mtetra
.596 .781 .969 r
.86555 .22334 .86905 .23645 .89554 .234 .89226 .22089 Mtetra
.596 .782 .969 r
.89226 .22089 .89554 .234 .92214 .23149 .91908 .21838 Mtetra
.617 .786 .963 r
.06918 .16119 .07871 .17305 .1016 .17022 .09223 .15831 Mtetra
.09223 .15831 .1016 .17022 .12458 .16738 .11538 .15542 Mtetra
.11538 .15542 .12458 .16738 .14765 .16453 .13862 .15252 Mtetra
.13862 .15252 .14765 .16453 .17081 .16167 .16194 .14961 Mtetra
.16194 .14961 .17081 .16167 .19405 .15879 .18536 .14669 Mtetra
.18536 .14669 .19405 .15879 .21739 .15591 .20887 .14376 Mtetra
.364 .643 .962 r
.20887 .14376 .21739 .15591 .23975 .17228 .23197 .14949 Mtetra
.098 .292 .771 r
.23197 .14949 .23975 .17228 .26207 .19437 .25428 .17367 Mtetra
.241 .422 .841 r
.25428 .17367 .26207 .19437 .285 .21004 .27724 .19088 Mtetra
.338 .511 .881 r
.27724 .19088 .285 .21004 .30836 .22131 .30067 .20333 Mtetra
.405 .573 .905 r
.30067 .20333 .30836 .22131 .33205 .22948 .32447 .21241 Mtetra
.451 .617 .921 r
.32447 .21241 .33205 .22948 .356 .23539 .34855 .21904 Mtetra
.485 .649 .931 r
.34855 .21904 .356 .23539 .38018 .23962 .37287 .22384 Mtetra
.509 .674 .938 r
.37287 .22384 .38018 .23962 .40455 .24257 .39739 .22725 Mtetra
.528 .693 .944 r
.39739 .22725 .40455 .24257 .42908 .24454 .42209 .22959 Mtetra
.542 .707 .948 r
.42209 .22959 .42908 .24454 .45377 .24573 .44695 .23109 Mtetra
.552 .72 .951 r
.44695 .23109 .45377 .24573 .47861 .2463 .47196 .23191 Mtetra
.561 .729 .954 r
.47196 .23191 .47861 .2463 .50357 .24637 .49711 .23219 Mtetra
.567 .737 .956 r
.49711 .23219 .50357 .24637 .52867 .24603 .52239 .23201 Mtetra
.573 .744 .958 r
.52239 .23201 .52867 .24603 .55389 .24534 .5478 .23147 Mtetra
.577 .75 .959 r
.5478 .23147 .55389 .24534 .57923 .24438 .57333 .23063 Mtetra
.581 .755 .961 r
.57333 .23063 .57923 .24438 .60469 .24317 .59899 .22952 Mtetra
.583 .759 .962 r
.59899 .22952 .60469 .24317 .63026 .24176 .62476 .22819 Mtetra
.586 .763 .963 r
.62476 .22819 .63026 .24176 .65595 .24018 .65066 .22667 Mtetra
.588 .766 .964 r
.65066 .22667 .65595 .24018 .68175 .23844 .67667 .22498 Mtetra
.589 .769 .965 r
.67667 .22498 .68175 .23844 .70767 .23657 .7028 .22316 Mtetra
.591 .771 .966 r
.7028 .22316 .70767 .23657 .7337 .23459 .72904 .22121 Mtetra
.592 .773 .966 r
.72904 .22121 .7337 .23459 .75984 .2325 .7554 .21914 Mtetra
.593 .775 .967 r
.7554 .21914 .75984 .2325 .7861 .23033 .78187 .21698 Mtetra
.593 .777 .967 r
.78187 .21698 .7861 .23033 .81247 .22807 .80846 .21474 Mtetra
.594 .778 .968 r
.80846 .21474 .81247 .22807 .83895 .22574 .83516 .21241 Mtetra
.595 .779 .968 r
.83516 .21241 .83895 .22574 .86555 .22334 .86198 .21001 Mtetra
.595 .781 .969 r
.86198 .21001 .86555 .22334 .89226 .22089 .88892 .20755 Mtetra
.595 .782 .969 r
.88892 .20755 .89226 .22089 .91908 .21838 .91597 .20503 Mtetra
.617 .786 .963 r
.05949 .14913 .06918 .16119 .09223 .15831 .08271 .1462 Mtetra
.08271 .1462 .09223 .15831 .11538 .15542 .10603 .14327 Mtetra
.10603 .14327 .11538 .15542 .13862 .15252 .12944 .14032 Mtetra
.12944 .14032 .13862 .15252 .16194 .14961 .15293 .13737 Mtetra
.15293 .13737 .16194 .14961 .18536 .14669 .17653 .1344 Mtetra
.17653 .1344 .18536 .14669 .20887 .14376 .20021 .13142 Mtetra
.20021 .13142 .20887 .14376 .23197 .14949 .22398 .12842 Mtetra
.029 .263 .762 r
.22398 .12842 .23197 .14949 .25428 .17367 .24638 .15269 Mtetra
.197 .39 .828 r
.24638 .15269 .25428 .17367 .27724 .19088 .26937 .17146 Mtetra
.306 .489 .874 r
.26937 .17146 .27724 .19088 .30067 .20333 .29288 .18509 Mtetra
.381 .557 .902 r
.29288 .18509 .30067 .20333 .32447 .21241 .31678 .19509 Mtetra
.433 .605 .919 r
.31678 .19509 .32447 .21241 .34855 .21904 .34099 .20244 Mtetra
.471 .64 .93 r
.34099 .20244 .34855 .21904 .37287 .22384 .36545 .20781 Mtetra
.498 .667 .938 r
.36545 .20781 .37287 .22384 .39739 .22725 .39012 .21169 Mtetra
.519 .687 .944 r
.39012 .21169 .39739 .22725 .42209 .22959 .41498 .21441 Mtetra
.534 .703 .948 r
.41498 .21441 .42209 .22959 .44695 .23109 .44001 .21621 Mtetra
.546 .716 .951 r
.44001 .21621 .44695 .23109 .47196 .23191 .4652 .21728 Mtetra
.556 .726 .954 r
.4652 .21728 .47196 .23191 .49711 .23219 .49053 .21777 Mtetra
.563 .735 .956 r
.49053 .21777 .49711 .23219 .52239 .23201 .516 .21777 Mtetra
.569 .742 .958 r
.516 .21777 .52239 .23201 .5478 .23147 .54161 .21738 Mtetra
.574 .748 .959 r
.54161 .21738 .5478 .23147 .57333 .23063 .56734 .21665 Mtetra
.578 .753 .961 r
.56734 .21665 .57333 .23063 .59899 .22952 .5932 .21564 Mtetra
.581 .757 .962 r
.5932 .21564 .59899 .22952 .62476 .22819 .61918 .21439 Mtetra
.584 .761 .963 r
.61918 .21439 .62476 .22819 .65066 .22667 .64528 .21293 Mtetra
.586 .765 .964 r
.64528 .21293 .65066 .22667 .67667 .22498 .6715 .2113 Mtetra
.588 .767 .965 r
.6715 .2113 .67667 .22498 .7028 .22316 .69784 .20952 Mtetra
.589 .77 .966 r
.69784 .20952 .7028 .22316 .72904 .22121 .7243 .20759 Mtetra
.59 .772 .966 r
.7243 .20759 .72904 .22121 .7554 .21914 .75087 .20556 Mtetra
.591 .774 .967 r
.75087 .20556 .7554 .21914 .78187 .21698 .77757 .20341 Mtetra
.592 .776 .968 r
.77757 .20341 .78187 .21698 .80846 .21474 .80438 .20117 Mtetra
.593 .777 .968 r
.80438 .20117 .80846 .21474 .83516 .21241 .83131 .19885 Mtetra
.594 .779 .969 r
.83131 .19885 .83516 .21241 .86198 .21001 .85835 .19645 Mtetra
.594 .78 .969 r
.85835 .19645 .86198 .21001 .88892 .20755 .88552 .19398 Mtetra
.595 .781 .969 r
.88552 .19398 .88892 .20755 .91597 .20503 .9128 .19145 Mtetra
.617 .786 .963 r
.04964 .13687 .05949 .14913 .08271 .1462 .07304 .1339 Mtetra
.07304 .1339 .08271 .1462 .10603 .14327 .09653 .13092 Mtetra
.09653 .13092 .10603 .14327 .12944 .14032 .12011 .12792 Mtetra
.12011 .12792 .12944 .14032 .15293 .13737 .14378 .12492 Mtetra
.14378 .12492 .15293 .13737 .17653 .1344 .16755 .1219 Mtetra
.16755 .1219 .17653 .1344 .20021 .13142 .19141 .11887 Mtetra
.19141 .11887 .20021 .13142 .22398 .12842 .21536 .11582 Mtetra
0 .358 .828 r
.21536 .11582 .22398 .12842 .24638 .15269 .23837 .13142 Mtetra
.152 .357 .813 r
.23837 .13142 .24638 .15269 .26937 .17146 .26139 .15176 Mtetra
.273 .466 .866 r
.26139 .15176 .26937 .17146 .29288 .18509 .28497 .16659 Mtetra
.357 .54 .898 r
.28497 .16659 .29288 .18509 .31678 .19509 .30898 .17751 Mtetra
.415 .593 .917 r
.30898 .17751 .31678 .19509 .34099 .20244 .33331 .18558 Mtetra
.456 .631 .929 r
.33331 .18558 .34099 .20244 .36545 .20781 .35791 .19154 Mtetra
.487 .659 .937 r
.35791 .19154 .36545 .20781 .39012 .21169 .38273 .19588 Mtetra
.509 .681 .943 r
.38273 .19588 .39012 .21169 .41498 .21441 .40776 .19898 Mtetra
.527 .698 .948 r
.40776 .19898 .41498 .21441 .44001 .21621 .43297 .20109 Mtetra
.54 .712 .951 r
.43297 .20109 .44001 .21621 .4652 .21728 .45833 .20242 Mtetra
.55 .723 .954 r
.45833 .20242 .4652 .21728 .49053 .21777 .48385 .20312 Mtetra
.559 .732 .956 r
.48385 .20312 .49053 .21777 .516 .21777 .50952 .20329 Mtetra
.565 .74 .958 r
.50952 .20329 .516 .21777 .54161 .21738 .53532 .20304 Mtetra
.57 .746 .96 r
.53532 .20304 .54161 .21738 .56734 .21665 .56125 .20243 Mtetra
.575 .751 .961 r
.56125 .20243 .56734 .21665 .5932 .21564 .58731 .20152 Mtetra
.578 .756 .962 r
.58731 .20152 .5932 .21564 .61918 .21439 .6135 .20035 Mtetra
.581 .76 .963 r
.6135 .20035 .61918 .21439 .64528 .21293 .63981 .19896 Mtetra
.584 .763 .964 r
.63981 .19896 .64528 .21293 .6715 .2113 .66624 .19738 Mtetra
.586 .766 .965 r
.66624 .19738 .6715 .2113 .69784 .20952 .6928 .19564 Mtetra
.587 .769 .966 r
.6928 .19564 .69784 .20952 .7243 .20759 .71947 .19375 Mtetra
.589 .771 .966 r
.71947 .19375 .7243 .20759 .75087 .20556 .74627 .19173 Mtetra
.59 .773 .967 r
.74627 .19173 .75087 .20556 .77757 .20341 .77319 .1896 Mtetra
.591 .775 .968 r
.77319 .1896 .77757 .20341 .80438 .20117 .80023 .18737 Mtetra
.592 .777 .968 r
.80023 .18737 .80438 .20117 .83131 .19885 .82739 .18505 Mtetra
.593 .778 .969 r
.82739 .18505 .83131 .19885 .85835 .19645 .85466 .18265 Mtetra
.593 .78 .969 r
.85466 .18265 .85835 .19645 .88552 .19398 .88206 .18017 Mtetra
.594 .781 .969 r
.88206 .18017 .88552 .19398 .9128 .19145 .90958 .17763 Mtetra
.617 .786 .963 r
.03963 .12441 .04964 .13687 .07304 .1339 .0632 .12139 Mtetra
.0632 .12139 .07304 .1339 .09653 .13092 .08686 .11836 Mtetra
.08686 .11836 .09653 .13092 .12011 .12792 .11062 .11531 Mtetra
.11062 .11531 .12011 .12792 .14378 .12492 .13447 .11226 Mtetra
.13447 .11226 .14378 .12492 .16755 .1219 .15842 .10919 Mtetra
.15842 .10919 .16755 .1219 .19141 .11887 .18246 .10611 Mtetra
.18246 .10611 .19141 .11887 .21536 .11582 .2066 .10302 Mtetra
.327 .618 .955 r
.2066 .10302 .21536 .11582 .23837 .13142 .23026 .10987 Mtetra
.107 .323 .796 r
.23026 .10987 .23837 .13142 .26139 .15176 .2533 .13178 Mtetra
.24 .441 .857 r
.2533 .13178 .26139 .15176 .28497 .16659 .27695 .14781 Mtetra
.331 .523 .893 r
.27695 .14781 .28497 .16659 .30898 .17751 .30105 .15966 Mtetra
.396 .58 .914 r
.30105 .15966 .30898 .17751 .33331 .18558 .32551 .16846 Mtetra
.442 .621 .928 r
.32551 .16846 .33331 .18558 .35791 .19154 .35025 .175 Mtetra
.475 .652 .937 r
.35025 .175 .35791 .19154 .38273 .19588 .37523 .17982 Mtetra
.5 .675 .943 r
.37523 .17982 .38273 .19588 .40776 .19898 .40042 .1833 Mtetra
.519 .694 .948 r
.40042 .1833 .40776 .19898 .43297 .20109 .4258 .18572 Mtetra
.534 .708 .951 r
.4258 .18572 .43297 .20109 .45833 .20242 .45135 .18731 Mtetra
.545 .72 .954 r
.45135 .18731 .45833 .20242 .48385 .20312 .47706 .18822 Mtetra
.554 .729 .956 r
.47706 .18822 .48385 .20312 .50952 .20329 .50292 .18857 Mtetra
.561 .737 .958 r
.50292 .18857 .50952 .20329 .53532 .20304 .52892 .18847 Mtetra
.567 .744 .96 r
.52892 .18847 .53532 .20304 .56125 .20243 .55505 .18798 Mtetra
.572 .75 .961 r
.55505 .18798 .56125 .20243 .58731 .20152 .58132 .18716 Mtetra
.576 .754 .962 r
.58132 .18716 .58731 .20152 .6135 .20035 .60772 .18607 Mtetra
.579 .758 .963 r
.60772 .18607 .6135 .20035 .63981 .19896 .63424 .18475 Mtetra
.582 .762 .964 r
.63424 .18475 .63981 .19896 .66624 .19738 .66089 .18322 Mtetra
.584 .765 .965 r
.66089 .18322 .66624 .19738 .6928 .19564 .68767 .18152 Mtetra
.586 .768 .966 r
.68767 .18152 .6928 .19564 .71947 .19375 .71457 .17966 Mtetra
.588 .77 .967 r
.71457 .17966 .71947 .19375 .74627 .19173 .74159 .17766 Mtetra
.589 .772 .967 r
.74159 .17766 .74627 .19173 .77319 .1896 .76873 .17555 Mtetra
.59 .774 .968 r
.76873 .17555 .77319 .1896 .80023 .18737 .796 .17333 Mtetra
.591 .776 .968 r
.796 .17333 .80023 .18737 .82739 .18505 .82339 .17101 Mtetra
.592 .778 .969 r
.82339 .17101 .82739 .18505 .85466 .18265 .85091 .1686 Mtetra
.593 .779 .969 r
.85091 .1686 .85466 .18265 .88206 .18017 .87854 .16611 Mtetra
.593 .78 .969 r
.87854 .16611 .88206 .18017 .90958 .17763 .9063 .16356 Mtetra
.617 .786 .963 r
.02946 .11175 .03963 .12441 .0632 .12139 .0532 .10868 Mtetra
.0532 .10868 .0632 .12139 .08686 .11836 .07704 .10559 Mtetra
.07704 .10559 .08686 .11836 .11062 .11531 .10098 .1025 Mtetra
.10098 .1025 .11062 .11531 .13447 .11226 .12501 .09939 Mtetra
.12501 .09939 .13447 .11226 .15842 .10919 .14914 .09627 Mtetra
.14914 .09627 .15842 .10919 .18246 .10611 .17336 .09314 Mtetra
.17336 .09314 .18246 .10611 .2066 .10302 .19768 .08999 Mtetra
.59 .773 .967 r
.19768 .08999 .2066 .10302 .23026 .10987 .22203 .08802 Mtetra
.061 .288 .777 r
.22203 .08802 .23026 .10987 .2533 .13178 .2451 .11152 Mtetra
.205 .416 .847 r
.2451 .11152 .2533 .13178 .27695 .14781 .26881 .12875 Mtetra
.306 .505 .887 r
.26881 .12875 .27695 .14781 .30105 .15966 .29301 .14154 Mtetra
.376 .567 .911 r
.29301 .14154 .30105 .15966 .32551 .16846 .31758 .15108 Mtetra
.427 .611 .926 r
.31758 .15108 .32551 .16846 .35025 .175 .34247 .15821 Mtetra
.463 .644 .936 r
.34247 .15821 .35025 .175 .37523 .17982 .36761 .1635 Mtetra
.491 .669 .943 r
.36761 .1635 .37523 .17982 .40042 .1833 .39297 .16736 Mtetra
.511 .689 .948 r
.39297 .16736 .40042 .1833 .4258 .18572 .41852 .17011 Mtetra
.527 .704 .951 r
.41852 .17011 .4258 .18572 .45135 .18731 .44426 .17195 Mtetra
.54 .716 .954 r
.44426 .17195 .45135 .18731 .47706 .18822 .47015 .17307 Mtetra
.55 .726 .957 r
.47015 .17307 .47706 .18822 .50292 .18857 .49621 .1736 Mtetra
.557 .735 .958 r
.49621 .1736 .50292 .18857 .52892 .18847 .52241 .17364 Mtetra
.564 .742 .96 r
.52241 .17364 .52892 .18847 .55505 .18798 .54875 .17327 Mtetra
.569 .748 .961 r
.54875 .17327 .55505 .18798 .58132 .18716 .57523 .17256 Mtetra
.573 .753 .962 r
.57523 .17256 .58132 .18716 .60772 .18607 .60184 .17155 Mtetra
.577 .757 .963 r
.60184 .17155 .60772 .18607 .63424 .18475 .62858 .17029 Mtetra
.58 .761 .964 r
.62858 .17029 .63424 .18475 .66089 .18322 .65545 .16882 Mtetra
.582 .764 .965 r
.65545 .16882 .66089 .18322 .68767 .18152 .68245 .16715 Mtetra
.584 .767 .966 r
.68245 .16715 .68767 .18152 .71457 .17966 .70957 .16532 Mtetra
.586 .769 .967 r
.70957 .16532 .71457 .17966 .74159 .17766 .73682 .16335 Mtetra
.588 .772 .967 r
.73682 .16335 .74159 .17766 .76873 .17555 .7642 .16125 Mtetra
.589 .774 .968 r
.7642 .16125 .76873 .17555 .796 .17333 .7917 .15903 Mtetra
.59 .775 .968 r
.7917 .15903 .796 .17333 .82339 .17101 .81933 .15671 Mtetra
.591 .777 .969 r
.81933 .15671 .82339 .17101 .85091 .1686 .84708 .1543 Mtetra
.592 .778 .969 r
.84708 .1543 .85091 .1686 .87854 .16611 .87496 .15181 Mtetra
.592 .78 .969 r
.87496 .15181 .87854 .16611 .9063 .16356 .90297 .14924 Mtetra
0 g
.89362 0 m
.98022 .38351 L
s
.98022 .38351 m
1 .65325 L
s
1 .65325 m
.91448 .33294 L
s
.91448 .33294 m
.89362 0 L
s
.02946 .11175 m
0 .4272 L
s
0 .4272 m
.91448 .33294 L
s
.91448 .33294 m
.89362 0 L
s
.89362 0 m
.02946 .11175 L
s
.02946 .11175 m
.89362 0 L
s
gsave
.44797 -0.02478 -66.3961 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(w) show
69.062500 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
0 .4272 m
.29069 .70824 L
s
gsave
.15892 .66839 -66.3192 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(P) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellMargins->{{Inherited, Inherited}, {0, 8}},
  ImageSize->{335, 112.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005?0000L1000`40O003h00OogooD7oo003oOom@
Ool00?mooe1oo`00ogooD7oo003oOom@Ool00?mooe1oo`00ogooD7oo003oOom@Ool005Eoo`03001o
o`000:=oo`03001oo`00055oo`00E7oo00D007oo001oo`000:5oo`05001oo`00Ool0001@Ool005Ao
o`05001oo`00Ool0002QOol01@00Ool007oo0000D7oo001COol300000goo0000002POol300000goo
0000001@Ool00?mooe1oo`00ogooD7oo003oOom@Ool00?mooe1oo`00ogooD7oo003oOom@Ool00?mo
oe1oo`00ogooD7oo0024Ool5002QOol4000QOol007aoo`T000=oo`03001oogoo09Moo`P000=oo`03
001oogoo01moo`00M7oo2@002goo00<007ooOol0Sgoo20002goo00<007ooOol07goo001/Ool9000C
Ool20028Ool8000COol2000POol006Aoo`T001]oo`80081oo`P001]oo`80021oo`00G7oo2@008goo
0P00N7oo20008goo0P0087oo001DOol9000[Ool2001`Ool8000[Ool2000POol004aoo`T003=oo`03
001oo`0006Moo`P003Aoo`8001moo`00A7oo2@00>goo00<007oo0000Ggoo2000?7oo0P007goo000l
Ool90013Ool00`00Ool0001GOol80014Ool2000OOol003Aoo`T004aoo`8004moo`P004aoo`8001mo
o`00;7oo2@0000YoodlNBae??T/MCai;7DlnBae?7TYoo`8004Moo`P0000:Oom;7DlnBae?7T/MCci;
7D/NA_e:Ool00`00Ool0000NOol002Qoo`D00004Oom?7TlNBah3Cah01D/NCai?7TlNBah00dlN00A;
7SJn=[h164Uoo`03001oo`00049oo`@00003Oom?7T/N00=?7P05Bai?7TlNCai;7P03Cah014/NCahV
OBYn0PDHB7oo00<007oo00007Woo000XOol06@00Bae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/M
Cai;7DlnBae?7SJn>]hf_PDH04Qoo`03001oo`00049oo`0I001;7DlNBae??T/MCai;7DlnBae?7T/M
Cci;7DlNBae??T/MCai;7BYn9Ud=F@DG6KX0Agoo00<007oo00007Woo000XOol00`00Oom;7P03Cah0
1D/NCai?7TlNBah00dlN00E;7TlNCai?7T/N00=?7P053M/=g0DH5IXAN@16Ool00`00Ool00012Ool0
1@00Cai?7TlNBah00dlN00E;7TlNCai?7T/N00=?7P0:Bai?7TlNCai;7RIn9Wd=>@DH6IY6Ool00`00
Ool0000NOol002Qoo`0I001oo`00Bae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7DlnBae?
7PgK3ET00QFJ00<ANGooOol0@goo00<007oo0000@Woo01/007ooCci;7DlNBae??T/MCai;7DlnBae?
7T/MCci;7DlNBae??T/MCah0m`5j2CP=FAFJ6KX0AGoo00@007ooOol001eoo`00:7oo00D007ooOol0
04/N00=?7P05Bai?7TlNCai;7P03Cah01D/NCai?7TlNBah00TlN00D160Th1APEVQVJ008Qfd=oo`03
001oo`00049oo`03001oogoo00=?7P05Bai?7TlNCai;7P03Cah01D/NCai?7TlNBah00dlN00D4m`5I
2CP=>AVj008Und=oo`04001oogoo000MOol002Qoo`0P001oogooOom?7T/MCci;7DlNBae??T/MCai;
7DlnBae?7T/MCci;7DlN@]i2oT;N4GT9>1Vj5IXI^QgK;S`Z745oo`04001oogoo0011Ool07P00Oomo
od/MCci;7DlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??RYm1AP0ma5i3ETM^aVj9Q`Qn`8^?41o
o`04001oogoo000MOol002Moo`03001oogoo00=oo`03Cai;7TlN009?7P05Bai?7TlNCai;7P03Cah0
14/NCai?7TlN0Q7l00<0n15i2CP00Qfj00HUnbXL:S`Z739M<U`nOol01000Oomoo`00@7oo00<007oo
Ool00Woo00E;7TlNCai?7T/N00=?7P05Bai?7TlNCai;7P03Cah01T/NCah^OPDH1?LAF@8Qf`039O/Z
72hl008^?003=WdfGGoo031oo`a;7P04001oogoo000MOol002Moo`03001oogoo00Aoo`0OCai;7Dln
Bae?7T/MCci;7DlNBae??T/MCai;7DlnBadAo0gL3CPAFA5i6KXMfaVj9O`Z?2hl<U`bGBiL>Yd00SIm
00<jWCjNOol0;Woo00Y;7TKnBai6oT/NA_i;7TKnBah0009oo`03001oogoo03ioo`03001oogoo00=o
o`0KBae??T/MCai;7DlnBae?7T/MCci;7DlNBae??T/MCai;7@4i2AL9>1Ei8M/MfR7K9O/Z72hl008b
G08fO@04>YdfO3jn>YdPOol04T/NA_e;7TKnBai6oD/NA_i;7TKmBai6oT/NA_e;7T[nBai6oP=;7P05
A_i;7T/NBah00002Ool00`00Oomoo`0JOol002Moo`03001oogoo00Aoo`03001?7T/N00=?7P05Bai?
7TlNCai;7P03Cah00d/NCai?7P024O`01PCg4ETANAgJ8M/V6`<^?003<UdfOCIm008fO@8jW@Dn_A]o
o`96oP0>Bai6oTKnA_i;7TKnBai77T/NA_i;7TLNBai6oP=;7P06Aai;7T/NBai77P000Woo00<007oo
Ool0?Woo00<007ooOol017oo00E;7TlNCai?7T/N00=?7P05Bai?7TlNCai;7P03Cah01@CF4EP961fj
5GT00RGk00L^72XK<U`b?39L=W`fO@03>Yd2?Yd3?[d01d:m@]i2_D;N@]e6gT;M0096gP03A_i6gDKn
00U6oP0>B_i6oT[nA_i:oTKnB_i6oT/NA_i;7T[nBai:oQ9;7P04001oogoo000LOol002Moo`03001o
ogoo00Eoo`0O001?7T/MCci;7DlNBae??T/MCai;7DlnBae?7SkN@_l4eP3g2ALIVQEi8M/M^Rhl9O/b
G2hl=WdbG3Im=W`00SZM01/n_CZM?[hjWD;N?[e2gSjm@]hn_DKN@]e2gT;MA_i2gDKn@]e6oT;MA_i6
gDKnA_e6oTKmB_h00TKn01e6oD/NA_i;7TKmBai6oT/NA_e;7TKnBai6oD/NA_i;7TKnBai6oT/NA_i;
7TKnBai6oT/NA_i;7P0000=oo`03001oogoo03eoo`03001oogoo00Eoo`0OBae??T/MCai;7DlnBae?
7T/MCci;7DlNBae??Qhm1?L1>15I2ALM^R7J9O/^6bhl:Q/fGC9L=WdfG3jM>Wd00SZM030n_SjM@[hn
_D;N?[e2gT:mA]i2gDKN@]e6oT;MA_i6gDKnA]e6oTKMB_i6oD[nA_e;7TKmBai6oD/NA_e;7TKmBai6
oT/NA_e;7TKnBai6oD/NA_i;7TKmBai:oT/NA_d3Bah01dKnBai;7T/NB_i;7P00009oo`03001oogoo
01Yoo`009goo00<007ooOol01Woo0TlN00E;7TlNCai?7T/N00=?7P04Bai?7TlNCah2?]h02`3g5ET9
61FJ5GTUnbXK:Q`^?39L;S`00cIm00@jOCZM>YdnW@<n_@0:@]hn_D:m@]e2gT;M@]i2gDKn@]d2A]h0
0dKnA]i6oP0=A_h03T[nA_i6oTKnBai6oT/NA_i;7TKnBai77T/NA_h3Bah01DLNBai;7T/NAah00T/N
00D007ooOomoo`0003moo`03001oogoo00Eoo`03Cai;7TlN009?7P05Bai?7TlNCai;7P03Cah02T/N
Cah=5`Cg4CPAF1fJ7KXUfbGk0Rhl0S9L00LfOCYm=W`nWCZM?[dnW@02?[d03T:m?[e2gD;MA]i2gD;N
A]e6gT;MA_i6gTKnA_d6A_h01T[nA_i:oTKnBai6oP9:oP06Bai6oT/NB_i;7T[n0d/N00=:oT/NBah0
3T/N00@007ooOol001aoo`009goo00<007ooOol01goo025;7DlNBae??T/MCai;7DlnBae?7T/MCci;
7@5j0ET8ma5H5ETIVAfj8M/UnbhK;S`b?39M<S`jOCIl>YdfO3jn>Yd00Sjm01A2_Sjm@]hn_D;N@[e2
gT;MA]i2gDKn@]e6oT;MA_i2gDKnA]e6oTKM0dKn01m6oD/NA_i:oTKmBai6oT/NA_e;7TKnBai6oD/N
A_i;7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBah00003Ool00`00Oomoo`0mOol00`00Oomoo`06
Ool0DTlNBae??T/MCai;7DlnBae?7T/MCci;7DlNBadNG@dG1?L=>27K8KXZ6bGk<S`^6bhl<U`fOCYl
>YdjW3jM>Ye2_CjM@[hn_D;N@[e6gT:mA]i2gDKnA]e6oTKMA_i6gDKnA]e:oTKmB_i6oD/NA_e:oTKm
Bai6oD/NA_e;7TKnBai6oD/NA_i;7TKmBai6oT/NA_e;7T[nBai6oD/NB_i;7T[n0d/N00E:oT/NBai;
7P00009oo`03001oogoo01Yoo`009goo00<007ooOol01goo00@004lNCai;7P=?7P05Bai?7TlNCai;
7P02Cah03`5j3ALINA5H8MXMVQfj:O/^?2hL;S`fG3IM=W`fO@03>Yd2?Yd3?[d02d:m@]i2_D;N@]e6
gT;M@]i6gTKn@]d03TKn00i;7TKnA_i6oT/NA_i;7TKnBai6oT/NA_i;7TKn0d/N00=77T/NBah01T/N
00D007ooOomoo`0003moo`03001oogoo00Moo`03Cai;7TlN009?7P06Bai?7TlNCai;7TlN0SkN00@8
ePdG3ALIN@<Q^P06;Q`^6c8l<S`fGCIL0SYm00HjWCjM?YdnWD:m?[d2@[d02T;N@]e2gD;MA]i2gDKN
A]e6oTKM0dKn00A6oDKnA_i:oP=6oP0:B_i6oT[nB_i;7T[nBai:oT/NB_h3Bah00d[nBai;7P0@Bah0
1@00Oomoogoo00006goo000WOol00`00Oomoo`08Ool07P00Bae?7T/MCci;7DlNBae??T/MCai;7AXm
0=H1NPCF7ITAF27K8KXZ72Gk<S`^>cIm<U`fOCIl?YdjW@8nW@0i?[hnWD:n?[e2gT:m@]i2_DKN@]e6
gT;MA_i2gDKn@]e6oTKMA_i6gDKnA_e6oTKmBai6oD[nA_e;7TKnBai6oD/NA_i;7TKmBai6oT/NA_e;
7TKnBai6oT/NA_i;7TKnBai6oT/NA_i;7TKnBah004/N009oo`03001oogoo03eoo`03001oogoo00Qo
o`0>Cai;7DlnBae?7T/MCci;7DlNBae??SkN?_hE=`8=5`066GTUfRWk:Q/^72XK0SIL00HjOCIL?Ydj
O3jm>Yd2?[d2@[d0;4;N@[e6gT:mA]i2gDKN@]e6oTKMA_i6gD[nA_e:oTKMB_i6oD[nA_e;7TKmBai6
oD/NA_e;7TKmBai6oT/NA_e;7T[nBai6oD/NB_i;7TKmBai:oT/NB_d3Bah024[mBai;7T/NB_i;7P00
Bah2Ool00`00Oomoo`0IOol002Moo`03001oogoo00Uoo`04001?7TlNBah3Cah024/NCai?7TlN0=HA
5PCF4CP26GT0126j8MX^6bhK0c8l00@fO3IL>WdjO@<nW@<n_@0>@[dn_D;M@]e2gT;M@]i6gDKN@]e6
oTKNA_i6gPY6oP0>B_i6oTKnA_i;7TKnBai6oT/NA_i;7T[nBai6oP=;7P03A_i;7T/N00Q;7P03001;
7Woo009oo`03001oogoo03aoo`03001oogoo00Uoo`03Cai;7TlN009?7P08Bai?7TlNCai;7PcE0;D<
mP8EF00?7ITUnbGJ9M/b>c8l<U`fG3Yl>WdjWCjM>Ydn_CjM00A2_@92g@06A]i2gDKNA]e6gTKM0dKn
00=6gDKnA_h00TKn00A:oTKnB_i6oP9:oP0:Bai:oT/NB_i;7T[nBai:oT/NB_h3Bah00d[nBai;7P0>
Bah01@00Baioogoo00006goo000WOol00`00Oomoo`0:Ool05TlnBae?7T/MCci;7DlNBae??T/M1=LJ
70CG6EPA>1Ui7ITUfRhL:Q/^738l0SIL03ljOCYl?YdjWCjm>Ye2_CjM@[hn_D;N@[e6gT:mA]i2gDKN
@]e6oT;MA_i6gDKnA]e6oTKmA_i6gD/NA_e:oTKmBai6oD/NA_e;7TKnBai6oD/NA_i;7TKmBai6oT/N
A_e;7TKnBai6oT/NA_i;7TKnBai77T/NA_i;7P00Bah00goo00<007ooOol0?7oo00<007ooOol02Goo
01];7DlNBae??T/MCai;7DlnBae?7T/M0=HE5aUH5CLYfQfI;Q/YnS8l;Q/jO3IL>WdjO3Ym>Y`00SjM
02i2_Cjm@]i2_DKN@[e6gT;MA]i2gDKnA]e6oTKMB_i6gD[nA]e:oTKmB_i6oD/NA_e;7TKmBai6oD/N
A_e;7T[mBai6oD/NB_i;7TKmBai:oT/NB_e;7T[nBai:o@=;7P03B_e;7T/N00E;7P05001;7WooOol0
000KOol001Uoo`8000aoo`03001oogoo00]oo`=?7P09Bai?7TlNCai;7R9M0=H4ea3f008IF00:8KXQ
VBGK9MXb?2hK=U`bG3IL>W`3>Yd3?Yd01D:m?[e2_D:m@]h00d;M00I6gT;MA]i6gDKnA]d3A_h00dKm
A_i6oP04A_h03T[nA_i6oTKnBai6oT[nA_i;7TKnBai:oT/NA_h3Bah00dKnBai;7P0;Bah01@00Oomo
ogoo0000;goo0P003Goo00<007ooOol02Woo0TlN00];7TlNCai?7T/NCah0edlN3=DI=`SF008EF00:
9MXYnbgk:O/f?3IL>U`fG3im>W`2?Yd6@[d01DKM@]e6gDKMA]h00dKM00Y6oTKMA_i6oD[nA_e:oTKn
B_i6oPI:oP06Bai:oT/NB_i;7T[n0d/N00=:oT/NBah044/N00<004/NOol00Woo00<007ooOol067oo
000HOol2000=Ool00`00Oomoo`0;Ool04@00Cci;7DlNBae??T/MCah@mATF0=HMF25h6GTU^R6j:OX0
0RhK00Pb?2hK>W`fG3Ym=U`nWCZL0SjM03Y2_Cjm@[e2_D;N@[e6gT:mA]i2gDKN@]e6oTKMA_i6gDKn
A]e6oTKMB_i6oD[nA_e;7TKmBai6oD/NA_i;7TKmBai6oT/NA_e;7TKnBai6oD/NA_i;7TKnBai6oT/N
A_i;7TKnBai6oT/NAai;7TKn001;7P9oo`03001oogoo02aoo`8000ioo`03001oogoo00]oo`0EBae?
7T/MCci;7DlN?]hLm@3F4=DE5QTg7GPQVBFi:MX^6c8K<S/fG3YL008jO004?YdjO4:m?Y`2@[d0:T;M
@[e6gT:mA]i2_DKnA]e6oTKMA_i6gD[nA]e:oTKmB_i6oD[nA_e;7TKmBai6oD/NA_e;7T[mBai6oD/N
B_i;7TKmBai:oT/NB_e;7T[nBai:o@=;7P05B_e;7T/NBai:o@04Bah014lN001;7T/N0Woo00<007oo
Ool067oo000GOol01000Oomoo`002goo00<007ooOol03Goo00D004lNCai?7T/N00=?7P0:7UdDmP3F
4AHQVAUH9MX]nbWk;O/2=S`2=U`00cYl?WdjW@02?Yd00d:m?Ye2_@03@[d2@]d02TKN@]e6gTKMA]i6
gDKnA]e6oTKm1TKn00i:oTKnA_i6oT[nA_i:oTKnBai6oT/NB_i;7TKn0d/N00=:oT/NBah03D/N00D0
04/NOomoo`0002eoo`04001oogoo000<Ool00`00Oomoo`0=Ool2Cah03D/NCai?7T;n6?@0eadf9GPE
=bVi7GP]nRgJ008b6`03>U`fFcYl008jO004?Y`nWCjM@Yd3@[d00dKM@[e2_@05A]d02TKnA]e6oDKm
B_i6oD[nA_e:oTKm0d[n00U:oD[nB_i;7T[nBai:oT/NB_h064/N00<004/NBah00Woo00<007ooOol0
67oo000GOol01000Oomoo`002goo00<007ooOol03Woo01<004lnBae?7T/M4GX=NACf5?DI5QTg8ITQ
N2WJ9KXb6bhK=U`b>`02=U`0>3jM>W`nWCjL@[dnW4:m?Ye6gT:mA]i2_DKN@]e6gT;MA_i2gDKnA]e6
oTKMA_i6gD[nA_e:oTKmB_i6oD/NA_e;7TKmBai6oD/NA_i;7TKmBai6oT/NA_e;7TKnBai6oD/NA_i;
7TKnBai:oT/NA_h3Bah01DKnBai;7P00A_h00goo00<007ooOol0:Woo00@007ooOol000aoo`03001o
ogoo00ioo`0IBae?7T/MCchM5D;n6=@0e`cE9GPE5RVi:MX]nS8K=S`f>cYL=S/nWCYl?YdnO4:m?Y`0
0T:m02Q6gD:mA]e2_DKNA]e6gTKMB_i6gD[nA]e:oTKMB_i6oD[nA_e:oTKmBai6oD/NA_e;7T[mBai6
oD/NB_e;7TKmBai:oD/NB_e;7T[nBai:o@=;7P06B_e?7T/NBai:oDlN0T/N00=;7DlNBah00T/N00D0
04/NOomoo`0001Yoo`005goo00@007ooOol000]oo`03001oogoo00moo`0;Bai?7TlN?[d=N@ej9CDI
5QCe:IPY^@028IT02Rgj<Q/b6c8K>U`fG3Yl>U`nWCjL0SjM00=2WD:m@[d00d:m00Y6gD;MA]e6gDKN
A]e6gTKMA_i6g@=6oP09A_e6oTKnB_i6oT[nA_i:oTKn009:oP06Bai6oT[nB_i;7T[n0d/N00=:oT/N
Bah03d/N00<004/NOol00Woo00<007ooOol0:Woo00@007ooOol000aoo`03001oogoo00moo`0>Cahe
MT/NCai2oQce0=HM=R5h9GPU^C8J;MX]nP8f>`03>U`nO3Yl008nO003@YdnW4:m00A2_@E6g@0:A]i6
gDKMA_e:oTKmB_i6oD[nA_d3B_h014[mB_i:oT/N0d[n00=;7T[nBah00T/N00=:oT/NBah05D/N00<0
04/NOol00Woo00<007ooOol05goo000GOol01000Oomoo`002goo00<007ooOol03goo00mAmDgDDODj
WBdd3ETY=REF6AHUMaeH:KT]fBgJ<O/00cHk00PjG3Yl?W`jO3jM?Wa2_CjL14:m02a6gT:mA]i2_DKn
A]e6oTKMB_i6gD[nA]e:oTKmB_i6oD[nA_e:oTKmBai6oD/NA_e;7TKmBai6oD/NA_i;7TKmBai6oT/N
A_e;7T[nBai6oD/NB_i;7TKn0d/N00I6oT/NBai;7TKn0002Bah2Ool00`00Oomoo`0ZOol01000Oomo
o`0037oo00<007ooOol03goo0199]35e=GI;7B4e6?@LmAdF9GPQMc7j9ITf6c7j=S/b6cil>U/2?W`0
2T:M?Ya2WD:LA[e2W4KM@[e6gTJm0TKM02E:oTKMB_i6gD[nA]e:oTKMB_i6oD[nA_e;7T[mBai6oD/N
B_e;7TKmBai:oD/NB_e;7T[mBai:oDlNB_i;7T[mCai:oT/NB_e?7P02Bah01T[mCai;7T/NBae?7P=;
7P04Cai;7P00Bah3Ool00`00Oomoo`0GOol001Qoo`8000aoo`03001oogoo00moo`06DOAAmDgd>E<]
=0ej0RDe00<UERVH9GP00RVi00<f6c8J=S/00SHk00HjG3il?W`nO3jL?Yd2@[d01D:M@[e2_DKM@[d0
1TKM00I6oTKMA_i6oDKnA_d2A_h00d[nA_e:oP02B_h014KnB_i:oT/N0d[n00I;7T[nBai:oT/NB_h3
Bah00d[nBai;7P0=Bah00`00Bai;7P02Ool00`00Oomoo`0[Ool2000=Ool00`00Oomoo`0?Ool03DFC
CaheMCEf8AD]EQSd;IL]^25h<MTafS7j008b6P08>U/j>cil?Wa2W3il@Ye2W092_@04A[e2_DKMA[d6
A]d02T[mA]e:oD[mB_i:oD[nB_e:oT[m0d[n00U:oD[nB_i;7T[nBai:oT/NB_h06D/N00<004/NOol0
0Woo00<007ooOol05goo000VOol00`00Oomoo`0?Ool06U7eCOAAmCUC?[hY52Te9CDYMc6h:IPUMcGj
<OXf6c7j>U`j>cil>U]2WCil@Y`nW4:m@Y`2@[d0;4KM@[e6gD:mA]i6gDKNA]e:oTKMB_i6gD[nA]e:
oTKMB_i6oD[nA_e;7TKmBai6oD/NA_e;7TKmBai:oD/NA_e;7T[nBai6oD/NB_i;7TKmBai:oT/NA_d3
Bah01DKnBai;7T/NA_h00T/N00<004LNBah00goo00<007ooOol0>Goo00<007ooOol03goo00i9]4FC
=IHaMCEE;EDLmBUg8CH]V37j;MTanSHJ0SXk00XjG3iK@W`nNd:L?Wa6_D:LA[e2_096_@0SA]e6_D[N
A]e:oTKMB_i6gD[nA]e:oTKMB_i6gD/NB_e;7T[mBai:oD/NB_e;7T[mBai:oDlNB_e;7T[mCai:oD/N
B_e?7P02Bah01T[mCai;7T/NB_e?7P9;7P0<Bae?7T/NCai;7DlNBai?7T/N001;7TlN0Woo00<007oo
Ool05goo000VOol00`00Oomoo`0?Ool01TgdDOAAm3UC>Yd]=08U=@03<ILUEc6h008af@05>S/j>SXk
>S/jF`05?W`014:M@Ya2_D:m0dJm24KM00M6oD[nA]e:oTKmB_i6o@03B_h00d[mB_i:oP04B_h01T/N
B_i;7T[nBai:oQE;7P03001;7T/N00=oo`03001oogoo03Uoo`03001oogoo00moo`95T`8eM@03<E@Q
5BeE008]M`8]^004=QXenSXk=QX3?U/2@W`3@Y`014Jm@[a6_DJm14KM0T[M00=:oDKMB_d01D[m00I:
oT[mB_i:oD[nB_d2B_h00d/NB_e;7P02Bah00d[nBai;7P0IBah00`00Bai;7P03Ool00`00Oomoo`0F
Ool002Ioo`03001oogoo011oo`0CCMAAmCUC>E@Y4cVF9CDY=C6G<MTa^3XJ<MTj>cXJ>S/nFd9l?W/0
0Sil00U2WD:LA[e2W4KM@[a6gD:mA]h00dKM02Q:oTKMB_i6gD[nA]e:oTKMB_i6oD[nA_e;7TKmBai6
oD/NB_e;7TKmBai:oD/NA_e;7T[mBai6oD/NB_i;7TKmBai:oT/NB_e;7T[nBai:o@=;7PH000=;7P9o
o`03001oogoo03Uoo`03001oogoo00moo`0>BKA5TcEf<GDeMC5D;GHYMRfG=MPinCGi>QXen@8nF`0m
?W`nFd:L?W]6_D:LA[a6W4JmA[a:gDJlB]e6gD[MA]e:oD[MB_e6gD[nB]e:oT[MB_i:oD[nB_e?7T[m
Bai:oDlNB_e;7T[mCai:oDlNB_e?7T[mCai:oDlNB_e?7T[mCai;7TlNB_e?7T/NCai;7DlNBai?7T/M
Cah01P0000=;7TlnOol00Woo00<007ooOol05Woo000VOol00`00Oomoo`0@Ool01E7eCO@iDcUC;C@0
0SFF00TU=C6g>OTaf36h>QXj>SXk>SX00SiK0T9l0T:L00=2_D:lA[d00dJm00=6gDJmA]d01DKM00Y:
oTKMB_e:oD[nB_e:oT[mB_i:o@9:oP0:Bai:oT[nB_i;7T[nBai:oT/NB_h3Bah00d[nBai;7P02Bah:
0005Bah01000Bai;7T/N0Woo00<007ooOol0>Goo00<007ooOol03goo0TFC00HmLcEf<E@eE2eE>MP2
;GL01SGI?SXn6Shj?S/nF`=2N`08AYa2W4JL@Ya6_DJlA]e6_@96g@06B]e6gD[MB]e:oD[M14[m00Y:
oT[mB_e:oD[nB_e:oT[mBai:o@9:oP03Bai:oD/N009;7P03B_i;7T/N00Q;7PX000E;7P03001;7T/N
00=oo`03001oogoo01Ioo`009Woo00<007ooOol047oo00m=m57e>E<iM3fE;C@eUSVF<ILe^3Wh?OTi
nCXJ?SX00T9K02M2O3ik@Ya2NdJL@Ya6_DJlA[e6_4[MA[e:gDJlB_i6gD[nA]e:oTKMB_i6gD[nA_e:
oTKmB_i:oD[nA_e;7T[mBai6oD/NB_e;7T[mBah02P0000E:oD/NBai;7T[m00=;7P03B_i;7T/N00E;
7P03001;7T/N009oo`03001oogoo03Uoo`03001oogoo00moo`0DBKA5Td6D<GDeEC5D?ML]ECWH=KLi
nCGH?SXn6DIk@UY2O3iK@Wa2N`96W00SB[e6W4ZmA[a:gDJlB]e6g4[mB]e:oD[MB_i:gD[nB]e>oT[m
B_i:oDlNB_e?7T[mCai:oDlNB_e?7T[mCai:oDlNB_e?7P0:00004d/NCai;7DlNBai?7T/MCai;7TlN
Bae??T/NCai;7Dln001?7T/N009oo`03001oogoo01Ioo`009Woo00<007ooOol047oo0U7d0SUC00I1
UBdd>IHeUSgh?ML2>OT0148j?SXnFchj0d9k00U2W4JLAYa6_4JLA[e6_4KMA[d00TKM00I:gDKMB]e:
gD[mA]d6B_d014[nB_e:oT[m2P000d/N00=:oT/NBah054/N00<004/NBah00goo00<007ooOol0>7oo
00<007ooOol03goo0TFC00@mLced<E@eE08m]P04>KLif3hI?QT2?SX01D9J@U]2FdJKAW/00TJL00I:
W4JlB[a6_4ZmB]`6B]d00d[mB]e:o@05B_d01T[nB_e:oD[mCai:o@X00005Cai;7T/NBai?7P03Bah0
1DlNBai;7T/NCah00d/N00=?7T/NBah01d/N00<004/NBah00goo00<007ooOol05Goo000VOol00`00
Oomoo`0@Ool05dgDDODiDcUD?IA1]CFF>IHmed7h@QQ2>ChI@SXn>DIk@UY6W4IkAYa2NdJmAY`00TJl
00]:gDJlB]e6_4[MA]e:oDKMB_e:gD[m00X0000DB_e;7T[mCai:oD/NB_e?7T[mBai:oDlNB_e;7T[m
Bai:oT/NB_e?7P9;7P05B_e?7T/NBai:o@09Bah00`00Bai;7P03Ool00`00Oomoo`0hOol00`00Oomo
o`0?Ool074VdAI=1U3ec=GDaE3ff>KI663Fg@QTmn48I@SU:NdIJBW]6NdJLAY]:_4JKB[a6W4[MB[a:
gDZl0T[M00M:oD[LC_e:gDkmB]e>oP0:00009d[mCai:oDlNB_e?7T[mCai:oDlNB_e?7T[mCai;7DlN
B_e?7T/MCai;7DlNBai?7T/MCai;7TlNBae??T/NCai;7DlnBai?7P00Cci;7P03Ool00`00Oomoo`0E
Ool002Eoo`03001oogoo015oo`0<DOE=m3UC>E=1]CfEAMHeUSgh?MLmn48I0dIJ00=2FdIKAW/00TIk
0TJL00A:_4JlB[a:_0X000A:o@0>B_i:oD[nB_e:oT[mB_i:oD/NB_e;7T[nBai:oP=;7P03B_i;7T/N
01I;7P04001;7T/NBah3000iOol00`00Oomoo`0@Ool2AI<013ec@GA5]CED0cff00U1n3hI@QTn6DIJ
@SY6NdIjAW/00dZK14Zl0T[L2P0001]>oD[mC_e:oDkmB_e?7T[mC_e:oDlNB_e?7T/MCai:oDlNBai?
7T/NCai;7TlNBai?7T/NCah00d/N00E?7T/NBai;7TlN00=;7P05Cai;7T/NBai?7P03Bah00`00Bai;
7P04000GOol002Eoo`03001oogoo015oo`0@BK=AmCUC>G@mUD6e@MI5mcgG?OPmedHi@QQ6FT8iBW/:
00009TJlB]e:_4[MB]a:oD[MB_e:gDknB]e>oD[MC_i:oDknB_e?7T[mCai:oDlNB_e?7T[mCai:oD/N
B_e?7T[mCai:oDlNB_e;7T[mCah2Bah01T[mCai;7T/NB_e?7P9;7P03Bae?7T/N009;7P05Cai;7T/N
Bah00002Bah2Ool00`00Oomoo`0gOol00`00Oomoo`0@Ool01dVdAI=1U3ecAME1]CgG008m]P08@OM:
>DHhBSU6FDYjAWY:N`X0000lB[a>gD[LC_e:g4kmB]e>oD[MC_e:oDlNB_e>oT[mCai:oDlNB_e?7T[m
Cai:oDlNB_e?7T[mCai:oDlNB_e?7T/MCai:oDlNBae?7T/MCai;7DlNBae?7T/NCai;7DlnBai?7T/M
Cci;7TlNBae??T/N001;7Tln0Woo00<007ooOol05Goo000UOol00`00Oomoo`0AOol2CK<2>E<00d6E
?ID000090002AW/2BY/5B[`00d[LB]e:_006B]d8B_d01TknB_e:oD[mCai:o@9:oP03Bai:oD/N009;
7P03B_i;7T/N01U;7P03001;7T/N009oo`03001oogoo03Moo`03001oogoo011oo`95T`05?G<mM4Fe
AME9mP0:0002BY/01TjKBY]>_4ZkC]a>_0=>g09>g@03C]a>oDkM00a>o@0:Cai>oDlNCae?7TlMCai?
7DlNBad3Cah044/NCai;7TlNBai?7T/NCai;7TlNBai?7T/NCai;7TlN0d/N00E?7T/NBai;7TlN009;
7P03001?7T/N009oo`03001oogoo01Eoo`009Goo00<007ooOol03Goo2P0000LmUDGg@MI:>4HGBUU6
>002BUT0=dijBWY>VdYjC[]:VdjlB[]>_4ZlC]a:g4kMB[a>oD[LC_e:g4kmB]e>oD[MC_i:oDknB_e?
7T[mCai:oDlNB_e?7T[mCai:oDlNB_e?7T[mCai:oDlNB_e?7T[mCai;7DlNB_e?7T/NCai:oDlN009;
7P06Bae?7T/NBai;7DlN0d/N00E??T/N001;7Tln009oo`03001oogoo03Moo`03001oogoo00eoo`X0
000CAOI:5dXGCSQ6>4XiASQ:NTIICY]:NTjkBY]>_4ZkC[a>^e;LC[`00TkL00UBoDkLC_e>g4kmC]a>
oD[LCad00Tkm031:oDlNB_e?7T[mCai>oDlNB_e?7T[mCai:oDlNBae?7T[mCai;7DlNB_e?7T/MCai;
7DlNBae?7T/MCai;7TlNBae??T/NCai;7DlnBai?7T/MCci;7TlnBad004/NCch2Ool00`00Oomoo`0E
Ool002Eoo`03001oogoo00=oo`X000Aoo`04CK=9/dgDCM@3COD01dGFAOM65dHHBSU:FDXi009:NP06
CY]:NTZKBY]>^dZk0Tjl00Q>g4ZlC]a>g4kMB]a>gD[M1Dkm015:oDkmC_e>oD[mC_e:oDlNB_e>oD[m
Cai:oDlNBae?7T[m009;7P03Cai;7T/N00E;7P03Cai;7T/N015;7P05001;7T/NOol0000iOol00`00
Oomoo`03Ool:0003Ool2AI<00cec@G@mL`02AKD014WgBOI:>4Xh0diI0Tij00=>NDjJCYX014jk00=>
_4kLC]`00dkL00A>oDkLC_e>o0Y>o@05Cae>oDlMCae?7P03Cad01TlNCae?7TlMCai?7@=?7P05Cae?
7TlNCai;7P03Cah04D/NCai;7TlNBai?7T/NCai;7TlNBai?7T/NCai;7TlN00000T/N0Woo00<007oo
Ool05Goo000UOol6000>Ool014VcCK=9ddgD0dge04iB=dhFDUQ>=e9iCUQBNDiiDYY>VU:KCYYB^djK
D[]>^e;LC[a>g4jkC_e>g4kmB]a>oD[LC_e:gDkmB_e>oD[mCai:oDlNB_e?7T[mCai:oDlNB_e?7T[m
Cai:oDlNB_e?7T[mCai:oDlNBae?7T[mCai;7DlNBae?7T/NCai;7DlNBai?7T/MCai;7TlNBae??T/N
Cai;7Tln0002Bah2Ool00`00Oomoo`0fOol6000=Ool024VdAI=1U3ec@IA1]DGEBOH2BQL0D4hhBQM>
FDYHDYY>NDijCYYBVdjKD[]>Ve;LC[]Bg4kKD]a>g5;lC]aBoDkLD_e>g5;mC_eC7DklDae>oDlMC_eC
7TkmCai>oDlNC_e?7TkmCai?7DlNB_e?7TlMCai:oDlNBae?7T/MCai;7DlNBae??T/MCai;7DlnBae?
7T/MCci;7TlNBae??T/NCci;7DlnBai??P00Cci;7Woo000GOol002Ioo`03001oogoo011oo`9=/`9=
e0==m@=>5P09DUQ>=diiCUUBNDiiCWY>VU:K00=>^`03C[a>^dkL00E>g003C_e>g4km00U>o@0ECae>
oDlMC_e?7TkmCai?7DlNB_e?7T/NCai;7DlNBai?7T/NCai;7TlN00=;7P05Cai;7T/NBai?7P0=Bah0
0`00Bai;7P02Ool00`00Oomoo`0gOol00`00Oomoo`0?Ool2AI<01Cec?G@mLdGEAKD00TWf00=>>4Xg
BSP00U9i00IBVE:JDYUB^U:JD[X3D[/2D]/00e;LC]aBo005D_`02U;mC_a>oDkmD_e>oE;mC_eC7Dkm
1TlM00I?7TlMCai?7DlNCad3Cah00dlMCai?7P09Cah054/NCai?7TlNBai?7T/NCai;7TlNBai?7T/N
Cai;7P00Bai?7Woo000GOol002Moo`03001oogoo00moo`1GBK==ddgDCMA9de8FCOEB=dhFDSM>=e9H
CUQBNDiHDYY>NEJkDYYB^djjD]]B^e;LC[]Bg4kLD_e>g5;mC]aBoDkLD_e>o5;mC_aC7DkmCae:oDlN
C_e?7T[mCai>oDlNB_e?7T[mCai:oDlNB_e?7T[mCai;7DlNB_e?7T/MCai;7DlNBai?7T/MCai;7TlN
Bae?7T/NCai;7DlnBai?7T/NCci;7TlN001??T/N009oo`03001oogoo03Qoo`03001oogoo00ioo`0>
DOA=de7dCM=Am57eDQEB5UHgDUMBF59GEUQBN09BN@1:EYYBVU:kDYYFfe:jE]]BfeKLD]]Bo5;KD_eB
g5;mD_aBoDklD_e>o5<MC_aC7DkmDae>oE<MC_eC7TkmDai>oE<NCae?7TkmDai?7DlNCae?7TlMCai;
7DlNCae?7T/MCci;7DlNBae??T/MCai;7DlnBai??T/MCci;7TlnBae??T/NCci;7Dln001??T/MOol0
01Moo`00:7oo00<007ooOol03Woo00==/dVcCM@00TgD0Tge00]>5ThGCQIFN5IGEWUBN5IiDYUFVU:I
009B^P=B^`03D]]Bg5;K009Bg006D_aBg5;lC_aBoDkl0Tkm00YBoDkmC_e>oDlMC_e?7DkmCae>o@9?
7@06Cai?7DlMCae?7TlM0dlN00a;7DlNCai?7T/NCai;7TlNBai?7T/NCah3Bah01DlNBai;7T/NCah0
24/N00D004/NBaioo`0003]oo`03001oogoo00eoo`03DM=Ae57d009Am09B5@06DSMB=U8fDUMBF59G
0U9i00=F^UJIEYT00eJj00QFfe:kE]aBfeKlD]aFo5;K0U;l00IBoE;lD_eBo5;mD_`2D_d02E<MC_eC
7DlMDae?7E<MCaeC7@03Cad01TlNCae?7TlMCai?7@=?7P03Cae?7TlN00U?7P05Bai?7TlNCai;7P03
Cah024/NCai;7TlNBah004/NCch2Ool00`00Oomoo`0DOol002Uoo`03001oogoo00eoo`03BK==/dWC
009=e09=m@1CFUMF=UYGDUMFN5IGEYUBN5JJDYUFVU:jE]]F^UKKD[YFg5;KE]aBfe;lD]aBo5;LD_eB
o5;mC_aC7DkmDae>oE<MC_eC7DkmDai>oDlNC_e?7TkmCai>oDlNCae?7T[mCai;7DlNB_e?7T/MCai;
7DlNBae?7T/MCai;7TlNBae??T/NCai;7DlnBai?7T/MCci;7TlNBai??T/N001;7TlnOol0000lOol0
0`00Oomoo`0<Ool0557dCM=Am57DDOAAmE8FDOEB=e8FFWQFMeYhEWQJVEIhE[YFVEJkD[X2E[X0AE[K
E]YFo5;KE_aBfeKlD]aFo5;lE_eBo5<MD_aC7E;lDaeBo5<MC_aC7DkmDae>oE<NCaeC7TkmDai?7E<N
CaeC7TlMCai?7E<nCae?7TlMCci?7DlNBae??TlMCci;7DlnBae??T/MCci;7TlnBae??T/NCci;7Dln
Bai??T/M001;7TlnOol0000FOol002Yoo`03001oogoo00aoo`9=/`==e09J=@=FEP08EWQFEeIhFYQJ
VEJIE[UFV@=F^P9Ff`05E]YFfeKKE_aBf`06D_`02U;mD_aBoE;mDae>oE<MC_eC7Dkm1TlM00I?7TlM
Cai?7DlNCad3Cah01DlMCai?7TlNBah00dlN00Q;7TlNBai?7T/NCai;7TlN0d/N00E?7T/NBai;7TlN
009;7P05001;7T/NOol0000mOol00`00Oomoo`0;Ool00e7CDOAAm002DO@3DQD00e8fFUIFM`02FWL0
0eZIEYQFV003F[T015ZjE[YFfeKJ0UKK00=FneKKE_`00UKl00UBo5KlE_aFo5;lD_eBo5<MD_d01e<M
00A?7E<MDaeC7@=?7@0:Cai?7DlNCae?7TlMCai?7DlNCadBCah02TlnBai?7TlNCch004lNBaioo`00
5Woo000[Ool00`00Oomoo`0;Ool0FTVcCM==e4gDFSAJ=EHeFUMF=UYGFWMNV5YgFYUFV5ZIEYUJ^UJj
F]YF^E[JE]YFfe;KE_aFfeKlD]]Fo5;lE_aBo5LMD_aC7E;lDaeBo5<MC_eC7DkmDae>oE<NC_eC7Tkm
Dai?7DlNCaeC7TlMCai;7DlNCae?7T/MCai;7DlNBae??T/MCai;7DlnBai?7T/MCci;7TlNBae??T/N
Cai;7DlnBai??T/NCch004lnOol003ioo`03001oogoo00Yoo`0ADOA=de7dCM=Am57eDQEAmEYgFUIJ
MUIgFWQJV5jhFYQJ^P02F[T05UJjF]YFfU[KE]YJo5KKF_]Ffe[lE_]Fo5;kEaeBo5LMD_aG7E;lEaeB
o5LM0U<M031BoE<MDaeC7DkmDai?7E<NCaeC7TlMDai?7E<nCaeC7TlMDci?7DlnCae??TlMCci?7Dln
Cae??T/MCci;7DlnBae??T/NCci;7DlnBai??T/MCci;7P00Bae??Woo000FOol002aoo`03001oogoo
00Yoo`06CK=9/dgDCMAN=EHe0UXe00IFEUifFWMJMeZGFWL2FYP3F[T025ZjF]YF^U[KF]YJfeKKE_/6
E_`01E;lE_aBo5<MD_d00e<M00QBoE<MDaeC7DlMDae?7E<M0dlM00I?7TlMCai?7DlNCad3Cah01DlM
Cai?7TlNBah00dlN00Q;7TlNBai?7T/NCai;7TlN0d/N00Y?7T/NBai;7TlNBah004/NCah003moo`03
001oogoo00Uoo`03DM=Ae57d009Am09B5@06FUEJEUYFFUIJN5jG0UZH00EN^5ZiF[UN^EkI00=JfP9J
f`=Jn`03E_]Fo5Kl00AFo006EaeFo5LLDaeG7E<L2e<M00U?7E<MCaeC7TlMCai?7DlNCad00dlN00=?
7DlNCah014lN00E??TlNCai?7Tln00=?7P0<Cci?7TlNCai??T/NCah004lnBaioo`005Woo000]Ool0
0`00Oomoo`08Ool04TgCBK==/dWCGUEJ=5XeESEJ=EHfGWIJEUjHFWMNV5ZHG[QJV09J^@17G]YJfEkJ
E]YJneKJF_]Ffe[kE_]Jo5;kEaaBo5LLD_aG7E;lEaeBo5LMD_aC7E;lDae>oE<MC_eC7TlMDai?7E<N
Cae?7TlMDai?7DlNCae??TlMCai;7DlnBae?7T/MCci;7DlNBae??T/NCai;7DlnBai??T/MCci;7Tln
Bae??T/NCch004lnBah00010Ool00`00Oomoo`08Ool0;e7dCM=Am57DDOAJ=EiEFSEJMUYFFWMNMejG
FWMN^EZHG]UJ^5kIF[UNfU[IG_YJfUkkF]YNne[jF_aFne/LE_]K75KkFaaFo5LMD_aG7E<LEaeBo5LM
DaaG7E<LEad00U<M02Y?7E<nCaeC7TlMDci?7E<nCaeC?TlMDci?7E<nCae??TlMDci?7DlnCae??TlM
Cci;7DlnCae??T/MCci;7TlnBae??T/NCci;7Dln001??Woo000FOol002ioo`03001oogoo00Moo`06
BK==/dfcCMAJ=5hd0UXe00AF=EifGWINMP9JM`07GYMN^5jHG[QN^EkIG[T00U[J00=Jne[JF]X00U[k
00AJfe[kF_]Jo0=Fo006EaaFo5LLEaaC7E;l1e<M00A?7E<MDaeC7@=?7@06Cai?7DlNCae?7TlM0dlN
00=?7DlNCah01DlN00a;7TlNCai?7T/NCai;7TlNBai?7T/NCah3Bah01000Bai;7P00@Goo00<007oo
Ool01goo00=Ade7dDO@00U7d00=JEEXeFUD00UYF00ANMUjGGYMNU`=N^006G]UJ^EkIG]UNfUkI0ekj
1E[k00=K75KlFa`00eLL00MG7ELLEaeG75LMDaeG7@0=Dad01U<NCaeC7TlMDci?7@9?7P05Cci?7DlN
Cai??P03Cah01DlnCai?7TlNCch00dlN00Y??TlNCai?7TlnBah004lNCch001Ioo`00;goo00<007oo
Ool01Woo01]=/dVcCM=J=5iEFSAJ=EHeHWEJEUifFUIRUejFH[MJV5jhG[MNfEjiG]UJfEkjG]UNne[J
G_/00U[k011Fne/LE_]K75KkFaaFo5LLD_aG7EKlEaeBo5LMDaaG7@AC7@0[CaeC?TlMDai?7E<nCaeC
7TlMDci?7E<NCaeC?TlMCai;7DlnCae??T/MCci;7DlnBae??T/NCci;7DlnBai??T/MCci;7TlnBai?
?T/N001;7Woo0000@Goo00<007ooOol01Woo05]Am4gCDOA=dfZeFSENEEXeFWMNMV:FGWENV6:FH[QN
Uf:hG[QRfEjhG_YJfF;jF]YNne[JG_]JnUlKF_]K75KkFaaJne/LE_aK75LLFaeFo5LMEaaG7E<LEceC
7ELMDaeG?E<MDceC7E<nDaeC?TlMDci?7E<nCaeC?TlMDci?7E<nCaeC?TlMDci?7DlnCaeC?TlMCci;
7DlnCai??T/MCci;7TlnBae??T/NCch004lnBah0000FOol0031oo`03001oogoo00Eoo`9=/`0FBK=N
=5hdGSEF=EXeGUERMEifHYINUf:GGYMR^5jhH[QNf6;IG]URfEkIG]X2G_X015kJG_]Jnekk0U[k00=J
o5/LF_/01ULL00=G7E<LDad02E<M00YC7TlMDae?7E<NCae?7TlMCai?7@m?7P0>Bai?7TlNCai;7TlN
Bai?7T/NCah004lnOol0049oo`03001oogoo00Eoo`08DM=Ae57dDOAVUEYEFSEJE@=NMP09HWINUf:G
HYMN^6:gH[QNfF;I00=Nf@=NnP0:F_]NnekjFa]JnelKFa]K75/KFa`3Ea`00e/LEaaG7@02Ead015LL
EaeC7ELM1e<M00YC?U<MDaeC7E<nCaeC7TlMDci?7@9?7P05Cci?7DlNCai??P03Cah01DlnCai?7TlN
Cch00dlN00Q??TlNCci?7P00Bai??P005Woo000aOol00`00Oomoo`04Ool06DgCBK=kE5XdGUEJ=5Xe
GUARMEiEGWIRMF:FGYMV]ejgH[QR]f;IG[QRfEkHH_YNfF;j009NnP0FG]YO6e[jGa]JnelLE_]K75Kl
FaaFo5LME_aG7ELLEaeC75LMDaaG7E<LEcd2Dad0:DlMDci?7E<nCaeC?TlMDci?7E<nCaeC?TlMDci?
7DlnCae??TlMCci;7DlnCae??T/MCci;7TlnBae??T/NCci;7DlnBai??T/N001;7Tln0000@goo00<0
07ooOol017oo00iAm4gCDOAVUFJeIYENEEXeHYINMF:FGWIR]ejF0V:g01=Rf6:gH]URf6;IG]URnUkI
G_YNfUlKG_YO6e[kGa]Jne/LF_]O7002Fa`0<5LKFceG75/LEaaK?ELLEceG75LmDaeG?E<MEceC7ELm
DaeC?U<MDci?7E<nCaeC?TlMDci?7E<nCaeC?TlMDci?7E<nCae??TlMDci?7DlnCae??TlNCci;7Dln
Bai??P=oo`03001oo`0001Ioo`00<Woo00<007ooOol00goo00Q9/dfcNeAN=EXdGSANEF9e0UiE0V:F
00eRMUjGH[MR]ejhH]QR]f;IG]QRf5kIH_YRf@04G_X01UkkG_YO6e[kGa]K6`AK709G7003EaeG75LM
009G7@03DaeG7E<M00YC7@06Dai?7DlNCaeC?TlM1TlN00E??TlNCai?7Tln00=?7P07Cci;7TlNCai?
?T/NCah00goo00<007oo0000A7oo00<007ooOol00goo00=Ade7dDO@00fJE00UJ=FZeI[ERMUifIYIR
Uf:gH[H00V:h00MVf6;HH]QRf6;iH]URn@02H_X00ekjGaYNnP04Ga/00elLFa]K7002Fa`015LLFaaK
75/M0ULL1ELM00EG?E<MDaeC7ELm00=C7@0CDceC7E<mDaeC?TlMDci?7E<nCae??TlNDci?7DlnCai?
?TlNCch037oo00<007oo00005Woo000cOol00`00Oomoo`02Ool034fcBK=kE5XdGUEJ=69eGUERMEiD
HYIRM@9RUP0oI[MRUVKHH[MVf6;HH]URf6;jH]URnEkiHaYNnV<KG_YS6e[kGa]JnelLFa]O75/KFaaG
75/LEaaK?ELLFaeC75LmDaeG7E<MEceC7E<mDaeC?U<MDci?7E<nCaeC?TlMDci?7E<nCaeC?TlMCci?
7E<nCae??T/MCci?7Dln00aoo`03001oo`0004Eoo`03001oogoo009oo`15DOA=dfJeIYEZ]FJEGUEV
UFZfGWIVUV:EH[MR]VJgH[MVf6:gI]QRf6KiH]QRnF;II_UNnV<JH_US6ekjHa]NnUlKFa]O75/KGcaK
6elLEaaK?5LLFceG75/mEaaG?ELLEceC7ELmDaaG?E<MEciC7ELnDaeC?TlMDciC7E<nCaeC?TlMDci?
7E<n01=oo`03001oo`0001Ioo`00=7oo00D007ooOomoodfc00=kE003GSAkMEiE009NE@06NeERMV:F
J]IR]f:F0VJf00IRf6KGI]MRf6KhH]P2H_T01VKiG_YRnV;jGa]NnP=O6`03Fa]O6elK00EK70=G7003
EaeG75LM009G7@04DaeG7E<MDcd3Dad02U<mDaeC7E<MDci?7E<NCaeC?TlM0TlN00=??WooOol04Goo
00<007oo0000AWoo00H007ooOomooe7CDM@4IYD02fJeJ[IV]FJFHYEVUV:fI[MV]VKHH]L00VKG00=V
n6;HI]P00f;i0f;j00=NnV<JHaX01UlK0U/L01UK?5/LFaaK75/lFaaG?ELLEceG7ELmEaeG?E<MEceG
7ELmDaeC?E<MDceC7E<mDaeC?P0HOol00`00Ool0000FOol003Eoo`80000AOom=dg]DNeAk<eiEMeER
MEiDHWEgEF:FHWE^eV:FI[MV]P02I]L0;FKHH[MVnF;HI_QRf6KiH_US6V;iHaYNnV<KG_YS6elJHa]K
6elLFa]O75/KFcaK75/lEaaK?ELLEceG75LmDaaG?E<MEceC7ELmDaeG?U<MDci?7E<nCaeC?P0JOol0
0`00Ool00017Ool20000>gooDOAgEVZeIYEV]FJEJ[IV]GMgHYEVUV:EI[MRUVJgH[MVf6:gJ]QRf6Kh
I]MVnF;iI_URnFLJH_US6V;jHa]O6V<KGaYO?5lKGaaK6ellFa]O?5/KFceK75/lEaaK?ELLFceG75Lm
EaeG?E<MEceC7ELmDad07goo0P005Woo000gOol00`00BK=kE002Ne@01eXdNeEkEF9eMeEkEF:F009Z
eP9V]P07I[M^mVKGI]MZef;HI]P00VKh00IRnFKiI_URnV;iHaT3HaX5Ga/00e/LGaaK6`02Fa`01E/m
EaaK75LLFcd00eLM00EG?ELMDceC7ELm029oo`8004Uoo`04001AdgMgMgH2IYD01WMhI[EZ]GMgIYIR
U@9gEP03I[MV]VJf00=Ve`=Vn09Vn@03I_QVnF;i009W6@=S6P9S6`=O6`0>GcaO6elLFaaO?5/LFcaK
75/mEaaK?ELmFceG709G?BAoo`8001Ioo`00>7oo00/007/cNeAkE7]eMeEkMEiENeIgEFkF009ZeP0V
I[IVefJfKaMR]f[gI]MVn6KGJ_QVf6KiH_QW6F;iIaYRnF<KH_YS6UlJHa]O6elkGa]O?5/KGcaK75ll
EaaK?ELLFceG75/mEaaK?BMoo`8004Yoo`08001gEWMgIYEgV7=gJ[IgMP9gM`0VIYIcEWMGH[IZeVJf
J]QVef[gI]IVn6KGJ_QRn6/II_QW6V;iIaYS6VLJH_US>f<JHa]O6f<kGa]O?5lKGcaK6ellFaaO?E/L
FceG72Uoo`03001oo`0001Eoo`00>7oo00IkE000NeAkE7]ENgD2NeD017MELiYZeV[F0WMg00AV]Vkg
K_IZe`9Ve`9Vn005I]QZn6KiI_UVn003IaT3HaX03V<KHaYS6elKHc]O6ellGa]O?5/LFcaK75/lFa`[
Ool2001:Ool01gMf001gMgMhLgQgN6Je00=gM`=gEP9V]P03J]IgMfKG009Ze`04I_MVn6KhI_T3I_P3
IaT00f<JIaYS6P02HaX01V<KGa]S>elkGcaO6`=O?003FaaK?7oo02Yoo`03001oo`0001Eoo`00>Goo
02]77P00AaikMGMENgEgEG]FKgUcVVZeMiMgMfJgJ_I_5fKGJ]MZeVkgI]QZn6KGJaUVn6/II_QW6VKi
IaURnVLJHaUS6f<JHc]O6f<kFa]O?5lKGcaK6`0_Ool2001:Ool01DLN00177WMhLgL00gMg02=gMWMG
MeIcVFJfJ]MgMWMgI]IZmg=GJ_QVef[hJ_MW6FKhJaUVnFLII_QW6V<IIaYS6VLkHaYS>elJHc]O6f<l
Ga]O?5/K02ioo`8001Eoo`00>goo00<004LnCeh00TmN00=_NFnIKgT00gMg00E^mVkgLgMgN6KG009Z
m`07J_QVn6[hJ_MVnFKhJaP00fLI00]W6V<JIaYS6V<KHaYS6elKGcaO6elk035oo`8004]oo`05Ach0
04LoAcm7?P03Deh01fmiLiU_NG>II[IgMfnJ009Ze`9cE`06J_QZmf[hI_Q[6F[h16LI0VLJ00IW>V<J
HaYS6f<kHa/2Gc/00f<kOomoo`0^Ool2000EOol003aoo`0T00177T/oAai7?dLNBcm77V^LIg][W6[f
MiQcMfkgJ_MgV7=gJ_QZmf[hI_Q[6FKhIaUVnF/IHaUW6V<IIc]S6VLkGaYS>elJ<goo0P00C7oo02A7
7P00Aai7?dLNBcm77TLoKgUcVVmiMgM_NG>JI]IcF7=GMeQZmf[hJ_M[6FKhJaQVn6/IIaQ[6F<IJcYW
6FLjHaYW>f<JHc/cOol2000EOol003eoo`030017?TLo0097?`05Aci7?fMkJiaWN`02MgP01F^KJg]Z
mgMhMiP00V[g00A_>7<hI_Q[60=W6@07JaUW6VLJIaUW>V<JIcX0=Goo0P00CGoo00E7?P00Acm7?dLn
00=7?`05Aci7?fnJKiY_N@02LeL01W=HLgUZn6/GKaQcN0=[6004IaU[6FLIIaX2IaT2IcX00fLJOomo
o`0cOol2000EOol003eoo`0PAah004LNBcm77TLoAai;?dLNAcm77V^LIg][Vg=gMiQ_NV[hKcMcF6lg
JaQZmflHIaQ[6FLHIcYW6F/jHaYW>cMoo`03001oogoo04aoo`0EAah004LNAcm77T/oAai7?dLNBcmC
GUMnDeecVFmiLiUZmflHLgQgV6[g009[6008KcQW66/iJaQ[>VLIJcYS6SMoo`03001oogoo01=oo`00
?Woo00=7?`00Ach00dLo00E7?TLoAcm7?dLn0097?`=_VP04KcQc>6lhLiT2JaP2KeP00fLIJaU[6002
IaTcOol7001?Ool01DLn0017?dLoAch00dLo00Y7?TLoAcm7?dLnHiaSO6NLJ_McV09_VP04JaQ_66lH
JaT2JaP00fLIJcUW6@0bOol7000EOol0041oo`0J00177T/oAai7?dLNBcm77TLoAai;?dLNFgiKGE]n
KcMcVFmhKaQZn7=IKcQ[>F/HJcUW6BMoo`d005Moo`0KAah004LNAcm77T/oAai7?dLNBcm77TLoAaiW
WF=lMiQcN6nKJgY_>6/GLiU[66/iJaQ[>VLI02Ioo`d001aoo`00@Goo00<004LnAcl00TLo00E7?TLo
Acm7?dLn0097?`06FgiKOG>IAcm[VfNK0VmH00AcVV/HJaQ[61]oo`d006Eoo`05Ach004LoAcm7?P03
Acl01DLnAcm7?dLoAch00dLo0Umm00=_67>ILiT00V/H00=[>6/HOol06Goo3@00:Goo0012Ool05P00
Aai;?dLNAcm77T/oAai7?dLNBcm77TLoAai;?e=NEgi_>7>JKiU[>F/H3Woo3P00Lgoo01M77P00Aai7
?dLNBcm77TLoAai;?dLNAcm77T/oAaiOWEmlLiUcN6nKJgY_>F/H00ioo`d003Ioo`00@goo00<004Ln
Acl00TLo00E7?TLoAcm7?dLn00=7?`07AciGGUMNLiYWVfNLIi/00Woo3@00Pgoo00@004LoAcm7?P=7
?`05Aci7?dLoAcm7?P03Acl01DLnKi]SOF>MJaP00Woo3@00@goo0014Ool04@00Aai;?dLNAcm77T/o
Aai7?dLNBcm77TLoAai;?dLNAcl01000T7oo01=77P00Aai7?dLNBcm77TLoAai;?dLNAcm77T/oAai7
?dLNHieOO003001@Ool004Eoo`030017?TLo0097?`04Aci7?dLoAcnLOol01DLn0017?dLoAch00dLo
00=7?TLoOol0FWoo000cOol3002SOol3001cOol003Aoo`03001oogoo0:=oo`03001oogoo079oo`00
=7oo0`00Xgoo0`00LWoo000dOol01000Oomoo`00XWoo00@007ooOol0075oo`00=7oo00@007ooOol0
0:9oo`04001oogoo001aOol003=oo`@00:9oo`@0079oo`00ogooD7oo003oOom@Ool00?mooe1oo`00
ogooD7oo003oOom@Ool00?mooe1oo`00ogooD7oo0000\
\>"],
  ImageRangeCache->{{{0, 334}, {111.875, 0}} -> {-0.0572359, -0.0168664, \
0.00633076, 0.00633076}, {{9, 159.438}, {109.188, 2.625}} -> {-0.309736, \
-0.0333356, 0.00821805, 0.00821805}, {{174.5, 324.938}, {109.188, 2.625}} -> \
{-1.66982, -0.0333356, 0.00821805, 0.00821805}}]
}, Open  ]],

Cell[TextData[{
  StyleBox["Figure 4.2.",
    FontFamily->"B Times Bold"],
  " The two figures show the skeleton of the equation ",
  Cell[BoxData[
      StyleBox[
        RowBox[{
          RowBox[{
            SubscriptBox["\[PartialD]", 
              RowBox[{
                StyleBox["x",
                  FontSlant->"Italic"], ",", 
                StyleBox["x",
                  FontSlant->"Italic"]}]], \(u[x]\)}], " ", "-"}],
        FontFamily->"Times"]], "InlineFormula"],
  StyleBox[" ", "InlineFormula"],
  Cell[BoxData[
      \(\(\ \((\[PartialD]\_x u[x])\)\/u[x]\^2\  + \ 1\/\(x\ u[x]\) = 0\)\)], 
    "InlineFormula",
    FontFamily->"Times"],
  " in canonical representations. Left: skeleton of equation ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(2\ w[t]\), "-", \(w[t]\^3\), "-", 
          RowBox[{"4", " ", 
            RowBox[{
              SuperscriptBox["w", "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], " ", "+"}], 
        " "}]], "InlineFormula",
    FontFamily->"Times"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"4", " ", \(w[t]\^2\), " ", 
          RowBox[{
            SuperscriptBox["w", "\[DoublePrime]",
              MultilineFunction->None], "[", "t", "]"}]}], "=", "0"}]], 
    "InlineFormula",
    FontFamily->"Times"],
  ". Right: skeleton of ",
  Cell[BoxData[
      StyleBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              FractionBox[
                RowBox[{
                  SuperscriptBox["w", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], \(w[t]\^2\)], 
              "-", 
              RowBox[{
                SuperscriptBox["w", "\[DoublePrime]",
                  MultilineFunction->None], "[", "t", "]"}]}], ")"}], "=", 
          "0"}],
        "InlineFormula",
        FontFamily->"Times"]]],
  ". The variables ",
  Cell[BoxData[
      \(TraditionalForm\`P\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`Q\)]],
  " denote the first and second derivatives of canonical variable ",
  Cell[BoxData[
      \(TraditionalForm\`w\)]],
  ", respectively."
}], "SmallText",
  CellMargins->{{Inherited, Inherited}, {0, 0}},
  PageBreakWithin->False,
  PageBreakBelow->True,
  TextJustification->1],

Cell[TextData[
"We observe that the two figures look very similar. However, the skeletons in \
their analytical representations are different. Applying canonical \
coordinates to the original equation, we impressively simplified the skeleton \
of the equation. The simplification occurs by the elimination of one of the \
coordinates from the \
manifold\[NonBreakingSpace]\[NoBreak]\[GothicCapitalM]."], "Text",
  CellTags->{"skeleton", "canonical coordinates"}],

Cell[TextData[{
  "The question arises of whether there are different solutions existing for \
similar looking skeletons or whether the solutions are equal. We will examine \
this question by solving the two canonical representations. First, let us \
solve the original equation by ",
  StyleBox["DSolve[]:", "MmaText"]
}], "Text",
  CellTags->{"canonical representation", "DSolve[]"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\ DSolve[firstExample == 0, u, x]\)\)], "Input"],

Cell[BoxData[
    RowBox[{"DSolve", "[", 
      RowBox[{
        RowBox[{
          RowBox[{\(1\/\(x\ u[x]\)\), "-", 
            FractionBox[
              RowBox[{
                SuperscriptBox["u", "\[Prime]",
                  MultilineFunction->None], "[", "x", "]"}], \(u[x]\^2\)], 
            "+", 
            RowBox[{
              SuperscriptBox["u", "\[DoublePrime]",
                MultilineFunction->None], "[", "x", "]"}]}], "==", "0"}], 
        ",", "u", ",", "x"}], "]"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "The result is disappointing. ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " is unable to solve the second-order equation. Calculating the solution of \
the first canonical reduction with ",
  StyleBox["DSolve[],", "MmaText"]
}], "Text",
  CellTags->"DSolve[]"],

Cell[CellGroupData[{

Cell[BoxData[
    \(sol1\  = \ DSolve[ceqk1, w, t]\)], "Input"],

Cell[BoxData[
    RowBox[{"DSolve", "[", 
      RowBox[{
        RowBox[{
          RowBox[{\(2\ w[t]\), "-", \(w[t]\^3\), "-", 
            RowBox[{"4", " ", 
              RowBox[{
                SuperscriptBox["w", "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            RowBox[{"4", " ", \(w[t]\^2\), " ", 
              RowBox[{
                SuperscriptBox["w", "\[DoublePrime]",
                  MultilineFunction->None], "[", "t", "]"}]}]}], "==", "0"}], 
        ",", "w", ",", "t"}], "]"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "shows that again ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " is unable to solve the equation. The following idea might reveal this \
problem. We know that a given equation admits a certain type of symmetry. \
This is also true for the first canonical reduction. The symmetries of the \
first canonical reduction follow by"
}], "Text",
  CellTags->"symmetries of first canonical reduction"],

Cell[CellGroupData[{

Cell[BoxData[
    \(infceqk1\  = \ Infinitesimals[ceqk1, w, t]; infceqk1\  // LTF\)], 
  "Input"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\(\[Phi]\_1 == E\^t\ k1\ w\)},
          {\(\[Xi]\_1 == 2\ E\^t\ k1 + k2\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {
        Equal[ 
          Subscript[ \[Phi], 1], 
          Times[ 
            Power[ E, t], k1, w]], 
        Equal[ 
          Subscript[ \[Xi], 1], 
          Plus[ 
            Times[ 2, 
              Power[ E, t], k1], k2]]}]]], "Output"]
}, Open  ]],

Cell[TextData[{
  "representing a two-dimensional symmetry group with an exponential \
dependence in ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  ". Since the subgroup with ",
  StyleBox["k2 ",
    FontSlant->"Italic"],
  "\[NotEqual] 0 only represents a translation in ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  ", we restrict our examinations to the case ",
  StyleBox["k",
    FontSlant->"Italic"],
  "1 = 1/2 and ",
  StyleBox["k2 ",
    FontSlant->"Italic"],
  "= 0. The canonical variables for this subgroup follow by"
}], "Text",
  CellTags->{"canonical variables", "subgroup"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(ccceqk11 = 
      CanonicalVariables[{w}, {t}, {E\^t}, {\(E\^t\ w\)\/2}, \n\t\t{v}, {s}]; 
    ccceqk11 // LTF\)], "Input"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\(s == \(-E\^\(-t\)\)\)},
          {\(v == E\^\(\(-t\)/2\)\ w\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {
        Equal[ s, 
          Times[ -1, 
            Power[ E, 
              Times[ -1, t]]]], 
        Equal[ v, 
          Times[ 
            Power[ E, 
              Times[ 
                Rational[ -1, 2], t]], w]]}]]], "Output"]
}, Open  ]],

Cell["\<\
Inserting these new coordinates into the first canonical reduction, \
we get a second canonical representation of the first reduction:\
\>", "Text",\

  PageBreakBelow->True,
  CellTags->"canonical reduction"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ceqk11 = CanonicalRepresentation[ceqk1, w, t, \n\t\tccceqk11, v, s]; 
    \(ceqk11 // Flatten\) // LTF\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {\(\(-4\)\ I\ \@s\ \((v\_s - v\^2\ v\_\(s, s\))\) == 0\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output"]
}, Open  ]],

Cell[TextData[{
  "The calculation shows that the two canonical representations of the first \
and second symmetry levels are identical. ",
  ButtonBox["Compare",
    ButtonData:>"second reduction",
    ButtonStyle->"Hyperlink"],
  " the second canonical reduction of the first symmetry level with the \
present result:"
}], "Text",
  CellTags->"canonical representation"],

Cell[CellGroupData[{

Cell[BoxData[
    \(eqh\  = \ 
      Thread[ceqk11\[LeftDoubleBracket]1\[RightDoubleBracket]/
            \((\(-4\)\ I\ \@s)\), Equal] == 0; eqh // LTF\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {\(v\_s - v\^2\ v\_\(s, s\) == 0\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output"]
}, Open  ]],

Cell["\<\
The symmetry analysis of this equation illustrates that the \
equation admits a second-order group. We know from the above discussions that \
a second-order group is sufficient to solve this kind of ODE. The \
infinitesimals of this ODE follow by\
\>", "Text",
  CellTags->"second-order group"],

Cell[CellGroupData[{

Cell[BoxData[
    \(infh\  = \ Infinitesimals[eqh, v, s]; infh // LTF\)], "Input"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {
            RowBox[{\(\[Phi]\_1\), "==", 
              StyleBox[\(\(k2\ v\)\/2\),
                ScriptLevel->0]}]},
          {\(\[Xi]\_1 == k1 + k2\ s\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {
        Equal[ 
          Subscript[ \[Phi], 1], 
          Times[ 
            Rational[ 1, 2], k2, v]], 
        Equal[ 
          Subscript[ \[Xi], 1], 
          Plus[ k1, 
            Times[ k2, s]]]}]]], "Output"]
}, Open  ]],

Cell[TextData[{
  "To solve the equation ",
  StyleBox["eqh",
    FontSlant->"Italic"],
  ", we apply the method of first integrals in an adapted form. First, let us \
determine the Lie matrix with the infinitesimals"
}], "Text",
  CellTags->{"Lie matrix", "infinitesimals"}],

Cell[BoxData[
    \(\(inf1\  = \ 
      \(\({{\(xi[1]\)[s, v]}, {\(phi[1]\)[s, v]}}\  /. infh\) /. {
            k1 \[Rule] 1, k2 \[Rule] 0}\)\  /. v \[Rule] v[s]; \)\)], "Input"],

Cell[BoxData[
    \(\(inf2\  = \ 
      \(\({{\(xi[1]\)[s, v]}, {\(phi[1]\)[s, v]}}\  /. infh\) /. {
            k1 \[Rule] 0, k2 \[Rule] 1}\)\  /. v \[Rule] v[s]; \)\)], "Input"],

Cell["Inserting the infinitesimals into the Lie matrix, we get", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"\[CapitalDelta]matrix", "=", 
        RowBox[{"DeltaMatrix", "[", 
          RowBox[{"s", ",", "v", ",", 
            FractionBox[
              RowBox[{
                SuperscriptBox["v", "\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], \(v[s]\^2\)], 
            ",", "2", ",", \({inf1, inf2}\)}], "]"}]}], ";", 
      \(TableForm[\[CapitalDelta]matrix] // LieTraditionalForm\)}]], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"1", "0", "0"},
          {"s", 
            StyleBox[\(v\/2\),
              ScriptLevel->0], 
            StyleBox[\(-\(v\_s\/2\)\),
              ScriptLevel->0]},
          {"1", \(v\_s\), 
            StyleBox[\(v\_s\/v\^2\),
              ScriptLevel->0]}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output"]
}, Open  ]],

Cell["whose determinant is a non-vanishing quantity", "Text",
  CellTags->"determinant"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Det[\[CapitalDelta]matrix] // LieTraditionalForm\)], "Input"],

Cell[BoxData[
    \(v\_s\/\(2\ v\) + v\_s\%2\/2\)], "Output"]
}, Open  ]],

Cell["One of the two first integrals follows from ", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(integral2\  = \ 
      FirstIntegral[s, v, \[CapitalDelta]matrix, 2] == \ c2\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(2\ Log[v[s]]\), "-", 
        RowBox[{"2", " ", 
          RowBox[{"Log", "[", 
            RowBox[{"1", "+", 
              RowBox[{\(v[s]\), " ", 
                RowBox[{
                  SuperscriptBox["v", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}]}]}], "]"}]}]}], 
      "==", "c2"}]], "Output"]
}, Open  ]],

Cell["\<\
The second first integral is not accessible by an integration:\
\>",
   "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(integral1\  = \ 
      FirstIntegral[s, v, \[CapitalDelta]matrix, 1] == \ c1\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"\[Integral]", 
        RowBox[{
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{
                    SuperscriptBox[\(v[s]\), "\[Prime]",
                      MultilineFunction->None], "[", "t", "]"}], " ", 
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{\(-\(1\/2\)\), " ", 
                        RowBox[{
                          RowBox[{
                            SuperscriptBox["v", "\[Prime]",
                              MultilineFunction->None], "[", "s", "]"}], "[", 
                          "t", "]"}]}], "-", 
                      FractionBox[
                        RowBox[{\(s[t]\), " ", 
                          RowBox[{
                            RowBox[{
                              SuperscriptBox["v", "\[Prime]",
                                MultilineFunction->None], "[", "s", "]"}], 
                            "[", "t", "]"}]}], \(\(v[s]\)[t]\^2\)]}], 
                    ")"}]}], "+", 
                RowBox[{
                  RowBox[{
                    SuperscriptBox["s", "\[Prime]",
                      MultilineFunction->None], "[", "t", "]"}], " ", 
                  RowBox[{"(", 
                    RowBox[{
                      FractionBox[
                        RowBox[{
                          RowBox[{
                            SuperscriptBox["v", "\[Prime]",
                              MultilineFunction->None], "[", "s", "]"}], "[", 
                          "t", "]"}], \(2\ \(v[s]\)[t]\)], "+", 
                      RowBox[{\(1\/2\), " ", 
                        SuperscriptBox[
                          RowBox[{
                            RowBox[{
                              SuperscriptBox["v", "\[Prime]",
                                MultilineFunction->None], "[", "s", "]"}], 
                            "[", "t", "]"}], "2"]}]}], ")"}]}], "+", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{\(\(-\(1\/2\)\)\ \(v[s]\)[t]\), "+", 
                      RowBox[{\(s[t]\), " ", 
                        RowBox[{
                          RowBox[{
                            SuperscriptBox["v", "\[Prime]",
                              MultilineFunction->None], "[", "s", "]"}], "[", 
                          "t", "]"}]}]}], ")"}], " ", 
                  RowBox[{
                    RowBox[{
                      SuperscriptBox["v", "\[DoublePrime]",
                        MultilineFunction->None], "[", "s", "]"}], "[", "t", 
                    "]"}]}]}], ")"}], "/", 
            RowBox[{"(", 
              RowBox[{
                FractionBox[
                  RowBox[{
                    RowBox[{
                      SuperscriptBox["v", "\[Prime]",
                        MultilineFunction->None], "[", "s", "]"}], "[", "t", 
                    "]"}], \(2\ \(v[s]\)[t]\)], "+", 
                RowBox[{\(1\/2\), " ", 
                  SuperscriptBox[
                    RowBox[{
                      RowBox[{
                        SuperscriptBox["v", "\[Prime]",
                          MultilineFunction->None], "[", "s", "]"}], "[", 
                      "t", "]"}], "2"]}]}], ")"}]}], 
          \(\[DifferentialD]t\)}]}], "==", "c1"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "However, the solution of the equation ",
  StyleBox["eqh",
    FontSlant->"Italic"],
  " is derived if we take the first integral as a defining equation for ",
  Cell[BoxData[
      \(TraditionalForm\`v\)]],
  ". Thus, another integration by ",
  StyleBox["DSolve[]", "MmaText"],
  " gives us the solution"
}], "Text",
  CellTags->"DSolve[]"],

Cell[CellGroupData[{

Cell[BoxData[
    \(csolex2\  = \ DSolve[integral2, v, s]\)], "Input"],

Cell[BoxData[
    \(InverseFunction::"ifun" \( : \ \) 
      "Warning: Inverse functions are being used. Values may be lost for \
multivalued inverses."\)], "Message"],

Cell[BoxData[
    \({{v \[Rule] 
          \((E\^\(c2/2\)\ 
                \((1 + ProductLog[
                      E\^\(\(-1\) + E\^\(-c2\)\ \((#1 - C[1])\)\)])\)&)\)}}
      \)], "Output"]
}, Open  ]],

Cell[TextData[{
  "This type of solution also follows by applying the function ",
  StyleBox["SecondOrderIntegrate[]", "MmaText"],
  " to the equation in canonical variables:"
}], "Text",
  CellTags->"SecondOrderIntegrate[]"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SecondOrderIntegrate[eqh, v, \ s]\)], "Input"],

Cell[BoxData[
    \(InverseFunction::"ifun" \( : \ \) 
      "Warning: Inverse functions are being used. Values may be lost for \
multivalued inverses."\)], "Message"],

Cell[BoxData[
    \({v \[Rule] 
        Function[s, 
          E\^\(CI[2]\/2\)\ 
            \((1 + ProductLog[E\^\(\(-1\) + E\^\(-CI[2]\)\ \((s - C[1])\)\)])
              \)]}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The solution of the original equation in variables ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`u\)]],
  " thus follows by inverting the canonical transformations"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(csol\  = \ 
      \(\((\(\((v[s]\  /. \ csolex2)\)\[LeftDoubleBracket]1
                    \[RightDoubleBracket]\  == \ v\  /. {v \[Rule] v[t, w], 
                  s \[Rule] s[t, w]}\)\  /. ccceqk11)\)\  /. {
            w \[Rule] w[x, u], t \[Rule] t[x, u]}\)\  /. cck1\)], "Input"],

Cell[BoxData[
    \(E\^\(c2/2\)\ 
        \((1 + ProductLog[
              E\^\(\(-1\) + E\^\(-c2\)\ \((\(-\(1\/x\)\) - C[1])\)\)])\) == 
      u\/x\)], "Output"]
}, Open  ]],

Cell["The explicit solution for the original equation thus reads", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(sol\  = \ Solve[csol, u] // Simplify\)], "Input"],

Cell[BoxData[
    \({{u \[Rule] 
          E\^\(c2/2\)\ x\ 
            \((1 + ProductLog[
                  E\^\(\(-1\) - \(E\^\(-c2\)\ \((1 + x\ C[1])\)\)\/x\)])\)}}
      \)], "Output"]
}, Open  ]],

Cell[TextData[{
  "where the constants ",
  Cell[BoxData[
      \(TraditionalForm\`c\_2\)]],
  " and ",
  StyleBox["C",
    FontSlant->"Italic"],
  "[1] are constants of integration. This example shows that a solution of an \
ODE is derived if a hybrid algorithm, combining the method of first \
integrals, the method of canonical variables, and the solution procedure of ",
  
  StyleBox["Mathematica,",
    FontSlant->"Italic"],
  " is applied. The solution calculated above is not accessible by ",
  StyleBox["DSolve[]", "MmaText"],
  " or one of the two other methods alone. We can check the solution by \
inserting the result into the original equation:"
}], "Text",
  CellTags->{"hybrid algorithm", "DSolve[]"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(firstExample\  /. 
        \((u \[Rule] Function[x, w]\  /. 
            \((sol\[LeftDoubleBracket]1, 1\[RightDoubleBracket] /. 
                u \[Rule] w)\))\) // Simplify\)], "Input"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The resulting zero demonstrates that the derived solution satisfies the \
original equation. This solution is new in the sense that the explicit \
representation for the original equation is given. The solution in an \
implicit representation was given by ",
  ButtonBox["Ibragimov [1994]",
    ButtonData:>"Ibragimov-1994",
    ButtonStyle->"Hyperlink"],
  ". A graphical representation of our result, for fixed constants ",
  Cell[BoxData[
      \(TraditionalForm\`c\_2\)]],
  " and ",
  StyleBox["C",
    FontSlant->"Italic"],
  "[1]",
  StyleBox[", ",
    FontSlant->"Italic"],
  " is shown by"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[
      \(u\  /. \ sol\)\  /. \ {c2 \[Rule] 1, C[1] \[Rule] 1/2}, {x, 
        \(- .20\),  .0510}, PlotStyle \[Rule] RGBColor[0.996109, \ 0, \ 0], 
      AxesLabel \[Rule] {"\<x\>", "\<y\>"}, PlotRange \[Rule] All]\)], "Input",\

  CellMargins->{{Inherited, Inherited}, {0, Inherited}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.782679 3.79435 0.531502 0.853913 [
[.02381 .519 -12 -9 ]
[.02381 .519 12 0 ]
[.21353 .519 -15 -9 ]
[.21353 .519 15 0 ]
[.40324 .519 -12 -9 ]
[.40324 .519 12 0 ]
[.59296 .519 -15 -9 ]
[.59296 .519 15 0 ]
[.9724 .519 -12 -9 ]
[.9724 .519 12 0 ]
[1.025 .5315 0 -7.5 ]
[1.025 .5315 10 7.5 ]
[.77018 .01915 -24 -4.5 ]
[.77018 .01915 0 4.5 ]
[.77018 .10454 -24 -4.5 ]
[.77018 .10454 0 4.5 ]
[.77018 .18994 -24 -4.5 ]
[.77018 .18994 0 4.5 ]
[.77018 .27533 -24 -4.5 ]
[.77018 .27533 0 4.5 ]
[.77018 .36072 -24 -4.5 ]
[.77018 .36072 0 4.5 ]
[.77018 .44611 -24 -4.5 ]
[.77018 .44611 0 4.5 ]
[.77018 .61689 -18 -4.5 ]
[.77018 .61689 0 4.5 ]
[.78268 .64303 -5 0 ]
[.78268 .64303 5 15 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.02381 .5315 m
.02381 .53775 L
s
[(-0.2)] .02381 .519 0 1 Mshowa
.21353 .5315 m
.21353 .53775 L
s
[(-0.15)] .21353 .519 0 1 Mshowa
.40324 .5315 m
.40324 .53775 L
s
[(-0.1)] .40324 .519 0 1 Mshowa
.59296 .5315 m
.59296 .53775 L
s
[(-0.05)] .59296 .519 0 1 Mshowa
.9724 .5315 m
.9724 .53775 L
s
[(0.05)] .9724 .519 0 1 Mshowa
.125 Mabswid
.06175 .5315 m
.06175 .53525 L
s
.0997 .5315 m
.0997 .53525 L
s
.13764 .5315 m
.13764 .53525 L
s
.17558 .5315 m
.17558 .53525 L
s
.25147 .5315 m
.25147 .53525 L
s
.28941 .5315 m
.28941 .53525 L
s
.32736 .5315 m
.32736 .53525 L
s
.3653 .5315 m
.3653 .53525 L
s
.44119 .5315 m
.44119 .53525 L
s
.47913 .5315 m
.47913 .53525 L
s
.51707 .5315 m
.51707 .53525 L
s
.55502 .5315 m
.55502 .53525 L
s
.6309 .5315 m
.6309 .53525 L
s
.66885 .5315 m
.66885 .53525 L
s
.70679 .5315 m
.70679 .53525 L
s
.74474 .5315 m
.74474 .53525 L
s
.82062 .5315 m
.82062 .53525 L
s
.85857 .5315 m
.85857 .53525 L
s
.89651 .5315 m
.89651 .53525 L
s
.93445 .5315 m
.93445 .53525 L
s
.25 Mabswid
0 .5315 m
1 .5315 L
s
gsave
1.025 .5315 -61 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.78268 .01915 m
.78893 .01915 L
s
[(-0.6)] .77018 .01915 1 0 Mshowa
.78268 .10454 m
.78893 .10454 L
s
[(-0.5)] .77018 .10454 1 0 Mshowa
.78268 .18994 m
.78893 .18994 L
s
[(-0.4)] .77018 .18994 1 0 Mshowa
.78268 .27533 m
.78893 .27533 L
s
[(-0.3)] .77018 .27533 1 0 Mshowa
.78268 .36072 m
.78893 .36072 L
s
[(-0.2)] .77018 .36072 1 0 Mshowa
.78268 .44611 m
.78893 .44611 L
s
[(-0.1)] .77018 .44611 1 0 Mshowa
.78268 .61689 m
.78893 .61689 L
s
[(0.1)] .77018 .61689 1 0 Mshowa
.125 Mabswid
.78268 .03623 m
.78643 .03623 L
s
.78268 .05331 m
.78643 .05331 L
s
.78268 .07039 m
.78643 .07039 L
s
.78268 .08747 m
.78643 .08747 L
s
.78268 .12162 m
.78643 .12162 L
s
.78268 .1387 m
.78643 .1387 L
s
.78268 .15578 m
.78643 .15578 L
s
.78268 .17286 m
.78643 .17286 L
s
.78268 .20701 m
.78643 .20701 L
s
.78268 .22409 m
.78643 .22409 L
s
.78268 .24117 m
.78643 .24117 L
s
.78268 .25825 m
.78643 .25825 L
s
.78268 .29241 m
.78643 .29241 L
s
.78268 .30948 m
.78643 .30948 L
s
.78268 .32656 m
.78643 .32656 L
s
.78268 .34364 m
.78643 .34364 L
s
.78268 .3778 m
.78643 .3778 L
s
.78268 .39488 m
.78643 .39488 L
s
.78268 .41195 m
.78643 .41195 L
s
.78268 .42903 m
.78643 .42903 L
s
.78268 .46319 m
.78643 .46319 L
s
.78268 .48027 m
.78643 .48027 L
s
.78268 .49735 m
.78643 .49735 L
s
.78268 .51442 m
.78643 .51442 L
s
.78268 .54858 m
.78643 .54858 L
s
.78268 .56566 m
.78643 .56566 L
s
.78268 .58274 m
.78643 .58274 L
s
.78268 .59981 m
.78643 .59981 L
s
.78268 .00208 m
.78643 .00208 L
s
.25 Mabswid
.78268 0 m
.78268 .61803 L
s
gsave
.78268 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.996 0 0 r
.5 Mabswid
.02381 .01472 m
.06244 .02885 L
.10458 .04383 L
.14415 .05741 L
.18221 .06996 L
.22272 .08267 L
.26171 .09418 L
.30316 .10547 L
.34309 .11526 L
.3815 .12349 L
.42237 .1307 L
.44268 .13359 L
.46172 .13583 L
.47994 .1375 L
.49018 .13823 L
.49955 .13874 L
.50432 .13895 L
.5094 .13912 L
.51187 .13919 L
.51419 .13925 L
.51626 .13929 L
.51854 .13933 L
.51975 .13934 L
.52106 .13935 L
.52178 .13936 L
.52244 .13937 L
.52372 .13937 L
.52489 .13938 L
.52617 .13938 L
.52738 .13938 L
.52849 .13937 L
.52977 .13936 L
.53097 .13935 L
.53229 .13934 L
.53371 .13932 L
.53661 .13927 L
.53926 .13921 L
.544 .13906 L
.54906 .13885 L
.55818 .13833 L
.56903 .13747 L
.57888 .13644 L
.59807 .13373 L
.61887 .1296 L
.63874 .12437 L
.65979 .11726 L
.69767 .09953 L
.71712 .08734 L
.73801 .07111 L
.74814 .06173 L
Mistroke
.75919 .04999 L
.76974 .03667 L
.77471 .02928 L
.77929 .02136 L
.78052 .0189 L
.78166 .01636 L
.78286 .53157 L
.78417 .53206 L
.78945 .53401 L
.799 .53756 L
.81999 .54534 L
.85895 .5598 L
.90036 .57517 L
.94026 .58997 L
.97619 .60332 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellMargins->{{90, Inherited}, {Inherited, 0}},
  ImageSize->{255.625, 157.938},
  ImageMargins->{{Inherited, 0}, {0, 7}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003o0000WA000`40O003h00O^Goo0P00A7oo002i
Ool00`00Oomoo`13Ool00:Ioo`8000Aoo`8000=oo`<000Eoo`03001oogoo04=oo`004Woo0W`0TGoo
00@007ooOol000Qoo`04001oogoo0003Ool00g`0001oo`14Ool001Aoo`9l08moo`04001oogoo0008
Ool01000Oomoo`000goo00=l00000000A7oo000FOol3O026Ool40002Ool01000Oomoo`0027oo0`00
17oo00=l0000Ool0A7oo000IOol3O029Ool01000Oomoo`002Goo00<007ooOol00Woo0W`000<007oo
Ool0@goo000LOol3O027Ool2000:Ool300001GooO01oog`00000AGoo000OOol3O02DOol00g`0Ooml
00020014Ool0029oo`=l091oo`05O01oogooO0000015Ool002Eoo`=l08eoo`05O01oogooO0000015
Ool002Qoo`=l08Uoo`06O01oogooOoml0000AGoo000[Ool3O024Ool2O004Ool00g`000000014Ool0
02ioo`9l085oo`03O01oogoo00Aoo`03O00007oo04Aoo`00<7oo0g`0OGoo00=l07ooOol01Goo00=l
0000Ool0A7oo000cOol3O01jOol00g`0Oomoo`05Ool00g`000000014Ool003Ioo`=l07Ioo`03O01o
ogoo00Ioo`03O00007oo04Aoo`00>Goo0g`0LGoo0W`02Goo00=l0000Ool0A7oo000lOol3O01/Ool2
O00;Ool00g`0001oo`14Ool003moo`=l06Qoo`03O01oogoo00]oo`03O000000004Aoo`00@Woo0g`0
I7oo00=l07ooOol037oo00=l0000Ool0A7oo0015Ool4O01MOol00`00O01l0003Ool20004Ool20004
Ool00g`0001oo`14Ool004Uoo`Al05Qoo`04001l07oo0008Ool01000Oomoo`000goo00=l0000Ool0
A7oo001=Ool5O01BOol2O002Ool00`00Oomoo`09Ool01@00OomoogooO0000P00A7oo001BOol4O019
Ool30002O0001Goo001oogoo00002Goo0P0017oo00=l0000Ool0A7oo001FOol4O016Ool2O003Ool0
1000Oomoo`002Goo00<007ooOol00goo00=l0000Ool0A7oo001JOol4O00nOol4O006Ool2000:Ool3
0003Ool00g`0001oo`14Ool005ioo`El03Eoo`Al01aoo`03O000000004Aoo`00Hgoo17`0;7oo1G`0
87oo00=l0000Ool0A7oo001WOol9O00OOol4O00UOol00g`0001oo`14Ool0071oo`il00Ioo`]l02Uo
o`03O000000004Aoo`00OGoo1g`0=7oo00=l0000Ool0A7oo002hOol00g`0001oo`14Ool00;Qoo`03
O00007oo04Aoo`00^7oo00=l00000000A7oo002hOol00g`0001oo`14Ool00;Qoo`03O00007oo04Ao
o`00^7oo00=l0000Ool0A7oo002hOol00g`000000014Ool00;Qoo`03O00007oo04Aoo`00YWoo0P00
17oo0P001Goo0`000Woo00=l0000Ool0A7oo002UOol01000Oomoo`002goo00H007ooOomoog`00015
Ool00:Eoo`04001oogoo0008Ool50002Ool00g`000000014Ool009moo`@0009oo`04001oogoo0008
Ool01000Oomoo`000goo00=l0000Ool0A7oo002UOol01000Oomoo`002Goo00<007oo00000goo00=l
0000Ool0A7oo002VOol2000;Ool20003Ool00g`000000014Ool00;Qoo`03O00007oo04Aoo`00^7oo
00=l0000Ool0A7oo002hOol00g`0001oo`14Ool00;Qoo`03O000000004Aoo`00^7oo00=l0000Ool0
A7oo002hOol00g`0001oo`14Ool00;Qoo`03O00007oo04Aoo`00^7oo00=l00000000A7oo002hOol0
0g`0001oo`14Ool00;Qoo`03O00007oo04Aoo`00^7oo00=l0000Ool0A7oo002hOol00g`000000014
Ool00:Ioo`8000Aoo`8000Aoo`8000Aoo`03O00007oo04Aoo`00YGoo00@007ooOol000Qoo`04001o
ogoo0003Ool00g`0001oo`14Ool00:Eoo`04001oogoo000:Ool00`00Oomoo`03Ool00g`0001oo`13
Ool009moo`@0009oo`04001oogoo000;Ool00`00Oomoo`02Ool00g`0Oomoo`13Ool00:Eoo`04001o
ogoo0008Ool01000Oomoo`0017oo00=l07ooOol0@goo002VOol2000:Ool20005Ool00g`0Oomoo`13
Ool00;Uoo`03O00007oo04=oo`00^Goo00=l07ooOol0@goo002iOol00g`0Oomoo`13Ool00;Uoo`03
O01oogoo04=oo`00^Goo00=l0000Ool0@goo002iOol00g`0Oomoo`13Ool00;Uoo`03O01oogoo04=o
o`00^Goo00=l07ooOol0@goo002iOol00g`0001oo`13Ool00;Uoo`03O01oogoo04=oo`00^Goo00=l
07ooOol0@goo002iOol00g`0Oomoo`13Ool00;Uoo`03O00007oo04=oo`00YWoo0P0017oo0P000goo
100017oo00=l07ooOol0@goo002UOol01000Oomoo`0027oo00<007ooOol01Goo00=l07ooOol0@goo
002UOol01000Oomoo`002Goo00<007ooOol017oo00=l0000Ool0@goo002OOol40002Ool01000Oomo
o`002Woo00<007ooOol00goo00=l07ooOol0@goo002UOol01000Oomoo`0027oo00@007ooOol000Ao
o`03O01oogoo04=oo`00YWoo0P002Woo0P001Goo00=l07ooOol0@goo002iOol00g`0001oo`13Ool0
0;Uoo`03O01oogoo04=oo`00^Goo00=l07ooOol0@goo002iOol00g`0Oomoo`13Ool00;Uoo`03O000
07oo04=oo`00^Goo00=l07ooOol0@goo002iOol00g`0Oomoo`13Ool00;Uoo`03O01oogoo04=oo`00
^Goo00=l0000Ool0@goo002iOol00g`0Oomoo`13Ool00;Uoo`03O01oogoo04=oo`00^Goo00=l0000
Ool0@goo002iOol00g`0Oomoo`13Ool00:Ioo`8000Aoo`8000=oo`D000=oo`03O01oogoo04=oo`00
YGoo00@007ooOol000Yoo`03001oogoo00=oo`03O01oogoo04=oo`00YGoo00@007ooOol000Yoo`03
001oogoo00=oo`03O00007oo04=oo`00Wgoo10000Woo00@007ooOol000Yoo`03001oogoo00=oo`03
O01oogoo04=oo`00YGoo00@007ooOol000Yoo`03001oogoo00=oo`03O01oogoo04=oo`00YWoo0P00
2Woo0P001Goo00=l07ooOol0@goo002iOol00g`0001oo`13Ool00;Uoo`03O01oogoo04=oo`00^Goo
00=l07ooOol0@goo002iOol00g`0Oomoo`13Ool000ioo`8000Aoo`8000=oo`@001Moo`8000Aoo`80
00=oo`D0009oo`8001Uoo`8000Aoo`8000=oo`D001Moo`8000Aoo`8000Aoo`8000Aoo`8001eoo`03
O00007oo01eoo`8000Aoo`8000Aoo`8000Aoo`80019oo`003Goo00@007ooOol000Qoo`03001oogoo
01Moo`04001oogoo000:Ool01@00Oomoogoo00000Woo00<007ooOol05Goo00@007ooOol000Yoo`03
001oogoo01Ioo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol001aoo`03O01oogoo01ao
o`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol0015oo`003Goo00@007ooOol000Uoo`03
001oogoo01Ioo`04001oogoo000:Ool00`00Oomoo`04Ool00`00Oomoo`0EOol01000Oomoo`002Woo
00<007ooOol05Woo00@007ooOol000Qoo`04001oogoo0005Ool00`00Oomoo`0JOol00g`0Oomoo`0L
Ool01000Oomoo`0027oo00@007ooOol000Eoo`03001oogoo00moo`001goo10000Woo00@007ooOol0
00Yoo`03001oogoo00moo`@0009oo`04001oogoo000:Ool00`00Oomoo`02Ool2000BOol40002Ool0
1000Oomoo`002Woo00<007ooOol047oo10000Woo00@007ooOol000Qoo`04001oogoo0003Ool2000M
Ool00g`0001oo`0LOol01000Oomoo`0027oo00@007ooOol000=oo`80019oo`003Goo00@007ooOol0
00Qoo`04001oogoo000FOol01000Oomoo`002Woo00<007ooOol00Woo00<007ooOol05goo00@007oo
Ool000Yoo`03001oogoo01Ioo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol077oo00=l
07ooOol077oo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`0AOol000ioo`8000Yoo`80
01Qoo`8000Yoo`8000Aoo`<001Qoo`8000Yoo`8001Uoo`8000Yoo`8000Aoo`<001aoo`03O01oogoo
01eoo`8000Yoo`8000Aoo`<0015oo`00^Goo00=l07ooOol0@goo002iOol00g`0001oo`13Ool00;Uo
o`03O01oogoo04=oo`00^Goo00=l07ooOol0=7oo0P0000=oo`0000002Woo002iOol00g`0Oomoo`0e
Ool00`00Ool0000;Ool000aoojd0009l02l000Qoo`03001oogoo00Yoo`004Woo00<007ooOol01Goo
00<007ooOol01Goo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Woo
00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol01Goo
00<007ooOol01Woo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol01Goo
00<007ooOol01Woo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Woo00<007ooO0000W`0
0goo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol0
2Woo0P0000=oo`0000002Woo002iOol00`00Oomoo`02Ool2O00oOol00;Uoo`03001oogoo00Aoo`=l
03aoo`00^Goo0P0027oo0g`0>Goo002iOol00`00Oomoo`0:Ool3O00fOol00;Uoo`03001oogoo00eo
o`=l03=oo`00^Goo0P004Goo0W`0<Goo002iOol00`00Oomoo`0BOol2O00_Ool00;Uoo`03001oogoo
01Aoo`9l02eoo`00^Goo00<007ooOol05Woo0g`0:Woo002iOol2000JOol2O00XOol00;Uoo`03001o
ogoo01]oo`=l02Eoo`00^Goo00<007ooOol07Woo0g`08Woo002iOol00`00Oomoo`0QOol2O00POol0
0;Uoo`8002Aoo`=l01eoo`00^Goo00<007ooOol09Woo0W`06goo002VOol20004Ool20003Ool50003
Ool00`00Oomoo`13Ool00:Eoo`04001oogoo000:Ool00`00Oomoo`03Ool00`00Oomoo`13Ool00:Eo
o`04001oogoo000:Ool00`00Oomoo`03Ool20014Ool00:Eoo`04001oogoo000:Ool00`00Oomoo`19
Ool00:Eoo`04001oogoo000:Ool00`00Oomoo`19Ool00:Ioo`8000Yoo`8004]oo`00ogoo003oOol0
0?moo`00ogoo003oOol00;Moo`8004Ioo`00^7oo00<007ooOol0A7oo002iOol00`00Oomoo`13Ool0
0;Qoo`03001oo`0004Aoo`00]goo00@007ooOol004Aoo`00]Woo0`0000=oo`000000@goo003oOol0
0?moo`00ogoo003oOol00?moo`00ogoo0000\
\>"],
  ImageRangeCache->{{{0, 254.625}, {156.938, 0}} -> {-0.221576, -0.623931, \
0.00119636, 0.00531602}}]
}, Open  ]],

Cell["\<\
The example presented in this section illustrates how the \
combination of different strategies allows the derivation of a solution. In \
the following section, we will generalize the presented procedures to \
higher-order ODEs.\
\>", "Text"],

Cell[TextData[ButtonBox["Next notebook",
  ButtonData:>{"symmet4.nb", None},
  ButtonStyle->"Hyperlink"]], "Text",
  CellFrame->{{0, 0}, {0, 0.5}}]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 695}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{"RulerBar", "EditBar"},
Evaluator->"Local",
WindowSize->{656, 668},
WindowMargins->{{4, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingStartingPageNumber->177,
PrintingPageRange->{170, 171},
PageHeaders->{{Cell[ 
        TextData[ {
          StyleBox[ 
            CounterBox[ "Page"], "PageNumber"], "     ", 
          StyleBox[ 
          "Symmetries of Ordinary Differential Equations", FontSlant -> 
            "Italic"]}], "Header"], Inherited, None}, {
    None, Inherited, Cell[ 
        TextData[ {
          StyleBox[ 
            CounterBox[ 
            "Section", CounterFunction :> (
              Part[ {"Analysis of Ordinary Differential Equations"}, #]&)], 
            FontSlant -> "Italic"], "     ", 
          StyleBox[ 
            CounterBox[ "Page"], "PageNumber"]}], "Header"]}},
PageHeaderLines->{False, False},
PrintingOptions->{"FirstPageHeader"->True,
"FirstPageFooter"->False,
"FacingPages"->True},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
Magnification->1,
StyleDefinitions -> "BookStyles.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Second order ordinary differential equations"->{
    Cell[1739, 51, 407, 5, 43, "Section",
      CounterAssignments->{{"Title", 4}, {"SubTitle", 0}, {
          "SubSubTitle", 0}, {"Section", 0}, {"SubSection", 0}, {
          "SubSubSection", 0}, {"NumberedEquation", 56}, {
          "NumberedFigure", 0}, {"NumberedTable", 0}},
      CellTags->"Second order ordinary differential equations"]},
  "second-order ordinary differential equations"->{
    Cell[2149, 58, 1580, 36, 146, "Text",
      CellTags->{
      "second-order ordinary differential equations", "engineering", 
        "physics", "Newton's second law", "mechanics"}]},
  "engineering"->{
    Cell[2149, 58, 1580, 36, 146, "Text",
      CellTags->{
      "second-order ordinary differential equations", "engineering", 
        "physics", "Newton's second law", "mechanics"}]},
  "physics"->{
    Cell[2149, 58, 1580, 36, 146, "Text",
      CellTags->{
      "second-order ordinary differential equations", "engineering", 
        "physics", "Newton's second law", "mechanics"}]},
  "Newton's second law"->{
    Cell[2149, 58, 1580, 36, 146, "Text",
      CellTags->{
      "second-order ordinary differential equations", "engineering", 
        "physics", "Newton's second law", "mechanics"}]},
  "mechanics"->{
    Cell[2149, 58, 1580, 36, 146, "Text",
      CellTags->{
      "second-order ordinary differential equations", "engineering", 
        "physics", "Newton's second law", "mechanics"}]},
  "transformation groups"->{
    Cell[3732, 96, 1008, 15, 129, "Text",
      CellTags->{
      "transformation groups", "integration strategies", 
        "general integration theory", "infinitesimal transformation", 
        "group"}]},
  "integration strategies"->{
    Cell[3732, 96, 1008, 15, 129, "Text",
      CellTags->{
      "transformation groups", "integration strategies", 
        "general integration theory", "infinitesimal transformation", 
        "group"}]},
  "general integration theory"->{
    Cell[3732, 96, 1008, 15, 129, "Text",
      CellTags->{
      "transformation groups", "integration strategies", 
        "general integration theory", "infinitesimal transformation", 
        "group"}]},
  "infinitesimal transformation"->{
    Cell[3732, 96, 1008, 15, 129, "Text",
      CellTags->{
      "transformation groups", "integration strategies", 
        "general integration theory", "infinitesimal transformation", 
        "group"}]},
  "group"->{
    Cell[3732, 96, 1008, 15, 129, "Text",
      CellTags->{
      "transformation groups", "integration strategies", 
        "general integration theory", "infinitesimal transformation", 
        "group"}]},
  "second-order ODE"->{
    Cell[4743, 113, 180, 3, 27, "Text",
      CellTags->"second-order ODE"],
    Cell[6356, 164, 657, 15, 61, "Text",
      CellTags->{
      "second-order ODE", "Lie algebra", "group theoretic quadrature", 
        "quadrature method", "algorithm"}],
    Cell[21414, 590, 504, 10, 61, "Text",
      CellTags->{"second-order ODE", "Lie\.b4s group classification"}],
    Cell[351019, 9624, 583, 13, 82, "Text",
      CellTags->{"SecondOrderIntegrate[]", "second-order ODE", "DSolve[]"}]},
  "solution of a second-order ODE"->{
    Cell[5669, 148, 554, 9, 78, "Text",
      CellTags->{
      "solution of a second-order ODE", "symmetry of an equation"}]},
  "symmetry of an equation"->{
    Cell[5669, 148, 554, 9, 78, "Text",
      CellTags->{
      "solution of a second-order ODE", "symmetry of an equation"}]},
  "Algorithm of Integration"->{
    Cell[6248, 161, 105, 1, 41, "Subsection",
      CellTags->"Algorithm of Integration"]},
  "Lie algebra"->{
    Cell[6356, 164, 657, 15, 61, "Text",
      CellTags->{
      "second-order ODE", "Lie algebra", "group theoretic quadrature", 
        "quadrature method", "algorithm"}],
    Cell[7016, 181, 646, 21, 20, "ListItem",
      CellTags->{"admitted Lie algebra", "Lie algebra"}],
    Cell[19393, 531, 1961, 54, 95, "Text",
      CellTags->{
      "subalgebra", "Lie algebra", "commutator", "pseudo scalar product"}],
    Cell[22569, 626, 1186, 28, 114, "Text",
      CellTags->{
      "Lie algebra", "Infinitesimals[]", "symbolic template", 
        "calculation of the infinitesimals"}],
    Cell[24834, 695, 1317, 40, 112, "Text",
      CellTags->{
      "Lie group", "symmetry group", "Lie algebra", "commutator table", 
        "calculate the commutator table", "structure constants"}],
    Cell[114290, 3851, 750, 24, 34, "ListItem",
      CellTags->{
      "five steps of integration", "Lie algebra", "tangent vector field", 
        "group constant"}],
    Cell[125688, 4212, 766, 14, 114, "Text",
      CellTags->{
      "Lie algebra", "subgroup of order two", "SecondOrderAlgebras[]", 
        "second-order solvable subalgebras", "group constants"}]},
  "group theoretic quadrature"->{
    Cell[6356, 164, 657, 15, 61, "Text",
      CellTags->{
      "second-order ODE", "Lie algebra", "group theoretic quadrature", 
        "quadrature method", "algorithm"}],
    Cell[113902, 3842, 385, 7, 44, "Text",
      CellTags->{"integration procedure", "group theoretic quadrature"}]},
  "quadrature method"->{
    Cell[6356, 164, 657, 15, 61, "Text",
      CellTags->{
      "second-order ODE", "Lie algebra", "group theoretic quadrature", 
        "quadrature method", "algorithm"}]},
  "algorithm"->{
    Cell[6356, 164, 657, 15, 61, "Text",
      CellTags->{
      "second-order ODE", "Lie algebra", "group theoretic quadrature", 
        "quadrature method", "algorithm"}]},
  "admitted Lie algebra"->{
    Cell[7016, 181, 646, 21, 20, "ListItem",
      CellTags->{"admitted Lie algebra", "Lie algebra"}]},
  "classification of second order algebras"->{
    Cell[8426, 235, 8296, 201, 67, "NumberedEquation",
      CellTags->"classification of second order algebras"]},
  "commutator"->{
    Cell[16725, 438, 2144, 72, 58, "ListItem",
      CellTags->{"commutator", "pseudo scalar product", "infinitesimals"}],
    Cell[19393, 531, 1961, 54, 95, "Text",
      CellTags->{
      "subalgebra", "Lie algebra", "commutator", "pseudo scalar product"}]},
  "pseudo scalar product"->{
    Cell[16725, 438, 2144, 72, 58, "ListItem",
      CellTags->{"commutator", "pseudo scalar product", "infinitesimals"}],
    Cell[19393, 531, 1961, 54, 95, "Text",
      CellTags->{
      "subalgebra", "Lie algebra", "commutator", "pseudo scalar product"}],
    Cell[26566, 755, 609, 15, 61, "Text",
      CellTags->{
      "algebra", "Lie's classification", "pseudo scalar product", 
        "infinitesimals"}],
    Cell[27768, 789, 191, 6, 27, "Text",
      CellTags->"pseudo scalar product"]},
  "infinitesimals"->{
    Cell[16725, 438, 2144, 72, 58, "ListItem",
      CellTags->{"commutator", "pseudo scalar product", "infinitesimals"}],
    Cell[26566, 755, 609, 15, 61, "Text",
      CellTags->{
      "algebra", "Lie's classification", "pseudo scalar product", 
        "infinitesimals"}],
    Cell[118058, 3976, 872, 30, 34, "ListItem",
      CellTags->"infinitesimals"],
    Cell[127375, 4247, 619, 11, 97, "Text",
      CellTags->{"SecondOrderAlgebras[]", "infinitesimals", "subalgebra"}],
    Cell[130174, 4324, 293, 6, 44, "Text",
      CellTags->{
      "infinitesimals", "matrix", "first prolongation", "prolongation"}],
    Cell[355365, 9768, 256, 8, 29, "Text",
      CellTags->{"infinitesimals", "Infinitesimals[]"}],
    Cell[356694, 9813, 551, 13, 78, "Text",
      CellTags->{"solvable", "infinitesimals"}],
    Cell[1924735, 45714, 275, 7, 44, "Text",
      CellTags->{"Lie matrix", "infinitesimals"}]},
  "canonical variables"->{
    Cell[18872, 512, 418, 14, 34, "ListItem",
      CellTags->"canonical variables"],
    Cell[28648, 820, 1783, 54, 134, "Text",
      CellTags->{
      "integration algorithm", "canonical variables", 
        "characteristic equation", "CanonicalVariables[]"}],
    Cell[32092, 942, 654, 12, 80, "Text",
      CellTags->{"CanonicalRepresentation[]", "canonical variables"}],
    Cell[34370, 1010, 140, 4, 27, "Text",
      CellTags->"canonical variables"],
    Cell[91881, 3064, 768, 25, 61, "Text",
      CellTags->{
      "subgroups", "integration process", "group parameter", 
        "canonical variables"}],
    Cell[372607, 10263, 1400, 33, 129, "Text",
      CellTags->{
      "method of generalized multipliers", "technique of integrating factor", 
        "canonical variables", "skeleton"}],
    Cell[374151, 10304, 710, 14, 95, "Text",
      CellTags->{
      "skeleton", "second-order equation", "canonical variables", 
        "method of first integrals"}],
    Cell[374895, 10322, 378, 9, 61, "Text",
      CellTags->"canonical variables"],
    Cell[1920927, 45575, 603, 19, 61, "Text",
      CellTags->{"canonical variables", "subgroup"}]},
  "subalgebra"->{
    Cell[19393, 531, 1961, 54, 95, "Text",
      CellTags->{
      "subalgebra", "Lie algebra", "commutator", "pseudo scalar product"}],
    Cell[120121, 4049, 986, 22, 118, "Text",
      PageBreakBelow->True,
      CellTags->{
      "Infinitesimals[]", "SecondOrderAlgebras[]", "subalgebra", 
        "DeltaMatrix[]", "FirstIntegral[]", "determination of integrals"}],
    Cell[127375, 4247, 619, 11, 97, "Text",
      CellTags->{"SecondOrderAlgebras[]", "infinitesimals", "subalgebra"}]},
  "Example: 1"->{
    Cell[21357, 587, 54, 1, 29, "Example",
      CellTags->"Example: 1"]},
  "Lie\.b4s group classification"->{
    Cell[21414, 590, 504, 10, 61, "Text",
      CellTags->{"second-order ODE", "Lie\.b4s group classification"}]},
  "Infinitesimals[]"->{
    Cell[22569, 626, 1186, 28, 114, "Text",
      CellTags->{
      "Lie algebra", "Infinitesimals[]", "symbolic template", 
        "calculation of the infinitesimals"}],
    Cell[89909, 3000, 893, 22, 81, "Text",
      CellTags->{"symmetry transformation", "Infinitesimals[]"}],
    Cell[120121, 4049, 986, 22, 118, "Text",
      PageBreakBelow->True,
      CellTags->{
      "Infinitesimals[]", "SecondOrderAlgebras[]", "subalgebra", 
        "DeltaMatrix[]", "FirstIntegral[]", "determination of integrals"}],
    Cell[121943, 4101, 280, 7, 29, "Text",
      CellTags->{"infinitesimal symmetries", "Infinitesimals[]"}],
    Cell[124200, 4172, 1485, 38, 131, "Text",
      CellTags->{
      "SubstitutionRules", "Infinitesimals[]", "eight parameter group", 
        "largest group of a second-order ODE", "solvable"}],
    Cell[355365, 9768, 256, 8, 29, "Text",
      CellTags->{"infinitesimals", "Infinitesimals[]"}]},
  "symbolic template"->{
    Cell[22569, 626, 1186, 28, 114, "Text",
      CellTags->{
      "Lie algebra", "Infinitesimals[]", "symbolic template", 
        "calculation of the infinitesimals"}]},
  "calculation of the infinitesimals"->{
    Cell[22569, 626, 1186, 28, 114, "Text",
      CellTags->{
      "Lie algebra", "Infinitesimals[]", "symbolic template", 
        "calculation of the infinitesimals"}]},
  "Lie group"->{
    Cell[24834, 695, 1317, 40, 112, "Text",
      CellTags->{
      "Lie group", "symmetry group", "Lie algebra", "commutator table", 
        "calculate the commutator table", "structure constants"}]},
  "symmetry group"->{
    Cell[24834, 695, 1317, 40, 112, "Text",
      CellTags->{
      "Lie group", "symmetry group", "Lie algebra", "commutator table", 
        "calculate the commutator table", "structure constants"}]},
  "commutator table"->{
    Cell[24834, 695, 1317, 40, 112, "Text",
      CellTags->{
      "Lie group", "symmetry group", "Lie algebra", "commutator table", 
        "calculate the commutator table", "structure constants"}]},
  "calculate the commutator table"->{
    Cell[24834, 695, 1317, 40, 112, "Text",
      CellTags->{
      "Lie group", "symmetry group", "Lie algebra", "commutator table", 
        "calculate the commutator table", "structure constants"}]},
  "structure constants"->{
    Cell[24834, 695, 1317, 40, 112, "Text",
      CellTags->{
      "Lie group", "symmetry group", "Lie algebra", "commutator table", 
        "calculate the commutator table", "structure constants"}]},
  "LieCommutatorTable[]"->{
    Cell[26176, 739, 116, 2, 23, "Input",
      CellTags->"LieCommutatorTable[]"]},
  "algebra"->{
    Cell[26566, 755, 609, 15, 61, "Text",
      CellTags->{
      "algebra", "Lie's classification", "pseudo scalar product", 
        "infinitesimals"}]},
  "Lie's classification"->{
    Cell[26566, 755, 609, 15, 61, "Text",
      CellTags->{
      "algebra", "Lie's classification", "pseudo scalar product", 
        "infinitesimals"}]},
  "integration algorithm"->{
    Cell[28648, 820, 1783, 54, 134, "Text",
      CellTags->{
      "integration algorithm", "canonical variables", 
        "characteristic equation", "CanonicalVariables[]"}]},
  "characteristic equation"->{
    Cell[28648, 820, 1783, 54, 134, "Text",
      CellTags->{
      "integration algorithm", "canonical variables", 
        "characteristic equation", "CanonicalVariables[]"}]},
  "CanonicalVariables[]"->{
    Cell[28648, 820, 1783, 54, 134, "Text",
      CellTags->{
      "integration algorithm", "canonical variables", 
        "characteristic equation", "CanonicalVariables[]"}]},
  "transformations"->{
    Cell[31090, 903, 193, 5, 44, "Text",
      CellTags->"transformations"]},
  "CanonicalRepresentation[]"->{
    Cell[32092, 942, 654, 12, 80, "Text",
      CellTags->{"CanonicalRepresentation[]", "canonical variables"}]},
  "DSolve[]"->{
    Cell[33279, 976, 428, 11, 65, "Text",
      CellTags->"DSolve[]"],
    Cell[35253, 1043, 337, 9, 46, "Text",
      CellTags->{"simplification of ODEs", "symmetry analysis", "DSolve[]"}],
    Cell[89142, 2973, 183, 5, 29, "Text",
      CellTags->"DSolve[]"],
    Cell[93957, 3143, 352, 7, 63, "Text",
      CellTags->{"DSolve[]", "canonical coordinates"}],
    Cell[351019, 9624, 583, 13, 82, "Text",
      CellTags->{"SecondOrderIntegrate[]", "second-order ODE", "DSolve[]"}],
    Cell[351864, 9650, 942, 33, 80, "Text",
      CellTags->"DSolve[]"],
    Cell[366849, 10116, 696, 24, 63, "Text",
      CellTags->"DSolve[]"],
    Cell[1917885, 45476, 385, 7, 63, "Text",
      CellTags->{"canonical representation", "DSolve[]"}],
    Cell[1918886, 45506, 291, 8, 46, "Text",
      CellTags->"DSolve[]"],
    Cell[1930892, 45890, 361, 11, 46, "Text",
      CellTags->"DSolve[]"],
    Cell[1933559, 45987, 717, 18, 80, "Text",
      CellTags->{"hybrid algorithm", "DSolve[]"}]},
  "simplification of ODEs"->{
    Cell[35253, 1043, 337, 9, 46, "Text",
      CellTags->{
      "simplification of ODEs", "symmetry analysis", "DSolve[]"}]},
  "symmetry analysis"->{
    Cell[35253, 1043, 337, 9, 46, "Text",
      CellTags->{
      "simplification of ODEs", "symmetry analysis", "DSolve[]"}]},
  "constants of integration"->{
    Cell[36023, 1070, 855, 23, 63, "Text",
      CellTags->{
      "constants of integration", "ProductLog[]", 
        "generalization of a logarithm", "transcendental equation"}]},
  "ProductLog[]"->{
    Cell[36023, 1070, 855, 23, 63, "Text",
      CellTags->{
      "constants of integration", "ProductLog[]", 
        "generalization of a logarithm", "transcendental equation"}]},
  "generalization of a logarithm"->{
    Cell[36023, 1070, 855, 23, 63, "Text",
      CellTags->{
      "constants of integration", "ProductLog[]", 
        "generalization of a logarithm", "transcendental equation"}]},
  "transcendental equation"->{
    Cell[36023, 1070, 855, 23, 63, "Text",
      CellTags->{
      "constants of integration", "ProductLog[]", 
        "generalization of a logarithm", "transcendental equation"}]},
  "inversion of a transformation"->{
    Cell[36881, 1095, 709, 13, 97, "Text",
      CellTags->{"inversion of a transformation", "BackTrafoCanonical[]"}]},
  "BackTrafoCanonical[]"->{
    Cell[36881, 1095, 709, 13, 97, "Text",
      CellTags->{"inversion of a transformation", "BackTrafoCanonical[]"}]},
  "special function"->{
    Cell[38278, 1140, 486, 12, 61, "Text",
      CellTags->"special function"]},
  "algorithm of group classification"->{
    Cell[86797, 2907, 498, 10, 78, "Text",
      CellTags->"algorithm of group classification"]},
  "heat transfer"->{
    Cell[87329, 2921, 731, 15, 78, "Text",
      CellTags->{
      "heat transfer", "vortex motion", "space charge of elasticity", 
        "glowing wire", "nebular theory", 
        "mass distribution of gaseous interstellar material", 
        "gravitational field"}]},
  "vortex motion"->{
    Cell[87329, 2921, 731, 15, 78, "Text",
      CellTags->{
      "heat transfer", "vortex motion", "space charge of elasticity", 
        "glowing wire", "nebular theory", 
        "mass distribution of gaseous interstellar material", 
        "gravitational field"}]},
  "space charge of elasticity"->{
    Cell[87329, 2921, 731, 15, 78, "Text",
      CellTags->{
      "heat transfer", "vortex motion", "space charge of elasticity", 
        "glowing wire", "nebular theory", 
        "mass distribution of gaseous interstellar material", 
        "gravitational field"}]},
  "glowing wire"->{
    Cell[87329, 2921, 731, 15, 78, "Text",
      CellTags->{
      "heat transfer", "vortex motion", "space charge of elasticity", 
        "glowing wire", "nebular theory", 
        "mass distribution of gaseous interstellar material", 
        "gravitational field"}]},
  "nebular theory"->{
    Cell[87329, 2921, 731, 15, 78, "Text",
      CellTags->{
      "heat transfer", "vortex motion", "space charge of elasticity", 
        "glowing wire", "nebular theory", 
        "mass distribution of gaseous interstellar material", 
        "gravitational field"}]},
  "mass distribution of gaseous interstellar material"->{
    Cell[87329, 2921, 731, 15, 78, "Text",
      CellTags->{
      "heat transfer", "vortex motion", "space charge of elasticity", 
        "glowing wire", "nebular theory", 
        "mass distribution of gaseous interstellar material", 
        "gravitational field"}]},
  "gravitational field"->{
    Cell[87329, 2921, 731, 15, 78, "Text",
      CellTags->{
      "heat transfer", "vortex motion", "space charge of elasticity", 
        "glowing wire", "nebular theory", 
        "mass distribution of gaseous interstellar material", 
        "gravitational field"}]},
  "cylindrical coordinates"->{
    Cell[88063, 2938, 481, 11, 61, "Text",
      CellTags->{
      "cylindrical coordinates", 
        "second-order ordinary differential equation"}]},
  "second-order ordinary differential equation"->{
    Cell[88063, 2938, 481, 11, 61, "Text",
      CellTags->{
      "cylindrical coordinates", 
        "second-order ordinary differential equation"}],
    Cell[111718, 3793, 273, 7, 44, "Text",
      CellTags->{
      "second-order ordinary differential equation", "classification", 
        "quadrature"}]},
  "symmetry transformation"->{
    Cell[89909, 3000, 893, 22, 81, "Text",
      CellTags->{"symmetry transformation", "Infinitesimals[]"}]},
  "subgroups"->{
    Cell[91881, 3064, 768, 25, 61, "Text",
      CellTags->{
      "subgroups", "integration process", "group parameter", 
        "canonical variables"}]},
  "integration process"->{
    Cell[91881, 3064, 768, 25, 61, "Text",
      CellTags->{
      "subgroups", "integration process", "group parameter", 
        "canonical variables"}]},
  "group parameter"->{
    Cell[91881, 3064, 768, 25, 61, "Text",
      CellTags->{
      "subgroups", "integration process", "group parameter", 
        "canonical variables"}]},
  "canonical coordinates"->{
    Cell[93957, 3143, 352, 7, 63, "Text",
      CellTags->{"DSolve[]", "canonical coordinates"}],
    Cell[1690682, 39880, 724, 19, 61, "Text",
      CellTags->{"method of canonical variables", "canonical coordinates"}],
    Cell[1917420, 45467, 462, 7, 61, "Text",
      CellTags->{"skeleton", "canonical coordinates"}]},
  "inversion"->{
    Cell[94927, 3172, 298, 10, 27, "Text",
      CellTags->{"inversion", "canonical transformation"}]},
  "canonical transformation"->{
    Cell[94927, 3172, 298, 10, 27, "Text",
      CellTags->{"inversion", "canonical transformation"}]},
  "classification"->{
    Cell[111718, 3793, 273, 7, 44, "Text",
      CellTags->{
      "second-order ordinary differential equation", "classification", 
        "quadrature"}]},
  "quadrature"->{
    Cell[111718, 3793, 273, 7, 44, "Text",
      CellTags->{
      "second-order ordinary differential equation", "classification", 
        "quadrature"}],
    Cell[112968, 3821, 931, 19, 112, "Text",
      CellTags->{
      "integrating factor", "quadrature", 
        "algorithm for integrating factors"}]},
  "Method of integrating factor"->{
    Cell[112862, 3818, 103, 1, 41, "Subsection",
      CellTags->"Method of integrating factor"]},
  "integrating factor"->{
    Cell[112968, 3821, 931, 19, 112, "Text",
      CellTags->{
      "integrating factor", "quadrature", 
        "algorithm for integrating factors"}],
    Cell[129119, 4291, 428, 9, 63, "Text",
      CellTags->{
      "Lie's matrix", "integrating factor", "DeltaMatrix[]", "subgroup"}]},
  "algorithm for integrating factors"->{
    Cell[112968, 3821, 931, 19, 112, "Text",
      CellTags->{
      "integrating factor", "quadrature", 
        "algorithm for integrating factors"}]},
  "integration procedure"->{
    Cell[113902, 3842, 385, 7, 44, "Text",
      CellTags->{"integration procedure", "group theoretic quadrature"}]},
  "five steps of integration"->{
    Cell[114290, 3851, 750, 24, 34, "ListItem",
      CellTags->{
      "five steps of integration", "Lie algebra", "tangent vector field", 
        "group constant"}]},
  "tangent vector field"->{
    Cell[114290, 3851, 750, 24, 34, "ListItem",
      CellTags->{
      "five steps of integration", "Lie algebra", "tangent vector field", 
        "group constant"}]},
  "group constant"->{
    Cell[114290, 3851, 750, 24, 34, "ListItem",
      CellTags->{
      "five steps of integration", "Lie algebra", "tangent vector field", 
        "group constant"}]},
  "determinant"->{
    Cell[115609, 3900, 543, 17, 20, "ListItem",
      CellTags->{"determinant", "Lie determinant", "first integrals"}],
    Cell[358546, 9870, 191, 7, 27, "Text",
      CellTags->"determinant"],
    Cell[1926426, 45768, 88, 1, 27, "Text",
      CellTags->"determinant"]},
  "Lie determinant"->{
    Cell[115609, 3900, 543, 17, 20, "ListItem",
      CellTags->{"determinant", "Lie determinant", "first integrals"}]},
  "first integrals"->{
    Cell[115609, 3900, 543, 17, 20, "ListItem",
      CellTags->{"determinant", "Lie determinant", "first integrals"}]},
  "Lie matrix"->{
    Cell[116155, 3919, 1393, 39, 51, "NumberedEquation",
      CellTags->"Lie matrix"],
    Cell[128554, 4275, 562, 14, 63, "Text",
      CellTags->{"Lie matrix", "DeltaMatrix[]", "matrix"}],
    Cell[357612, 9838, 340, 8, 44, "Text",
      CellTags->"Lie matrix"],
    Cell[1924735, 45714, 275, 7, 44, "Text",
      CellTags->{"Lie matrix", "infinitesimals"}]},
  "eq-21"->{
    Cell[118933, 4008, 549, 15, 35, "NumberedEquation",
      CellTags->"eq-21"]},
  "SecondOrderAlgebras[]"->{
    Cell[120121, 4049, 986, 22, 118, "Text",
      PageBreakBelow->True,
      CellTags->{
      "Infinitesimals[]", "SecondOrderAlgebras[]", "subalgebra", 
        "DeltaMatrix[]", "FirstIntegral[]", "determination of integrals"}],
    Cell[125688, 4212, 766, 14, 114, "Text",
      CellTags->{
      "Lie algebra", "subgroup of order two", "SecondOrderAlgebras[]", 
        "second-order solvable subalgebras", "group constants"}],
    Cell[127375, 4247, 619, 11, 97, "Text",
      CellTags->{"SecondOrderAlgebras[]", "infinitesimals", "subalgebra"}]},
  "DeltaMatrix[]"->{
    Cell[120121, 4049, 986, 22, 118, "Text",
      PageBreakBelow->True,
      CellTags->{
      "Infinitesimals[]", "SecondOrderAlgebras[]", "subalgebra", 
        "DeltaMatrix[]", "FirstIntegral[]", "determination of integrals"}],
    Cell[128554, 4275, 562, 14, 63, "Text",
      CellTags->{"Lie matrix", "DeltaMatrix[]", "matrix"}],
    Cell[129119, 4291, 428, 9, 63, "Text",
      CellTags->{
      "Lie's matrix", "integrating factor", "DeltaMatrix[]", "subgroup"}]},
  "FirstIntegral[]"->{
    Cell[120121, 4049, 986, 22, 118, "Text",
      PageBreakBelow->True,
      CellTags->{
      "Infinitesimals[]", "SecondOrderAlgebras[]", "subalgebra", 
        "DeltaMatrix[]", "FirstIntegral[]", "determination of integrals"}]},
  "determination of integrals"->{
    Cell[120121, 4049, 986, 22, 118, "Text",
      PageBreakBelow->True,
      CellTags->{
      "Infinitesimals[]", "SecondOrderAlgebras[]", "subalgebra", 
        "DeltaMatrix[]", "FirstIntegral[]", "determination of integrals"}]},
  "nonlinear second-order equation"->{
    Cell[121213, 4077, 278, 4, 44, "Text",
      CellTags->"nonlinear second-order equation"]},
  "infinitesimal symmetries"->{
    Cell[121943, 4101, 280, 7, 29, "Text",
      CellTags->{"infinitesimal symmetries", "Infinitesimals[]"}]},
  "SubstitutionRules"->{
    Cell[124200, 4172, 1485, 38, 131, "Text",
      CellTags->{
      "SubstitutionRules", "Infinitesimals[]", "eight parameter group", 
        "largest group of a second-order ODE", "solvable"}]},
  "eight parameter group"->{
    Cell[124200, 4172, 1485, 38, 131, "Text",
      CellTags->{
      "SubstitutionRules", "Infinitesimals[]", "eight parameter group", 
        "largest group of a second-order ODE", "solvable"}]},
  "largest group of a second-order ODE"->{
    Cell[124200, 4172, 1485, 38, 131, "Text",
      CellTags->{
      "SubstitutionRules", "Infinitesimals[]", "eight parameter group", 
        "largest group of a second-order ODE", "solvable"}]},
  "solvable"->{
    Cell[124200, 4172, 1485, 38, 131, "Text",
      CellTags->{
      "SubstitutionRules", "Infinitesimals[]", "eight parameter group", 
        "largest group of a second-order ODE", "solvable"}],
    Cell[356694, 9813, 551, 13, 78, "Text",
      CellTags->{"solvable", "infinitesimals"}]},
  "subgroup of order two"->{
    Cell[125688, 4212, 766, 14, 114, "Text",
      CellTags->{
      "Lie algebra", "subgroup of order two", "SecondOrderAlgebras[]", 
        "second-order solvable subalgebras", "group constants"}]},
  "second-order solvable subalgebras"->{
    Cell[125688, 4212, 766, 14, 114, "Text",
      CellTags->{
      "Lie algebra", "subgroup of order two", "SecondOrderAlgebras[]", 
        "second-order solvable subalgebras", "group constants"}]},
  "group constants"->{
    Cell[125688, 4212, 766, 14, 114, "Text",
      CellTags->{
      "Lie algebra", "subgroup of order two", "SecondOrderAlgebras[]", 
        "second-order solvable subalgebras", "group constants"}]},
  "matrix"->{
    Cell[128554, 4275, 562, 14, 63, "Text",
      CellTags->{"Lie matrix", "DeltaMatrix[]", "matrix"}],
    Cell[130174, 4324, 293, 6, 44, "Text",
      CellTags->{
      "infinitesimals", "matrix", "first prolongation", "prolongation"}]},
  "Lie's matrix"->{
    Cell[129119, 4291, 428, 9, 63, "Text",
      CellTags->{
      "Lie's matrix", "integrating factor", "DeltaMatrix[]", "subgroup"}]},
  "subgroup"->{
    Cell[129119, 4291, 428, 9, 63, "Text",
      CellTags->{
      "Lie's matrix", "integrating factor", "DeltaMatrix[]", "subgroup"}],
    Cell[1920927, 45575, 603, 19, 61, "Text",
      CellTags->{"canonical variables", "subgroup"}]},
  "first prolongation"->{
    Cell[130174, 4324, 293, 6, 44, "Text",
      CellTags->{
      "infinitesimals", "matrix", "first prolongation", "prolongation"}]},
  "prolongation"->{
    Cell[130174, 4324, 293, 6, 44, "Text",
      CellTags->{
      "infinitesimals", "matrix", "first prolongation", "prolongation"}]},
  "second-order polynomial"->{
    Cell[130714, 4342, 576, 14, 61, "Text",
      CellTags->{
      "second-order polynomial", "first integral", 
        "calculate first integrals"}]},
  "first integral"->{
    Cell[130714, 4342, 576, 14, 61, "Text",
      CellTags->{
      "second-order polynomial", "first integral", 
        "calculate first integrals"}],
    Cell[348471, 9535, 279, 8, 44, "Text",
      CellTags->"first integral"],
    Cell[362849, 10008, 477, 12, 61, "Text",
      CellTags->"first integral"]},
  "calculate first integrals"->{
    Cell[130714, 4342, 576, 14, 61, "Text",
      CellTags->{
      "second-order polynomial", "first integral", 
        "calculate first integrals"}]},
  "implicit representation of a solution"->{
    Cell[349701, 9581, 319, 8, 44, "Text",
      CellTags->"implicit representation of a solution"]},
  "translation"->{
    Cell[350384, 9604, 632, 18, 61, "Text",
      CellTags->"translation"]},
  "SecondOrderIntegrate[]"->{
    Cell[351019, 9624, 583, 13, 82, "Text",
      CellTags->{"SecondOrderIntegrate[]", "second-order ODE", "DSolve[]"}],
    Cell[365704, 10087, 179, 4, 23, "Input",
      CellTags->"SecondOrderIntegrate[]"],
    Cell[1931727, 45921, 225, 5, 46, "Text",
      CellTags->"SecondOrderIntegrate[]"]},
  "Lie's method of first integrals"->{
    Cell[353012, 9695, 370, 8, 44, "Text",
      CellTags->"Lie's method of first integrals"]},
  "generalized suspended cable equation"->{
    Cell[353416, 9707, 176, 4, 27, "Text",
      CellTags->"generalized suspended cable equation"]},
  "suspended cable"->{
    Cell[353731, 9718, 334, 8, 44, "Text",
      CellTags->"suspended cable"]},
  "Lie's integration algorithm"->{
    Cell[355124, 9762, 238, 4, 44, "Text",
      CellTags->{"Lie's integration algorithm", "point symmetries"}]},
  "point symmetries"->{
    Cell[355124, 9762, 238, 4, 44, "Text",
      CellTags->{"Lie's integration algorithm", "point symmetries"}]},
  "transcendental function"->{
    Cell[364270, 10046, 162, 4, 27, "Text",
      CellTags->"transcendental function"],
    Cell[372253, 10256, 351, 5, 44, "Text",
      CellTags->{"transcendental function", "generalized cable equation"}]},
  "generalized cable equation"->{
    Cell[372253, 10256, 351, 5, 44, "Text",
      CellTags->{"transcendental function", "generalized cable equation"}]},
  "method of generalized multipliers"->{
    Cell[372607, 10263, 1400, 33, 129, "Text",
      CellTags->{
      "method of generalized multipliers", "technique of integrating factor", 
        "canonical variables", "skeleton"}]},
  "technique of integrating factor"->{
    Cell[372607, 10263, 1400, 33, 129, "Text",
      CellTags->{
      "method of generalized multipliers", "technique of integrating factor", 
        "canonical variables", "skeleton"}]},
  "skeleton"->{
    Cell[372607, 10263, 1400, 33, 129, "Text",
      CellTags->{
      "method of generalized multipliers", "technique of integrating factor", 
        "canonical variables", "skeleton"}],
    Cell[374151, 10304, 710, 14, 95, "Text",
      CellTags->{
      "skeleton", "second-order equation", "canonical variables", 
        "method of first integrals"}],
    Cell[376959, 10394, 1056, 18, 129, "Text",
      CellTags->{
      "group of scaling", "group of projection", "skeleton", "manifold"}],
    Cell[1917420, 45467, 462, 7, 61, "Text",
      CellTags->{"skeleton", "canonical coordinates"}]},
  "Method of canonical variables"->{
    Cell[374044, 10301, 104, 1, 41, "Subsection",
      CellTags->"Method of canonical variables"]},
  "second-order equation"->{
    Cell[374151, 10304, 710, 14, 95, "Text",
      CellTags->{
      "skeleton", "second-order equation", "canonical variables", 
        "method of first integrals"}]},
  "method of first integrals"->{
    Cell[374151, 10304, 710, 14, 95, "Text",
      CellTags->{
      "skeleton", "second-order equation", "canonical variables", 
        "method of first integrals"}]},
  "group of scaling"->{
    Cell[376959, 10394, 1056, 18, 129, "Text",
      CellTags->{
      "group of scaling", "group of projection", "skeleton", "manifold"}]},
  "group of projection"->{
    Cell[376959, 10394, 1056, 18, 129, "Text",
      CellTags->{
      "group of scaling", "group of projection", "skeleton", "manifold"}]},
  "manifold"->{
    Cell[376959, 10394, 1056, 18, 129, "Text",
      CellTags->{
      "group of scaling", "group of projection", "skeleton", "manifold"}],
    Cell[1689963, 39858, 716, 20, 78, "Text",
      CellTags->{"animation", "manifold"}]},
  "animation"->{
    Cell[378103, 10417, 590, 16, 61, "Text",
      CellTags->{"animation", "submanifold"}],
    Cell[1689963, 39858, 716, 20, 78, "Text",
      CellTags->{"animation", "manifold"}]},
  "submanifold"->{
    Cell[378103, 10417, 590, 16, 61, "Text",
      CellTags->{"animation", "submanifold"}]},
  "method of canonical variables"->{
    Cell[1690682, 39880, 724, 19, 61, "Text",
      CellTags->{"method of canonical variables", "canonical coordinates"}]},
  "first reduction"->{
    Cell[1693340, 39981, 152, 3, 39, "Input",
      CellTags->"first reduction"]},
  "second reduction"->{
    Cell[1693906, 40004, 153, 3, 39, "Input",
      CellTags->"second reduction"]},
  "reduced manifold"->{
    Cell[1694552, 40027, 464, 10, 61, "Text",
      CellTags->"reduced manifold"]},
  "canonical representation"->{
    Cell[1917885, 45476, 385, 7, 63, "Text",
      CellTags->{"canonical representation", "DSolve[]"}],
    Cell[1922893, 45649, 372, 9, 44, "Text",
      CellTags->"canonical representation"]},
  "symmetries of first canonical reduction"->{
    Cell[1919835, 45537, 423, 9, 61, "Text",
      CellTags->"symmetries of first canonical reduction"]},
  "canonical reduction"->{
    Cell[1922226, 45624, 219, 6, 44, "Text",
      PageBreakBelow->True,
      CellTags->"canonical reduction"]},
  "second-order group"->{
    Cell[1923720, 45678, 304, 6, 61, "Text",
      CellTags->"second-order group"]},
  "hybrid algorithm"->{
    Cell[1933559, 45987, 717, 18, 80, "Text",
      CellTags->{"hybrid algorithm", "DSolve[]"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Second order ordinary differential equations", 1951427, 46607},
  {"second-order ordinary differential equations", 1951827, 46614},
  {"engineering", 1952034, 46619},
  {"physics", 1952237, 46624},
  {"Newton's second law", 1952452, 46629},
  {"mechanics", 1952657, 46634},
  {"transformation groups", 1952874, 46639},
  {"integration strategies", 1953113, 46645},
  {"general integration theory", 1953356, 46651},
  {"infinitesimal transformation", 1953601, 46657},
  {"group", 1953823, 46663},
  {"second-order ODE", 1954056, 46669},
  {"solution of a second-order ODE", 1954582, 46680},
  {"symmetry of an equation", 1954741, 46684},
  {"Algorithm of Integration", 1954901, 46688},
  {"Lie algebra", 1955012, 46691},
  {"group theoretic quadrature", 1956206, 46717},
  {"quadrature method", 1956524, 46724},
  {"algorithm", 1956717, 46729},
  {"admitted Lie algebra", 1956921, 46734},
  {"classification of second order algebras", 1957072, 46737},
  {"commutator", 1957206, 46740},
  {"pseudo scalar product", 1957496, 46746},
  {"infinitesimals", 1958017, 46758},
  {"canonical variables", 1958950, 46778},
  {"subalgebra", 1960126, 46805},
  {"Example: 1", 1960635, 46816},
  {"Lie\.b4s group classification", 1960747, 46819},
  {"Infinitesimals[]", 1960886, 46822},
  {"symbolic template", 1961834, 46842},
  {"calculation of the infinitesimals", 1962048, 46847},
  {"Lie group", 1962238, 46852},
  {"symmetry group", 1962463, 46857},
  {"commutator table", 1962690, 46862},
  {"calculate the commutator table", 1962931, 46867},
  {"structure constants", 1963161, 46872},
  {"LieCommutatorTable[]", 1963392, 46877},
  {"algebra", 1963491, 46880},
  {"Lie's classification", 1963675, 46885},
  {"integration algorithm", 1963860, 46890},
  {"characteristic equation", 1964070, 46895},
  {"CanonicalVariables[]", 1964277, 46900},
  {"transformations", 1964479, 46905},
  {"CanonicalRepresentation[]", 1964590, 46908},
  {"DSolve[]", 1964720, 46911},
  {"simplification of ODEs", 1965729, 46934},
  {"symmetry analysis", 1965882, 46938},
  {"constants of integration", 1966042, 46942},
  {"ProductLog[]", 1966245, 46947},
  {"generalization of a logarithm", 1966465, 46952},
  {"transcendental equation", 1966679, 46957},
  {"inversion of a transformation", 1966899, 46962},
  {"BackTrafoCanonical[]", 1967047, 46965},
  {"special function", 1967191, 46968},
  {"algorithm of group classification", 1967313, 46971},
  {"heat transfer", 1967432, 46974},
  {"vortex motion", 1967725, 46981},
  {"space charge of elasticity", 1968031, 46988},
  {"glowing wire", 1968323, 46995},
  {"nebular theory", 1968617, 47002},
  {"mass distribution of gaseous interstellar material", 1968947, 47009},
  {"gravitational field", 1969246, 47016},
  {"cylindrical coordinates", 1969549, 47023},
  {"second-order ordinary differential equation", 1969753, 47028},
  {"symmetry transformation", 1970094, 47037},
  {"subgroups", 1970221, 47040},
  {"integration process", 1970405, 47045},
  {"group parameter", 1970585, 47050},
  {"canonical coordinates", 1970771, 47055},
  {"inversion", 1971111, 47062},
  {"canonical transformation", 1971247, 47065},
  {"classification", 1971373, 47068},
  {"quadrature", 1971549, 47073},
  {"Method of integrating factor", 1971896, 47082},
  {"integrating factor", 1972021, 47085},
  {"algorithm for integrating factors", 1972352, 47093},
  {"integration procedure", 1972535, 47098},
  {"five steps of integration", 1972686, 47101},
  {"tangent vector field", 1972884, 47106},
  {"group constant", 1973076, 47111},
  {"determinant", 1973265, 47116},
  {"Lie determinant", 1973560, 47123},
  {"first integrals", 1973704, 47126},
  {"Lie matrix", 1973843, 47129},
  {"eq-21", 1974219, 47138},
  {"SecondOrderAlgebras[]", 1974331, 47141},
  {"DeltaMatrix[]", 1974907, 47153},
  {"FirstIntegral[]", 1975404, 47164},
  {"determination of integrals", 1975672, 47170},
  {"nonlinear second-order equation", 1975945, 47176},
  {"infinitesimal symmetries", 1976073, 47179},
  {"SubstitutionRules", 1976209, 47182},
  {"eight parameter group", 1976437, 47187},
  {"largest group of a second-order ODE", 1976679, 47192},
  {"solvable", 1976894, 47197},
  {"subgroup of order two", 1977215, 47204},
  {"second-order solvable subalgebras", 1977458, 47209},
  {"group constants", 1977683, 47214},
  {"matrix", 1977899, 47219},
  {"Lie's matrix", 1978159, 47225},
  {"subgroup", 1978312, 47229},
  {"first prolongation", 1978575, 47235},
  {"prolongation", 1978731, 47239},
  {"second-order polynomial", 1978898, 47243},
  {"first integral", 1979074, 47248},
  {"calculate first integrals", 1979419, 47257},
  {"implicit representation of a solution", 1979618, 47262},
  {"translation", 1979739, 47265},
  {"SecondOrderIntegrate[]", 1979846, 47268},
  {"Lie's method of first integrals", 1980183, 47275},
  {"generalized suspended cable equation", 1980323, 47278},
  {"suspended cable", 1980447, 47281},
  {"Lie's integration algorithm", 1980562, 47284},
  {"point symmetries", 1980700, 47287},
  {"transcendental function", 1980845, 47290},
  {"generalized cable equation", 1981088, 47295},
  {"method of generalized multipliers", 1981250, 47298},
  {"technique of integrating factor", 1981479, 47303},
  {"skeleton", 1981685, 47308},
  {"Method of canonical variables", 1982322, 47322},
  {"second-order equation", 1982452, 47325},
  {"method of first integrals", 1982655, 47330},
  {"group of scaling", 1982849, 47335},
  {"group of projection", 1983017, 47339},
  {"manifold", 1983174, 47343},
  {"animation", 1983422, 47349},
  {"submanifold", 1983624, 47354},
  {"method of canonical variables", 1983754, 47357},
  {"first reduction", 1983901, 47360},
  {"second reduction", 1984008, 47363},
  {"reduced manifold", 1984116, 47366},
  {"canonical representation", 1984232, 47369},
  {"symmetries of first canonical reduction", 1984474, 47374},
  {"canonical reduction", 1984607, 47377},
  {"second-order group", 1984747, 47381},
  {"hybrid algorithm", 1984856, 47384}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 407, 5, 43, "Section",
  CounterAssignments->{{"Title", 4}, {"SubTitle", 0}, {"SubSubTitle", 0}, {
      "Section", 0}, {"SubSection", 0}, {"SubSubSection", 0}, {
      "NumberedEquation", 56}, {"NumberedFigure", 0}, {"NumberedTable", 0}},
  CellTags->"Second order ordinary differential equations"],
Cell[2149, 58, 1580, 36, 146, "Text",
  CellTags->{
  "second-order ordinary differential equations", "engineering", "physics", 
    "Newton's second law", "mechanics"}],
Cell[3732, 96, 1008, 15, 129, "Text",
  CellTags->{
  "transformation groups", "integration strategies", 
    "general integration theory", "infinitesimal transformation", "group"}],
Cell[4743, 113, 180, 3, 27, "Text",
  CellTags->"second-order ODE"],
Cell[4926, 118, 98, 2, 22, "NumberedEquation"],
Cell[5027, 122, 289, 7, 44, "Text"],
Cell[5319, 131, 102, 2, 22, "NumberedEquation"],
Cell[5424, 135, 242, 11, 27, "Text"],
Cell[5669, 148, 554, 9, 78, "Text",
  CellTags->{"solution of a second-order ODE", "symmetry of an equation"}],

Cell[CellGroupData[{
Cell[6248, 161, 105, 1, 41, "Subsection",
  CellTags->"Algorithm of Integration"],
Cell[6356, 164, 657, 15, 61, "Text",
  CellTags->{
  "second-order ODE", "Lie algebra", "group theoretic quadrature", 
    "quadrature method", "algorithm"}],
Cell[7016, 181, 646, 21, 20, "ListItem",
  CellTags->{"admitted Lie algebra", "Lie algebra"}],
Cell[7665, 204, 574, 21, 62, "ListItem"],
Cell[8242, 227, 181, 6, 20, "ListItem"],
Cell[8426, 235, 8296, 201, 67, "NumberedEquation",
  CellTags->"classification of second order algebras"],
Cell[16725, 438, 2144, 72, 58, "ListItem",
  CellTags->{"commutator", "pseudo scalar product", "infinitesimals"}],
Cell[18872, 512, 418, 14, 34, "ListItem",
  CellTags->"canonical variables"],
Cell[19293, 528, 97, 1, 20, "ListItem"],
Cell[19393, 531, 1961, 54, 95, "Text",
  CellTags->{
  "subalgebra", "Lie algebra", "commutator", "pseudo scalar product"}],
Cell[21357, 587, 54, 1, 29, "Example",
  CellTags->"Example: 1"],
Cell[21414, 590, 504, 10, 61, "Text",
  CellTags->{"second-order ODE", "Lie\.b4s group classification"}],

Cell[CellGroupData[{
Cell[21943, 604, 154, 3, 38, "Input"],
Cell[22100, 609, 454, 14, 34, "Output"]
}, Open  ]],
Cell[22569, 626, 1186, 28, 114, "Text",
  CellTags->{
  "Lie algebra", "Infinitesimals[]", "symbolic template", 
    "calculation of the infinitesimals"}],

Cell[CellGroupData[{
Cell[23780, 658, 434, 12, 24, "Input"],
Cell[24217, 672, 602, 20, 36, "Output"]
}, Open  ]],
Cell[24834, 695, 1317, 40, 112, "Text",
  CellTags->{
  "Lie group", "symmetry group", "Lie algebra", "commutator table", 
    "calculate the commutator table", "structure constants"}],

Cell[CellGroupData[{
Cell[26176, 739, 116, 2, 23, "Input",
  CellTags->"LieCommutatorTable[]"],
Cell[26295, 743, 256, 9, 32, "Output"]
}, Open  ]],
Cell[26566, 755, 609, 15, 61, "Text",
  CellTags->{
  "algebra", "Lie's classification", "pseudo scalar product", 
    "infinitesimals"}],
Cell[27178, 772, 587, 15, 37, "DisplayFormula"],
Cell[27768, 789, 191, 6, 27, "Text",
  CellTags->"pseudo scalar product"],
Cell[27962, 797, 150, 3, 23, "Input"],
Cell[28115, 802, 150, 3, 23, "Input"],

Cell[CellGroupData[{
Cell[28290, 809, 292, 5, 23, "Input"],
Cell[28585, 816, 48, 1, 35, "Output"]
}, Open  ]],
Cell[28648, 820, 1783, 54, 134, "Text",
  CellTags->{
  "integration algorithm", "canonical variables", "characteristic equation", 
    "CanonicalVariables[]"}],

Cell[CellGroupData[{
Cell[30456, 878, 125, 2, 32, "Input"],
Cell[30584, 882, 491, 18, 50, "Output"]
}, Open  ]],
Cell[31090, 903, 193, 5, 44, "Text",
  CellTags->"transformations"],

Cell[CellGroupData[{
Cell[31308, 912, 157, 3, 39, "Input"],
Cell[31468, 917, 609, 22, 58, "Output"]
}, Open  ]],
Cell[32092, 942, 654, 12, 80, "Text",
  CellTags->{"CanonicalRepresentation[]", "canonical variables"}],

Cell[CellGroupData[{
Cell[32771, 958, 222, 5, 54, "Input"],
Cell[32996, 965, 268, 8, 24, "Output"]
}, Open  ]],
Cell[33279, 976, 428, 11, 65, "Text",
  CellTags->"DSolve[]"],

Cell[CellGroupData[{
Cell[33732, 991, 68, 1, 23, "Input"],
Cell[33803, 994, 552, 13, 23, "Output"]
}, Open  ]],
Cell[34370, 1010, 140, 4, 27, "Text",
  CellTags->"canonical variables"],

Cell[CellGroupData[{
Cell[34535, 1018, 225, 5, 51, "Input"],
Cell[34763, 1025, 475, 15, 32, "Output"]
}, Open  ]],
Cell[35253, 1043, 337, 9, 46, "Text",
  CellTags->{"simplification of ODEs", "symmetry analysis", "DSolve[]"}],

Cell[CellGroupData[{
Cell[35615, 1056, 68, 1, 23, "Input"],
Cell[35686, 1059, 168, 3, 37, "Message"],
Cell[35857, 1064, 151, 3, 41, "Output"]
}, Open  ]],
Cell[36023, 1070, 855, 23, 63, "Text",
  CellTags->{
  "constants of integration", "ProductLog[]", "generalization of a logarithm",
     "transcendental equation"}],
Cell[36881, 1095, 709, 13, 97, "Text",
  CellTags->{"inversion of a transformation", "BackTrafoCanonical[]"}],

Cell[CellGroupData[{
Cell[37615, 1112, 132, 3, 23, "Input"],
Cell[37750, 1117, 222, 6, 44, "Output"]
}, Open  ]],
Cell[37987, 1126, 142, 3, 27, "Text"],

Cell[CellGroupData[{
Cell[38154, 1133, 69, 1, 23, "Input"],
Cell[38226, 1136, 37, 1, 23, "Output"]
}, Open  ]],
Cell[38278, 1140, 486, 12, 61, "Text",
  CellTags->"special function"],
Cell[38767, 1154, 165, 3, 23, "Input"],
Cell[38935, 1159, 154, 5, 27, "Text"],
Cell[39092, 1166, 54, 1, 23, "Input"],

Cell[CellGroupData[{
Cell[39171, 1171, 342, 6, 55, "Input"],
Cell[39516, 1179, 24063, 870, 145, 16800, 776, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[63594, 2052, 136, 5, 27, "Text"],
Cell[63733, 2059, 148, 3, 23, "Input"],

Cell[CellGroupData[{
Cell[63906, 2066, 342, 6, 55, "Input"],
Cell[64251, 2074, 22531, 830, 138, 16568, 752, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[86797, 2907, 498, 10, 78, "Text",
  CellTags->"algorithm of group classification"],
Cell[87298, 2919, 28, 0, 29, "Example"],
Cell[87329, 2921, 731, 15, 78, "Text",
  CellTags->{
  "heat transfer", "vortex motion", "space charge of elasticity", 
    "glowing wire", "nebular theory", 
    "mass distribution of gaseous interstellar material", 
    "gravitational field"}],
Cell[88063, 2938, 481, 11, 61, "Text",
  CellTags->{
  "cylindrical coordinates", "second-order ordinary differential equation"}],

Cell[CellGroupData[{
Cell[88569, 2953, 162, 3, 34, "Input"],
Cell[88734, 2958, 393, 12, 32, "Output"]
}, Open  ]],
Cell[89142, 2973, 183, 5, 29, "Text",
  CellTags->"DSolve[]"],

Cell[CellGroupData[{
Cell[89350, 2982, 56, 1, 23, "Input"],
Cell[89409, 2985, 485, 12, 34, "Output"]
}, Open  ]],
Cell[89909, 3000, 893, 22, 81, "Text",
  CellTags->{"symmetry transformation", "Infinitesimals[]"}],

Cell[CellGroupData[{
Cell[90827, 3026, 370, 11, 23, "Input"],
Cell[91200, 3039, 666, 22, 36, "Output"]
}, Open  ]],
Cell[91881, 3064, 768, 25, 61, "Text",
  CellTags->{
  "subgroups", "integration process", "group parameter", 
    "canonical variables"}],

Cell[CellGroupData[{
Cell[92674, 3093, 150, 3, 39, "Input"],
Cell[92827, 3098, 435, 16, 32, "Output"]
}, Open  ]],
Cell[93277, 3117, 188, 5, 27, "Text"],

Cell[CellGroupData[{
Cell[93490, 3126, 182, 4, 39, "Input"],
Cell[93675, 3132, 267, 8, 24, "Output"]
}, Open  ]],
Cell[93957, 3143, 352, 7, 63, "Text",
  CellTags->{"DSolve[]", "canonical coordinates"}],

Cell[CellGroupData[{
Cell[94334, 3154, 67, 1, 23, "Input"],
Cell[94404, 3157, 508, 12, 79, "Output"]
}, Open  ]],
Cell[94927, 3172, 298, 10, 27, "Text",
  CellTags->{"inversion", "canonical transformation"}],

Cell[CellGroupData[{
Cell[95250, 3186, 150, 3, 23, "Input"],
Cell[95403, 3191, 623, 17, 95, "Output"]
}, Open  ]],
Cell[96041, 3211, 169, 5, 27, "Text"],

Cell[CellGroupData[{
Cell[96235, 3220, 61, 1, 23, "Input"],
Cell[96299, 3223, 35, 1, 23, "Output"]
}, Open  ]],
Cell[96349, 3227, 278, 11, 27, "Text"],

Cell[CellGroupData[{
Cell[96652, 3242, 351, 7, 39, "Input"],
Cell[97006, 3251, 14697, 539, 149, 7296, 444, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[111718, 3793, 273, 7, 44, "Text",
  CellTags->{
  "second-order ordinary differential equation", "classification", 
    "quadrature"}],
Cell[111994, 3802, 831, 11, 129, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[112862, 3818, 103, 1, 41, "Subsection",
  CellTags->"Method of integrating factor"],
Cell[112968, 3821, 931, 19, 112, "Text",
  CellTags->{
  "integrating factor", "quadrature", "algorithm for integrating factors"}],
Cell[113902, 3842, 385, 7, 44, "Text",
  CellTags->{"integration procedure", "group theoretic quadrature"}],
Cell[114290, 3851, 750, 24, 34, "ListItem",
  CellTags->{
  "five steps of integration", "Lie algebra", "tangent vector field", 
    "group constant"}],
Cell[115043, 3877, 563, 21, 62, "ListItem"],
Cell[115609, 3900, 543, 17, 20, "ListItem",
  CellTags->{"determinant", "Lie determinant", "first integrals"}],
Cell[116155, 3919, 1393, 39, 51, "NumberedEquation",
  CellTags->"Lie matrix"],
Cell[117551, 3960, 23, 0, 20, "ListItem"],
Cell[117577, 3962, 478, 12, 53, "NumberedEquation"],
Cell[118058, 3976, 872, 30, 34, "ListItem",
  CellTags->"infinitesimals"],
Cell[118933, 4008, 549, 15, 35, "NumberedEquation",
  CellTags->"eq-21"],
Cell[119485, 4025, 152, 5, 20, "ListItem"],
Cell[119640, 4032, 182, 5, 20, "ListItem"],
Cell[119825, 4039, 293, 8, 34, "ListItem"],
Cell[120121, 4049, 986, 22, 118, "Text",
  PageBreakBelow->True,
  CellTags->{
  "Infinitesimals[]", "SecondOrderAlgebras[]", "subalgebra", "DeltaMatrix[]", 
    "FirstIntegral[]", "determination of integrals"}],
Cell[121110, 4073, 100, 2, 27, "Text"],
Cell[121213, 4077, 278, 4, 44, "Text",
  CellTags->"nonlinear second-order equation"],

Cell[CellGroupData[{
Cell[121516, 4085, 149, 3, 23, "Input"],
Cell[121668, 4090, 260, 8, 24, "Output"]
}, Open  ]],
Cell[121943, 4101, 280, 7, 29, "Text",
  CellTags->{"infinitesimal symmetries", "Infinitesimals[]"}],

Cell[CellGroupData[{
Cell[122248, 4112, 175, 4, 23, "Input"],
Cell[122426, 4118, 1759, 51, 60, "Output"]
}, Open  ]],
Cell[124200, 4172, 1485, 38, 131, "Text",
  CellTags->{
  "SubstitutionRules", "Infinitesimals[]", "eight parameter group", 
    "largest group of a second-order ODE", "solvable"}],
Cell[125688, 4212, 766, 14, 114, "Text",
  CellTags->{
  "Lie algebra", "subgroup of order two", "SecondOrderAlgebras[]", 
    "second-order solvable subalgebras", "group constants"}],

Cell[CellGroupData[{
Cell[126479, 4230, 99, 2, 23, "Input"],
Cell[126581, 4234, 779, 10, 83, "Output"]
}, Open  ]],
Cell[127375, 4247, 619, 11, 97, "Text",
  CellTags->{"SecondOrderAlgebras[]", "infinitesimals", "subalgebra"}],

Cell[CellGroupData[{
Cell[128019, 4262, 425, 7, 39, "Input"],
Cell[128447, 4271, 92, 1, 23, "Output"]
}, Open  ]],
Cell[128554, 4275, 562, 14, 63, "Text",
  CellTags->{"Lie matrix", "DeltaMatrix[]", "matrix"}],
Cell[129119, 4291, 428, 9, 63, "Text",
  CellTags->{
  "Lie's matrix", "integrating factor", "DeltaMatrix[]", "subgroup"}],

Cell[CellGroupData[{
Cell[129572, 4304, 203, 4, 39, "Input"],
Cell[129778, 4310, 381, 11, 48, "Output"]
}, Open  ]],
Cell[130174, 4324, 293, 6, 44, "Text",
  CellTags->{
  "infinitesimals", "matrix", "first prolongation", "prolongation"}],

Cell[CellGroupData[{
Cell[130492, 4334, 81, 1, 23, "Input"],
Cell[130576, 4337, 123, 2, 23, "Output"]
}, Open  ]],
Cell[130714, 4342, 576, 14, 61, "Text",
  CellTags->{
  "second-order polynomial", "first integral", "calculate first integrals"}],

Cell[CellGroupData[{
Cell[131315, 4360, 192, 4, 39, "Input"],
Cell[131510, 4366, 2207, 67, 64, "Output"]
}, Open  ]],
Cell[133732, 4436, 712, 20, 78, "Text"],
Cell[134447, 4458, 213390, 5052, 212, 156177, 4341, "GraphicsData", \
"PostScript", "Graphics"],
Cell[347840, 9512, 628, 21, 45, "SmallText"],
Cell[348471, 9535, 279, 8, 44, "Text",
  CellTags->"first integral"],

Cell[CellGroupData[{
Cell[348775, 9547, 143, 3, 23, "Input"],
Cell[348921, 9552, 336, 8, 35, "Output"]
}, Open  ]],
Cell[349272, 9563, 90, 3, 27, "Text"],

Cell[CellGroupData[{
Cell[349387, 9570, 158, 3, 23, "Input"],
Cell[349548, 9575, 138, 3, 35, "Output"]
}, Open  ]],
Cell[349701, 9581, 319, 8, 44, "Text",
  CellTags->"implicit representation of a solution"],

Cell[CellGroupData[{
Cell[350045, 9593, 115, 2, 23, "Input"],
Cell[350163, 9597, 206, 4, 38, "Output"]
}, Open  ]],
Cell[350384, 9604, 632, 18, 61, "Text",
  CellTags->"translation"],
Cell[351019, 9624, 583, 13, 82, "Text",
  CellTags->{"SecondOrderIntegrate[]", "second-order ODE", "DSolve[]"}],

Cell[CellGroupData[{
Cell[351627, 9641, 108, 2, 23, "Input"],
Cell[351738, 9645, 111, 2, 34, "Output"]
}, Open  ]],
Cell[351864, 9650, 942, 33, 80, "Text",
  CellTags->"DSolve[]"],

Cell[CellGroupData[{
Cell[352831, 9687, 64, 1, 23, "Input"],
Cell[352898, 9690, 99, 2, 35, "Output"]
}, Open  ]],
Cell[353012, 9695, 370, 8, 44, "Text",
  CellTags->"Lie's method of first integrals"],
Cell[353385, 9705, 28, 0, 29, "Example"],
Cell[353416, 9707, 176, 4, 27, "Text",
  CellTags->"generalized suspended cable equation"],
Cell[353595, 9713, 133, 3, 25, "NumberedEquation"],
Cell[353731, 9718, 334, 8, 44, "Text",
  CellTags->"suspended cable"],
Cell[354068, 9728, 136, 3, 23, "NumberedEquation"],
Cell[354207, 9733, 406, 8, 61, "Text"],

Cell[CellGroupData[{
Cell[354638, 9745, 191, 4, 24, "Input"],
Cell[354832, 9751, 277, 8, 24, "Output"]
}, Open  ]],
Cell[355124, 9762, 238, 4, 44, "Text",
  CellTags->{"Lie's integration algorithm", "point symmetries"}],
Cell[355365, 9768, 256, 8, 29, "Text",
  CellTags->{"infinitesimals", "Infinitesimals[]"}],

Cell[CellGroupData[{
Cell[355646, 9780, 183, 4, 39, "Input"],
Cell[355832, 9786, 382, 13, 32, "Output"]
}, Open  ]],
Cell[356229, 9802, 462, 9, 112, "Text"],
Cell[356694, 9813, 551, 13, 78, "Text",
  CellTags->{"solvable", "infinitesimals"}],
Cell[357248, 9828, 179, 3, 23, "Input"],
Cell[357430, 9833, 179, 3, 23, "Input"],
Cell[357612, 9838, 340, 8, 44, "Text",
  CellTags->"Lie matrix"],

Cell[CellGroupData[{
Cell[357977, 9850, 233, 5, 44, "Input"],
Cell[358213, 9857, 318, 10, 48, "Output"]
}, Open  ]],
Cell[358546, 9870, 191, 7, 27, "Text",
  CellTags->"determinant"],

Cell[CellGroupData[{
Cell[358762, 9881, 81, 1, 23, "Input"],
Cell[358846, 9884, 120, 2, 23, "Output"]
}, Open  ]],
Cell[358981, 9889, 166, 5, 27, "Text"],

Cell[CellGroupData[{
Cell[359172, 9898, 192, 4, 39, "Input"],
Cell[359367, 9904, 1757, 53, 70, "Output"]
}, Open  ]],
Cell[361139, 9960, 187, 5, 27, "Text"],

Cell[CellGroupData[{
Cell[361351, 9969, 143, 3, 23, "Input"],
Cell[361497, 9974, 1337, 31, 129, "Output"]
}, Open  ]],
Cell[362849, 10008, 477, 12, 61, "Text",
  CellTags->"first integral"],

Cell[CellGroupData[{
Cell[363351, 10024, 167, 3, 23, "Input"],
Cell[363521, 10029, 734, 14, 97, "Output"]
}, Open  ]],
Cell[364270, 10046, 162, 4, 27, "Text",
  CellTags->"transcendental function"],

Cell[CellGroupData[{
Cell[364457, 10054, 66, 1, 23, "Input"],
Cell[364526, 10057, 180, 3, 37, "Message"],
Cell[364709, 10062, 771, 14, 168, "Output"]
}, Open  ]],
Cell[365495, 10079, 184, 4, 44, "Text"],

Cell[CellGroupData[{
Cell[365704, 10087, 179, 4, 23, "Input",
  CellTags->"SecondOrderIntegrate[]"],
Cell[365886, 10093, 181, 3, 37, "Message"],
Cell[366070, 10098, 764, 15, 205, "Output"]
}, Open  ]],
Cell[366849, 10116, 696, 24, 63, "Text",
  CellTags->"DSolve[]"],

Cell[CellGroupData[{
Cell[367570, 10144, 83, 1, 23, "Input"],
Cell[367656, 10147, 358, 6, 38, "Message"],
Cell[368017, 10155, 358, 6, 38, "Message"],
Cell[368378, 10163, 507, 10, 39, "Message"],
Cell[368888, 10175, 157, 3, 37, "Message"],
Cell[369048, 10180, 3190, 73, 61, "Output"]
}, Open  ]],
Cell[372253, 10256, 351, 5, 44, "Text",
  CellTags->{"transcendental function", "generalized cable equation"}],
Cell[372607, 10263, 1400, 33, 129, "Text",
  CellTags->{
  "method of generalized multipliers", "technique of integrating factor", 
    "canonical variables", "skeleton"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[374044, 10301, 104, 1, 41, "Subsection",
  CellTags->"Method of canonical variables"],
Cell[374151, 10304, 710, 14, 95, "Text",
  CellTags->{
  "skeleton", "second-order equation", "canonical variables", 
    "method of first integrals"}],
Cell[374864, 10320, 28, 0, 29, "Example"],
Cell[374895, 10322, 378, 9, 61, "Text",
  CellTags->"canonical variables"],

Cell[CellGroupData[{
Cell[375298, 10335, 176, 3, 38, "Input"],
Cell[375477, 10340, 454, 14, 34, "Output"]
}, Open  ]],
Cell[375946, 10357, 64, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[376035, 10361, 175, 4, 39, "Input"],
Cell[376213, 10367, 731, 24, 46, "Output"]
}, Open  ]],
Cell[376959, 10394, 1056, 18, 129, "Text",
  CellTags->{
  "group of scaling", "group of projection", "skeleton", "manifold"}],
Cell[378018, 10414, 82, 1, 34, "Input"],
Cell[378103, 10417, 590, 16, 61, "Text",
  CellTags->{"animation", "submanifold"}],

Cell[CellGroupData[{
Cell[378718, 10437, 444, 8, 71, "Input"],

Cell[CellGroupData[{
Cell[379187, 10449, 128464, 2652, 194, 90876, 2183, "GraphicsData", \
"PostScript", "Graphics"],
Cell[507654, 13103, 134133, 2983, 194, 96202, 2510, "GraphicsData", \
"PostScript", "Graphics"],
Cell[641790, 16088, 135162, 3060, 194, 97508, 2590, "GraphicsData", \
"PostScript", "Graphics"],
Cell[776955, 19150, 133482, 3036, 194, 97529, 2587, "GraphicsData", \
"PostScript", "Graphics"],
Cell[910440, 22188, 132081, 3002, 194, 97180, 2566, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1042524, 25192, 130413, 2963, 193, 96561, 2540, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1172940, 28157, 129794, 2945, 194, 96400, 2528, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1302737, 31104, 129225, 2924, 194, 96178, 2511, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1431965, 34030, 129014, 2913, 194, 96003, 2500, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1560982, 36945, 128954, 2909, 194, 95806, 2495, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]],
Cell[1689963, 39858, 716, 20, 78, "Text",
  CellTags->{"animation", "manifold"}],
Cell[1690682, 39880, 724, 19, 61, "Text",
  CellTags->{"method of canonical variables", "canonical coordinates"}],

Cell[CellGroupData[{
Cell[1691431, 39903, 115, 2, 50, "Input"],
Cell[1691549, 39907, 491, 18, 50, "Output"]
}, Open  ]],
Cell[1692055, 39928, 228, 8, 27, "Text"],

Cell[CellGroupData[{
Cell[1692308, 39940, 118, 2, 39, "Input"],
Cell[1692429, 39944, 580, 21, 58, "Output"]
}, Open  ]],
Cell[1693024, 39968, 291, 9, 44, "Text"],

Cell[CellGroupData[{
Cell[1693340, 39981, 152, 3, 39, "Input",
  CellTags->"first reduction"],
Cell[1693495, 39986, 268, 8, 24, "Output"]
}, Open  ]],
Cell[1693778, 39997, 103, 3, 27, "Text"],

Cell[CellGroupData[{
Cell[1693906, 40004, 153, 3, 39, "Input",
  CellTags->"second reduction"],
Cell[1694062, 40009, 475, 15, 32, "Output"]
}, Open  ]],
Cell[1694552, 40027, 464, 10, 61, "Text",
  CellTags->"reduced manifold"],

Cell[CellGroupData[{
Cell[1695041, 40041, 749, 13, 149, "Input"],
Cell[1695793, 40056, 219352, 5337, 121, 190404, 4975, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[1915160, 45396, 2257, 69, 55, "SmallText",
  PageBreakWithin->False,
  PageBreakBelow->True],
Cell[1917420, 45467, 462, 7, 61, "Text",
  CellTags->{"skeleton", "canonical coordinates"}],
Cell[1917885, 45476, 385, 7, 63, "Text",
  CellTags->{"canonical representation", "DSolve[]"}],

Cell[CellGroupData[{
Cell[1918295, 45487, 70, 1, 23, "Input"],
Cell[1918368, 45490, 503, 13, 38, "Output"]
}, Open  ]],
Cell[1918886, 45506, 291, 8, 46, "Text",
  CellTags->"DSolve[]"],

Cell[CellGroupData[{
Cell[1919202, 45518, 63, 1, 23, "Input"],
Cell[1919268, 45521, 552, 13, 23, "Output"]
}, Open  ]],
Cell[1919835, 45537, 423, 9, 61, "Text",
  CellTags->"symmetries of first canonical reduction"],

Cell[CellGroupData[{
Cell[1920283, 45550, 97, 2, 23, "Input"],
Cell[1920383, 45554, 529, 18, 36, "Output"]
}, Open  ]],
Cell[1920927, 45575, 603, 19, 61, "Text",
  CellTags->{"canonical variables", "subgroup"}],

Cell[CellGroupData[{
Cell[1921555, 45598, 143, 3, 53, "Input"],
Cell[1921701, 45603, 510, 18, 36, "Output"]
}, Open  ]],
Cell[1922226, 45624, 219, 6, 44, "Text",
  PageBreakBelow->True,
  CellTags->"canonical reduction"],

Cell[CellGroupData[{
Cell[1922470, 45634, 135, 2, 39, "Input"],
Cell[1922608, 45638, 270, 8, 25, "Output"]
}, Open  ]],
Cell[1922893, 45649, 372, 9, 44, "Text",
  CellTags->"canonical representation"],

Cell[CellGroupData[{
Cell[1923290, 45662, 164, 3, 25, "Input"],
Cell[1923457, 45667, 248, 8, 24, "Output"]
}, Open  ]],
Cell[1923720, 45678, 304, 6, 61, "Text",
  CellTags->"second-order group"],

Cell[CellGroupData[{
Cell[1924049, 45688, 82, 1, 23, "Input"],
Cell[1924134, 45691, 586, 20, 46, "Output"]
}, Open  ]],
Cell[1924735, 45714, 275, 7, 44, "Text",
  CellTags->{"Lie matrix", "infinitesimals"}],
Cell[1925013, 45723, 179, 3, 23, "Input"],
Cell[1925195, 45728, 179, 3, 23, "Input"],
Cell[1925377, 45733, 72, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[1925474, 45737, 459, 10, 55, "Input"],
Cell[1925936, 45749, 475, 16, 68, "Output"]
}, Open  ]],
Cell[1926426, 45768, 88, 1, 27, "Text",
  CellTags->"determinant"],

Cell[CellGroupData[{
Cell[1926539, 45773, 81, 1, 23, "Input"],
Cell[1926623, 45776, 61, 1, 35, "Output"]
}, Open  ]],
Cell[1926699, 45780, 60, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[1926784, 45784, 109, 2, 23, "Input"],
Cell[1926896, 45788, 376, 10, 23, "Output"]
}, Open  ]],
Cell[1927287, 45801, 89, 3, 27, "Text"],

Cell[CellGroupData[{
Cell[1927401, 45808, 109, 2, 23, "Input"],
Cell[1927513, 45812, 3364, 75, 70, "Output"]
}, Open  ]],
Cell[1930892, 45890, 361, 11, 46, "Text",
  CellTags->"DSolve[]"],

Cell[CellGroupData[{
Cell[1931278, 45905, 70, 1, 23, "Input"],
Cell[1931351, 45908, 167, 3, 37, "Message"],
Cell[1931521, 45913, 191, 5, 24, "Output"]
}, Open  ]],
Cell[1931727, 45921, 225, 5, 46, "Text",
  CellTags->"SecondOrderIntegrate[]"],

Cell[CellGroupData[{
Cell[1931977, 45930, 66, 1, 23, "Input"],
Cell[1932046, 45933, 167, 3, 37, "Message"],
Cell[1932216, 45938, 191, 5, 26, "Output"]
}, Open  ]],
Cell[1932422, 45946, 252, 8, 27, "Text"],

Cell[CellGroupData[{
Cell[1932699, 45958, 306, 5, 39, "Input"],
Cell[1933008, 45965, 162, 4, 32, "Output"]
}, Open  ]],
Cell[1933185, 45972, 74, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[1933284, 45976, 69, 1, 23, "Input"],
Cell[1933356, 45979, 188, 5, 30, "Output"]
}, Open  ]],
Cell[1933559, 45987, 717, 18, 80, "Text",
  CellTags->{"hybrid algorithm", "DSolve[]"}],

Cell[CellGroupData[{
Cell[1934301, 46009, 207, 4, 23, "Input"],
Cell[1934511, 46015, 35, 1, 23, "Output"]
}, Open  ]],
Cell[1934561, 46019, 629, 18, 78, "Text"],

Cell[CellGroupData[{
Cell[1935215, 46041, 310, 6, 35, "Input"],
Cell[1935528, 46049, 13692, 493, 169, 6541, 400, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[1949235, 46545, 252, 5, 61, "Text"],
Cell[1949490, 46552, 147, 3, 35, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

